/********************************************************************************
** Form generated from reading UI file 'GraphicsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GRAPHICSUI_H
#define UI_GRAPHICSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_GraphicsUi
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *Graphics;
    QGridLayout *gridLayout1;
    QPushButton *browsePB;
    QGroupBox *sizeGB;
    QGridLayout *gridLayout2;
    lyx::frontend::LengthCombo *widthUnit;
    lyx::frontend::LengthCombo *heightUnit;
    QLineEdit *Width;
    QSpacerItem *spacerItem;
    QLineEdit *Scale;
    QLineEdit *Height;
    QCheckBox *HeightCB;
    QCheckBox *scaleCB;
    QCheckBox *WidthCB;
    QCheckBox *aspectratio;
    QGroupBox *rotationGB;
    QGridLayout *gridLayout3;
    QCheckBox *rotateOrderCB;
    QComboBox *origin;
    QLabel *originL;
    QLineEdit *angle;
    QLabel *angleL;
    QLabel *filenameL;
    QLineEdit *filename;
    QWidget *Clipping;
    QGridLayout *gridLayout4;
    QSpacerItem *spacerItem1;
    QCheckBox *clip;
    QFrame *bbFrame;
    QGridLayout *gridLayout5;
    QLabel *lbL;
    QLineEdit *rtX;
    QLineEdit *rtY;
    QLineEdit *lbY;
    QLineEdit *lbX;
    QComboBox *lbXunit;
    QComboBox *rtXunit;
    QComboBox *rtYunit;
    QComboBox *lbYunit;
    QLabel *rtL;
    QLabel *yL_2;
    QLabel *yL;
    QLabel *xL_2;
    QLabel *xL;
    QSpacerItem *spacerItem2;
    QPushButton *getPB;
    QWidget *ExtraOptions;
    QGridLayout *gridLayout6;
    QGroupBox *displayGB;
    QGridLayout *gridLayout7;
    QLineEdit *displayscale;
    QLabel *scaleLA;
    QSpacerItem *spacerItem3;
    QCheckBox *darkModeCB;
    QSpacerItem *spacerItem4;
    QLabel *latexoptionsLA;
    QLineEdit *latexoptions;
    QGroupBox *graphicsGroupGB;
    QGridLayout *gridLayout8;
    QLabel *label;
    QSpacerItem *spacerItem5;
    QPushButton *newGroupPB;
    QComboBox *groupCO;
    QCheckBox *draftCB;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GraphicsUi)
    {
        if (GraphicsUi->objectName().isEmpty())
            GraphicsUi->setObjectName(QStringLiteral("GraphicsUi"));
        GraphicsUi->resize(718, 512);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GraphicsUi->sizePolicy().hasHeightForWidth());
        GraphicsUi->setSizePolicy(sizePolicy);
        GraphicsUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(GraphicsUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget = new QTabWidget(GraphicsUi);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        Graphics = new QWidget();
        Graphics->setObjectName(QStringLiteral("Graphics"));
        gridLayout1 = new QGridLayout(Graphics);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        browsePB = new QPushButton(Graphics);
        browsePB->setObjectName(QStringLiteral("browsePB"));

        gridLayout1->addWidget(browsePB, 0, 2, 1, 1);

        sizeGB = new QGroupBox(Graphics);
        sizeGB->setObjectName(QStringLiteral("sizeGB"));
        sizeGB->setFlat(true);
        gridLayout2 = new QGridLayout(sizeGB);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        widthUnit = new lyx::frontend::LengthCombo(sizeGB);
        widthUnit->setObjectName(QStringLiteral("widthUnit"));

        gridLayout2->addWidget(widthUnit, 1, 2, 1, 1);

        heightUnit = new lyx::frontend::LengthCombo(sizeGB);
        heightUnit->setObjectName(QStringLiteral("heightUnit"));

        gridLayout2->addWidget(heightUnit, 2, 2, 1, 1);

        Width = new QLineEdit(sizeGB);
        Width->setObjectName(QStringLiteral("Width"));
        Width->setEnabled(true);
        sizePolicy.setHeightForWidth(Width->sizePolicy().hasHeightForWidth());
        Width->setSizePolicy(sizePolicy);

        gridLayout2->addWidget(Width, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(61, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout2->addItem(spacerItem, 0, 2, 1, 1);

        Scale = new QLineEdit(sizeGB);
        Scale->setObjectName(QStringLiteral("Scale"));

        gridLayout2->addWidget(Scale, 0, 1, 1, 1);

        Height = new QLineEdit(sizeGB);
        Height->setObjectName(QStringLiteral("Height"));
        Height->setEnabled(true);
        sizePolicy.setHeightForWidth(Height->sizePolicy().hasHeightForWidth());
        Height->setSizePolicy(sizePolicy);

        gridLayout2->addWidget(Height, 2, 1, 1, 1);

        HeightCB = new QCheckBox(sizeGB);
        HeightCB->setObjectName(QStringLiteral("HeightCB"));
        HeightCB->setEnabled(true);

        gridLayout2->addWidget(HeightCB, 2, 0, 1, 1);

        scaleCB = new QCheckBox(sizeGB);
        scaleCB->setObjectName(QStringLiteral("scaleCB"));

        gridLayout2->addWidget(scaleCB, 0, 0, 1, 1);

        WidthCB = new QCheckBox(sizeGB);
        WidthCB->setObjectName(QStringLiteral("WidthCB"));
        WidthCB->setEnabled(true);

        gridLayout2->addWidget(WidthCB, 1, 0, 1, 1);

        aspectratio = new QCheckBox(sizeGB);
        aspectratio->setObjectName(QStringLiteral("aspectratio"));
        aspectratio->setEnabled(true);

        gridLayout2->addWidget(aspectratio, 3, 1, 1, 2);


        gridLayout1->addWidget(sizeGB, 1, 0, 1, 5);

        rotationGB = new QGroupBox(Graphics);
        rotationGB->setObjectName(QStringLiteral("rotationGB"));
        rotationGB->setFlat(true);
        gridLayout3 = new QGridLayout(rotationGB);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        rotateOrderCB = new QCheckBox(rotationGB);
        rotateOrderCB->setObjectName(QStringLiteral("rotateOrderCB"));

        gridLayout3->addWidget(rotateOrderCB, 1, 0, 1, 2);

        origin = new QComboBox(rotationGB);
        origin->setObjectName(QStringLiteral("origin"));

        gridLayout3->addWidget(origin, 0, 3, 1, 1);

        originL = new QLabel(rotationGB);
        originL->setObjectName(QStringLiteral("originL"));

        gridLayout3->addWidget(originL, 0, 2, 1, 1);

        angle = new QLineEdit(rotationGB);
        angle->setObjectName(QStringLiteral("angle"));
        sizePolicy.setHeightForWidth(angle->sizePolicy().hasHeightForWidth());
        angle->setSizePolicy(sizePolicy);

        gridLayout3->addWidget(angle, 0, 1, 1, 1);

        angleL = new QLabel(rotationGB);
        angleL->setObjectName(QStringLiteral("angleL"));

        gridLayout3->addWidget(angleL, 0, 0, 1, 1);


        gridLayout1->addWidget(rotationGB, 2, 0, 1, 5);

        filenameL = new QLabel(Graphics);
        filenameL->setObjectName(QStringLiteral("filenameL"));

        gridLayout1->addWidget(filenameL, 0, 0, 1, 1);

        filename = new QLineEdit(Graphics);
        filename->setObjectName(QStringLiteral("filename"));

        gridLayout1->addWidget(filename, 0, 1, 1, 1);

        tabWidget->addTab(Graphics, QString());
        Clipping = new QWidget();
        Clipping->setObjectName(QStringLiteral("Clipping"));
        gridLayout4 = new QGridLayout(Clipping);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout4->addItem(spacerItem1, 3, 0, 1, 2);

        clip = new QCheckBox(Clipping);
        clip->setObjectName(QStringLiteral("clip"));

        gridLayout4->addWidget(clip, 0, 0, 1, 2);

        bbFrame = new QFrame(Clipping);
        bbFrame->setObjectName(QStringLiteral("bbFrame"));
        bbFrame->setEnabled(true);
        sizePolicy.setHeightForWidth(bbFrame->sizePolicy().hasHeightForWidth());
        bbFrame->setSizePolicy(sizePolicy);
        bbFrame->setFrameShape(QFrame::StyledPanel);
        bbFrame->setFrameShadow(QFrame::Plain);
        gridLayout5 = new QGridLayout(bbFrame);
        gridLayout5->setSpacing(6);
        gridLayout5->setObjectName(QStringLiteral("gridLayout5"));
        gridLayout5->setContentsMargins(9, 9, 9, 9);
        lbL = new QLabel(bbFrame);
        lbL->setObjectName(QStringLiteral("lbL"));

        gridLayout5->addWidget(lbL, 0, 0, 1, 6);

        rtX = new QLineEdit(bbFrame);
        rtX->setObjectName(QStringLiteral("rtX"));

        gridLayout5->addWidget(rtX, 3, 1, 1, 1);

        rtY = new QLineEdit(bbFrame);
        rtY->setObjectName(QStringLiteral("rtY"));

        gridLayout5->addWidget(rtY, 3, 4, 1, 1);

        lbY = new QLineEdit(bbFrame);
        lbY->setObjectName(QStringLiteral("lbY"));

        gridLayout5->addWidget(lbY, 1, 4, 1, 1);

        lbX = new QLineEdit(bbFrame);
        lbX->setObjectName(QStringLiteral("lbX"));

        gridLayout5->addWidget(lbX, 1, 1, 1, 1);

        lbXunit = new QComboBox(bbFrame);
        lbXunit->setObjectName(QStringLiteral("lbXunit"));

        gridLayout5->addWidget(lbXunit, 1, 2, 1, 1);

        rtXunit = new QComboBox(bbFrame);
        rtXunit->setObjectName(QStringLiteral("rtXunit"));

        gridLayout5->addWidget(rtXunit, 3, 2, 1, 1);

        rtYunit = new QComboBox(bbFrame);
        rtYunit->setObjectName(QStringLiteral("rtYunit"));

        gridLayout5->addWidget(rtYunit, 3, 5, 1, 1);

        lbYunit = new QComboBox(bbFrame);
        lbYunit->setObjectName(QStringLiteral("lbYunit"));

        gridLayout5->addWidget(lbYunit, 1, 5, 1, 1);

        rtL = new QLabel(bbFrame);
        rtL->setObjectName(QStringLiteral("rtL"));

        gridLayout5->addWidget(rtL, 2, 0, 1, 6);

        yL_2 = new QLabel(bbFrame);
        yL_2->setObjectName(QStringLiteral("yL_2"));

        gridLayout5->addWidget(yL_2, 3, 3, 1, 1);

        yL = new QLabel(bbFrame);
        yL->setObjectName(QStringLiteral("yL"));

        gridLayout5->addWidget(yL, 1, 3, 1, 1);

        xL_2 = new QLabel(bbFrame);
        xL_2->setObjectName(QStringLiteral("xL_2"));

        gridLayout5->addWidget(xL_2, 3, 0, 1, 1);

        xL = new QLabel(bbFrame);
        xL->setObjectName(QStringLiteral("xL"));

        gridLayout5->addWidget(xL, 1, 0, 1, 1);


        gridLayout4->addWidget(bbFrame, 1, 0, 1, 2);

        spacerItem2 = new QSpacerItem(181, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout4->addItem(spacerItem2, 2, 0, 1, 1);

        getPB = new QPushButton(Clipping);
        getPB->setObjectName(QStringLiteral("getPB"));

        gridLayout4->addWidget(getPB, 2, 1, 1, 1);

        tabWidget->addTab(Clipping, QString());
        ExtraOptions = new QWidget();
        ExtraOptions->setObjectName(QStringLiteral("ExtraOptions"));
        gridLayout6 = new QGridLayout(ExtraOptions);
        gridLayout6->setSpacing(6);
        gridLayout6->setObjectName(QStringLiteral("gridLayout6"));
        gridLayout6->setContentsMargins(9, 9, 9, 9);
        displayGB = new QGroupBox(ExtraOptions);
        displayGB->setObjectName(QStringLiteral("displayGB"));
        displayGB->setFocusPolicy(Qt::StrongFocus);
        displayGB->setFlat(true);
        displayGB->setCheckable(true);
        gridLayout7 = new QGridLayout(displayGB);
        gridLayout7->setSpacing(6);
        gridLayout7->setObjectName(QStringLiteral("gridLayout7"));
        gridLayout7->setContentsMargins(9, 9, 9, 9);
        displayscale = new QLineEdit(displayGB);
        displayscale->setObjectName(QStringLiteral("displayscale"));
        displayscale->setEnabled(true);
        sizePolicy.setHeightForWidth(displayscale->sizePolicy().hasHeightForWidth());
        displayscale->setSizePolicy(sizePolicy);

        gridLayout7->addWidget(displayscale, 0, 1, 1, 1);

        scaleLA = new QLabel(displayGB);
        scaleLA->setObjectName(QStringLiteral("scaleLA"));

        gridLayout7->addWidget(scaleLA, 0, 0, 1, 1);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout7->addItem(spacerItem3, 0, 2, 1, 1);

        darkModeCB = new QCheckBox(displayGB);
        darkModeCB->setObjectName(QStringLiteral("darkModeCB"));

        gridLayout7->addWidget(darkModeCB, 1, 0, 1, 1);


        gridLayout6->addWidget(displayGB, 3, 0, 1, 3);

        spacerItem4 = new QSpacerItem(354, 81, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout6->addItem(spacerItem4, 5, 0, 1, 3);

        latexoptionsLA = new QLabel(ExtraOptions);
        latexoptionsLA->setObjectName(QStringLiteral("latexoptionsLA"));

        gridLayout6->addWidget(latexoptionsLA, 0, 0, 1, 1);

        latexoptions = new QLineEdit(ExtraOptions);
        latexoptions->setObjectName(QStringLiteral("latexoptions"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(latexoptions->sizePolicy().hasHeightForWidth());
        latexoptions->setSizePolicy(sizePolicy1);

        gridLayout6->addWidget(latexoptions, 0, 1, 1, 1);

        graphicsGroupGB = new QGroupBox(ExtraOptions);
        graphicsGroupGB->setObjectName(QStringLiteral("graphicsGroupGB"));
        graphicsGroupGB->setFlat(true);
        gridLayout8 = new QGridLayout(graphicsGroupGB);
        gridLayout8->setSpacing(6);
        gridLayout8->setObjectName(QStringLiteral("gridLayout8"));
        gridLayout8->setContentsMargins(9, 9, 9, 9);
        label = new QLabel(graphicsGroupGB);
        label->setObjectName(QStringLiteral("label"));
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout8->addWidget(label, 0, 0, 1, 1);

        spacerItem5 = new QSpacerItem(121, 51, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout8->addItem(spacerItem5, 0, 2, 2, 1);

        newGroupPB = new QPushButton(graphicsGroupGB);
        newGroupPB->setObjectName(QStringLiteral("newGroupPB"));

        gridLayout8->addWidget(newGroupPB, 1, 1, 1, 1);

        groupCO = new QComboBox(graphicsGroupGB);
        groupCO->setObjectName(QStringLiteral("groupCO"));
        groupCO->setEditable(false);

        gridLayout8->addWidget(groupCO, 0, 1, 1, 1);


        gridLayout6->addWidget(graphicsGroupGB, 4, 0, 1, 3);

        draftCB = new QCheckBox(ExtraOptions);
        draftCB->setObjectName(QStringLiteral("draftCB"));

        gridLayout6->addWidget(draftCB, 1, 0, 1, 3);

        tabWidget->addTab(ExtraOptions, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(GraphicsUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        originL->setBuddy(origin);
        angleL->setBuddy(angle);
        filenameL->setBuddy(filename);
        lbL->setBuddy(lbX);
        rtL->setBuddy(rtX);
        scaleLA->setBuddy(displayscale);
        latexoptionsLA->setBuddy(latexoptions);
        label->setBuddy(groupCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(tabWidget, filename);
        QWidget::setTabOrder(filename, browsePB);
        QWidget::setTabOrder(browsePB, scaleCB);
        QWidget::setTabOrder(scaleCB, Scale);
        QWidget::setTabOrder(Scale, WidthCB);
        QWidget::setTabOrder(WidthCB, Width);
        QWidget::setTabOrder(Width, widthUnit);
        QWidget::setTabOrder(widthUnit, HeightCB);
        QWidget::setTabOrder(HeightCB, Height);
        QWidget::setTabOrder(Height, heightUnit);
        QWidget::setTabOrder(heightUnit, aspectratio);
        QWidget::setTabOrder(aspectratio, angle);
        QWidget::setTabOrder(angle, origin);
        QWidget::setTabOrder(origin, rotateOrderCB);
        QWidget::setTabOrder(rotateOrderCB, clip);
        QWidget::setTabOrder(clip, lbX);
        QWidget::setTabOrder(lbX, lbXunit);
        QWidget::setTabOrder(lbXunit, lbY);
        QWidget::setTabOrder(lbY, lbYunit);
        QWidget::setTabOrder(lbYunit, rtX);
        QWidget::setTabOrder(rtX, rtXunit);
        QWidget::setTabOrder(rtXunit, rtY);
        QWidget::setTabOrder(rtY, rtYunit);
        QWidget::setTabOrder(rtYunit, getPB);
        QWidget::setTabOrder(getPB, latexoptions);
        QWidget::setTabOrder(latexoptions, draftCB);
        QWidget::setTabOrder(draftCB, displayGB);

        retranslateUi(GraphicsUi);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(GraphicsUi);
    } // setupUi

    void retranslateUi(QDialog *GraphicsUi)
    {
        GraphicsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        tabWidget->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        browsePB->setToolTip(lyx::qt_("Select an image file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        browsePB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
        sizeGB->setTitle(lyx::qt_("Output Size", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        Width->setToolTip(lyx::qt_("Width of image in output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        Height->setToolTip(lyx::qt_("Height of image in output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        HeightCB->setToolTip(lyx::qt_("Sets height of graphic. Leave unchecked to set automatically.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        HeightCB->setText(lyx::qt_("Set &height:", Q_NULLPTR));
        scaleCB->setText(lyx::qt_("&Scale graphics (%):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        WidthCB->setToolTip(lyx::qt_("Sets width of graphic. Leave unchecked to set automatically.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        WidthCB->setText(lyx::qt_("Set &width:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        aspectratio->setToolTip(lyx::qt_("Scale image to maximum size not exceeding width and height", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        aspectratio->setText(lyx::qt_("&Maintain aspect ratio", Q_NULLPTR));
        rotationGB->setTitle(lyx::qt_("Rotate Graphics", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rotateOrderCB->setToolTip(lyx::qt_("Check to change the order of rotating and scaling", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rotateOrderCB->setText(lyx::qt_("Ro&tate after scaling", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        origin->setToolTip(lyx::qt_("The origin of the rotation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        originL->setToolTip(lyx::qt_("The origin of the rotation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        originL->setText(lyx::qt_("Or&igin:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        angle->setToolTip(lyx::qt_("Angle to rotate image by", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        angleL->setToolTip(lyx::qt_("Angle to rotate image by", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        angleL->setText(lyx::qt_("A&ngle (degrees):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        filenameL->setToolTip(lyx::qt_("File name of image", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        filenameL->setText(lyx::qt_("&File:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        filename->setToolTip(lyx::qt_("File name of image", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tabWidget->setTabText(tabWidget->indexOf(Graphics), lyx::qt_("&Graphics", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        clip->setToolTip(lyx::qt_("Clip to the coordinates specified below (bounding box for DVI/PS output, viewport for PDF output)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        clip->setText(lyx::qt_("Clip to c&oordinates", Q_NULLPTR));
        lbL->setText(lyx::qt_("Left botto&m:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lbX->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        rtL->setText(lyx::qt_("Right &top:", Q_NULLPTR));
        yL_2->setText(lyx::qt_("y:", Q_NULLPTR));
        yL->setText(lyx::qt_("y:", Q_NULLPTR));
        xL_2->setText(lyx::qt_("x:", Q_NULLPTR));
        xL->setText(lyx::qt_("x:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        getPB->setToolTip(lyx::qt_("Read coordinates from the file (bounding box value in case of PostScript files, graphic dimensions in case of other file types)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        getPB->setText(lyx::qt_("&Get from File", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(Clipping), lyx::qt_("&Coordinates and Clipping", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        displayGB->setToolTip(lyx::qt_("Enable LyX to preview this graphics, if graphics previewing is not disabled at application level (see Preferences dialog).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        displayGB->setTitle(lyx::qt_("Sho&w in LyX", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        displayscale->setToolTip(lyx::qt_("Percentage to scale by in LyX (1 to 1000)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        scaleLA->setToolTip(lyx::qt_("Percentage to scale by in LyX (1 to 1000)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        scaleLA->setText(lyx::qt_("Sca&le on screen (%):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        darkModeCB->setToolTip(lyx::qt_("If LyX uses a dark theme, revert the colors of this graphics in the workarea", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        darkModeCB->setText(lyx::qt_("Re&vert colors in dark mode", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexoptionsLA->setToolTip(lyx::qt_("Additional LaTeX options", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        latexoptionsLA->setText(lyx::qt_("LaTeX &options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexoptions->setToolTip(lyx::qt_("Additional LaTeX options", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        graphicsGroupGB->setToolTip(lyx::qt_("Assign the graphic to a group of graphics that share the same settings", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        graphicsGroupGB->setTitle(lyx::qt_("Graphics Group", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        label->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        label->setText(lyx::qt_("Assigned &to group:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        newGroupPB->setToolTip(lyx::qt_("Click to define a new graphics group.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        newGroupPB->setText(lyx::qt_("O&pen new group...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupCO->setToolTip(lyx::qt_("Select an existing group for the current graphics.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        draftCB->setToolTip(lyx::qt_("Draft mode", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        draftCB->setText(lyx::qt_("&Draft mode", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(ExtraOptions), lyx::qt_("LaTe&X and LyX options", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class GraphicsUi: public Ui_GraphicsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GRAPHICSUI_H
