/********************************************************************************
** Form generated from reading UI file 'LyXFilesUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LYXFILESUI_H
#define UI_LYXFILESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LyXFilesUi
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *filterGB;
    QGridLayout *gridLayout;
    QLabel *filesTypeLA;
    QComboBox *fileTypeCO;
    QLabel *findKeysLA;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QHBoxLayout *filterBarL;
    QCheckBox *csFindCB;
    QHBoxLayout *horizontalLayout;
    QLabel *languageLA;
    QComboBox *languageCO;
    QTreeWidget *filesLW;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *browsePB;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LyXFilesUi)
    {
        if (LyXFilesUi->objectName().isEmpty())
            LyXFilesUi->setObjectName(QStringLiteral("LyXFilesUi"));
        LyXFilesUi->resize(284, 479);
        LyXFilesUi->setSizeGripEnabled(true);
        gridLayout_2 = new QGridLayout(LyXFilesUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        filterGB = new QGroupBox(LyXFilesUi);
        filterGB->setObjectName(QStringLiteral("filterGB"));
        filterGB->setFlat(true);
        gridLayout = new QGridLayout(filterGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        filesTypeLA = new QLabel(filterGB);
        filesTypeLA->setObjectName(QStringLiteral("filesTypeLA"));

        gridLayout->addWidget(filesTypeLA, 0, 0, 1, 1);

        fileTypeCO = new QComboBox(filterGB);
        fileTypeCO->setObjectName(QStringLiteral("fileTypeCO"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileTypeCO->sizePolicy().hasHeightForWidth());
        fileTypeCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileTypeCO, 0, 1, 1, 1);

        findKeysLA = new QLabel(filterGB);
        findKeysLA->setObjectName(QStringLiteral("findKeysLA"));
        findKeysLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(findKeysLA, 1, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        filterBarL = new QHBoxLayout();
        filterBarL->setObjectName(QStringLiteral("filterBarL"));

        horizontalLayout_3->addLayout(filterBarL);

        csFindCB = new QCheckBox(filterGB);
        csFindCB->setObjectName(QStringLiteral("csFindCB"));

        horizontalLayout_3->addWidget(csFindCB);


        verticalLayout_2->addLayout(horizontalLayout_3);


        gridLayout->addLayout(verticalLayout_2, 1, 1, 1, 1);


        gridLayout_2->addWidget(filterGB, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        languageLA = new QLabel(LyXFilesUi);
        languageLA->setObjectName(QStringLiteral("languageLA"));

        horizontalLayout->addWidget(languageLA);

        languageCO = new QComboBox(LyXFilesUi);
        languageCO->setObjectName(QStringLiteral("languageCO"));
        sizePolicy.setHeightForWidth(languageCO->sizePolicy().hasHeightForWidth());
        languageCO->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(languageCO);


        gridLayout_2->addLayout(horizontalLayout, 1, 0, 1, 1);

        filesLW = new QTreeWidget(LyXFilesUi);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        filesLW->setHeaderItem(__qtreewidgetitem);
        filesLW->setObjectName(QStringLiteral("filesLW"));
        filesLW->setRootIsDecorated(true);
        filesLW->setItemsExpandable(true);
        filesLW->header()->setVisible(false);

        gridLayout_2->addWidget(filesLW, 2, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        browsePB = new QPushButton(LyXFilesUi);
        browsePB->setObjectName(QStringLiteral("browsePB"));

        horizontalLayout_2->addWidget(browsePB);


        gridLayout_2->addLayout(horizontalLayout_2, 3, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(LyXFilesUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Open);

        hboxLayout->addWidget(buttonBox);


        gridLayout_2->addLayout(hboxLayout, 4, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        filesTypeLA->setBuddy(fileTypeCO);
        languageLA->setBuddy(languageCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(LyXFilesUi);

        QMetaObject::connectSlotsByName(LyXFilesUi);
    } // setupUi

    void retranslateUi(QDialog *LyXFilesUi)
    {
        LyXFilesUi->setWindowTitle(QString());
        filterGB->setTitle(lyx::qt_("Filter", Q_NULLPTR));
        filesTypeLA->setText(lyx::qt_("&Type:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fileTypeCO->setToolTip(lyx::qt_("Determines whether only personal user files, system files or all files are displayed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        findKeysLA->setText(lyx::qt_("&Name:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        csFindCB->setToolTip(lyx::qt_("Filter case-sensitively", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        csFindCB->setText(lyx::qt_("Case Sensiti&ve", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languageLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        languageLA->setText(lyx::qt_("File &Language:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languageCO->setToolTip(lyx::qt_("The available language(s) of the selected file will be displayed here", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        browsePB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LyXFilesUi: public Ui_LyXFilesUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LYXFILESUI_H
