/********************************************************************************
** Form generated from reading UI file 'PrefLatexUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFLATEXUI_H
#define UI_PREFLATEXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefLatexUi
{
public:
    QGridLayout *gridLayout_8;
    QGridLayout *gridLayout_4;
    QLabel *latexDviPaperLA;
    QLineEdit *latexDviPaperED;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *bibtexGB;
    QGridLayout *gridLayout_7;
    QGridLayout *gridLayout;
    QLabel *latexBibtexLA;
    QComboBox *latexBibtexCO;
    QLabel *latexBibtexOptionsLA;
    QLineEdit *latexBibtexED;
    QLabel *latexJBibtexLA;
    QComboBox *latexJBibtexCO;
    QLabel *latexJBibtexOptionsLA;
    QLineEdit *latexJBibtexED;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *indexGB;
    QGridLayout *gridLayout_5;
    QGridLayout *gridLayout_2;
    QLabel *latexIndexLA;
    QComboBox *latexIndexCO;
    QLabel *latexIndexOptionsLA;
    QLineEdit *latexIndexED;
    QLabel *latexJIndexLA;
    QLineEdit *latexJIndexED;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_6;
    QGridLayout *gridLayout_3;
    QLineEdit *latexNomenclED;
    QLineEdit *latexChecktexED;
    QLabel *latexChecktexLA;
    QLabel *latexNomenclLA;
    QCheckBox *pathCB;
    QCheckBox *latexAutoresetCB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PrefLatexUi)
    {
        if (PrefLatexUi->objectName().isEmpty())
            PrefLatexUi->setObjectName(QStringLiteral("PrefLatexUi"));
        PrefLatexUi->resize(425, 582);
        gridLayout_8 = new QGridLayout(PrefLatexUi);
        gridLayout_8->setObjectName(QStringLiteral("gridLayout_8"));
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        latexDviPaperLA = new QLabel(PrefLatexUi);
        latexDviPaperLA->setObjectName(QStringLiteral("latexDviPaperLA"));

        gridLayout_4->addWidget(latexDviPaperLA, 0, 0, 1, 1);

        latexDviPaperED = new QLineEdit(PrefLatexUi);
        latexDviPaperED->setObjectName(QStringLiteral("latexDviPaperED"));

        gridLayout_4->addWidget(latexDviPaperED, 0, 1, 1, 1);


        gridLayout_8->addLayout(gridLayout_4, 0, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(33, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_4, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_8->addItem(verticalSpacer_2, 1, 0, 1, 1);

        bibtexGB = new QGroupBox(PrefLatexUi);
        bibtexGB->setObjectName(QStringLiteral("bibtexGB"));
        bibtexGB->setFlat(true);
        gridLayout_7 = new QGridLayout(bibtexGB);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        latexBibtexLA = new QLabel(bibtexGB);
        latexBibtexLA->setObjectName(QStringLiteral("latexBibtexLA"));

        gridLayout->addWidget(latexBibtexLA, 0, 0, 1, 1);

        latexBibtexCO = new QComboBox(bibtexGB);
        latexBibtexCO->setObjectName(QStringLiteral("latexBibtexCO"));

        gridLayout->addWidget(latexBibtexCO, 0, 1, 1, 1);

        latexBibtexOptionsLA = new QLabel(bibtexGB);
        latexBibtexOptionsLA->setObjectName(QStringLiteral("latexBibtexOptionsLA"));

        gridLayout->addWidget(latexBibtexOptionsLA, 1, 0, 1, 1);

        latexBibtexED = new QLineEdit(bibtexGB);
        latexBibtexED->setObjectName(QStringLiteral("latexBibtexED"));

        gridLayout->addWidget(latexBibtexED, 1, 1, 1, 1);

        latexJBibtexLA = new QLabel(bibtexGB);
        latexJBibtexLA->setObjectName(QStringLiteral("latexJBibtexLA"));

        gridLayout->addWidget(latexJBibtexLA, 2, 0, 1, 1);

        latexJBibtexCO = new QComboBox(bibtexGB);
        latexJBibtexCO->setObjectName(QStringLiteral("latexJBibtexCO"));

        gridLayout->addWidget(latexJBibtexCO, 2, 1, 1, 1);

        latexJBibtexOptionsLA = new QLabel(bibtexGB);
        latexJBibtexOptionsLA->setObjectName(QStringLiteral("latexJBibtexOptionsLA"));

        gridLayout->addWidget(latexJBibtexOptionsLA, 3, 0, 1, 1);

        latexJBibtexED = new QLineEdit(bibtexGB);
        latexJBibtexED->setObjectName(QStringLiteral("latexJBibtexED"));

        gridLayout->addWidget(latexJBibtexED, 3, 1, 1, 1);


        gridLayout_7->addLayout(gridLayout, 0, 0, 2, 1);

        horizontalSpacer = new QSpacerItem(52, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_7->addItem(horizontalSpacer, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(49, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_3, 1, 1, 1, 1);


        gridLayout_8->addWidget(bibtexGB, 2, 0, 1, 2);

        indexGB = new QGroupBox(PrefLatexUi);
        indexGB->setObjectName(QStringLiteral("indexGB"));
        indexGB->setFlat(true);
        gridLayout_5 = new QGridLayout(indexGB);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        latexIndexLA = new QLabel(indexGB);
        latexIndexLA->setObjectName(QStringLiteral("latexIndexLA"));

        gridLayout_2->addWidget(latexIndexLA, 0, 0, 1, 1);

        latexIndexCO = new QComboBox(indexGB);
        latexIndexCO->setObjectName(QStringLiteral("latexIndexCO"));

        gridLayout_2->addWidget(latexIndexCO, 0, 1, 1, 1);

        latexIndexOptionsLA = new QLabel(indexGB);
        latexIndexOptionsLA->setObjectName(QStringLiteral("latexIndexOptionsLA"));

        gridLayout_2->addWidget(latexIndexOptionsLA, 1, 0, 1, 1);

        latexIndexED = new QLineEdit(indexGB);
        latexIndexED->setObjectName(QStringLiteral("latexIndexED"));

        gridLayout_2->addWidget(latexIndexED, 1, 1, 1, 1);

        latexJIndexLA = new QLabel(indexGB);
        latexJIndexLA->setObjectName(QStringLiteral("latexJIndexLA"));

        gridLayout_2->addWidget(latexJIndexLA, 2, 0, 1, 1);

        latexJIndexED = new QLineEdit(indexGB);
        latexJIndexED->setObjectName(QStringLiteral("latexJIndexED"));

        gridLayout_2->addWidget(latexJIndexED, 2, 1, 1, 1);


        gridLayout_5->addLayout(gridLayout_2, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(52, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_2, 0, 1, 1, 1);


        gridLayout_8->addWidget(indexGB, 3, 0, 1, 2);

        groupBox = new QGroupBox(PrefLatexUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout_6 = new QGridLayout(groupBox);
        gridLayout_6->setObjectName(QStringLiteral("gridLayout_6"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        latexNomenclED = new QLineEdit(groupBox);
        latexNomenclED->setObjectName(QStringLiteral("latexNomenclED"));

        gridLayout_3->addWidget(latexNomenclED, 0, 1, 1, 1);

        latexChecktexED = new QLineEdit(groupBox);
        latexChecktexED->setObjectName(QStringLiteral("latexChecktexED"));

        gridLayout_3->addWidget(latexChecktexED, 1, 1, 1, 1);

        latexChecktexLA = new QLabel(groupBox);
        latexChecktexLA->setObjectName(QStringLiteral("latexChecktexLA"));

        gridLayout_3->addWidget(latexChecktexLA, 1, 0, 1, 1);

        latexNomenclLA = new QLabel(groupBox);
        latexNomenclLA->setObjectName(QStringLiteral("latexNomenclLA"));

        gridLayout_3->addWidget(latexNomenclLA, 0, 0, 1, 1);


        gridLayout_6->addLayout(gridLayout_3, 0, 0, 1, 1);

        pathCB = new QCheckBox(groupBox);
        pathCB->setObjectName(QStringLiteral("pathCB"));
        pathCB->setEnabled(true);
        pathCB->setLayoutDirection(Qt::LeftToRight);

        gridLayout_6->addWidget(pathCB, 1, 0, 1, 1);

        latexAutoresetCB = new QCheckBox(groupBox);
        latexAutoresetCB->setObjectName(QStringLiteral("latexAutoresetCB"));

        gridLayout_6->addWidget(latexAutoresetCB, 2, 0, 1, 1);


        gridLayout_8->addWidget(groupBox, 4, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_8->addItem(verticalSpacer, 5, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        latexDviPaperLA->setBuddy(latexDviPaperED);
        latexBibtexLA->setBuddy(latexBibtexCO);
        latexBibtexOptionsLA->setBuddy(latexBibtexED);
        latexJBibtexLA->setBuddy(latexJBibtexCO);
        latexJBibtexOptionsLA->setBuddy(latexJBibtexED);
        latexIndexLA->setBuddy(latexIndexCO);
        latexIndexOptionsLA->setBuddy(latexIndexED);
        latexJIndexLA->setBuddy(latexJIndexED);
        latexChecktexLA->setBuddy(latexChecktexED);
        latexNomenclLA->setBuddy(latexNomenclED);
#endif // QT_NO_SHORTCUT

        retranslateUi(PrefLatexUi);

        QMetaObject::connectSlotsByName(PrefLatexUi);
    } // setupUi

    void retranslateUi(QWidget *PrefLatexUi)
    {
        PrefLatexUi->setWindowTitle(QString());
        latexDviPaperLA->setText(lyx::qt_("&DVI viewer paper size options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexDviPaperED->setToolTip(lyx::qt_("Optional paper size flag (-paper) for some DVI viewers", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibtexGB->setTitle(lyx::qt_("Bibliography Generation", Q_NULLPTR));
        latexBibtexLA->setText(lyx::qt_("P&rocessor:", Q_NULLPTR));
        latexBibtexOptionsLA->setText(lyx::qt_("Op&tions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexBibtexED->setToolTip(lyx::qt_("BibTeX command and options", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        latexJBibtexLA->setText(lyx::qt_("Processor for &Japanese:", Q_NULLPTR));
        latexJBibtexOptionsLA->setText(lyx::qt_("Options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexJBibtexED->setToolTip(lyx::qt_("Specific BibTeX command and options for pLaTeX (Japanese)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        indexGB->setTitle(lyx::qt_("Index Generation", Q_NULLPTR));
        latexIndexLA->setText(lyx::qt_("&Processor:", Q_NULLPTR));
        latexIndexOptionsLA->setText(lyx::qt_("Op&tions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexIndexED->setToolTip(lyx::qt_("Index command and options (makeindex, xindy)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        latexJIndexLA->setText(lyx::qt_("Processor for &Japanese:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexJIndexED->setToolTip(lyx::qt_("Specific index command and options for pLaTeX (Japanese)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(QString());
#ifndef QT_NO_TOOLTIP
        latexNomenclED->setToolTip(lyx::qt_("Command and options for nomencl (usually makeindex)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        latexChecktexED->setToolTip(lyx::qt_("CheckTeX start options and flags", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        latexChecktexLA->setText(lyx::qt_("&CheckTeX command:", Q_NULLPTR));
        latexNomenclLA->setText(lyx::qt_("&Nomenclature command:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pathCB->setToolTip(lyx::qt_("Select whether LyX should output Windows or Cygwin style paths to LaTeX files. Change the default only if the TeX engine was not correctly detected at configure time. Warning: Your changes here will not be saved.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pathCB->setText(lyx::qt_("&Use Windows-style paths in LaTeX files", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        latexAutoresetCB->setToolTip(lyx::qt_("Set class options to default on class change", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        latexAutoresetCB->setText(lyx::qt_("R&eset class options when document class changes", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefLatexUi: public Ui_PrefLatexUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFLATEXUI_H
