/********************************************************************************
** Form generated from reading UI file 'ModulesUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODULESUI_H
#define UI_MODULESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ModulesUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QLabel *availmodL;
    QTreeView *availableLV;
    QHBoxLayout *horizontalLayout_6;
    QLabel *findModulesLA;
    QHBoxLayout *moduleFilterBarL;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *addPB;
    QPushButton *deletePB;
    QPushButton *upPB;
    QPushButton *downPB;
    QSpacerItem *spacerItem1;
    QVBoxLayout *vboxLayout2;
    QLabel *selmodL;
    QTreeView *selectedLV;
    QTextBrowser *infoML;

    void setupUi(QWidget *ModulesUi)
    {
        if (ModulesUi->objectName().isEmpty())
            ModulesUi->setObjectName(QStringLiteral("ModulesUi"));
        ModulesUi->resize(407, 343);
        gridLayout = new QGridLayout(ModulesUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        availmodL = new QLabel(ModulesUi);
        availmodL->setObjectName(QStringLiteral("availmodL"));
        availmodL->setFrameShape(QFrame::NoFrame);

        vboxLayout->addWidget(availmodL);

        availableLV = new QTreeView(ModulesUi);
        availableLV->setObjectName(QStringLiteral("availableLV"));
        availableLV->setRootIsDecorated(true);

        vboxLayout->addWidget(availableLV);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        findModulesLA = new QLabel(ModulesUi);
        findModulesLA->setObjectName(QStringLiteral("findModulesLA"));
        findModulesLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_6->addWidget(findModulesLA);

        moduleFilterBarL = new QHBoxLayout();
        moduleFilterBarL->setObjectName(QStringLiteral("moduleFilterBarL"));

        horizontalLayout_6->addLayout(moduleFilterBarL);


        vboxLayout->addLayout(horizontalLayout_6);


        hboxLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(51, 20, QSizePolicy::Minimum, QSizePolicy::Minimum);

        vboxLayout1->addItem(spacerItem);

        addPB = new QPushButton(ModulesUi);
        addPB->setObjectName(QStringLiteral("addPB"));

        vboxLayout1->addWidget(addPB);

        deletePB = new QPushButton(ModulesUi);
        deletePB->setObjectName(QStringLiteral("deletePB"));

        vboxLayout1->addWidget(deletePB);

        upPB = new QPushButton(ModulesUi);
        upPB->setObjectName(QStringLiteral("upPB"));

        vboxLayout1->addWidget(upPB);

        downPB = new QPushButton(ModulesUi);
        downPB->setObjectName(QStringLiteral("downPB"));

        vboxLayout1->addWidget(downPB);

        spacerItem1 = new QSpacerItem(60, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem1);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        selmodL = new QLabel(ModulesUi);
        selmodL->setObjectName(QStringLiteral("selmodL"));

        vboxLayout2->addWidget(selmodL);

        selectedLV = new QTreeView(ModulesUi);
        selectedLV->setObjectName(QStringLiteral("selectedLV"));
        selectedLV->setRootIsDecorated(false);

        vboxLayout2->addWidget(selectedLV);


        hboxLayout->addLayout(vboxLayout2);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        infoML = new QTextBrowser(ModulesUi);
        infoML->setObjectName(QStringLiteral("infoML"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(infoML->sizePolicy().hasHeightForWidth());
        infoML->setSizePolicy(sizePolicy);
        infoML->setMaximumSize(QSize(16777215, 120));

        gridLayout->addWidget(infoML, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        availmodL->setBuddy(availableLV);
        selmodL->setBuddy(selectedLV);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(availableLV, addPB);
        QWidget::setTabOrder(addPB, deletePB);
        QWidget::setTabOrder(deletePB, upPB);
        QWidget::setTabOrder(upPB, downPB);
        QWidget::setTabOrder(downPB, infoML);

        retranslateUi(ModulesUi);

        QMetaObject::connectSlotsByName(ModulesUi);
    } // setupUi

    void retranslateUi(QWidget *ModulesUi)
    {
        ModulesUi->setWindowTitle(QString());
        availmodL->setText(lyx::qt_("A&vailable:", Q_NULLPTR));
        findModulesLA->setText(lyx::qt_("&Filter:", Q_NULLPTR));
        addPB->setText(lyx::qt_("A&dd", Q_NULLPTR));
        deletePB->setText(lyx::qt_("De&lete", Q_NULLPTR));
        upPB->setText(lyx::qt_("&Up", Q_NULLPTR));
        downPB->setText(lyx::qt_("Do&wn", Q_NULLPTR));
        selmodL->setText(lyx::qt_("S&elected:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ModulesUi: public Ui_ModulesUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MODULESUI_H
