/********************************************************************************
** Form generated from reading UI file 'MarginsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARGINSUI_H
#define UI_MARGINSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_MarginsUi
{
public:
    QGridLayout *gridLayout;
    QCheckBox *marginCB;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QLabel *topL;
    QLabel *bottomL;
    QLabel *innerL;
    QLabel *outerL;
    QLabel *headsepL;
    QLabel *headheightL;
    QLabel *footskipL;
    QLabel *columnsepL;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    QLineEdit *topLE;
    lyx::frontend::LengthCombo *topUnit;
    QHBoxLayout *hboxLayout2;
    QLineEdit *bottomLE;
    lyx::frontend::LengthCombo *bottomUnit;
    QHBoxLayout *hboxLayout3;
    QLineEdit *innerLE;
    lyx::frontend::LengthCombo *innerUnit;
    QHBoxLayout *hboxLayout4;
    QLineEdit *outerLE;
    lyx::frontend::LengthCombo *outerUnit;
    QHBoxLayout *hboxLayout5;
    QLineEdit *headsepLE;
    lyx::frontend::LengthCombo *headsepUnit;
    QHBoxLayout *hboxLayout6;
    QLineEdit *headheightLE;
    lyx::frontend::LengthCombo *headheightUnit;
    QHBoxLayout *hboxLayout7;
    QLineEdit *footskipLE;
    lyx::frontend::LengthCombo *footskipUnit;
    QHBoxLayout *hboxLayout8;
    QLineEdit *columnsepLE;
    lyx::frontend::LengthCombo *columnsepUnit;

    void setupUi(QWidget *MarginsUi)
    {
        if (MarginsUi->objectName().isEmpty())
            MarginsUi->setObjectName(QStringLiteral("MarginsUi"));
        MarginsUi->resize(329, 411);
        gridLayout = new QGridLayout(MarginsUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(11, 11, 11, 11);
        marginCB = new QCheckBox(MarginsUi);
        marginCB->setObjectName(QStringLiteral("marginCB"));
        marginCB->setAcceptDrops(true);

        gridLayout->addWidget(marginCB, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 1, 1, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem1, 2, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        topL = new QLabel(MarginsUi);
        topL->setObjectName(QStringLiteral("topL"));
        topL->setEnabled(false);

        vboxLayout->addWidget(topL);

        bottomL = new QLabel(MarginsUi);
        bottomL->setObjectName(QStringLiteral("bottomL"));
        bottomL->setEnabled(false);

        vboxLayout->addWidget(bottomL);

        innerL = new QLabel(MarginsUi);
        innerL->setObjectName(QStringLiteral("innerL"));
        innerL->setEnabled(false);

        vboxLayout->addWidget(innerL);

        outerL = new QLabel(MarginsUi);
        outerL->setObjectName(QStringLiteral("outerL"));
        outerL->setEnabled(false);

        vboxLayout->addWidget(outerL);

        headsepL = new QLabel(MarginsUi);
        headsepL->setObjectName(QStringLiteral("headsepL"));
        headsepL->setEnabled(false);

        vboxLayout->addWidget(headsepL);

        headheightL = new QLabel(MarginsUi);
        headheightL->setObjectName(QStringLiteral("headheightL"));
        headheightL->setEnabled(false);

        vboxLayout->addWidget(headheightL);

        footskipL = new QLabel(MarginsUi);
        footskipL->setObjectName(QStringLiteral("footskipL"));
        footskipL->setEnabled(false);

        vboxLayout->addWidget(footskipL);

        columnsepL = new QLabel(MarginsUi);
        columnsepL->setObjectName(QStringLiteral("columnsepL"));
        columnsepL->setEnabled(false);

        vboxLayout->addWidget(columnsepL);


        hboxLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        topLE = new QLineEdit(MarginsUi);
        topLE->setObjectName(QStringLiteral("topLE"));
        topLE->setEnabled(false);

        hboxLayout1->addWidget(topLE);

        topUnit = new lyx::frontend::LengthCombo(MarginsUi);
        topUnit->setObjectName(QStringLiteral("topUnit"));
        topUnit->setEnabled(false);

        hboxLayout1->addWidget(topUnit);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        bottomLE = new QLineEdit(MarginsUi);
        bottomLE->setObjectName(QStringLiteral("bottomLE"));
        bottomLE->setEnabled(false);

        hboxLayout2->addWidget(bottomLE);

        bottomUnit = new lyx::frontend::LengthCombo(MarginsUi);
        bottomUnit->setObjectName(QStringLiteral("bottomUnit"));
        bottomUnit->setEnabled(false);

        hboxLayout2->addWidget(bottomUnit);


        vboxLayout1->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName(QStringLiteral("hboxLayout3"));
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        innerLE = new QLineEdit(MarginsUi);
        innerLE->setObjectName(QStringLiteral("innerLE"));
        innerLE->setEnabled(false);

        hboxLayout3->addWidget(innerLE);

        innerUnit = new lyx::frontend::LengthCombo(MarginsUi);
        innerUnit->setObjectName(QStringLiteral("innerUnit"));
        innerUnit->setEnabled(false);

        hboxLayout3->addWidget(innerUnit);


        vboxLayout1->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName(QStringLiteral("hboxLayout4"));
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        outerLE = new QLineEdit(MarginsUi);
        outerLE->setObjectName(QStringLiteral("outerLE"));
        outerLE->setEnabled(false);

        hboxLayout4->addWidget(outerLE);

        outerUnit = new lyx::frontend::LengthCombo(MarginsUi);
        outerUnit->setObjectName(QStringLiteral("outerUnit"));
        outerUnit->setEnabled(false);

        hboxLayout4->addWidget(outerUnit);


        vboxLayout1->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(6);
        hboxLayout5->setObjectName(QStringLiteral("hboxLayout5"));
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        headsepLE = new QLineEdit(MarginsUi);
        headsepLE->setObjectName(QStringLiteral("headsepLE"));
        headsepLE->setEnabled(false);

        hboxLayout5->addWidget(headsepLE);

        headsepUnit = new lyx::frontend::LengthCombo(MarginsUi);
        headsepUnit->setObjectName(QStringLiteral("headsepUnit"));
        headsepUnit->setEnabled(false);

        hboxLayout5->addWidget(headsepUnit);


        vboxLayout1->addLayout(hboxLayout5);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setSpacing(6);
        hboxLayout6->setObjectName(QStringLiteral("hboxLayout6"));
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
        headheightLE = new QLineEdit(MarginsUi);
        headheightLE->setObjectName(QStringLiteral("headheightLE"));
        headheightLE->setEnabled(false);

        hboxLayout6->addWidget(headheightLE);

        headheightUnit = new lyx::frontend::LengthCombo(MarginsUi);
        headheightUnit->setObjectName(QStringLiteral("headheightUnit"));
        headheightUnit->setEnabled(false);

        hboxLayout6->addWidget(headheightUnit);


        vboxLayout1->addLayout(hboxLayout6);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setSpacing(6);
        hboxLayout7->setObjectName(QStringLiteral("hboxLayout7"));
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        footskipLE = new QLineEdit(MarginsUi);
        footskipLE->setObjectName(QStringLiteral("footskipLE"));
        footskipLE->setEnabled(false);

        hboxLayout7->addWidget(footskipLE);

        footskipUnit = new lyx::frontend::LengthCombo(MarginsUi);
        footskipUnit->setObjectName(QStringLiteral("footskipUnit"));
        footskipUnit->setEnabled(false);

        hboxLayout7->addWidget(footskipUnit);


        vboxLayout1->addLayout(hboxLayout7);

        hboxLayout8 = new QHBoxLayout();
        hboxLayout8->setSpacing(6);
        hboxLayout8->setObjectName(QStringLiteral("hboxLayout8"));
        hboxLayout8->setContentsMargins(0, 0, 0, 0);
        columnsepLE = new QLineEdit(MarginsUi);
        columnsepLE->setObjectName(QStringLiteral("columnsepLE"));
        columnsepLE->setEnabled(false);

        hboxLayout8->addWidget(columnsepLE);

        columnsepUnit = new lyx::frontend::LengthCombo(MarginsUi);
        columnsepUnit->setObjectName(QStringLiteral("columnsepUnit"));
        columnsepUnit->setEnabled(false);

        hboxLayout8->addWidget(columnsepUnit);


        vboxLayout1->addLayout(hboxLayout8);


        hboxLayout->addLayout(vboxLayout1);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        topL->setBuddy(topLE);
        bottomL->setBuddy(bottomLE);
        innerL->setBuddy(innerLE);
        outerL->setBuddy(outerLE);
        headsepL->setBuddy(headsepLE);
        headheightL->setBuddy(headheightLE);
        footskipL->setBuddy(footskipLE);
        columnsepL->setBuddy(columnsepLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(topLE, bottomLE);
        QWidget::setTabOrder(bottomLE, innerLE);
        QWidget::setTabOrder(innerLE, outerLE);
        QWidget::setTabOrder(outerLE, headsepLE);
        QWidget::setTabOrder(headsepLE, headheightLE);
        QWidget::setTabOrder(headheightLE, footskipLE);

        retranslateUi(MarginsUi);

        QMetaObject::connectSlotsByName(MarginsUi);
    } // setupUi

    void retranslateUi(QWidget *MarginsUi)
    {
        MarginsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        marginCB->setToolTip(lyx::qt_("Use the margin settings provided by the document class.<br>Note that if this is unchecked, different defaults may be used.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        marginCB->setText(lyx::qt_("&Default margins", Q_NULLPTR));
        topL->setText(lyx::qt_("&Top:", Q_NULLPTR));
        bottomL->setText(lyx::qt_("&Bottom:", Q_NULLPTR));
        innerL->setText(lyx::qt_("&Inner:", Q_NULLPTR));
        outerL->setText(lyx::qt_("O&uter:", Q_NULLPTR));
        headsepL->setText(lyx::qt_("Head &sep:", Q_NULLPTR));
        headheightL->setText(lyx::qt_("Head &height:", Q_NULLPTR));
        footskipL->setText(lyx::qt_("&Foot skip:", Q_NULLPTR));
        columnsepL->setText(lyx::qt_("&Column sep:", Q_NULLPTR));
        bottomLE->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class MarginsUi: public Ui_MarginsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MARGINSUI_H
