/****************************************************************************
** Meta object code from reading C++ file 'Compare.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lyx-2.4.4/src/Compare.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Compare.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__Compare_t {
    QByteArrayData data[11];
    char stringdata0[96];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__Compare_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__Compare_t qt_meta_stringdata_lyx__Compare = {
    {
QT_MOC_LITERAL(0, 0, 12), // "lyx::Compare"
QT_MOC_LITERAL(1, 13, 5), // "error"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 8), // "finished"
QT_MOC_LITERAL(4, 29, 7), // "aborted"
QT_MOC_LITERAL(5, 37, 8), // "progress"
QT_MOC_LITERAL(6, 46, 11), // "progressMax"
QT_MOC_LITERAL(7, 58, 3), // "max"
QT_MOC_LITERAL(8, 62, 13), // "statusMessage"
QT_MOC_LITERAL(9, 76, 3), // "msg"
QT_MOC_LITERAL(10, 80, 15) // "doStatusMessage"

    },
    "lyx::Compare\0error\0\0finished\0aborted\0"
    "progress\0progressMax\0max\0statusMessage\0"
    "msg\0doStatusMessage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__Compare[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    1,   45,    2, 0x06 /* Public */,
       5,    1,   48,    2, 0x06 /* Public */,
       6,    1,   51,    2, 0x06 /* Public */,
       8,    1,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   57,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::QString,    9,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void lyx::Compare::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Compare *_t = static_cast<Compare *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->error(); break;
        case 1: _t->finished((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->progress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->progressMax((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->statusMessage((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->doStatusMessage(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Compare::*_t)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Compare::error)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Compare::*_t)(bool ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Compare::finished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Compare::*_t)(int ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Compare::progress)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Compare::*_t)(int ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Compare::progressMax)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Compare::*_t)(QString ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Compare::statusMessage)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject lyx::Compare::staticMetaObject = {
    { &QThread::staticMetaObject, qt_meta_stringdata_lyx__Compare.data,
      qt_meta_data_lyx__Compare,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::Compare::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::Compare::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__Compare.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int lyx::Compare::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void lyx::Compare::error()const
{
    QMetaObject::activate(const_cast< lyx::Compare *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void lyx::Compare::finished(bool _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::Compare *>(this), &staticMetaObject, 1, _a);
}

// SIGNAL 2
void lyx::Compare::progress(int _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::Compare *>(this), &staticMetaObject, 2, _a);
}

// SIGNAL 3
void lyx::Compare::progressMax(int _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::Compare *>(this), &staticMetaObject, 3, _a);
}

// SIGNAL 4
void lyx::Compare::statusMessage(QString _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::Compare *>(this), &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
