/********************************************************************************
** Form generated from reading UI file 'SearchUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHUI_H
#define UI_SEARCHUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_SearchUi
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QPushButton *findPrevPB;
    QPushButton *replaceallPB;
    QComboBox *findCO;
    QPushButton *minimizePB;
    QLabel *replaceLA;
    QLabel *findLA;
    QComboBox *replaceCO;
    QPushButton *replacePB;
    QPushButton *replacePrevPB;
    QPushButton *findPB;
    QFrame *CBFrame;
    QHBoxLayout *CBLayout;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *caseCB;
    QCheckBox *wordsCB;
    QCheckBox *selectionCB;
    QCheckBox *instantSearchCB;
    QCheckBox *wrapCB;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *SearchUi)
    {
        if (SearchUi->objectName().isEmpty())
            SearchUi->setObjectName(QStringLiteral("SearchUi"));
        SearchUi->resize(706, 103);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchUi->sizePolicy().hasHeightForWidth());
        SearchUi->setSizePolicy(sizePolicy);
        SearchUi->setProperty("sizeGripEnabled", QVariant(false));
        gridLayout_2 = new QGridLayout(SearchUi);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setContentsMargins(6, 3, 3, 3);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(3);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        findPrevPB = new QPushButton(SearchUi);
        findPrevPB->setObjectName(QStringLiteral("findPrevPB"));
        findPrevPB->setEnabled(false);

        gridLayout->addWidget(findPrevPB, 0, 2, 1, 1);

        replaceallPB = new QPushButton(SearchUi);
        replaceallPB->setObjectName(QStringLiteral("replaceallPB"));
        replaceallPB->setEnabled(false);

        gridLayout->addWidget(replaceallPB, 1, 4, 1, 1);

        findCO = new QComboBox(SearchUi);
        findCO->setObjectName(QStringLiteral("findCO"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(findCO->sizePolicy().hasHeightForWidth());
        findCO->setSizePolicy(sizePolicy1);
        findCO->setFocusPolicy(Qt::StrongFocus);
        findCO->setEditable(true);
        findCO->setMaxCount(666);
        findCO->setInsertPolicy(QComboBox::InsertAtTop);
        findCO->setDuplicatesEnabled(false);

        gridLayout->addWidget(findCO, 0, 1, 1, 1);

        minimizePB = new QPushButton(SearchUi);
        minimizePB->setObjectName(QStringLiteral("minimizePB"));

        gridLayout->addWidget(minimizePB, 0, 4, 1, 1);

        replaceLA = new QLabel(SearchUi);
        replaceLA->setObjectName(QStringLiteral("replaceLA"));

        gridLayout->addWidget(replaceLA, 1, 0, 1, 1);

        findLA = new QLabel(SearchUi);
        findLA->setObjectName(QStringLiteral("findLA"));

        gridLayout->addWidget(findLA, 0, 0, 1, 1);

        replaceCO = new QComboBox(SearchUi);
        replaceCO->setObjectName(QStringLiteral("replaceCO"));
        sizePolicy1.setHeightForWidth(replaceCO->sizePolicy().hasHeightForWidth());
        replaceCO->setSizePolicy(sizePolicy1);
        replaceCO->setEditable(true);
        replaceCO->setMaxCount(666);
        replaceCO->setInsertPolicy(QComboBox::InsertAtTop);
        replaceCO->setDuplicatesEnabled(false);

        gridLayout->addWidget(replaceCO, 1, 1, 1, 1);

        replacePB = new QPushButton(SearchUi);
        replacePB->setObjectName(QStringLiteral("replacePB"));
        replacePB->setEnabled(false);
        replacePB->setLayoutDirection(Qt::LeftToRight);

        gridLayout->addWidget(replacePB, 1, 3, 1, 1);

        replacePrevPB = new QPushButton(SearchUi);
        replacePrevPB->setObjectName(QStringLiteral("replacePrevPB"));
        replacePrevPB->setEnabled(false);

        gridLayout->addWidget(replacePrevPB, 1, 2, 1, 1);

        findPB = new QPushButton(SearchUi);
        findPB->setObjectName(QStringLiteral("findPB"));
        findPB->setEnabled(false);
        findPB->setLayoutDirection(Qt::LeftToRight);

        gridLayout->addWidget(findPB, 0, 3, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        CBFrame = new QFrame(SearchUi);
        CBFrame->setObjectName(QStringLiteral("CBFrame"));
        CBLayout = new QHBoxLayout(CBFrame);
        CBLayout->setSpacing(0);
        CBLayout->setObjectName(QStringLiteral("CBLayout"));
        CBLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(-1, 6, -1, -1);
        caseCB = new QCheckBox(CBFrame);
        caseCB->setObjectName(QStringLiteral("caseCB"));

        horizontalLayout_2->addWidget(caseCB);

        wordsCB = new QCheckBox(CBFrame);
        wordsCB->setObjectName(QStringLiteral("wordsCB"));

        horizontalLayout_2->addWidget(wordsCB);

        selectionCB = new QCheckBox(CBFrame);
        selectionCB->setObjectName(QStringLiteral("selectionCB"));

        horizontalLayout_2->addWidget(selectionCB);

        instantSearchCB = new QCheckBox(CBFrame);
        instantSearchCB->setObjectName(QStringLiteral("instantSearchCB"));

        horizontalLayout_2->addWidget(instantSearchCB);

        wrapCB = new QCheckBox(CBFrame);
        wrapCB->setObjectName(QStringLiteral("wrapCB"));
        wrapCB->setChecked(true);

        horizontalLayout_2->addWidget(wrapCB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        CBLayout->addLayout(horizontalLayout_2);


        gridLayout_2->addWidget(CBFrame, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        replaceLA->setBuddy(replaceCO);
        findLA->setBuddy(findCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(replaceCO, findPB);
        QWidget::setTabOrder(findPB, findPrevPB);
        QWidget::setTabOrder(findPrevPB, minimizePB);
        QWidget::setTabOrder(minimizePB, replacePB);
        QWidget::setTabOrder(replacePB, replacePrevPB);
        QWidget::setTabOrder(replacePrevPB, replaceallPB);
        QWidget::setTabOrder(replaceallPB, caseCB);
        QWidget::setTabOrder(caseCB, wordsCB);
        QWidget::setTabOrder(wordsCB, selectionCB);
        QWidget::setTabOrder(selectionCB, instantSearchCB);
        QWidget::setTabOrder(instantSearchCB, wrapCB);
        QWidget::setTabOrder(wrapCB, findCO);

        retranslateUi(SearchUi);

        findPB->setDefault(true);


        QMetaObject::connectSlotsByName(SearchUi);
    } // setupUi

    void retranslateUi(QWidget *SearchUi)
    {
        SearchUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        findPrevPB->setToolTip(lyx::qt_("Find previous occurrence (Shift+Enter)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        findPrevPB->setText(lyx::qt_("&< Find", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replaceallPB->setToolTip(lyx::qt_("Replace all occurrences", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replaceallPB->setText(lyx::qt_("Replace &All", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        minimizePB->setToolTip(lyx::qt_("Hide replace and option widgets", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        minimizePB->setText(lyx::qt_("&Minimize", Q_NULLPTR));
        replaceLA->setText(lyx::qt_("Rep&lace with:", Q_NULLPTR));
        findLA->setText(lyx::qt_("&Search:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replacePB->setToolTip(lyx::qt_("Replace and find next occurrence", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replacePB->setText(lyx::qt_("&Replace >", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replacePrevPB->setToolTip(lyx::qt_("Replace and find previous occurrence", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replacePrevPB->setText(lyx::qt_("< Re&place", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        findPB->setToolTip(lyx::qt_("Find next occurrence (Enter)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        findPB->setText(lyx::qt_("Find &>", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        caseCB->setToolTip(lyx::qt_("Treat uppercase/lowercase writing as distinct", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        caseCB->setText(lyx::qt_("&Case sensitive[[search]]", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        wordsCB->setToolTip(lyx::qt_("Match whole words only", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        wordsCB->setText(lyx::qt_("Wh&ole words", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        selectionCB->setToolTip(lyx::qt_("Limit search and replace to selection", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        selectionCB->setText(lyx::qt_("Selection onl&y", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        instantSearchCB->setToolTip(lyx::qt_("If this is checked, LyX will search forward immediately", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        instantSearchCB->setText(lyx::qt_("Search as yo&u type", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        wrapCB->setToolTip(lyx::qt_("If the end/start of the document is reached, automatically wrap around", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        wrapCB->setText(lyx::qt_("&Wrap", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SearchUi: public Ui_SearchUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHUI_H
