/****************************************************************************
** Meta object code from reading C++ file 'GuiDocument.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiDocument.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiDocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiDocument_t {
    QByteArrayData data[85];
    char stringdata0[1370];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiDocument_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiDocument_t qt_meta_stringdata_lyx__frontend__GuiDocument = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiDocument"
QT_MOC_LITERAL(1, 27, 19), // "onBufferViewChanged"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 9), // "onClosing"
QT_MOC_LITERAL(4, 58, 6), // "slotOK"
QT_MOC_LITERAL(5, 65, 9), // "slotApply"
QT_MOC_LITERAL(6, 75, 13), // "slotButtonBox"
QT_MOC_LITERAL(7, 89, 16), // "QAbstractButton*"
QT_MOC_LITERAL(8, 106, 15), // "updateNumbering"
QT_MOC_LITERAL(9, 122, 14), // "change_adaptor"
QT_MOC_LITERAL(10, 137, 18), // "shellescapeChanged"
QT_MOC_LITERAL(11, 156, 18), // "includeonlyClicked"
QT_MOC_LITERAL(12, 175, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 192, 4), // "item"
QT_MOC_LITERAL(14, 197, 18), // "setListingsMessage"
QT_MOC_LITERAL(15, 216, 22), // "listingsPackageChanged"
QT_MOC_LITERAL(16, 239, 18), // "saveDefaultClicked"
QT_MOC_LITERAL(17, 258, 18), // "useDefaultsClicked"
QT_MOC_LITERAL(18, 277, 11), // "setLSpacing"
QT_MOC_LITERAL(19, 289, 10), // "setMargins"
QT_MOC_LITERAL(20, 300, 16), // "papersizeChanged"
QT_MOC_LITERAL(21, 317, 9), // "setColSep"
QT_MOC_LITERAL(22, 327, 16), // "setCustomMargins"
QT_MOC_LITERAL(23, 344, 14), // "fontencChanged"
QT_MOC_LITERAL(24, 359, 12), // "romanChanged"
QT_MOC_LITERAL(25, 372, 11), // "sansChanged"
QT_MOC_LITERAL(26, 384, 9), // "ttChanged"
QT_MOC_LITERAL(27, 394, 14), // "fontOsfToggled"
QT_MOC_LITERAL(28, 409, 5), // "state"
QT_MOC_LITERAL(29, 415, 13), // "fontScToggled"
QT_MOC_LITERAL(30, 429, 9), // "setIndent"
QT_MOC_LITERAL(31, 439, 12), // "enableIndent"
QT_MOC_LITERAL(32, 452, 7), // "setSkip"
QT_MOC_LITERAL(33, 460, 10), // "enableSkip"
QT_MOC_LITERAL(34, 471, 15), // "allowMathIndent"
QT_MOC_LITERAL(35, 487, 16), // "enableMathIndent"
QT_MOC_LITERAL(36, 504, 12), // "browseLayout"
QT_MOC_LITERAL(37, 517, 12), // "browseMaster"
QT_MOC_LITERAL(38, 530, 12), // "classChanged"
QT_MOC_LITERAL(39, 543, 20), // "classChanged_adaptor"
QT_MOC_LITERAL(40, 564, 20), // "colorlinksCB_adaptor"
QT_MOC_LITERAL(41, 585, 22), // "languagePackageChanged"
QT_MOC_LITERAL(42, 608, 13), // "biblioChanged"
QT_MOC_LITERAL(43, 622, 14), // "rescanBibFiles"
QT_MOC_LITERAL(44, 637, 19), // "resetDefaultBibfile"
QT_MOC_LITERAL(45, 657, 11), // "std::string"
QT_MOC_LITERAL(46, 669, 5), // "which"
QT_MOC_LITERAL(47, 675, 22), // "resetDefaultBbxBibfile"
QT_MOC_LITERAL(48, 698, 22), // "resetDefaultCbxBibfile"
QT_MOC_LITERAL(49, 721, 17), // "citeEngineChanged"
QT_MOC_LITERAL(50, 739, 16), // "citeStyleChanged"
QT_MOC_LITERAL(51, 756, 13), // "bibtexChanged"
QT_MOC_LITERAL(52, 770, 24), // "updateResetDefaultBiblio"
QT_MOC_LITERAL(53, 795, 19), // "matchBiblatexStyles"
QT_MOC_LITERAL(54, 815, 22), // "updateEngineDependends"
QT_MOC_LITERAL(55, 838, 16), // "updateModuleInfo"
QT_MOC_LITERAL(56, 855, 14), // "modulesChanged"
QT_MOC_LITERAL(57, 870, 21), // "changeBackgroundColor"
QT_MOC_LITERAL(58, 892, 21), // "deleteBackgroundColor"
QT_MOC_LITERAL(59, 914, 15), // "changeFontColor"
QT_MOC_LITERAL(60, 930, 15), // "deleteFontColor"
QT_MOC_LITERAL(61, 946, 19), // "changeNoteFontColor"
QT_MOC_LITERAL(62, 966, 19), // "deleteNoteFontColor"
QT_MOC_LITERAL(63, 986, 24), // "changeBoxBackgroundColor"
QT_MOC_LITERAL(64, 1011, 24), // "deleteBoxBackgroundColor"
QT_MOC_LITERAL(65, 1036, 15), // "languageChanged"
QT_MOC_LITERAL(66, 1052, 14), // "osFontsChanged"
QT_MOC_LITERAL(67, 1067, 16), // "encodingSwitched"
QT_MOC_LITERAL(68, 1084, 21), // "inputencodingToDialog"
QT_MOC_LITERAL(69, 1106, 15), // "mathFontChanged"
QT_MOC_LITERAL(70, 1122, 14), // "branchesRename"
QT_MOC_LITERAL(71, 1137, 9), // "docstring"
QT_MOC_LITERAL(72, 1147, 15), // "allPackagesAuto"
QT_MOC_LITERAL(73, 1163, 17), // "allPackagesAlways"
QT_MOC_LITERAL(74, 1181, 14), // "allPackagesNot"
QT_MOC_LITERAL(75, 1196, 19), // "moduleFilterPressed"
QT_MOC_LITERAL(76, 1216, 19), // "moduleFilterChanged"
QT_MOC_LITERAL(77, 1236, 4), // "text"
QT_MOC_LITERAL(78, 1241, 17), // "resetModuleFilter"
QT_MOC_LITERAL(79, 1259, 13), // "linenoToggled"
QT_MOC_LITERAL(80, 1273, 20), // "outputChangesToggled"
QT_MOC_LITERAL(81, 1294, 13), // "setOutputSync"
QT_MOC_LITERAL(82, 1308, 20), // "bookmarksopenChanged"
QT_MOC_LITERAL(83, 1329, 21), // "changeTrackingChanged"
QT_MOC_LITERAL(84, 1351, 18) // "updateMarginLabels"

    },
    "lyx::frontend::GuiDocument\0"
    "onBufferViewChanged\0\0onClosing\0slotOK\0"
    "slotApply\0slotButtonBox\0QAbstractButton*\0"
    "updateNumbering\0change_adaptor\0"
    "shellescapeChanged\0includeonlyClicked\0"
    "QTreeWidgetItem*\0item\0setListingsMessage\0"
    "listingsPackageChanged\0saveDefaultClicked\0"
    "useDefaultsClicked\0setLSpacing\0"
    "setMargins\0papersizeChanged\0setColSep\0"
    "setCustomMargins\0fontencChanged\0"
    "romanChanged\0sansChanged\0ttChanged\0"
    "fontOsfToggled\0state\0fontScToggled\0"
    "setIndent\0enableIndent\0setSkip\0"
    "enableSkip\0allowMathIndent\0enableMathIndent\0"
    "browseLayout\0browseMaster\0classChanged\0"
    "classChanged_adaptor\0colorlinksCB_adaptor\0"
    "languagePackageChanged\0biblioChanged\0"
    "rescanBibFiles\0resetDefaultBibfile\0"
    "std::string\0which\0resetDefaultBbxBibfile\0"
    "resetDefaultCbxBibfile\0citeEngineChanged\0"
    "citeStyleChanged\0bibtexChanged\0"
    "updateResetDefaultBiblio\0matchBiblatexStyles\0"
    "updateEngineDependends\0updateModuleInfo\0"
    "modulesChanged\0changeBackgroundColor\0"
    "deleteBackgroundColor\0changeFontColor\0"
    "deleteFontColor\0changeNoteFontColor\0"
    "deleteNoteFontColor\0changeBoxBackgroundColor\0"
    "deleteBoxBackgroundColor\0languageChanged\0"
    "osFontsChanged\0encodingSwitched\0"
    "inputencodingToDialog\0mathFontChanged\0"
    "branchesRename\0docstring\0allPackagesAuto\0"
    "allPackagesAlways\0allPackagesNot\0"
    "moduleFilterPressed\0moduleFilterChanged\0"
    "text\0resetModuleFilter\0linenoToggled\0"
    "outputChangesToggled\0setOutputSync\0"
    "bookmarksopenChanged\0changeTrackingChanged\0"
    "updateMarginLabels"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiDocument[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      76,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  394,    2, 0x0a /* Public */,
       3,    1,  395,    2, 0x0a /* Public */,
       4,    0,  398,    2, 0x0a /* Public */,
       5,    0,  399,    2, 0x0a /* Public */,
       6,    1,  400,    2, 0x0a /* Public */,
       8,    0,  403,    2, 0x08 /* Private */,
       9,    0,  404,    2, 0x08 /* Private */,
      10,    0,  405,    2, 0x08 /* Private */,
      11,    2,  406,    2, 0x08 /* Private */,
      14,    0,  411,    2, 0x08 /* Private */,
      15,    1,  412,    2, 0x08 /* Private */,
      16,    0,  415,    2, 0x08 /* Private */,
      17,    0,  416,    2, 0x08 /* Private */,
      18,    1,  417,    2, 0x08 /* Private */,
      19,    0,  420,    2, 0x08 /* Private */,
      20,    1,  421,    2, 0x08 /* Private */,
      21,    0,  424,    2, 0x08 /* Private */,
      22,    1,  425,    2, 0x08 /* Private */,
      23,    1,  428,    2, 0x08 /* Private */,
      24,    1,  431,    2, 0x08 /* Private */,
      25,    1,  434,    2, 0x08 /* Private */,
      26,    1,  437,    2, 0x08 /* Private */,
      27,    1,  440,    2, 0x08 /* Private */,
      29,    1,  443,    2, 0x08 /* Private */,
      30,    1,  446,    2, 0x08 /* Private */,
      31,    1,  449,    2, 0x08 /* Private */,
      32,    1,  452,    2, 0x08 /* Private */,
      33,    1,  455,    2, 0x08 /* Private */,
      34,    0,  458,    2, 0x08 /* Private */,
      35,    1,  459,    2, 0x08 /* Private */,
      36,    0,  462,    2, 0x08 /* Private */,
      37,    0,  463,    2, 0x08 /* Private */,
      38,    0,  464,    2, 0x08 /* Private */,
      39,    0,  465,    2, 0x08 /* Private */,
      40,    1,  466,    2, 0x08 /* Private */,
      41,    1,  469,    2, 0x08 /* Private */,
      42,    0,  472,    2, 0x08 /* Private */,
      43,    0,  473,    2, 0x08 /* Private */,
      44,    1,  474,    2, 0x08 /* Private */,
      44,    0,  477,    2, 0x28 /* Private | MethodCloned */,
      47,    0,  478,    2, 0x08 /* Private */,
      48,    0,  479,    2, 0x08 /* Private */,
      49,    1,  480,    2, 0x08 /* Private */,
      50,    0,  483,    2, 0x08 /* Private */,
      51,    1,  484,    2, 0x08 /* Private */,
      52,    0,  487,    2, 0x08 /* Private */,
      53,    0,  488,    2, 0x08 /* Private */,
      54,    0,  489,    2, 0x08 /* Private */,
      55,    0,  490,    2, 0x08 /* Private */,
      56,    0,  491,    2, 0x08 /* Private */,
      57,    0,  492,    2, 0x08 /* Private */,
      58,    0,  493,    2, 0x08 /* Private */,
      59,    0,  494,    2, 0x08 /* Private */,
      60,    0,  495,    2, 0x08 /* Private */,
      61,    0,  496,    2, 0x08 /* Private */,
      62,    0,  497,    2, 0x08 /* Private */,
      63,    0,  498,    2, 0x08 /* Private */,
      64,    0,  499,    2, 0x08 /* Private */,
      65,    1,  500,    2, 0x08 /* Private */,
      66,    1,  503,    2, 0x08 /* Private */,
      67,    1,  506,    2, 0x08 /* Private */,
      68,    0,  509,    2, 0x08 /* Private */,
      69,    1,  510,    2, 0x08 /* Private */,
      70,    2,  513,    2, 0x08 /* Private */,
      72,    0,  518,    2, 0x08 /* Private */,
      73,    0,  519,    2, 0x08 /* Private */,
      74,    0,  520,    2, 0x08 /* Private */,
      75,    0,  521,    2, 0x08 /* Private */,
      76,    1,  522,    2, 0x08 /* Private */,
      78,    0,  525,    2, 0x08 /* Private */,
      79,    1,  526,    2, 0x08 /* Private */,
      80,    1,  529,    2, 0x08 /* Private */,
      81,    1,  532,    2, 0x08 /* Private */,
      82,    1,  535,    2, 0x08 /* Private */,
      83,    1,  538,    2, 0x08 /* Private */,
      84,    1,  541,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int,   13,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 45,   46,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 71, 0x80000000 | 71,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   77,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void lyx::frontend::GuiDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiDocument *_t = static_cast<GuiDocument *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onBufferViewChanged(); break;
        case 1: _t->onClosing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slotOK(); break;
        case 3: _t->slotApply(); break;
        case 4: _t->slotButtonBox((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 5: _t->updateNumbering(); break;
        case 6: _t->change_adaptor(); break;
        case 7: _t->shellescapeChanged(); break;
        case 8: _t->includeonlyClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: _t->setListingsMessage(); break;
        case 10: _t->listingsPackageChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->saveDefaultClicked(); break;
        case 12: _t->useDefaultsClicked(); break;
        case 13: _t->setLSpacing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->setMargins(); break;
        case 15: _t->papersizeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->setColSep(); break;
        case 17: _t->setCustomMargins((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->fontencChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->romanChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->sansChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->ttChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->fontOsfToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->fontScToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->setIndent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->enableIndent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->setSkip((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->enableSkip((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->allowMathIndent(); break;
        case 29: _t->enableMathIndent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->browseLayout(); break;
        case 31: _t->browseMaster(); break;
        case 32: _t->classChanged(); break;
        case 33: _t->classChanged_adaptor(); break;
        case 34: _t->colorlinksCB_adaptor((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 35: _t->languagePackageChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->biblioChanged(); break;
        case 37: _t->rescanBibFiles(); break;
        case 38: _t->resetDefaultBibfile((*reinterpret_cast< const std::string(*)>(_a[1]))); break;
        case 39: _t->resetDefaultBibfile(); break;
        case 40: _t->resetDefaultBbxBibfile(); break;
        case 41: _t->resetDefaultCbxBibfile(); break;
        case 42: _t->citeEngineChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->citeStyleChanged(); break;
        case 44: _t->bibtexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: _t->updateResetDefaultBiblio(); break;
        case 46: _t->matchBiblatexStyles(); break;
        case 47: _t->updateEngineDependends(); break;
        case 48: _t->updateModuleInfo(); break;
        case 49: _t->modulesChanged(); break;
        case 50: _t->changeBackgroundColor(); break;
        case 51: _t->deleteBackgroundColor(); break;
        case 52: _t->changeFontColor(); break;
        case 53: _t->deleteFontColor(); break;
        case 54: _t->changeNoteFontColor(); break;
        case 55: _t->deleteNoteFontColor(); break;
        case 56: _t->changeBoxBackgroundColor(); break;
        case 57: _t->deleteBoxBackgroundColor(); break;
        case 58: _t->languageChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 59: _t->osFontsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 60: _t->encodingSwitched((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 61: _t->inputencodingToDialog(); break;
        case 62: _t->mathFontChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: _t->branchesRename((*reinterpret_cast< const docstring(*)>(_a[1])),(*reinterpret_cast< const docstring(*)>(_a[2]))); break;
        case 64: _t->allPackagesAuto(); break;
        case 65: _t->allPackagesAlways(); break;
        case 66: _t->allPackagesNot(); break;
        case 67: _t->moduleFilterPressed(); break;
        case 68: _t->moduleFilterChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 69: _t->resetModuleFilter(); break;
        case 70: _t->linenoToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 71: _t->outputChangesToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 72: _t->setOutputSync((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 73: _t->bookmarksopenChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 74: _t->changeTrackingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 75: _t->updateMarginLabels((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiDocument::staticMetaObject = {
    { &GuiDialog::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiDocument.data,
      qt_meta_data_lyx__frontend__GuiDocument,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiDocument.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::DocumentUi"))
        return static_cast< Ui::DocumentUi*>(this);
    return GuiDialog::qt_metacast(_clname);
}

int lyx::frontend::GuiDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 76)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 76;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 76)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 76;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__PreambleModule_t {
    QByteArrayData data[6];
    char stringdata0[77];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__PreambleModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__PreambleModule_t qt_meta_stringdata_lyx__frontend__PreambleModule = {
    {
QT_MOC_LITERAL(0, 0, 29), // "lyx::frontend::PreambleModule"
QT_MOC_LITERAL(1, 30, 7), // "changed"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 15), // "checkFindButton"
QT_MOC_LITERAL(4, 55, 8), // "findText"
QT_MOC_LITERAL(5, 64, 12) // "editExternal"

    },
    "lyx::frontend::PreambleModule\0changed\0"
    "\0checkFindButton\0findText\0editExternal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__PreambleModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   35,    2, 0x08 /* Private */,
       4,    0,   36,    2, 0x08 /* Private */,
       5,    0,   37,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::PreambleModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PreambleModule *_t = static_cast<PreambleModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->checkFindButton(); break;
        case 2: _t->findText(); break;
        case 3: _t->editExternal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PreambleModule::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PreambleModule::changed)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::PreambleModule::staticMetaObject = {
    { &UiWidget<Ui::PreambleUi>::staticMetaObject, qt_meta_stringdata_lyx__frontend__PreambleModule.data,
      qt_meta_data_lyx__frontend__PreambleModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::PreambleModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::PreambleModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__PreambleModule.stringdata0))
        return static_cast<void*>(this);
    return UiWidget<Ui::PreambleUi>::qt_metacast(_clname);
}

int lyx::frontend::PreambleModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UiWidget<Ui::PreambleUi>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::PreambleModule::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__LocalLayout_t {
    QByteArrayData data[7];
    char stringdata0[92];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__LocalLayout_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__LocalLayout_t qt_meta_stringdata_lyx__frontend__LocalLayout = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::LocalLayout"
QT_MOC_LITERAL(1, 27, 7), // "changed"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 11), // "textChanged"
QT_MOC_LITERAL(4, 48, 15), // "validatePressed"
QT_MOC_LITERAL(5, 64, 14), // "convertPressed"
QT_MOC_LITERAL(6, 79, 12) // "editExternal"

    },
    "lyx::frontend::LocalLayout\0changed\0\0"
    "textChanged\0validatePressed\0convertPressed\0"
    "editExternal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__LocalLayout[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   40,    2, 0x08 /* Private */,
       4,    0,   41,    2, 0x08 /* Private */,
       5,    0,   42,    2, 0x08 /* Private */,
       6,    0,   43,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::LocalLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LocalLayout *_t = static_cast<LocalLayout *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->textChanged(); break;
        case 2: _t->validatePressed(); break;
        case 3: _t->convertPressed(); break;
        case 4: _t->editExternal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LocalLayout::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LocalLayout::changed)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::LocalLayout::staticMetaObject = {
    { &UiWidget<Ui::LocalLayoutUi>::staticMetaObject, qt_meta_stringdata_lyx__frontend__LocalLayout.data,
      qt_meta_data_lyx__frontend__LocalLayout,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::LocalLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::LocalLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__LocalLayout.stringdata0))
        return static_cast<void*>(this);
    return UiWidget<Ui::LocalLayoutUi>::qt_metacast(_clname);
}

int lyx::frontend::LocalLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UiWidget<Ui::LocalLayoutUi>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::LocalLayout::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__FontModule_t {
    QByteArrayData data[1];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__FontModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__FontModule_t qt_meta_stringdata_lyx__frontend__FontModule = {
    {
QT_MOC_LITERAL(0, 0, 25) // "lyx::frontend::FontModule"

    },
    "lyx::frontend::FontModule"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__FontModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void lyx::frontend::FontModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::FontModule::staticMetaObject = {
    { &UiWidget<Ui::FontUi>::staticMetaObject, qt_meta_stringdata_lyx__frontend__FontModule.data,
      qt_meta_data_lyx__frontend__FontModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::FontModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::FontModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__FontModule.stringdata0))
        return static_cast<void*>(this);
    return UiWidget<Ui::FontUi>::qt_metacast(_clname);
}

int lyx::frontend::FontModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = UiWidget<Ui::FontUi>::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
