/********************************************************************************
** Form generated from reading UI file 'PrefInputUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFINPUTUI_H
#define UI_PREFINPUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefInputUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *keyboardGB;
    QGridLayout *gridLayout;
    QCheckBox *keymapCB;
    QLineEdit *firstKeymapED;
    QPushButton *secondKeymapPB;
    QPushButton *firstKeymapPB;
    QLabel *secondKeymapLA;
    QLabel *firstKeymapLA;
    QCheckBox *dontswapCB;
    QLineEdit *secondKeymapED;
    QGroupBox *mouseGB;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *scrollingSpeedLA;
    QDoubleSpinBox *mouseWheelSpeedSB;
    QSpacerItem *horizontalSpacer;
    QCheckBox *mmPasteCB;
    QGroupBox *scrollzoomGB;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *scrollzoomEnableCB;
    QComboBox *scrollzoomValueCO;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *PrefInputUi)
    {
        if (PrefInputUi->objectName().isEmpty())
            PrefInputUi->setObjectName(QStringLiteral("PrefInputUi"));
        PrefInputUi->resize(417, 420);
        gridLayout_4 = new QGridLayout(PrefInputUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        keyboardGB = new QGroupBox(PrefInputUi);
        keyboardGB->setObjectName(QStringLiteral("keyboardGB"));
        keyboardGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        keyboardGB->setFlat(true);
        gridLayout = new QGridLayout(keyboardGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        keymapCB = new QCheckBox(keyboardGB);
        keymapCB->setObjectName(QStringLiteral("keymapCB"));
        keymapCB->setChecked(false);

        gridLayout->addWidget(keymapCB, 0, 0, 1, 2);

        firstKeymapED = new QLineEdit(keyboardGB);
        firstKeymapED->setObjectName(QStringLiteral("firstKeymapED"));
        firstKeymapED->setEnabled(false);

        gridLayout->addWidget(firstKeymapED, 1, 1, 1, 1);

        secondKeymapPB = new QPushButton(keyboardGB);
        secondKeymapPB->setObjectName(QStringLiteral("secondKeymapPB"));
        secondKeymapPB->setEnabled(false);
        secondKeymapPB->setAutoDefault(false);

        gridLayout->addWidget(secondKeymapPB, 2, 2, 1, 1);

        firstKeymapPB = new QPushButton(keyboardGB);
        firstKeymapPB->setObjectName(QStringLiteral("firstKeymapPB"));
        firstKeymapPB->setEnabled(false);
        firstKeymapPB->setAutoDefault(false);

        gridLayout->addWidget(firstKeymapPB, 1, 2, 1, 1);

        secondKeymapLA = new QLabel(keyboardGB);
        secondKeymapLA->setObjectName(QStringLiteral("secondKeymapLA"));
        secondKeymapLA->setEnabled(false);

        gridLayout->addWidget(secondKeymapLA, 2, 0, 1, 1);

        firstKeymapLA = new QLabel(keyboardGB);
        firstKeymapLA->setObjectName(QStringLiteral("firstKeymapLA"));
        firstKeymapLA->setEnabled(false);

        gridLayout->addWidget(firstKeymapLA, 1, 0, 1, 1);

        dontswapCB = new QCheckBox(keyboardGB);
        dontswapCB->setObjectName(QStringLiteral("dontswapCB"));
        dontswapCB->setChecked(false);

        gridLayout->addWidget(dontswapCB, 3, 0, 1, 3);

        secondKeymapED = new QLineEdit(keyboardGB);
        secondKeymapED->setObjectName(QStringLiteral("secondKeymapED"));
        secondKeymapED->setEnabled(false);

        gridLayout->addWidget(secondKeymapED, 2, 1, 1, 1);


        gridLayout_4->addWidget(keyboardGB, 0, 0, 1, 1);

        mouseGB = new QGroupBox(PrefInputUi);
        mouseGB->setObjectName(QStringLiteral("mouseGB"));
        mouseGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        mouseGB->setFlat(true);
        gridLayout_2 = new QGridLayout(mouseGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        scrollingSpeedLA = new QLabel(mouseGB);
        scrollingSpeedLA->setObjectName(QStringLiteral("scrollingSpeedLA"));

        horizontalLayout->addWidget(scrollingSpeedLA);

        mouseWheelSpeedSB = new QDoubleSpinBox(mouseGB);
        mouseWheelSpeedSB->setObjectName(QStringLiteral("mouseWheelSpeedSB"));
        mouseWheelSpeedSB->setDecimals(1);
        mouseWheelSpeedSB->setMinimum(0.1);
        mouseWheelSpeedSB->setMaximum(10);
        mouseWheelSpeedSB->setSingleStep(0.1);
        mouseWheelSpeedSB->setValue(1.1);

        horizontalLayout->addWidget(mouseWheelSpeedSB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 1);

        mmPasteCB = new QCheckBox(mouseGB);
        mmPasteCB->setObjectName(QStringLiteral("mmPasteCB"));

        gridLayout_2->addWidget(mmPasteCB, 1, 0, 1, 1);


        gridLayout_4->addWidget(mouseGB, 1, 0, 1, 1);

        scrollzoomGB = new QGroupBox(PrefInputUi);
        scrollzoomGB->setObjectName(QStringLiteral("scrollzoomGB"));
        scrollzoomGB->setMinimumSize(QSize(0, 65));
        scrollzoomGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        scrollzoomGB->setFlat(true);
        gridLayout_3 = new QGridLayout(scrollzoomGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        scrollzoomEnableCB = new QCheckBox(scrollzoomGB);
        scrollzoomEnableCB->setObjectName(QStringLiteral("scrollzoomEnableCB"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollzoomEnableCB->sizePolicy().hasHeightForWidth());
        scrollzoomEnableCB->setSizePolicy(sizePolicy);
        scrollzoomEnableCB->setMinimumSize(QSize(86, 0));

        horizontalLayout_2->addWidget(scrollzoomEnableCB);

        scrollzoomValueCO = new QComboBox(scrollzoomGB);
        scrollzoomValueCO->setObjectName(QStringLiteral("scrollzoomValueCO"));
        scrollzoomValueCO->setEnabled(false);
        scrollzoomValueCO->setEditable(false);

        horizontalLayout_2->addWidget(scrollzoomValueCO);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 0, 1, 1);


        gridLayout_4->addWidget(scrollzoomGB, 2, 0, 1, 1);

        spacerItem = new QSpacerItem(0, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        secondKeymapLA->setBuddy(secondKeymapED);
        firstKeymapLA->setBuddy(firstKeymapED);
        scrollingSpeedLA->setBuddy(mouseWheelSpeedSB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(keymapCB, firstKeymapED);
        QWidget::setTabOrder(firstKeymapED, firstKeymapPB);
        QWidget::setTabOrder(firstKeymapPB, secondKeymapED);
        QWidget::setTabOrder(secondKeymapED, secondKeymapPB);
        QWidget::setTabOrder(secondKeymapPB, mouseWheelSpeedSB);

        retranslateUi(PrefInputUi);

        QMetaObject::connectSlotsByName(PrefInputUi);
    } // setupUi

    void retranslateUi(QWidget *PrefInputUi)
    {
        PrefInputUi->setWindowTitle(QString());
        keyboardGB->setTitle(lyx::qt_("Keyboard", Q_NULLPTR));
        keymapCB->setText(lyx::qt_("Use &keyboard map", Q_NULLPTR));
        secondKeymapPB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
        firstKeymapPB->setText(lyx::qt_("Br&owse...", Q_NULLPTR));
        secondKeymapLA->setText(lyx::qt_("S&econdary:", Q_NULLPTR));
        firstKeymapLA->setText(lyx::qt_("&Primary:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        dontswapCB->setToolTip(lyx::qt_("Mac OS X specific setting for use with emacs bindings. Takes effect next time LyX is launched.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        dontswapCB->setText(lyx::qt_("Do not swap Apple and Control keys", Q_NULLPTR));
        mouseGB->setTitle(lyx::qt_("Mouse", Q_NULLPTR));
        scrollingSpeedLA->setText(lyx::qt_("&Wheel scrolling speed:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        mouseWheelSpeedSB->setToolTip(lyx::qt_("1.0 is the standard scrolling speed with the mouse wheel. Higher values will speed it up, low values slow it down.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        mmPasteCB->setToolTip(lyx::qt_("If this is checked, the middle mouse button will paste the recent selection", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        mmPasteCB->setText(lyx::qt_("&Middle mouse button pasting", Q_NULLPTR));
        scrollzoomGB->setTitle(lyx::qt_("Scroll Wheel Zoom", Q_NULLPTR));
        scrollzoomEnableCB->setText(lyx::qt_("&Enable", Q_NULLPTR));
        scrollzoomValueCO->clear();
        scrollzoomValueCO->insertItems(0, QStringList()
         << lyx::qt_("Ctrl", Q_NULLPTR)
         << lyx::qt_("Shift", Q_NULLPTR)
         << lyx::qt_("Alt", Q_NULLPTR)
        );
    } // retranslateUi

};

namespace Ui {
    class PrefInputUi: public Ui_PrefInputUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFINPUTUI_H
