/********************************************************************************
** Form generated from reading UI file 'LanguageUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LANGUAGEUI_H
#define UI_LANGUAGEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LanguageUi
{
public:
    QGridLayout *gridLayout_4;
    QGridLayout *gridLayout_2;
    QLabel *languageL;
    QComboBox *languageCO;
    QLabel *typeL;
    QComboBox *quoteStyleCO;
    QHBoxLayout *horizontalLayout;
    QCheckBox *dynamicQuotesCB;
    QSpacerItem *spacerItem;
    QGroupBox *encodingGB;
    QGridLayout *gridLayout_3;
    QGridLayout *gridLayout;
    QLabel *encodingLA;
    QComboBox *encodingCO;
    QComboBox *unicodeEncodingCO;
    QComboBox *autoEncodingCO;
    QComboBox *customEncodingCO;
    QLabel *encodingVariantLA;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *languagePackageLA;
    QComboBox *languagePackageCO;
    QLineEdit *languagePackageLE;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *LanguageUi)
    {
        if (LanguageUi->objectName().isEmpty())
            LanguageUi->setObjectName(QStringLiteral("LanguageUi"));
        LanguageUi->resize(472, 316);
        gridLayout_4 = new QGridLayout(LanguageUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        languageL = new QLabel(LanguageUi);
        languageL->setObjectName(QStringLiteral("languageL"));

        gridLayout_2->addWidget(languageL, 0, 0, 1, 1);

        languageCO = new QComboBox(LanguageUi);
        languageCO->setObjectName(QStringLiteral("languageCO"));
        languageCO->setMaxVisibleItems(20);

        gridLayout_2->addWidget(languageCO, 0, 1, 1, 1);

        typeL = new QLabel(LanguageUi);
        typeL->setObjectName(QStringLiteral("typeL"));

        gridLayout_2->addWidget(typeL, 1, 0, 1, 1);

        quoteStyleCO = new QComboBox(LanguageUi);
        quoteStyleCO->setObjectName(QStringLiteral("quoteStyleCO"));

        gridLayout_2->addWidget(quoteStyleCO, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));

        gridLayout_2->addLayout(horizontalLayout, 2, 0, 1, 1);

        dynamicQuotesCB = new QCheckBox(LanguageUi);
        dynamicQuotesCB->setObjectName(QStringLiteral("dynamicQuotesCB"));

        gridLayout_2->addWidget(dynamicQuotesCB, 2, 1, 1, 1);


        gridLayout_4->addLayout(gridLayout_2, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(0, 23, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(spacerItem, 0, 1, 1, 1);

        encodingGB = new QGroupBox(LanguageUi);
        encodingGB->setObjectName(QStringLiteral("encodingGB"));
        gridLayout_3 = new QGridLayout(encodingGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        encodingLA = new QLabel(encodingGB);
        encodingLA->setObjectName(QStringLiteral("encodingLA"));

        gridLayout->addWidget(encodingLA, 0, 0, 1, 1);

        encodingCO = new QComboBox(encodingGB);
        encodingCO->setObjectName(QStringLiteral("encodingCO"));
        encodingCO->setEnabled(true);
        encodingCO->setDuplicatesEnabled(false);

        gridLayout->addWidget(encodingCO, 0, 1, 1, 1);

        unicodeEncodingCO = new QComboBox(encodingGB);
        unicodeEncodingCO->setObjectName(QStringLiteral("unicodeEncodingCO"));
        unicodeEncodingCO->setVisible(true);

        gridLayout->addWidget(unicodeEncodingCO, 1, 1, 1, 1);

        autoEncodingCO = new QComboBox(encodingGB);
        autoEncodingCO->setObjectName(QStringLiteral("autoEncodingCO"));
        autoEncodingCO->setEnabled(false);

        gridLayout->addWidget(autoEncodingCO, 1, 1, 1, 1);

        customEncodingCO = new QComboBox(encodingGB);
        customEncodingCO->setObjectName(QStringLiteral("customEncodingCO"));
        customEncodingCO->setVisible(false);

        gridLayout->addWidget(customEncodingCO, 1, 1, 1, 1);

        encodingVariantLA = new QLabel(encodingGB);
        encodingVariantLA->setObjectName(QStringLiteral("encodingVariantLA"));

        gridLayout->addWidget(encodingVariantLA, 1, 0, 1, 1);


        gridLayout_3->addLayout(gridLayout, 0, 0, 1, 1);


        gridLayout_4->addWidget(encodingGB, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 1, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        languagePackageLA = new QLabel(LanguageUi);
        languagePackageLA->setObjectName(QStringLiteral("languagePackageLA"));

        horizontalLayout_2->addWidget(languagePackageLA);

        languagePackageCO = new QComboBox(LanguageUi);
        languagePackageCO->setObjectName(QStringLiteral("languagePackageCO"));

        horizontalLayout_2->addWidget(languagePackageCO);

        languagePackageLE = new QLineEdit(LanguageUi);
        languagePackageLE->setObjectName(QStringLiteral("languagePackageLE"));

        horizontalLayout_2->addWidget(languagePackageLE);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout_4->addLayout(horizontalLayout_2, 2, 0, 1, 2);

        spacerItem1 = new QSpacerItem(71, 171, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem1, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        languageL->setBuddy(languageCO);
        typeL->setBuddy(quoteStyleCO);
        encodingLA->setBuddy(encodingCO);
        encodingVariantLA->setBuddy(autoEncodingCO);
        languagePackageLA->setBuddy(languagePackageCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(languageCO, quoteStyleCO);

        retranslateUi(LanguageUi);

        QMetaObject::connectSlotsByName(LanguageUi);
    } // setupUi

    void retranslateUi(QWidget *LanguageUi)
    {
        LanguageUi->setWindowTitle(QString());
        languageL->setText(lyx::qt_("&Language:", Q_NULLPTR));
        typeL->setText(lyx::qt_("&Quote style:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        quoteStyleCO->setToolTip(lyx::qt_("Select the default quotation marks style", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        dynamicQuotesCB->setToolTip(lyx::qt_("Output quotation marks that automatically adapt to the style selected above. If this is not selected, the quotation marks will stick with the style they have been inserted with.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        dynamicQuotesCB->setText(lyx::qt_("Use d&ynamic quotation marks", Q_NULLPTR));
        encodingGB->setTitle(lyx::qt_("Encoding", Q_NULLPTR));
        encodingLA->setText(lyx::qt_("&Type:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        encodingCO->setToolTip(lyx::qt_("Select encoding of the generated LaTeX source (LaTeX input encoding).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        unicodeEncodingCO->setToolTip(lyx::qt_("Select Unicode encoding variant.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        autoEncodingCO->setToolTip(lyx::qt_("Specify whether to load the 'inputenc' package.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        customEncodingCO->setToolTip(lyx::qt_("Select custom encoding.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        encodingVariantLA->setText(lyx::qt_("&Variant:", Q_NULLPTR));
        languagePackageLA->setText(lyx::qt_("Language pa&ckage:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languagePackageCO->setToolTip(lyx::qt_("Select which language package LyX should use", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        languagePackageLE->setToolTip(lyx::qt_("Enter the command to load the language package (default: \\usepackage{babel})", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class LanguageUi: public Ui_LanguageUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LANGUAGEUI_H
