/********************************************************************************
** Form generated from reading UI file 'FloatPlacementUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FLOATPLACEMENTUI_H
#define UI_FLOATPLACEMENTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_FloatPlacementUi
{
public:
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *floatTypeTitle;
    QComboBox *floatTypeCO;
    QSpacerItem *verticalSpacer;
    QSpacerItem *spacerItem;
    QGroupBox *alignmentGB;
    QGridLayout *_2;
    QRadioButton *alignRightRB;
    QRadioButton *alignDocDefaultRB;
    QRadioButton *alignClassDefaultRB;
    QRadioButton *alignCenterRB;
    QRadioButton *alignLeftRB;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *optionsGB;
    QGridLayout *gridLayout_2;
    QCheckBox *spanCB;
    QCheckBox *sidewaysCB;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *placementLA;
    QComboBox *placementCO;
    QCheckBox *topCB;
    QCheckBox *bottomCB;
    QCheckBox *pageCB;
    QCheckBox *herepossiblyCB;
    QCheckBox *heredefinitelyCB;
    QCheckBox *ignoreCB;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *FloatPlacementUi)
    {
        if (FloatPlacementUi->objectName().isEmpty())
            FloatPlacementUi->setObjectName(QStringLiteral("FloatPlacementUi"));
        FloatPlacementUi->resize(530, 413);
        gridLayout_3 = new QGridLayout(FloatPlacementUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        floatTypeTitle = new QLabel(FloatPlacementUi);
        floatTypeTitle->setObjectName(QStringLiteral("floatTypeTitle"));

        horizontalLayout_2->addWidget(floatTypeTitle);

        floatTypeCO = new QComboBox(FloatPlacementUi);
        floatTypeCO->setObjectName(QStringLiteral("floatTypeCO"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(floatTypeCO->sizePolicy().hasHeightForWidth());
        floatTypeCO->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(floatTypeCO);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 154, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 2, 3, 3, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(spacerItem, 4, 0, 1, 1);

        alignmentGB = new QGroupBox(FloatPlacementUi);
        alignmentGB->setObjectName(QStringLiteral("alignmentGB"));
        alignmentGB->setFlat(true);
        _2 = new QGridLayout(alignmentGB);
        _2->setSpacing(6);
        _2->setObjectName(QStringLiteral("_2"));
        _2->setContentsMargins(9, 9, 9, 9);
        alignRightRB = new QRadioButton(alignmentGB);
        alignRightRB->setObjectName(QStringLiteral("alignRightRB"));

        _2->addWidget(alignRightRB, 4, 0, 1, 1);

        alignDocDefaultRB = new QRadioButton(alignmentGB);
        alignDocDefaultRB->setObjectName(QStringLiteral("alignDocDefaultRB"));

        _2->addWidget(alignDocDefaultRB, 1, 0, 1, 1);

        alignClassDefaultRB = new QRadioButton(alignmentGB);
        alignClassDefaultRB->setObjectName(QStringLiteral("alignClassDefaultRB"));

        _2->addWidget(alignClassDefaultRB, 0, 0, 1, 1);

        alignCenterRB = new QRadioButton(alignmentGB);
        alignCenterRB->setObjectName(QStringLiteral("alignCenterRB"));

        _2->addWidget(alignCenterRB, 3, 0, 1, 1);

        alignLeftRB = new QRadioButton(alignmentGB);
        alignLeftRB->setObjectName(QStringLiteral("alignLeftRB"));

        _2->addWidget(alignLeftRB, 2, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _2->addItem(horizontalSpacer_3, 2, 1, 1, 1);


        gridLayout_3->addWidget(alignmentGB, 1, 3, 1, 1);

        optionsGB = new QGroupBox(FloatPlacementUi);
        optionsGB->setObjectName(QStringLiteral("optionsGB"));
        optionsGB->setFlat(true);
        gridLayout_2 = new QGridLayout(optionsGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        spanCB = new QCheckBox(optionsGB);
        spanCB->setObjectName(QStringLiteral("spanCB"));

        gridLayout_2->addWidget(spanCB, 0, 0, 1, 1);

        sidewaysCB = new QCheckBox(optionsGB);
        sidewaysCB->setObjectName(QStringLiteral("sidewaysCB"));

        gridLayout_2->addWidget(sidewaysCB, 0, 1, 1, 1);


        gridLayout_3->addWidget(optionsGB, 3, 0, 1, 2);

        groupBox = new QGroupBox(FloatPlacementUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        placementLA = new QLabel(groupBox);
        placementLA->setObjectName(QStringLiteral("placementLA"));

        horizontalLayout->addWidget(placementLA);

        placementCO = new QComboBox(groupBox);
        placementCO->setObjectName(QStringLiteral("placementCO"));

        horizontalLayout->addWidget(placementCO);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        topCB = new QCheckBox(groupBox);
        topCB->setObjectName(QStringLiteral("topCB"));

        gridLayout->addWidget(topCB, 1, 0, 1, 1);

        bottomCB = new QCheckBox(groupBox);
        bottomCB->setObjectName(QStringLiteral("bottomCB"));

        gridLayout->addWidget(bottomCB, 2, 0, 1, 1);

        pageCB = new QCheckBox(groupBox);
        pageCB->setObjectName(QStringLiteral("pageCB"));

        gridLayout->addWidget(pageCB, 3, 0, 1, 1);

        herepossiblyCB = new QCheckBox(groupBox);
        herepossiblyCB->setObjectName(QStringLiteral("herepossiblyCB"));

        gridLayout->addWidget(herepossiblyCB, 4, 0, 1, 1);

        heredefinitelyCB = new QCheckBox(groupBox);
        heredefinitelyCB->setObjectName(QStringLiteral("heredefinitelyCB"));

        gridLayout->addWidget(heredefinitelyCB, 5, 0, 1, 1);

        ignoreCB = new QCheckBox(groupBox);
        ignoreCB->setObjectName(QStringLiteral("ignoreCB"));

        gridLayout->addWidget(ignoreCB, 6, 0, 1, 1);


        gridLayout_3->addWidget(groupBox, 1, 0, 2, 2);

        horizontalSpacer = new QSpacerItem(303, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 1, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 1, 4, 1, 1);

#ifndef QT_NO_SHORTCUT
        floatTypeTitle->setBuddy(floatTypeCO);
        placementLA->setBuddy(placementCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(topCB, bottomCB);
        QWidget::setTabOrder(bottomCB, pageCB);
        QWidget::setTabOrder(pageCB, herepossiblyCB);
        QWidget::setTabOrder(herepossiblyCB, heredefinitelyCB);
        QWidget::setTabOrder(heredefinitelyCB, ignoreCB);

        retranslateUi(FloatPlacementUi);

        QMetaObject::connectSlotsByName(FloatPlacementUi);
    } // setupUi

    void retranslateUi(QWidget *FloatPlacementUi)
    {
        FloatPlacementUi->setWindowTitle(lyx::qt_("Form", Q_NULLPTR));
        floatTypeTitle->setText(lyx::qt_("Float T&ype:", Q_NULLPTR));
        alignmentGB->setTitle(lyx::qt_("Alignment of Contents", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignRightRB->setToolTip(lyx::qt_("Right-align float contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignRightRB->setText(lyx::qt_("&Right", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignDocDefaultRB->setToolTip(lyx::qt_("Use the document's default alignment for floats, as specified in Document Settings.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignDocDefaultRB->setText(lyx::qt_("D&ocument Default", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignClassDefaultRB->setToolTip(lyx::qt_("Use the class' default alignment for floats, whatever it is.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignClassDefaultRB->setText(lyx::qt_("Class &Default", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignCenterRB->setToolTip(lyx::qt_("Center float contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignCenterRB->setText(lyx::qt_("&Center", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignLeftRB->setToolTip(lyx::qt_("Left-align float contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignLeftRB->setText(lyx::qt_("&Left", Q_NULLPTR));
        optionsGB->setTitle(lyx::qt_("Further Options", Q_NULLPTR));
        spanCB->setText(lyx::qt_("&Span columns", Q_NULLPTR));
        sidewaysCB->setText(lyx::qt_("Rotate side&ways", Q_NULLPTR));
        groupBox->setTitle(lyx::qt_("Position on Page", Q_NULLPTR));
        placementLA->setText(lyx::qt_("Place&ment Settings:", Q_NULLPTR));
        topCB->setText(lyx::qt_("&Top of page", Q_NULLPTR));
        bottomCB->setText(lyx::qt_("&Bottom of page", Q_NULLPTR));
        pageCB->setText(lyx::qt_("&Page of floats", Q_NULLPTR));
        herepossiblyCB->setText(lyx::qt_("&Here if possible", Q_NULLPTR));
        heredefinitelyCB->setText(lyx::qt_("Here de&finitely", Q_NULLPTR));
        ignoreCB->setText(lyx::qt_("&Ignore LaTeX rules", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class FloatPlacementUi: public Ui_FloatPlacementUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FLOATPLACEMENTUI_H
