/********************************************************************************
** Form generated from reading UI file 'TabularCreateUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABULARCREATEUI_H
#define UI_TABULARCREATEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "EmptyTable.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_TabularCreateUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *rowsL;
    QSpinBox *rowsSB;
    QHBoxLayout *horizontalLayout_2;
    QLabel *columnsL;
    QSpinBox *columnsSB;
    QSpacerItem *horizontalSpacer;
    EmptyTable *table;
    QHBoxLayout *horizontalLayout_4;
    QLabel *styleLA;
    QComboBox *styleCO;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TabularCreateUi)
    {
        if (TabularCreateUi->objectName().isEmpty())
            TabularCreateUi->setObjectName(QStringLiteral("TabularCreateUi"));
        TabularCreateUi->resize(374, 339);
        TabularCreateUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(TabularCreateUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        rowsL = new QLabel(TabularCreateUi);
        rowsL->setObjectName(QStringLiteral("rowsL"));

        horizontalLayout->addWidget(rowsL);

        rowsSB = new QSpinBox(TabularCreateUi);
        rowsSB->setObjectName(QStringLiteral("rowsSB"));
        rowsSB->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        rowsSB->setMinimum(1);
        rowsSB->setMaximum(511);

        horizontalLayout->addWidget(rowsSB);


        horizontalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        columnsL = new QLabel(TabularCreateUi);
        columnsL->setObjectName(QStringLiteral("columnsL"));

        horizontalLayout_2->addWidget(columnsL);

        columnsSB = new QSpinBox(TabularCreateUi);
        columnsSB->setObjectName(QStringLiteral("columnsSB"));
        columnsSB->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        columnsSB->setMinimum(1);
        columnsSB->setMaximum(511);

        horizontalLayout_2->addWidget(columnsSB);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        horizontalLayout_3->addLayout(horizontalLayout_2);


        gridLayout->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        table = new EmptyTable(TabularCreateUi);
        table->setObjectName(QStringLiteral("table"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(table->sizePolicy().hasHeightForWidth());
        table->setSizePolicy(sizePolicy);

        gridLayout->addWidget(table, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        styleLA = new QLabel(TabularCreateUi);
        styleLA->setObjectName(QStringLiteral("styleLA"));

        horizontalLayout_4->addWidget(styleLA);

        styleCO = new QComboBox(TabularCreateUi);
        styleCO->setObjectName(QStringLiteral("styleCO"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(styleCO->sizePolicy().hasHeightForWidth());
        styleCO->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(styleCO);


        gridLayout->addLayout(horizontalLayout_4, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(TabularCreateUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        rowsL->setBuddy(rowsSB);
        columnsL->setBuddy(columnsSB);
        styleLA->setBuddy(styleCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(rowsSB, columnsSB);

        retranslateUi(TabularCreateUi);

        QMetaObject::connectSlotsByName(TabularCreateUi);
    } // setupUi

    void retranslateUi(QDialog *TabularCreateUi)
    {
        TabularCreateUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        rowsL->setToolTip(lyx::qt_("Number of rows", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rowsL->setText(lyx::qt_("&Rows:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rowsSB->setToolTip(lyx::qt_("Number of rows", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        columnsL->setToolTip(lyx::qt_("Number of columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        columnsL->setText(lyx::qt_("&Columns:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        columnsSB->setToolTip(lyx::qt_("Number of columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        table->setToolTip(lyx::qt_("Resize this to the correct table dimensions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        styleLA->setText(lyx::qt_("&Style:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TabularCreateUi: public Ui_TabularCreateUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABULARCREATEUI_H
