/****************************************************************************
** Meta object code from reading C++ file 'GuiWorkArea.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiWorkArea.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiWorkArea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiWorkArea_t {
    QByteArrayData data[22];
    char stringdata0[263];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiWorkArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiWorkArea_t qt_meta_stringdata_lyx__frontend__GuiWorkArea = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiWorkArea"
QT_MOC_LITERAL(1, 27, 12), // "titleChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 12), // "GuiWorkArea*"
QT_MOC_LITERAL(4, 54, 4), // "busy"
QT_MOC_LITERAL(5, 59, 17), // "bufferViewChanged"
QT_MOC_LITERAL(6, 77, 14), // "compressKeySym"
QT_MOC_LITERAL(7, 92, 9), // "KeySymbol"
QT_MOC_LITERAL(8, 102, 3), // "sym"
QT_MOC_LITERAL(9, 106, 11), // "KeyModifier"
QT_MOC_LITERAL(10, 118, 3), // "mod"
QT_MOC_LITERAL(11, 122, 12), // "isAutoRepeat"
QT_MOC_LITERAL(12, 135, 13), // "processKeySym"
QT_MOC_LITERAL(13, 149, 3), // "key"
QT_MOC_LITERAL(14, 153, 17), // "stopBlinkingCaret"
QT_MOC_LITERAL(15, 171, 18), // "startBlinkingCaret"
QT_MOC_LITERAL(16, 190, 8), // "scrollTo"
QT_MOC_LITERAL(17, 199, 5), // "value"
QT_MOC_LITERAL(18, 205, 18), // "doubleClickTimeout"
QT_MOC_LITERAL(19, 224, 11), // "toggleCaret"
QT_MOC_LITERAL(20, 236, 5), // "close"
QT_MOC_LITERAL(21, 242, 20) // "fixVerticalScrollBar"

    },
    "lyx::frontend::GuiWorkArea\0titleChanged\0"
    "\0GuiWorkArea*\0busy\0bufferViewChanged\0"
    "compressKeySym\0KeySymbol\0sym\0KeyModifier\0"
    "mod\0isAutoRepeat\0processKeySym\0key\0"
    "stopBlinkingCaret\0startBlinkingCaret\0"
    "scrollTo\0value\0doubleClickTimeout\0"
    "toggleCaret\0close\0fixVerticalScrollBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiWorkArea[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    1,   77,    2, 0x06 /* Public */,
       5,    0,   80,    2, 0x06 /* Public */,
       6,    3,   81,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    2,   88,    2, 0x0a /* Public */,
      14,    0,   93,    2, 0x0a /* Public */,
      15,    0,   94,    2, 0x0a /* Public */,
      16,    1,   95,    2, 0x08 /* Private */,
      18,    0,   98,    2, 0x08 /* Private */,
      19,    0,   99,    2, 0x08 /* Private */,
      20,    0,  100,    2, 0x08 /* Private */,
      21,    0,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9, QMetaType::Bool,    8,   10,   11,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9,   13,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiWorkArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiWorkArea *_t = static_cast<GuiWorkArea *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast< GuiWorkArea*(*)>(_a[1]))); break;
        case 1: _t->busy((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->bufferViewChanged(); break;
        case 3: _t->compressKeySym((*reinterpret_cast< KeySymbol(*)>(_a[1])),(*reinterpret_cast< KeyModifier(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->processKeySym((*reinterpret_cast< const KeySymbol(*)>(_a[1])),(*reinterpret_cast< KeyModifier(*)>(_a[2]))); break;
        case 5: _t->stopBlinkingCaret(); break;
        case 6: _t->startBlinkingCaret(); break;
        case 7: _t->scrollTo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->doubleClickTimeout(); break;
        case 9: _t->toggleCaret(); break;
        case 10: _t->close(); break;
        case 11: _t->fixVerticalScrollBar(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< GuiWorkArea* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiWorkArea::*_t)(GuiWorkArea * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiWorkArea::titleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiWorkArea::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiWorkArea::busy)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiWorkArea::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiWorkArea::bufferViewChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GuiWorkArea::*_t)(KeySymbol , KeyModifier , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiWorkArea::compressKeySym)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiWorkArea::staticMetaObject = {
    { &QAbstractScrollArea::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiWorkArea.data,
      qt_meta_data_lyx__frontend__GuiWorkArea,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiWorkArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiWorkArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiWorkArea.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "WorkArea"))
        return static_cast< WorkArea*>(this);
    return QAbstractScrollArea::qt_metacast(_clname);
}

int lyx::frontend::GuiWorkArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiWorkArea::titleChanged(GuiWorkArea * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void lyx::frontend::GuiWorkArea::busy(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void lyx::frontend::GuiWorkArea::bufferViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void lyx::frontend::GuiWorkArea::compressKeySym(KeySymbol _t1, KeyModifier _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
struct qt_meta_stringdata_lyx__frontend__CompressorProxy_t {
    QByteArrayData data[9];
    char stringdata0[87];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__CompressorProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__CompressorProxy_t qt_meta_stringdata_lyx__frontend__CompressorProxy = {
    {
QT_MOC_LITERAL(0, 0, 30), // "lyx::frontend::CompressorProxy"
QT_MOC_LITERAL(1, 31, 6), // "signal"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 9), // "KeySymbol"
QT_MOC_LITERAL(4, 49, 3), // "sym"
QT_MOC_LITERAL(5, 53, 11), // "KeyModifier"
QT_MOC_LITERAL(6, 65, 3), // "mod"
QT_MOC_LITERAL(7, 69, 4), // "slot"
QT_MOC_LITERAL(8, 74, 12) // "isAutoRepeat"

    },
    "lyx::frontend::CompressorProxy\0signal\0"
    "\0KeySymbol\0sym\0KeyModifier\0mod\0slot\0"
    "isAutoRepeat"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__CompressorProxy[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x04 /* Private */,

 // slots: name, argc, parameters, tag, flags
       7,    3,   29,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::Bool,    4,    6,    8,

       0        // eod
};

void lyx::frontend::CompressorProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CompressorProxy *_t = static_cast<CompressorProxy *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signal((*reinterpret_cast< KeySymbol(*)>(_a[1])),(*reinterpret_cast< KeyModifier(*)>(_a[2]))); break;
        case 1: _t->slot((*reinterpret_cast< KeySymbol(*)>(_a[1])),(*reinterpret_cast< KeyModifier(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (CompressorProxy::*_t)(KeySymbol , KeyModifier );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CompressorProxy::signal)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::CompressorProxy::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_lyx__frontend__CompressorProxy.data,
      qt_meta_data_lyx__frontend__CompressorProxy,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::CompressorProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::CompressorProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__CompressorProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int lyx::frontend::CompressorProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::CompressorProxy::signal(KeySymbol _t1, KeyModifier _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea_t {
    QByteArrayData data[1];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea_t qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea = {
    {
QT_MOC_LITERAL(0, 0, 31) // "lyx::frontend::EmbeddedWorkArea"

    },
    "lyx::frontend::EmbeddedWorkArea"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__EmbeddedWorkArea[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void lyx::frontend::EmbeddedWorkArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::EmbeddedWorkArea::staticMetaObject = {
    { &GuiWorkArea::staticMetaObject, qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea.data,
      qt_meta_data_lyx__frontend__EmbeddedWorkArea,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::EmbeddedWorkArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::EmbeddedWorkArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__EmbeddedWorkArea.stringdata0))
        return static_cast<void*>(this);
    return GuiWorkArea::qt_metacast(_clname);
}

int lyx::frontend::EmbeddedWorkArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiWorkArea::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__TabWorkArea_t {
    QByteArrayData data[31];
    char stringdata0[441];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__TabWorkArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__TabWorkArea_t qt_meta_stringdata_lyx__frontend__TabWorkArea = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::TabWorkArea"
QT_MOC_LITERAL(1, 27, 22), // "currentWorkAreaChanged"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 12), // "GuiWorkArea*"
QT_MOC_LITERAL(4, 64, 19), // "lastWorkAreaRemoved"
QT_MOC_LITERAL(5, 84, 18), // "closeCurrentBuffer"
QT_MOC_LITERAL(6, 103, 14), // "hideCurrentTab"
QT_MOC_LITERAL(7, 118, 16), // "closeTabsToRight"
QT_MOC_LITERAL(8, 135, 15), // "closeTabsToLeft"
QT_MOC_LITERAL(9, 151, 14), // "closeOtherTabs"
QT_MOC_LITERAL(10, 166, 21), // "moveToStartCurrentTab"
QT_MOC_LITERAL(11, 188, 19), // "moveToEndCurrentTab"
QT_MOC_LITERAL(12, 208, 22), // "openEnclosingDirectory"
QT_MOC_LITERAL(13, 231, 8), // "closeTab"
QT_MOC_LITERAL(14, 240, 5), // "index"
QT_MOC_LITERAL(15, 246, 7), // "moveTab"
QT_MOC_LITERAL(16, 254, 9), // "fromIndex"
QT_MOC_LITERAL(17, 264, 7), // "toIndex"
QT_MOC_LITERAL(18, 272, 14), // "updateTabTexts"
QT_MOC_LITERAL(19, 287, 20), // "on_currentTabChanged"
QT_MOC_LITERAL(20, 308, 16), // "on_tabBarClicked"
QT_MOC_LITERAL(21, 325, 15), // "showContextMenu"
QT_MOC_LITERAL(22, 341, 3), // "pos"
QT_MOC_LITERAL(23, 345, 15), // "mousePressEvent"
QT_MOC_LITERAL(24, 361, 12), // "QMouseEvent*"
QT_MOC_LITERAL(25, 374, 2), // "me"
QT_MOC_LITERAL(26, 377, 17), // "mouseReleaseEvent"
QT_MOC_LITERAL(27, 395, 21), // "mouseDoubleClickEvent"
QT_MOC_LITERAL(28, 417, 5), // "event"
QT_MOC_LITERAL(29, 423, 15), // "indexOfWorkArea"
QT_MOC_LITERAL(30, 439, 1) // "w"

    },
    "lyx::frontend::TabWorkArea\0"
    "currentWorkAreaChanged\0\0GuiWorkArea*\0"
    "lastWorkAreaRemoved\0closeCurrentBuffer\0"
    "hideCurrentTab\0closeTabsToRight\0"
    "closeTabsToLeft\0closeOtherTabs\0"
    "moveToStartCurrentTab\0moveToEndCurrentTab\0"
    "openEnclosingDirectory\0closeTab\0index\0"
    "moveTab\0fromIndex\0toIndex\0updateTabTexts\0"
    "on_currentTabChanged\0on_tabBarClicked\0"
    "showContextMenu\0pos\0mousePressEvent\0"
    "QMouseEvent*\0me\0mouseReleaseEvent\0"
    "mouseDoubleClickEvent\0event\0indexOfWorkArea\0"
    "w"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__TabWorkArea[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       4,    0,  117,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,  118,    2, 0x0a /* Public */,
       6,    0,  119,    2, 0x0a /* Public */,
       7,    0,  120,    2, 0x0a /* Public */,
       8,    0,  121,    2, 0x0a /* Public */,
       9,    0,  122,    2, 0x0a /* Public */,
      10,    0,  123,    2, 0x0a /* Public */,
      11,    0,  124,    2, 0x0a /* Public */,
      12,    0,  125,    2, 0x0a /* Public */,
      13,    1,  126,    2, 0x0a /* Public */,
      15,    2,  129,    2, 0x0a /* Public */,
      18,    0,  134,    2, 0x0a /* Public */,
      19,    1,  135,    2, 0x08 /* Private */,
      20,    1,  138,    2, 0x08 /* Private */,
      21,    1,  141,    2, 0x08 /* Private */,
      23,    1,  144,    2, 0x08 /* Private */,
      26,    1,  147,    2, 0x08 /* Private */,
      27,    1,  150,    2, 0x08 /* Private */,
      29,    1,  153,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   16,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QPoint,   22,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 24,   28,
    QMetaType::Int, 0x80000000 | 3,   30,

       0        // eod
};

void lyx::frontend::TabWorkArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabWorkArea *_t = static_cast<TabWorkArea *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->currentWorkAreaChanged((*reinterpret_cast< GuiWorkArea*(*)>(_a[1]))); break;
        case 1: _t->lastWorkAreaRemoved(); break;
        case 2: _t->closeCurrentBuffer(); break;
        case 3: _t->hideCurrentTab(); break;
        case 4: { bool _r = _t->closeTabsToRight();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->closeTabsToLeft();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->closeOtherTabs(); break;
        case 7: _t->moveToStartCurrentTab(); break;
        case 8: _t->moveToEndCurrentTab(); break;
        case 9: { bool _r = _t->openEnclosingDirectory();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->closeTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->moveTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 12: _t->updateTabTexts(); break;
        case 13: _t->on_currentTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->on_tabBarClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->showContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 16: _t->mousePressEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 17: _t->mouseReleaseEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 18: _t->mouseDoubleClickEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 19: { int _r = _t->indexOfWorkArea((*reinterpret_cast< GuiWorkArea*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< GuiWorkArea* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< GuiWorkArea* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TabWorkArea::*_t)(GuiWorkArea * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TabWorkArea::currentWorkAreaChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TabWorkArea::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TabWorkArea::lastWorkAreaRemoved)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::TabWorkArea::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__TabWorkArea.data,
      qt_meta_data_lyx__frontend__TabWorkArea,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::TabWorkArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::TabWorkArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__TabWorkArea.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int lyx::frontend::TabWorkArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::TabWorkArea::currentWorkAreaChanged(GuiWorkArea * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void lyx::frontend::TabWorkArea::lastWorkAreaRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer_t {
    QByteArrayData data[5];
    char stringdata0[65];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer_t qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer = {
    {
QT_MOC_LITERAL(0, 0, 35), // "lyx::frontend::GuiWorkAreaCon..."
QT_MOC_LITERAL(1, 36, 13), // "updateDisplay"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 6), // "reload"
QT_MOC_LITERAL(4, 58, 6) // "ignore"

    },
    "lyx::frontend::GuiWorkAreaContainer\0"
    "updateDisplay\0\0reload\0ignore"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiWorkAreaContainer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x08 /* Private */,
       3,    0,   30,    2, 0x08 /* Private */,
       4,    0,   31,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiWorkAreaContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiWorkAreaContainer *_t = static_cast<GuiWorkAreaContainer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateDisplay(); break;
        case 1: _t->reload(); break;
        case 2: _t->ignore(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::GuiWorkAreaContainer::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer.data,
      qt_meta_data_lyx__frontend__GuiWorkAreaContainer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiWorkAreaContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiWorkAreaContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiWorkAreaContainer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WorkAreaUi"))
        return static_cast< Ui::WorkAreaUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::GuiWorkAreaContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
