/********************************************************************************
** Form generated from reading UI file 'PrefDocHandlingUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFDOCHANDLINGUI_H
#define UI_PREFDOCHANDLINGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefDocHandlingUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *GeometryGB;
    QGridLayout *gridLayout_3;
    QCheckBox *allowGeometrySessionCB;
    QCheckBox *restoreCursorCB;
    QCheckBox *loadSessionCB;
    QPushButton *clearSessionPB;
    QSpacerItem *horizontalSpacer;
    QGroupBox *documentsGB;
    QGridLayout *gridLayout_2;
    QCheckBox *backupCB;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *autoSaveCB;
    QSpinBox *autoSaveSB;
    QLabel *TextLabel1;
    QSpacerItem *spacerItem;
    QCheckBox *saveCompressedCB;
    QCheckBox *saveOriginCB;
    QGroupBox *tabsGB;
    QGridLayout *gridLayout;
    QCheckBox *openDocumentsInTabsCB;
    QCheckBox *singleInstanceCB;
    QCheckBox *singleCloseTabButtonCB;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *closeLastViewCO;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *PrefDocHandlingUi)
    {
        if (PrefDocHandlingUi->objectName().isEmpty())
            PrefDocHandlingUi->setObjectName(QStringLiteral("PrefDocHandlingUi"));
        PrefDocHandlingUi->resize(853, 575);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefDocHandlingUi->sizePolicy().hasHeightForWidth());
        PrefDocHandlingUi->setSizePolicy(sizePolicy);
        gridLayout_4 = new QGridLayout(PrefDocHandlingUi);
        gridLayout_4->setSpacing(4);
        gridLayout_4->setContentsMargins(9, 9, 9, 9);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        GeometryGB = new QGroupBox(PrefDocHandlingUi);
        GeometryGB->setObjectName(QStringLiteral("GeometryGB"));
        GeometryGB->setFlat(true);
        gridLayout_3 = new QGridLayout(GeometryGB);
        gridLayout_3->setSpacing(4);
        gridLayout_3->setContentsMargins(9, 9, 9, 9);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        allowGeometrySessionCB = new QCheckBox(GeometryGB);
        allowGeometrySessionCB->setObjectName(QStringLiteral("allowGeometrySessionCB"));
        allowGeometrySessionCB->setEnabled(true);

        gridLayout_3->addWidget(allowGeometrySessionCB, 0, 0, 1, 1);

        restoreCursorCB = new QCheckBox(GeometryGB);
        restoreCursorCB->setObjectName(QStringLiteral("restoreCursorCB"));

        gridLayout_3->addWidget(restoreCursorCB, 1, 0, 1, 1);

        loadSessionCB = new QCheckBox(GeometryGB);
        loadSessionCB->setObjectName(QStringLiteral("loadSessionCB"));

        gridLayout_3->addWidget(loadSessionCB, 2, 0, 1, 1);

        clearSessionPB = new QPushButton(GeometryGB);
        clearSessionPB->setObjectName(QStringLiteral("clearSessionPB"));

        gridLayout_3->addWidget(clearSessionPB, 3, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(225, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 3, 1, 1, 1);


        gridLayout_4->addWidget(GeometryGB, 0, 0, 1, 1);

        documentsGB = new QGroupBox(PrefDocHandlingUi);
        documentsGB->setObjectName(QStringLiteral("documentsGB"));
        documentsGB->setFlat(true);
        gridLayout_2 = new QGridLayout(documentsGB);
        gridLayout_2->setSpacing(4);
        gridLayout_2->setContentsMargins(9, 9, 9, 9);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        backupCB = new QCheckBox(documentsGB);
        backupCB->setObjectName(QStringLiteral("backupCB"));

        gridLayout_2->addWidget(backupCB, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(4);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        autoSaveCB = new QCheckBox(documentsGB);
        autoSaveCB->setObjectName(QStringLiteral("autoSaveCB"));

        horizontalLayout_2->addWidget(autoSaveCB);

        autoSaveSB = new QSpinBox(documentsGB);
        autoSaveSB->setObjectName(QStringLiteral("autoSaveSB"));
        autoSaveSB->setMinimum(1);
        autoSaveSB->setMaximum(300);

        horizontalLayout_2->addWidget(autoSaveSB);

        TextLabel1 = new QLabel(documentsGB);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));

        horizontalLayout_2->addWidget(TextLabel1);

        spacerItem = new QSpacerItem(61, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacerItem);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 0, 1, 1);

        saveCompressedCB = new QCheckBox(documentsGB);
        saveCompressedCB->setObjectName(QStringLiteral("saveCompressedCB"));

        gridLayout_2->addWidget(saveCompressedCB, 2, 0, 1, 1);

        saveOriginCB = new QCheckBox(documentsGB);
        saveOriginCB->setObjectName(QStringLiteral("saveOriginCB"));

        gridLayout_2->addWidget(saveOriginCB, 3, 0, 1, 1);


        gridLayout_4->addWidget(documentsGB, 1, 0, 1, 1);

        tabsGB = new QGroupBox(PrefDocHandlingUi);
        tabsGB->setObjectName(QStringLiteral("tabsGB"));
        tabsGB->setFlat(true);
        gridLayout = new QGridLayout(tabsGB);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        openDocumentsInTabsCB = new QCheckBox(tabsGB);
        openDocumentsInTabsCB->setObjectName(QStringLiteral("openDocumentsInTabsCB"));

        gridLayout->addWidget(openDocumentsInTabsCB, 0, 0, 1, 1);

        singleInstanceCB = new QCheckBox(tabsGB);
        singleInstanceCB->setObjectName(QStringLiteral("singleInstanceCB"));

        gridLayout->addWidget(singleInstanceCB, 1, 0, 1, 1);

        singleCloseTabButtonCB = new QCheckBox(tabsGB);
        singleCloseTabButtonCB->setObjectName(QStringLiteral("singleCloseTabButtonCB"));

        gridLayout->addWidget(singleCloseTabButtonCB, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(4);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(tabsGB);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        closeLastViewCO = new QComboBox(tabsGB);
        closeLastViewCO->setObjectName(QStringLiteral("closeLastViewCO"));

        horizontalLayout->addWidget(closeLastViewCO);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);


        gridLayout_4->addWidget(tabsGB, 2, 0, 1, 1);

        spacerItem1 = new QSpacerItem(395, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem1, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        TextLabel1->setBuddy(autoSaveSB);
        label->setBuddy(closeLastViewCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(restoreCursorCB, loadSessionCB);
        QWidget::setTabOrder(loadSessionCB, clearSessionPB);
        QWidget::setTabOrder(clearSessionPB, backupCB);
        QWidget::setTabOrder(backupCB, autoSaveCB);
        QWidget::setTabOrder(autoSaveCB, autoSaveSB);
        QWidget::setTabOrder(autoSaveSB, saveCompressedCB);
        QWidget::setTabOrder(saveCompressedCB, saveOriginCB);

        retranslateUi(PrefDocHandlingUi);

        QMetaObject::connectSlotsByName(PrefDocHandlingUi);
    } // setupUi

    void retranslateUi(QWidget *PrefDocHandlingUi)
    {
        PrefDocHandlingUi->setWindowTitle(QString());
        GeometryGB->setTitle(lyx::qt_("Session Handling", Q_NULLPTR));
        allowGeometrySessionCB->setText(lyx::qt_("Restore window layouts and &geometries", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        restoreCursorCB->setToolTip(lyx::qt_("Restore to the cursor position when the file was last closed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        restoreCursorCB->setText(lyx::qt_("Restore cursor &positions", Q_NULLPTR));
        loadSessionCB->setText(lyx::qt_("&Load opened files from last session", Q_NULLPTR));
        clearSessionPB->setText(lyx::qt_("&Clear all session information", Q_NULLPTR));
        documentsGB->setTitle(lyx::qt_("Backup && Saving", Q_NULLPTR));
        backupCB->setText(lyx::qt_("Backup &original documents when saving", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        autoSaveCB->setToolTip(lyx::qt_("If this is checked, LyX saves a temporary copy of changed documents in the given interval (as #filename.lyx# in the given directory). As opposed to the backup above, this snapshot will be removed when changes are being saved. If the application crashes with unsaved changes and the restoration from the emergency file (named filename.lyx.emergency) fails, this snapshot can be at rescue.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        autoSaveCB->setText(lyx::qt_("Make a&uto-save snapshots every[[ N minutes]]", Q_NULLPTR));
        TextLabel1->setText(lyx::qt_("[[Make auto-save snapshots every N ]]&minutes", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        saveCompressedCB->setToolTip(lyx::qt_("If this is checked, new documents will be saved in a compressed binary-format by default. Existing documents will still be saved in their current state (compressed or uncompressed).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        saveCompressedCB->setText(lyx::qt_("&Save new documents compressed by default", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        saveOriginCB->setToolTip(lyx::qt_("If this is checked, the document directory path will be saved in the document. This allows moving the document elsewhere and still finding the included files.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        saveOriginCB->setText(lyx::qt_("Save the &document directory path", Q_NULLPTR));
        tabsGB->setTitle(lyx::qt_("Windows && Work Area", Q_NULLPTR));
        openDocumentsInTabsCB->setText(lyx::qt_("Open documents in &tabs", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        singleInstanceCB->setToolTip(lyx::qt_("Whether to open documents in an already running instance of LyX. (Set the LyXServer pipe path and restart LyX to enable this feature)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        singleInstanceCB->setText(lyx::qt_("Use s&ingle instance", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        singleCloseTabButtonCB->setToolTip(lyx::qt_("Whether to place close button on each tab or only one in the top right.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        singleCloseTabButtonCB->setText(lyx::qt_("Displa&y single close-tab button", Q_NULLPTR));
        label->setText(lyx::qt_("Closing last &view:", Q_NULLPTR));
        closeLastViewCO->clear();
        closeLastViewCO->insertItems(0, QStringList()
         << lyx::qt_("Closes document", Q_NULLPTR)
         << lyx::qt_("Hides document", Q_NULLPTR)
         << lyx::qt_("Ask the user", Q_NULLPTR)
        );
    } // retranslateUi

};

namespace Ui {
    class PrefDocHandlingUi: public Ui_PrefDocHandlingUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFDOCHANDLINGUI_H
