/****************************************************************************
** Meta object code from reading C++ file 'GuiCommandBuffer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiCommandBuffer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiCommandBuffer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiCommandBuffer_t {
    QByteArrayData data[10];
    char stringdata0[114];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiCommandBuffer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiCommandBuffer_t qt_meta_stringdata_lyx__frontend__GuiCommandBuffer = {
    {
QT_MOC_LITERAL(0, 0, 31), // "lyx::frontend::GuiCommandBuffer"
QT_MOC_LITERAL(1, 32, 8), // "dispatch"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 8), // "complete"
QT_MOC_LITERAL(4, 51, 13), // "listHistoryUp"
QT_MOC_LITERAL(5, 65, 12), // "itemSelected"
QT_MOC_LITERAL(6, 78, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(7, 95, 2), // "up"
QT_MOC_LITERAL(8, 98, 4), // "down"
QT_MOC_LITERAL(9, 103, 10) // "hideParent"

    },
    "lyx::frontend::GuiCommandBuffer\0"
    "dispatch\0\0complete\0listHistoryUp\0"
    "itemSelected\0QListWidgetItem*\0up\0down\0"
    "hideParent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiCommandBuffer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    0,   50,    2, 0x0a /* Public */,
       4,    0,   51,    2, 0x0a /* Public */,
       5,    1,   52,    2, 0x0a /* Public */,
       7,    0,   55,    2, 0x0a /* Public */,
       8,    0,   56,    2, 0x0a /* Public */,
       9,    0,   57,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiCommandBuffer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiCommandBuffer *_t = static_cast<GuiCommandBuffer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dispatch(); break;
        case 1: _t->complete(); break;
        case 2: _t->listHistoryUp(); break;
        case 3: _t->itemSelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 4: _t->up(); break;
        case 5: _t->down(); break;
        case 6: _t->hideParent(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiCommandBuffer::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiCommandBuffer.data,
      qt_meta_data_lyx__frontend__GuiCommandBuffer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiCommandBuffer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiCommandBuffer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiCommandBuffer.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::GuiCommandBuffer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
