/********************************************************************************
** Form generated from reading UI file 'PrefPathsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFPATHSUI_H
#define UI_PREFPATHSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefPathsUi
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *pathPrefixLA;
    QLineEdit *pathPrefixED;
    QLabel *texinputsPrefixLA;
    QLineEdit *texinputsPrefixED;
    QPushButton *thesaurusDirPB;
    QLabel *thesaurusDirLA;
    QLineEdit *thesaurusDirED;
    QPushButton *tempDirPB;
    QLineEdit *tempDirED;
    QLabel *tempDirLA;
    QPushButton *lyxserverDirPB;
    QLineEdit *lyxserverDirED;
    QLabel *lyxserverDirLA;
    QPushButton *backupDirPB;
    QLineEdit *backupDirED;
    QLabel *backupDirLA;
    QPushButton *exampleDirPB;
    QLineEdit *exampleDirED;
    QLabel *exampleDirLA;
    QPushButton *templateDirPB;
    QLineEdit *templateDirED;
    QLabel *templateDirLA;
    QPushButton *workingDirPB;
    QLineEdit *workingDirED;
    QLabel *workingDirLA;
    QLabel *hunspellDirLA;
    QLineEdit *hunspellDirED;
    QPushButton *hunspellDirPB;

    void setupUi(QWidget *PrefPathsUi)
    {
        if (PrefPathsUi->objectName().isEmpty())
            PrefPathsUi->setObjectName(QStringLiteral("PrefPathsUi"));
        PrefPathsUi->resize(347, 467);
        gridLayout = new QGridLayout(PrefPathsUi);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(PrefPathsUi);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        gridLayout->addWidget(label, 12, 0, 1, 3);

        pathPrefixLA = new QLabel(PrefPathsUi);
        pathPrefixLA->setObjectName(QStringLiteral("pathPrefixLA"));

        gridLayout->addWidget(pathPrefixLA, 10, 0, 1, 1);

        pathPrefixED = new QLineEdit(PrefPathsUi);
        pathPrefixED->setObjectName(QStringLiteral("pathPrefixED"));

        gridLayout->addWidget(pathPrefixED, 10, 1, 1, 2);

        texinputsPrefixLA = new QLabel(PrefPathsUi);
        texinputsPrefixLA->setObjectName(QStringLiteral("texinputsPrefixLA"));

        gridLayout->addWidget(texinputsPrefixLA, 11, 0, 1, 1);

        texinputsPrefixED = new QLineEdit(PrefPathsUi);
        texinputsPrefixED->setObjectName(QStringLiteral("texinputsPrefixED"));

        gridLayout->addWidget(texinputsPrefixED, 11, 1, 1, 2);

        thesaurusDirPB = new QPushButton(PrefPathsUi);
        thesaurusDirPB->setObjectName(QStringLiteral("thesaurusDirPB"));
        thesaurusDirPB->setAutoDefault(false);

        gridLayout->addWidget(thesaurusDirPB, 6, 2, 1, 1);

        thesaurusDirLA = new QLabel(PrefPathsUi);
        thesaurusDirLA->setObjectName(QStringLiteral("thesaurusDirLA"));

        gridLayout->addWidget(thesaurusDirLA, 6, 0, 1, 1);

        thesaurusDirED = new QLineEdit(PrefPathsUi);
        thesaurusDirED->setObjectName(QStringLiteral("thesaurusDirED"));

        gridLayout->addWidget(thesaurusDirED, 6, 1, 1, 1);

        tempDirPB = new QPushButton(PrefPathsUi);
        tempDirPB->setObjectName(QStringLiteral("tempDirPB"));
        tempDirPB->setAutoDefault(false);

        gridLayout->addWidget(tempDirPB, 5, 2, 1, 1);

        tempDirED = new QLineEdit(PrefPathsUi);
        tempDirED->setObjectName(QStringLiteral("tempDirED"));

        gridLayout->addWidget(tempDirED, 5, 1, 1, 1);

        tempDirLA = new QLabel(PrefPathsUi);
        tempDirLA->setObjectName(QStringLiteral("tempDirLA"));

        gridLayout->addWidget(tempDirLA, 5, 0, 1, 1);

        lyxserverDirPB = new QPushButton(PrefPathsUi);
        lyxserverDirPB->setObjectName(QStringLiteral("lyxserverDirPB"));
        lyxserverDirPB->setAutoDefault(false);

        gridLayout->addWidget(lyxserverDirPB, 4, 2, 1, 1);

        lyxserverDirED = new QLineEdit(PrefPathsUi);
        lyxserverDirED->setObjectName(QStringLiteral("lyxserverDirED"));

        gridLayout->addWidget(lyxserverDirED, 4, 1, 1, 1);

        lyxserverDirLA = new QLabel(PrefPathsUi);
        lyxserverDirLA->setObjectName(QStringLiteral("lyxserverDirLA"));

        gridLayout->addWidget(lyxserverDirLA, 4, 0, 1, 1);

        backupDirPB = new QPushButton(PrefPathsUi);
        backupDirPB->setObjectName(QStringLiteral("backupDirPB"));
        backupDirPB->setAutoDefault(false);

        gridLayout->addWidget(backupDirPB, 3, 2, 1, 1);

        backupDirED = new QLineEdit(PrefPathsUi);
        backupDirED->setObjectName(QStringLiteral("backupDirED"));

        gridLayout->addWidget(backupDirED, 3, 1, 1, 1);

        backupDirLA = new QLabel(PrefPathsUi);
        backupDirLA->setObjectName(QStringLiteral("backupDirLA"));

        gridLayout->addWidget(backupDirLA, 3, 0, 1, 1);

        exampleDirPB = new QPushButton(PrefPathsUi);
        exampleDirPB->setObjectName(QStringLiteral("exampleDirPB"));
        exampleDirPB->setAutoDefault(false);

        gridLayout->addWidget(exampleDirPB, 2, 2, 1, 1);

        exampleDirED = new QLineEdit(PrefPathsUi);
        exampleDirED->setObjectName(QStringLiteral("exampleDirED"));

        gridLayout->addWidget(exampleDirED, 2, 1, 1, 1);

        exampleDirLA = new QLabel(PrefPathsUi);
        exampleDirLA->setObjectName(QStringLiteral("exampleDirLA"));

        gridLayout->addWidget(exampleDirLA, 2, 0, 1, 1);

        templateDirPB = new QPushButton(PrefPathsUi);
        templateDirPB->setObjectName(QStringLiteral("templateDirPB"));
        templateDirPB->setAutoDefault(false);

        gridLayout->addWidget(templateDirPB, 1, 2, 1, 1);

        templateDirED = new QLineEdit(PrefPathsUi);
        templateDirED->setObjectName(QStringLiteral("templateDirED"));

        gridLayout->addWidget(templateDirED, 1, 1, 1, 1);

        templateDirLA = new QLabel(PrefPathsUi);
        templateDirLA->setObjectName(QStringLiteral("templateDirLA"));

        gridLayout->addWidget(templateDirLA, 1, 0, 1, 1);

        workingDirPB = new QPushButton(PrefPathsUi);
        workingDirPB->setObjectName(QStringLiteral("workingDirPB"));
        workingDirPB->setAutoDefault(false);

        gridLayout->addWidget(workingDirPB, 0, 2, 1, 1);

        workingDirED = new QLineEdit(PrefPathsUi);
        workingDirED->setObjectName(QStringLiteral("workingDirED"));

        gridLayout->addWidget(workingDirED, 0, 1, 1, 1);

        workingDirLA = new QLabel(PrefPathsUi);
        workingDirLA->setObjectName(QStringLiteral("workingDirLA"));

        gridLayout->addWidget(workingDirLA, 0, 0, 1, 1);

        hunspellDirLA = new QLabel(PrefPathsUi);
        hunspellDirLA->setObjectName(QStringLiteral("hunspellDirLA"));

        gridLayout->addWidget(hunspellDirLA, 8, 0, 1, 1);

        hunspellDirED = new QLineEdit(PrefPathsUi);
        hunspellDirED->setObjectName(QStringLiteral("hunspellDirED"));

        gridLayout->addWidget(hunspellDirED, 8, 1, 1, 1);

        hunspellDirPB = new QPushButton(PrefPathsUi);
        hunspellDirPB->setObjectName(QStringLiteral("hunspellDirPB"));
        hunspellDirPB->setAutoDefault(false);

        gridLayout->addWidget(hunspellDirPB, 8, 2, 1, 1);

#ifndef QT_NO_SHORTCUT
        pathPrefixLA->setBuddy(pathPrefixED);
        texinputsPrefixLA->setBuddy(texinputsPrefixED);
        thesaurusDirLA->setBuddy(thesaurusDirED);
        tempDirLA->setBuddy(tempDirED);
        lyxserverDirLA->setBuddy(lyxserverDirED);
        backupDirLA->setBuddy(backupDirED);
        exampleDirLA->setBuddy(exampleDirED);
        templateDirLA->setBuddy(templateDirED);
        workingDirLA->setBuddy(workingDirED);
        hunspellDirLA->setBuddy(hunspellDirED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(workingDirED, workingDirPB);
        QWidget::setTabOrder(workingDirPB, templateDirED);
        QWidget::setTabOrder(templateDirED, templateDirPB);
        QWidget::setTabOrder(templateDirPB, exampleDirED);
        QWidget::setTabOrder(exampleDirED, exampleDirPB);
        QWidget::setTabOrder(exampleDirPB, backupDirED);
        QWidget::setTabOrder(backupDirED, backupDirPB);
        QWidget::setTabOrder(backupDirPB, lyxserverDirED);
        QWidget::setTabOrder(lyxserverDirED, lyxserverDirPB);
        QWidget::setTabOrder(lyxserverDirPB, tempDirED);
        QWidget::setTabOrder(tempDirED, tempDirPB);
        QWidget::setTabOrder(tempDirPB, thesaurusDirED);
        QWidget::setTabOrder(thesaurusDirED, thesaurusDirPB);
        QWidget::setTabOrder(thesaurusDirPB, hunspellDirED);
        QWidget::setTabOrder(hunspellDirED, hunspellDirPB);
        QWidget::setTabOrder(hunspellDirPB, pathPrefixED);
        QWidget::setTabOrder(pathPrefixED, texinputsPrefixED);

        retranslateUi(PrefPathsUi);

        QMetaObject::connectSlotsByName(PrefPathsUi);
    } // setupUi

    void retranslateUi(QWidget *PrefPathsUi)
    {
        PrefPathsUi->setWindowTitle(QString());
        label->setText(lyx::qt_("Relative and absolute paths are allowed. Relative paths will be expanded with respect to the working directory (WD). For all paths except the \"TEXINPUTS prefix\" the WD is the directory from which you start LyX, and thus could change for each LyX session. For the \"TEXINPUTS prefix\" path the WD is the directory containing the document. The path \".\" (without quotes) is a common example of a relative path and refers to the WD.", Q_NULLPTR));
        pathPrefixLA->setText(lyx::qt_("&PATH prefix:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pathPrefixED->setToolTip(lyx::qt_("Specify those directories which should be prepended to the PATH environment variable. Use the OS native format.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        texinputsPrefixLA->setText(lyx::qt_("TEX&INPUTS prefix:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        texinputsPrefixED->setToolTip(lyx::qt_("Specify those directories which should be prepended to the TEXINPUTS environment variable. Use the OS native format.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        thesaurusDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        thesaurusDirLA->setText(lyx::qt_("T&hesaurus dictionaries:", Q_NULLPTR));
        tempDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        tempDirLA->setText(lyx::qt_("&Temporary directory:", Q_NULLPTR));
        lyxserverDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        lyxserverDirLA->setText(lyx::qt_("Ly&XServer pipe:", Q_NULLPTR));
        backupDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        backupDirED->setToolTip(lyx::qt_("If a path is specified here, all backups of LyX files will be stored there. If no path is given, backups will be stored alongside the original document. This requires 'Backup original documents when saving' in Look & Feel > Document Handling to be checked.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        backupDirLA->setText(lyx::qt_("&Backup directory:", Q_NULLPTR));
        exampleDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        exampleDirLA->setText(lyx::qt_("&Example files:", Q_NULLPTR));
        templateDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        templateDirLA->setText(lyx::qt_("&Document templates:", Q_NULLPTR));
        workingDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
        workingDirLA->setText(lyx::qt_("&Working directory:", Q_NULLPTR));
        hunspellDirLA->setText(lyx::qt_("H&unspell dictionaries:", Q_NULLPTR));
        hunspellDirPB->setText(lyx::qt_("Browse...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefPathsUi: public Ui_PrefPathsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFPATHSUI_H
