/****************************************************************************
** Meta object code from reading C++ file 'GuiView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiView_t {
    QByteArrayData data[44];
    char stringdata0[688];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiView_t qt_meta_stringdata_lyx__frontend__GuiView = {
    {
QT_MOC_LITERAL(0, 0, 22), // "lyx::frontend::GuiView"
QT_MOC_LITERAL(1, 23, 7), // "closing"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 17), // "triggerShowDialog"
QT_MOC_LITERAL(4, 50, 5), // "qname"
QT_MOC_LITERAL(5, 56, 5), // "qdata"
QT_MOC_LITERAL(6, 62, 6), // "Inset*"
QT_MOC_LITERAL(7, 69, 5), // "inset"
QT_MOC_LITERAL(8, 75, 17), // "bufferViewChanged"
QT_MOC_LITERAL(9, 93, 18), // "currentZoomChanged"
QT_MOC_LITERAL(10, 112, 12), // "scriptKilled"
QT_MOC_LITERAL(11, 125, 21), // "changeTrackingToggled"
QT_MOC_LITERAL(12, 147, 27), // "dockWidgetVisibilityChanged"
QT_MOC_LITERAL(13, 175, 7), // "setBusy"
QT_MOC_LITERAL(14, 183, 12), // "clearMessage"
QT_MOC_LITERAL(15, 196, 9), // "showStats"
QT_MOC_LITERAL(16, 206, 17), // "updateWindowTitle"
QT_MOC_LITERAL(17, 224, 12), // "GuiWorkArea*"
QT_MOC_LITERAL(18, 237, 2), // "wa"
QT_MOC_LITERAL(19, 240, 18), // "disableShellEscape"
QT_MOC_LITERAL(20, 259, 29), // "onDockWidgetVisibilityChanged"
QT_MOC_LITERAL(21, 289, 16), // "resetWindowTitle"
QT_MOC_LITERAL(22, 306, 14), // "flatGroupBoxes"
QT_MOC_LITERAL(23, 321, 14), // "const QObject*"
QT_MOC_LITERAL(24, 336, 6), // "object"
QT_MOC_LITERAL(25, 343, 4), // "flag"
QT_MOC_LITERAL(26, 348, 21), // "checkCancelBackground"
QT_MOC_LITERAL(27, 370, 12), // "statsPressed"
QT_MOC_LITERAL(28, 383, 15), // "zoomSliderMoved"
QT_MOC_LITERAL(29, 399, 16), // "zoomValueChanged"
QT_MOC_LITERAL(30, 416, 13), // "zoomInPressed"
QT_MOC_LITERAL(31, 430, 14), // "zoomOutPressed"
QT_MOC_LITERAL(32, 445, 19), // "showZoomContextMenu"
QT_MOC_LITERAL(33, 465, 24), // "showStatusBarContextMenu"
QT_MOC_LITERAL(34, 490, 25), // "on_currentWorkAreaChanged"
QT_MOC_LITERAL(35, 516, 19), // "onBufferViewChanged"
QT_MOC_LITERAL(36, 536, 22), // "on_lastWorkAreaRemoved"
QT_MOC_LITERAL(37, 559, 23), // "processingThreadStarted"
QT_MOC_LITERAL(38, 583, 24), // "processingThreadFinished"
QT_MOC_LITERAL(39, 608, 22), // "autoSaveThreadFinished"
QT_MOC_LITERAL(40, 631, 12), // "doShowDialog"
QT_MOC_LITERAL(41, 644, 22), // "updateStatusBarMessage"
QT_MOC_LITERAL(42, 667, 3), // "str"
QT_MOC_LITERAL(43, 671, 16) // "clearMessageText"

    },
    "lyx::frontend::GuiView\0closing\0\0"
    "triggerShowDialog\0qname\0qdata\0Inset*\0"
    "inset\0bufferViewChanged\0currentZoomChanged\0"
    "scriptKilled\0changeTrackingToggled\0"
    "dockWidgetVisibilityChanged\0setBusy\0"
    "clearMessage\0showStats\0updateWindowTitle\0"
    "GuiWorkArea*\0wa\0disableShellEscape\0"
    "onDockWidgetVisibilityChanged\0"
    "resetWindowTitle\0flatGroupBoxes\0"
    "const QObject*\0object\0flag\0"
    "checkCancelBackground\0statsPressed\0"
    "zoomSliderMoved\0zoomValueChanged\0"
    "zoomInPressed\0zoomOutPressed\0"
    "showZoomContextMenu\0showStatusBarContextMenu\0"
    "on_currentWorkAreaChanged\0onBufferViewChanged\0"
    "on_lastWorkAreaRemoved\0processingThreadStarted\0"
    "processingThreadFinished\0"
    "autoSaveThreadFinished\0doShowDialog\0"
    "updateStatusBarMessage\0str\0clearMessageText"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  174,    2, 0x06 /* Public */,
       3,    3,  177,    2, 0x06 /* Public */,
       8,    0,  184,    2, 0x06 /* Public */,
       9,    1,  185,    2, 0x06 /* Public */,
      10,    0,  188,    2, 0x06 /* Public */,
      11,    1,  189,    2, 0x06 /* Public */,
      12,    0,  192,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,  193,    2, 0x0a /* Public */,
      14,    0,  196,    2, 0x0a /* Public */,
      15,    0,  197,    2, 0x0a /* Public */,
      16,    1,  198,    2, 0x0a /* Public */,
      19,    0,  201,    2, 0x0a /* Public */,
      20,    0,  202,    2, 0x0a /* Public */,
      21,    0,  203,    2, 0x08 /* Private */,
      22,    2,  204,    2, 0x08 /* Private */,
      26,    0,  209,    2, 0x08 /* Private */,
      27,    0,  210,    2, 0x08 /* Private */,
      28,    1,  211,    2, 0x08 /* Private */,
      29,    1,  214,    2, 0x08 /* Private */,
      30,    0,  217,    2, 0x08 /* Private */,
      31,    0,  218,    2, 0x08 /* Private */,
      32,    0,  219,    2, 0x08 /* Private */,
      33,    0,  220,    2, 0x08 /* Private */,
      34,    1,  221,    2, 0x08 /* Private */,
      35,    0,  224,    2, 0x08 /* Private */,
      36,    0,  225,    2, 0x08 /* Private */,
      37,    0,  226,    2, 0x08 /* Private */,
      38,    0,  227,    2, 0x08 /* Private */,
      39,    0,  228,    2, 0x08 /* Private */,
      40,    3,  229,    2, 0x08 /* Private */,
      41,    1,  236,    2, 0x08 /* Private */,
      43,    0,  239,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 6,    4,    5,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23, QMetaType::Bool,   24,   25,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 6,    4,    5,    7,
    QMetaType::Void, QMetaType::QString,   42,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiView *_t = static_cast<GuiView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->closing((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->triggerShowDialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< Inset*(*)>(_a[3]))); break;
        case 2: _t->bufferViewChanged(); break;
        case 3: _t->currentZoomChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->scriptKilled(); break;
        case 5: _t->changeTrackingToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->dockWidgetVisibilityChanged(); break;
        case 7: _t->setBusy((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->clearMessage(); break;
        case 9: _t->showStats(); break;
        case 10: _t->updateWindowTitle((*reinterpret_cast< GuiWorkArea*(*)>(_a[1]))); break;
        case 11: _t->disableShellEscape(); break;
        case 12: _t->onDockWidgetVisibilityChanged(); break;
        case 13: _t->resetWindowTitle(); break;
        case 14: _t->flatGroupBoxes((*reinterpret_cast< const QObject*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 15: _t->checkCancelBackground(); break;
        case 16: _t->statsPressed(); break;
        case 17: _t->zoomSliderMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->zoomValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->zoomInPressed(); break;
        case 20: _t->zoomOutPressed(); break;
        case 21: _t->showZoomContextMenu(); break;
        case 22: _t->showStatusBarContextMenu(); break;
        case 23: _t->on_currentWorkAreaChanged((*reinterpret_cast< GuiWorkArea*(*)>(_a[1]))); break;
        case 24: _t->onBufferViewChanged(); break;
        case 25: _t->on_lastWorkAreaRemoved(); break;
        case 26: _t->processingThreadStarted(); break;
        case 27: _t->processingThreadFinished(); break;
        case 28: _t->autoSaveThreadFinished(); break;
        case 29: _t->doShowDialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< Inset*(*)>(_a[3]))); break;
        case 30: _t->updateStatusBarMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->clearMessageText(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiView::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::closing)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)(QString const & , QString const & , Inset * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::triggerShowDialog)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::bufferViewChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::currentZoomChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::scriptKilled)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::changeTrackingToggled)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (GuiView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiView::dockWidgetVisibilityChanged)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiView::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiView.data,
      qt_meta_data_lyx__frontend__GuiView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiView.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "GuiBufferViewDelegate"))
        return static_cast< GuiBufferViewDelegate*>(this);
    if (!strcmp(_clname, "GuiBufferDelegate"))
        return static_cast< GuiBufferDelegate*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int lyx::frontend::GuiView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiView::closing(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void lyx::frontend::GuiView::triggerShowDialog(QString const & _t1, QString const & _t2, Inset * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void lyx::frontend::GuiView::bufferViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void lyx::frontend::GuiView::currentZoomChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void lyx::frontend::GuiView::scriptKilled()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void lyx::frontend::GuiView::changeTrackingToggled(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void lyx::frontend::GuiView::dockWidgetVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__SEMenu_t {
    QByteArrayData data[3];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__SEMenu_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__SEMenu_t qt_meta_stringdata_lyx__frontend__SEMenu = {
    {
QT_MOC_LITERAL(0, 0, 21), // "lyx::frontend::SEMenu"
QT_MOC_LITERAL(1, 22, 8), // "showMenu"
QT_MOC_LITERAL(2, 31, 0) // ""

    },
    "lyx::frontend::SEMenu\0showMenu\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__SEMenu[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QPoint,    2,

       0        // eod
};

void lyx::frontend::SEMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SEMenu *_t = static_cast<SEMenu *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::SEMenu::staticMetaObject = {
    { &QMenu::staticMetaObject, qt_meta_stringdata_lyx__frontend__SEMenu.data,
      qt_meta_data_lyx__frontend__SEMenu,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::SEMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::SEMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__SEMenu.stringdata0))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int lyx::frontend::SEMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__PressableSvgWidget_t {
    QByteArrayData data[3];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__PressableSvgWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__PressableSvgWidget_t qt_meta_stringdata_lyx__frontend__PressableSvgWidget = {
    {
QT_MOC_LITERAL(0, 0, 33), // "lyx::frontend::PressableSvgWi..."
QT_MOC_LITERAL(1, 34, 7), // "pressed"
QT_MOC_LITERAL(2, 42, 0) // ""

    },
    "lyx::frontend::PressableSvgWidget\0"
    "pressed\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__PressableSvgWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::PressableSvgWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PressableSvgWidget *_t = static_cast<PressableSvgWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->pressed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PressableSvgWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PressableSvgWidget::pressed)) {
                *result = 0;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::PressableSvgWidget::staticMetaObject = {
    { &QSvgWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__PressableSvgWidget.data,
      qt_meta_data_lyx__frontend__PressableSvgWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::PressableSvgWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::PressableSvgWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__PressableSvgWidget.stringdata0))
        return static_cast<void*>(this);
    return QSvgWidget::qt_metacast(_clname);
}

int lyx::frontend::PressableSvgWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSvgWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::PressableSvgWidget::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
