/********************************************************************************
** Form generated from reading UI file 'NumberingUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NUMBERINGUI_H
#define UI_NUMBERINGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_NumberingUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *linenoCB;
    QSpacerItem *horizontalSpacer;
    QLabel *linenoLA;
    QLineEdit *linenoLE;
    QLabel *TextLabel1;
    QSlider *tocSL;
    QLabel *TextLabel1_2;
    QTreeWidget *tocTW;
    QSlider *depthSL;

    void setupUi(QWidget *NumberingUi)
    {
        if (NumberingUi->objectName().isEmpty())
            NumberingUi->setObjectName(QStringLiteral("NumberingUi"));
        NumberingUi->resize(414, 323);
        gridLayout = new QGridLayout(NumberingUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        linenoCB = new QCheckBox(NumberingUi);
        linenoCB->setObjectName(QStringLiteral("linenoCB"));

        horizontalLayout_2->addWidget(linenoCB);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        linenoLA = new QLabel(NumberingUi);
        linenoLA->setObjectName(QStringLiteral("linenoLA"));

        horizontalLayout_2->addWidget(linenoLA);

        linenoLE = new QLineEdit(NumberingUi);
        linenoLE->setObjectName(QStringLiteral("linenoLE"));

        horizontalLayout_2->addWidget(linenoLE);


        gridLayout->addLayout(horizontalLayout_2, 6, 0, 3, 1);

        TextLabel1 = new QLabel(NumberingUi);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));

        gridLayout->addWidget(TextLabel1, 2, 0, 1, 1);

        tocSL = new QSlider(NumberingUi);
        tocSL->setObjectName(QStringLiteral("tocSL"));
        tocSL->setMinimum(-1);
        tocSL->setMaximum(5);
        tocSL->setValue(3);
        tocSL->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(tocSL, 3, 0, 1, 1);

        TextLabel1_2 = new QLabel(NumberingUi);
        TextLabel1_2->setObjectName(QStringLiteral("TextLabel1_2"));

        gridLayout->addWidget(TextLabel1_2, 0, 0, 1, 1);

        tocTW = new QTreeWidget(NumberingUi);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        tocTW->setHeaderItem(__qtreewidgetitem);
        tocTW->setObjectName(QStringLiteral("tocTW"));

        gridLayout->addWidget(tocTW, 4, 0, 1, 1);

        depthSL = new QSlider(NumberingUi);
        depthSL->setObjectName(QStringLiteral("depthSL"));
        depthSL->setMinimum(-2);
        depthSL->setMaximum(5);
        depthSL->setValue(3);
        depthSL->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(depthSL, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        linenoLA->setBuddy(linenoLE);
        TextLabel1->setBuddy(tocSL);
        TextLabel1_2->setBuddy(depthSL);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(depthSL, tocSL);
        QWidget::setTabOrder(tocSL, tocTW);

        retranslateUi(NumberingUi);

        QMetaObject::connectSlotsByName(NumberingUi);
    } // setupUi

    void retranslateUi(QWidget *NumberingUi)
    {
        NumberingUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        linenoCB->setToolTip(lyx::qt_("Add line numbers to the side of the document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        linenoCB->setText(lyx::qt_("L&ine numbering", Q_NULLPTR));
        linenoLA->setText(lyx::qt_("O&ptions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        linenoLE->setToolTip(lyx::qt_("Line numbering (lineno package) options (e.g. right, modulo, switch(*), pagewise). Please refer to the lineno package manual for details.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        TextLabel1->setText(lyx::qt_("&List in Table of Contents", Q_NULLPTR));
        TextLabel1_2->setText(lyx::qt_("&Numbering", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NumberingUi: public Ui_NumberingUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NUMBERINGUI_H
