/********************************************************************************
** Form generated from reading UI file 'BibtexUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BIBTEXUI_H
#define UI_BIBTEXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BibtexUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *bibGB;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *bibLA;
    QListView *availableLV;
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QPushButton *addBibPB;
    QPushButton *browseBibPB;
    QPushButton *relAbsPB;
    QPushButton *inheritPB;
    QPushButton *deletePB;
    QPushButton *upPB;
    QPushButton *downPB;
    QSpacerItem *verticalSpacer_2;
    QPushButton *editPB;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QTableView *selectedLV;
    QHBoxLayout *horizontalLayout_5;
    QLabel *findKeysLA;
    QHBoxLayout *filterBarL;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QLabel *bibEncodingLA;
    QComboBox *bibEncodingCO;
    QGroupBox *bstGB;
    QGridLayout *gridLayout_2;
    QComboBox *styleCB;
    QPushButton *stylePB;
    QGroupBox *optionsGB;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *btPrintLA;
    QComboBox *btPrintCO;
    QCheckBox *bibtocCB;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QLabel *biblatexOptsLA;
    QLineEdit *biblatexOptsLE;
    QHBoxLayout *hboxLayout;
    QPushButton *rescanPB;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BibtexUi)
    {
        if (BibtexUi->objectName().isEmpty())
            BibtexUi->setObjectName(QStringLiteral("BibtexUi"));
        BibtexUi->resize(542, 702);
        BibtexUi->setSizeGripEnabled(true);
        gridLayout_4 = new QGridLayout(BibtexUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        bibGB = new QGroupBox(BibtexUi);
        bibGB->setObjectName(QStringLiteral("bibGB"));
        bibGB->setFlat(true);
        gridLayout = new QGridLayout(bibGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        bibLA = new QLabel(bibGB);
        bibLA->setObjectName(QStringLiteral("bibLA"));

        verticalLayout_2->addWidget(bibLA);

        availableLV = new QListView(bibGB);
        availableLV->setObjectName(QStringLiteral("availableLV"));
        availableLV->setEditTriggers(QAbstractItemView::NoEditTriggers);

        verticalLayout_2->addWidget(availableLV);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label_2 = new QLabel(bibGB);
        label_2->setObjectName(QStringLiteral("label_2"));

        verticalLayout->addWidget(label_2);

        addBibPB = new QPushButton(bibGB);
        addBibPB->setObjectName(QStringLiteral("addBibPB"));

        verticalLayout->addWidget(addBibPB);

        browseBibPB = new QPushButton(bibGB);
        browseBibPB->setObjectName(QStringLiteral("browseBibPB"));
        browseBibPB->setAutoDefault(false);

        verticalLayout->addWidget(browseBibPB);

        relAbsPB = new QPushButton(bibGB);
        relAbsPB->setObjectName(QStringLiteral("relAbsPB"));

        verticalLayout->addWidget(relAbsPB);

        inheritPB = new QPushButton(bibGB);
        inheritPB->setObjectName(QStringLiteral("inheritPB"));

        verticalLayout->addWidget(inheritPB);

        deletePB = new QPushButton(bibGB);
        deletePB->setObjectName(QStringLiteral("deletePB"));

        verticalLayout->addWidget(deletePB);

        upPB = new QPushButton(bibGB);
        upPB->setObjectName(QStringLiteral("upPB"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(upPB->sizePolicy().hasHeightForWidth());
        upPB->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        upPB->setIcon(icon);
        upPB->setAutoDefault(false);

        verticalLayout->addWidget(upPB);

        downPB = new QPushButton(bibGB);
        downPB->setObjectName(QStringLiteral("downPB"));
        sizePolicy.setHeightForWidth(downPB->sizePolicy().hasHeightForWidth());
        downPB->setSizePolicy(sizePolicy);
        downPB->setIcon(icon);
        downPB->setAutoDefault(false);

        verticalLayout->addWidget(downPB);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        editPB = new QPushButton(bibGB);
        editPB->setObjectName(QStringLiteral("editPB"));
        editPB->setIcon(icon);

        verticalLayout->addWidget(editPB);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        label = new QLabel(bibGB);
        label->setObjectName(QStringLiteral("label"));

        verticalLayout_3->addWidget(label);

        selectedLV = new QTableView(bibGB);
        selectedLV->setObjectName(QStringLiteral("selectedLV"));

        verticalLayout_3->addWidget(selectedLV);


        gridLayout->addLayout(verticalLayout_3, 0, 2, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        findKeysLA = new QLabel(bibGB);
        findKeysLA->setObjectName(QStringLiteral("findKeysLA"));
        findKeysLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_5->addWidget(findKeysLA);

        filterBarL = new QHBoxLayout();
        filterBarL->setObjectName(QStringLiteral("filterBarL"));

        horizontalLayout_5->addLayout(filterBarL);


        gridLayout->addLayout(horizontalLayout_5, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        bibEncodingLA = new QLabel(bibGB);
        bibEncodingLA->setObjectName(QStringLiteral("bibEncodingLA"));

        horizontalLayout_2->addWidget(bibEncodingLA);

        bibEncodingCO = new QComboBox(bibGB);
        bibEncodingCO->setObjectName(QStringLiteral("bibEncodingCO"));

        horizontalLayout_2->addWidget(bibEncodingCO);


        gridLayout->addLayout(horizontalLayout_2, 1, 1, 1, 2);


        gridLayout_4->addWidget(bibGB, 0, 0, 1, 1);

        bstGB = new QGroupBox(BibtexUi);
        bstGB->setObjectName(QStringLiteral("bstGB"));
        gridLayout_2 = new QGridLayout(bstGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        styleCB = new QComboBox(bstGB);
        styleCB->setObjectName(QStringLiteral("styleCB"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(styleCB->sizePolicy().hasHeightForWidth());
        styleCB->setSizePolicy(sizePolicy1);
        styleCB->setEditable(true);
        styleCB->setDuplicatesEnabled(false);

        gridLayout_2->addWidget(styleCB, 0, 0, 1, 1);

        stylePB = new QPushButton(bstGB);
        stylePB->setObjectName(QStringLiteral("stylePB"));
        stylePB->setAutoDefault(false);

        gridLayout_2->addWidget(stylePB, 0, 1, 1, 1);


        gridLayout_4->addWidget(bstGB, 1, 0, 1, 1);

        optionsGB = new QGroupBox(BibtexUi);
        optionsGB->setObjectName(QStringLiteral("optionsGB"));
        optionsGB->setFlat(true);
        gridLayout_3 = new QGridLayout(optionsGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        btPrintLA = new QLabel(optionsGB);
        btPrintLA->setObjectName(QStringLiteral("btPrintLA"));
        sizePolicy.setHeightForWidth(btPrintLA->sizePolicy().hasHeightForWidth());
        btPrintLA->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(btPrintLA);

        btPrintCO = new QComboBox(optionsGB);
        btPrintCO->setObjectName(QStringLiteral("btPrintCO"));

        horizontalLayout_3->addWidget(btPrintCO);

        bibtocCB = new QCheckBox(optionsGB);
        bibtocCB->setObjectName(QStringLiteral("bibtocCB"));

        horizontalLayout_3->addWidget(bibtocCB);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        gridLayout_3->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        biblatexOptsLA = new QLabel(optionsGB);
        biblatexOptsLA->setObjectName(QStringLiteral("biblatexOptsLA"));

        horizontalLayout->addWidget(biblatexOptsLA);

        biblatexOptsLE = new QLineEdit(optionsGB);
        biblatexOptsLE->setObjectName(QStringLiteral("biblatexOptsLE"));

        horizontalLayout->addWidget(biblatexOptsLE);


        gridLayout_3->addLayout(horizontalLayout, 2, 0, 1, 1);


        gridLayout_4->addWidget(optionsGB, 2, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        rescanPB = new QPushButton(BibtexUi);
        rescanPB->setObjectName(QStringLiteral("rescanPB"));

        hboxLayout->addWidget(rescanPB);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(BibtexUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout_4->addLayout(hboxLayout, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        bibLA->setBuddy(availableLV);
        label->setBuddy(selectedLV);
        bibEncodingLA->setBuddy(bibEncodingCO);
        btPrintLA->setBuddy(btPrintCO);
        biblatexOptsLA->setBuddy(biblatexOptsLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(deletePB, styleCB);
        QWidget::setTabOrder(styleCB, stylePB);
        QWidget::setTabOrder(stylePB, btPrintCO);

        retranslateUi(BibtexUi);

        browseBibPB->setDefault(true);


        QMetaObject::connectSlotsByName(BibtexUi);
    } // setupUi

    void retranslateUi(QDialog *BibtexUi)
    {
        BibtexUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        bibGB->setToolTip(lyx::qt_("BibTeX database(s) to use", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibGB->setTitle(lyx::qt_("&Databases", Q_NULLPTR));
        bibLA->setText(lyx::qt_("Found b&y LaTeX:", Q_NULLPTR));
        label_2->setText(QString());
#ifndef QT_NO_TOOLTIP
        addBibPB->setToolTip(lyx::qt_("Add the selected BibTeX database from the list on the left", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addBibPB->setText(lyx::qt_("&Add Selected[[bib]]", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        browseBibPB->setToolTip(lyx::qt_("Add a BibTeX database from your local directory", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        browseBibPB->setText(lyx::qt_("Add &Local...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        relAbsPB->setToolTip(lyx::qt_("Transfer an absolute local path to a relative one or vice versa", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        relAbsPB->setText(lyx::qt_("&Make Relative", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inheritPB->setToolTip(lyx::qt_("Inherit bibliography databases from the master document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        inheritPB->setText(lyx::qt_("&Inherit from Master", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        deletePB->setToolTip(lyx::qt_("Remove the selected database", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        deletePB->setText(lyx::qt_("&Delete", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        upPB->setToolTip(lyx::qt_("Move the selected database up (Ctrl-Up)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        upPB->setText(lyx::qt_("&Up", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        downPB->setToolTip(lyx::qt_("Move the selected database down (Ctrl-Down)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        downPB->setText(lyx::qt_("Do&wn", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        editPB->setToolTip(lyx::qt_("Edit selected database externally", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        editPB->setText(lyx::qt_("&Edit...", Q_NULLPTR));
        label->setText(lyx::qt_("Sele&cted:", Q_NULLPTR));
        findKeysLA->setText(lyx::qt_("&Filter:", Q_NULLPTR));
        bibEncodingLA->setText(lyx::qt_("E&ncoding:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bibEncodingCO->setToolTip(lyx::qt_("If your bibliography databases use a different encoding than the LyX document, specify it here", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        bstGB->setToolTip(lyx::qt_("The BibTeX style", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bstGB->setTitle(lyx::qt_("St&yle", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        styleCB->setToolTip(lyx::qt_("Choose a style file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        stylePB->setToolTip(lyx::qt_("Select a style file from your local directory", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        stylePB->setText(lyx::qt_("Add L&ocal...", Q_NULLPTR));
        optionsGB->setTitle(lyx::qt_("Options", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        btPrintLA->setToolTip(lyx::qt_("This bibliography section contains...", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        btPrintLA->setText(lyx::qt_("&Content:", Q_NULLPTR));
        btPrintCO->clear();
        btPrintCO->insertItems(0, QStringList()
         << lyx::qt_("all cited references", Q_NULLPTR)
         << lyx::qt_("all uncited references", Q_NULLPTR)
         << lyx::qt_("all references", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        btPrintCO->setToolTip(lyx::qt_("This bibliography section contains...", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        bibtocCB->setToolTip(lyx::qt_("Add bibliography to the table of contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibtocCB->setText(lyx::qt_("Add bibliography to &TOC", Q_NULLPTR));
        biblatexOptsLA->setText(lyx::qt_("Custo&m:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        biblatexOptsLE->setToolTip(lyx::qt_("Options to the biblatex bibliography command. See the biblatex manual for details.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        rescanPB->setToolTip(lyx::qt_("Scan for new databases and styles", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rescanPB->setText(lyx::qt_("&Rescan", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BibtexUi: public Ui_BibtexUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BIBTEXUI_H
