/********************************************************************************
** Form generated from reading UI file 'TextLayoutUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTLAYOUTUI_H
#define UI_TEXTLAYOUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_TextLayoutUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *spacingGB;
    QGridLayout *gridLayout_2;
    QLabel *lspacingL;
    QComboBox *lspacingCO;
    QLineEdit *lspacingLE;
    QSpacerItem *horizontalSpacer;
    QGroupBox *tableStyleGB;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *tableStyleLA;
    QComboBox *tableStyleCO;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem;
    QGroupBox *separateGB;
    QGridLayout *gridLayout;
    QRadioButton *indentRB;
    QComboBox *indentCO;
    QSpacerItem *spacerItem1;
    QLineEdit *indentLE;
    lyx::frontend::LengthCombo *indentLengthCO;
    QSpacerItem *spacerItem2;
    QRadioButton *skipRB;
    QComboBox *skipCO;
    QSpacerItem *spacerItem3;
    QLineEdit *skipLE;
    lyx::frontend::LengthCombo *skipLengthCO;
    QSpacerItem *spacerItem4;
    QCheckBox *justCB;
    QCheckBox *twoColumnCB;

    void setupUi(QWidget *TextLayoutUi)
    {
        if (TextLayoutUi->objectName().isEmpty())
            TextLayoutUi->setObjectName(QStringLiteral("TextLayoutUi"));
        TextLayoutUi->resize(470, 468);
        gridLayout_4 = new QGridLayout(TextLayoutUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        spacingGB = new QGroupBox(TextLayoutUi);
        spacingGB->setObjectName(QStringLiteral("spacingGB"));
        spacingGB->setMinimumSize(QSize(0, 0));
        spacingGB->setFlat(true);
        spacingGB->setCheckable(false);
        gridLayout_2 = new QGridLayout(spacingGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        lspacingL = new QLabel(spacingGB);
        lspacingL->setObjectName(QStringLiteral("lspacingL"));
        lspacingL->setMinimumSize(QSize(91, 18));

        gridLayout_2->addWidget(lspacingL, 0, 0, 1, 1);

        lspacingCO = new QComboBox(spacingGB);
        lspacingCO->setObjectName(QStringLiteral("lspacingCO"));
        lspacingCO->setDuplicatesEnabled(false);

        gridLayout_2->addWidget(lspacingCO, 0, 1, 1, 1);

        lspacingLE = new QLineEdit(spacingGB);
        lspacingLE->setObjectName(QStringLiteral("lspacingLE"));
        lspacingLE->setEnabled(false);

        gridLayout_2->addWidget(lspacingLE, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(69, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 3, 1, 1);


        gridLayout_4->addWidget(spacingGB, 1, 0, 1, 1);

        tableStyleGB = new QGroupBox(TextLayoutUi);
        tableStyleGB->setObjectName(QStringLiteral("tableStyleGB"));
        tableStyleGB->setFlat(true);
        gridLayout_3 = new QGridLayout(tableStyleGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        tableStyleLA = new QLabel(tableStyleGB);
        tableStyleLA->setObjectName(QStringLiteral("tableStyleLA"));

        horizontalLayout->addWidget(tableStyleLA);

        tableStyleCO = new QComboBox(tableStyleGB);
        tableStyleCO->setObjectName(QStringLiteral("tableStyleCO"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tableStyleCO->sizePolicy().hasHeightForWidth());
        tableStyleCO->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(tableStyleCO);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout_3->addLayout(horizontalLayout, 0, 0, 1, 1);


        gridLayout_4->addWidget(tableStyleGB, 4, 0, 1, 1);

        spacerItem = new QSpacerItem(403, 21, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem, 7, 0, 1, 1);

        separateGB = new QGroupBox(TextLayoutUi);
        separateGB->setObjectName(QStringLiteral("separateGB"));
        separateGB->setFlat(true);
        gridLayout = new QGridLayout(separateGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        indentRB = new QRadioButton(separateGB);
        indentRB->setObjectName(QStringLiteral("indentRB"));
        indentRB->setMinimumSize(QSize(91, 18));

        gridLayout->addWidget(indentRB, 0, 0, 1, 1);

        indentCO = new QComboBox(separateGB);
        indentCO->setObjectName(QStringLiteral("indentCO"));
        indentCO->setEnabled(false);

        gridLayout->addWidget(indentCO, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(133, 23, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 2, 1, 2);

        indentLE = new QLineEdit(separateGB);
        indentLE->setObjectName(QStringLiteral("indentLE"));
        indentLE->setEnabled(false);

        gridLayout->addWidget(indentLE, 1, 1, 1, 1);

        indentLengthCO = new lyx::frontend::LengthCombo(separateGB);
        indentLengthCO->setObjectName(QStringLiteral("indentLengthCO"));
        indentLengthCO->setEnabled(false);

        gridLayout->addWidget(indentLengthCO, 1, 2, 1, 1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem2, 1, 3, 1, 1);

        skipRB = new QRadioButton(separateGB);
        skipRB->setObjectName(QStringLiteral("skipRB"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(skipRB->sizePolicy().hasHeightForWidth());
        skipRB->setSizePolicy(sizePolicy1);
        skipRB->setMinimumSize(QSize(91, 18));

        gridLayout->addWidget(skipRB, 2, 0, 1, 1);

        skipCO = new QComboBox(separateGB);
        skipCO->setObjectName(QStringLiteral("skipCO"));
        skipCO->setEnabled(false);

        gridLayout->addWidget(skipCO, 2, 1, 1, 1);

        spacerItem3 = new QSpacerItem(137, 26, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem3, 2, 2, 1, 2);

        skipLE = new QLineEdit(separateGB);
        skipLE->setObjectName(QStringLiteral("skipLE"));
        skipLE->setEnabled(false);

        gridLayout->addWidget(skipLE, 3, 1, 1, 1);

        skipLengthCO = new lyx::frontend::LengthCombo(separateGB);
        skipLengthCO->setObjectName(QStringLiteral("skipLengthCO"));
        skipLengthCO->setEnabled(false);

        gridLayout->addWidget(skipLengthCO, 3, 2, 1, 1);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem4, 3, 3, 1, 1);


        gridLayout_4->addWidget(separateGB, 0, 0, 1, 1);

        justCB = new QCheckBox(TextLayoutUi);
        justCB->setObjectName(QStringLiteral("justCB"));

        gridLayout_4->addWidget(justCB, 6, 0, 1, 1);

        twoColumnCB = new QCheckBox(TextLayoutUi);
        twoColumnCB->setObjectName(QStringLiteral("twoColumnCB"));

        gridLayout_4->addWidget(twoColumnCB, 5, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        lspacingL->setBuddy(lspacingCO);
        tableStyleLA->setBuddy(tableStyleCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(indentRB, indentCO);
        QWidget::setTabOrder(indentCO, indentLE);
        QWidget::setTabOrder(indentLE, indentLengthCO);
        QWidget::setTabOrder(indentLengthCO, skipRB);
        QWidget::setTabOrder(skipRB, skipCO);
        QWidget::setTabOrder(skipCO, skipLE);
        QWidget::setTabOrder(skipLE, skipLengthCO);
        QWidget::setTabOrder(skipLengthCO, lspacingCO);
        QWidget::setTabOrder(lspacingCO, lspacingLE);

        retranslateUi(TextLayoutUi);

        QMetaObject::connectSlotsByName(TextLayoutUi);
    } // setupUi

    void retranslateUi(QWidget *TextLayoutUi)
    {
        TextLayoutUi->setWindowTitle(QString());
        spacingGB->setTitle(lyx::qt_("Spacing", Q_NULLPTR));
        lspacingL->setText(lyx::qt_("&Line spacing:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lspacingCO->setToolTip(lyx::qt_("Spacing type", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        lspacingLE->setToolTip(lyx::qt_("Number of lines", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tableStyleGB->setTitle(lyx::qt_("Table Style", Q_NULLPTR));
        tableStyleLA->setText(lyx::qt_("Default St&yle:", Q_NULLPTR));
        separateGB->setTitle(lyx::qt_("Paragraph Separation", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indentRB->setToolTip(lyx::qt_("Indent consecutive paragraphs", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        indentRB->setText(lyx::qt_("&Indentation:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indentCO->setToolTip(lyx::qt_("Size of the indentation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        indentLE->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        indentLE->setText(QString());
#ifndef QT_NO_TOOLTIP
        indentLengthCO->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        skipRB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        skipRB->setText(lyx::qt_("&Vertical space:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        skipCO->setToolTip(lyx::qt_("Size of the vertical space", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        skipLE->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        skipLengthCO->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        justCB->setToolTip(lyx::qt_("Justify text in the LyX editor (this does not affect whether the text is justified in the output)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        justCB->setText(lyx::qt_("Use &justification in LyX work area", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        twoColumnCB->setToolTip(lyx::qt_("Format text into two columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        twoColumnCB->setText(lyx::qt_("Two-&column document", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TextLayoutUi: public Ui_TextLayoutUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TEXTLAYOUTUI_H
