/****************************************************************************
** Meta object code from reading C++ file 'GuiCitation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiCitation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiCitation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiCitation_t {
    QByteArrayData data[23];
    char stringdata0[383];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiCitation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiCitation_t qt_meta_stringdata_lyx__frontend__GuiCitation = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiCitation"
QT_MOC_LITERAL(1, 27, 21), // "on_buttonBox_accepted"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 21), // "on_buttonBox_rejected"
QT_MOC_LITERAL(4, 72, 20), // "on_buttonBox_clicked"
QT_MOC_LITERAL(5, 93, 16), // "QAbstractButton*"
QT_MOC_LITERAL(6, 110, 20), // "on_literalCB_clicked"
QT_MOC_LITERAL(7, 131, 13), // "filterPressed"
QT_MOC_LITERAL(8, 145, 13), // "filterChanged"
QT_MOC_LITERAL(9, 159, 4), // "text"
QT_MOC_LITERAL(10, 164, 31), // "on_fieldsCO_currentIndexChanged"
QT_MOC_LITERAL(11, 196, 5), // "index"
QT_MOC_LITERAL(12, 202, 32), // "on_entriesCO_currentIndexChanged"
QT_MOC_LITERAL(13, 235, 38), // "on_citationStyleCO_currentInd..."
QT_MOC_LITERAL(14, 274, 11), // "resetFilter"
QT_MOC_LITERAL(15, 286, 11), // "caseChanged"
QT_MOC_LITERAL(16, 298, 12), // "regexChanged"
QT_MOC_LITERAL(17, 311, 14), // "instantChanged"
QT_MOC_LITERAL(18, 326, 7), // "checked"
QT_MOC_LITERAL(19, 334, 7), // "changed"
QT_MOC_LITERAL(20, 342, 12), // "setCitedKeys"
QT_MOC_LITERAL(21, 355, 12), // "updateStyles"
QT_MOC_LITERAL(22, 368, 14) // "updateControls"

    },
    "lyx::frontend::GuiCitation\0"
    "on_buttonBox_accepted\0\0on_buttonBox_rejected\0"
    "on_buttonBox_clicked\0QAbstractButton*\0"
    "on_literalCB_clicked\0filterPressed\0"
    "filterChanged\0text\0on_fieldsCO_currentIndexChanged\0"
    "index\0on_entriesCO_currentIndexChanged\0"
    "on_citationStyleCO_currentIndexChanged\0"
    "resetFilter\0caseChanged\0regexChanged\0"
    "instantChanged\0checked\0changed\0"
    "setCitedKeys\0updateStyles\0updateControls"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiCitation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x08 /* Private */,
       3,    0,  100,    2, 0x08 /* Private */,
       4,    1,  101,    2, 0x08 /* Private */,
       6,    0,  104,    2, 0x08 /* Private */,
       7,    0,  105,    2, 0x08 /* Private */,
       8,    1,  106,    2, 0x08 /* Private */,
      10,    1,  109,    2, 0x08 /* Private */,
      12,    1,  112,    2, 0x08 /* Private */,
      13,    1,  115,    2, 0x08 /* Private */,
      14,    0,  118,    2, 0x08 /* Private */,
      15,    0,  119,    2, 0x08 /* Private */,
      16,    0,  120,    2, 0x08 /* Private */,
      17,    1,  121,    2, 0x08 /* Private */,
      19,    0,  124,    2, 0x08 /* Private */,
      20,    0,  125,    2, 0x08 /* Private */,
      21,    0,  126,    2, 0x08 /* Private */,
      22,    0,  127,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiCitation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiCitation *_t = static_cast<GuiCitation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_buttonBox_accepted(); break;
        case 1: _t->on_buttonBox_rejected(); break;
        case 2: _t->on_buttonBox_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 3: _t->on_literalCB_clicked(); break;
        case 4: _t->filterPressed(); break;
        case 5: _t->filterChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->on_fieldsCO_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_entriesCO_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_citationStyleCO_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->resetFilter(); break;
        case 10: _t->caseChanged(); break;
        case 11: _t->regexChanged(); break;
        case 12: _t->instantChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->changed(); break;
        case 14: _t->setCitedKeys(); break;
        case 15: _t->updateStyles(); break;
        case 16: _t->updateControls(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiCitation::staticMetaObject = {
    { &DialogView::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiCitation.data,
      qt_meta_data_lyx__frontend__GuiCitation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiCitation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiCitation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiCitation.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CitationUi"))
        return static_cast< Ui::CitationUi*>(this);
    return DialogView::qt_metacast(_clname);
}

int lyx::frontend::GuiCitation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DialogView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
