/****************************************************************************
** Meta object code from reading C++ file 'GuiBranches.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiBranches.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiBranches.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiBranches_t {
    QByteArrayData data[21];
    char stringdata0[400];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiBranches_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiBranches_t qt_meta_stringdata_lyx__frontend__GuiBranches = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiBranches"
QT_MOC_LITERAL(1, 27, 7), // "changed"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 14), // "renameBranches"
QT_MOC_LITERAL(4, 51, 9), // "docstring"
QT_MOC_LITERAL(5, 61, 9), // "okPressed"
QT_MOC_LITERAL(6, 71, 26), // "on_newBranchLE_textChanged"
QT_MOC_LITERAL(7, 98, 22), // "on_addBranchPB_pressed"
QT_MOC_LITERAL(8, 121, 19), // "on_removePB_pressed"
QT_MOC_LITERAL(9, 141, 19), // "on_renamePB_pressed"
QT_MOC_LITERAL(10, 161, 21), // "on_activatePB_pressed"
QT_MOC_LITERAL(11, 183, 31), // "on_branchesTW_itemDoubleClicked"
QT_MOC_LITERAL(12, 215, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 232, 34), // "on_branchesTW_itemSelectionCh..."
QT_MOC_LITERAL(14, 267, 18), // "on_colorPB_clicked"
QT_MOC_LITERAL(15, 286, 23), // "on_resetColorPB_clicked"
QT_MOC_LITERAL(16, 310, 19), // "on_suffixPB_pressed"
QT_MOC_LITERAL(17, 330, 20), // "on_unknownPB_pressed"
QT_MOC_LITERAL(18, 351, 10), // "addUnknown"
QT_MOC_LITERAL(19, 362, 13), // "addAllUnknown"
QT_MOC_LITERAL(20, 376, 23) // "unknownBranchSelChanged"

    },
    "lyx::frontend::GuiBranches\0changed\0\0"
    "renameBranches\0docstring\0okPressed\0"
    "on_newBranchLE_textChanged\0"
    "on_addBranchPB_pressed\0on_removePB_pressed\0"
    "on_renamePB_pressed\0on_activatePB_pressed\0"
    "on_branchesTW_itemDoubleClicked\0"
    "QTreeWidgetItem*\0on_branchesTW_itemSelectionChanged\0"
    "on_colorPB_clicked\0on_resetColorPB_clicked\0"
    "on_suffixPB_pressed\0on_unknownPB_pressed\0"
    "addUnknown\0addAllUnknown\0"
    "unknownBranchSelChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiBranches[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,
       3,    2,  100,    2, 0x06 /* Public */,
       5,    0,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,  106,    2, 0x09 /* Protected */,
       7,    0,  109,    2, 0x09 /* Protected */,
       8,    0,  110,    2, 0x09 /* Protected */,
       9,    0,  111,    2, 0x09 /* Protected */,
      10,    0,  112,    2, 0x09 /* Protected */,
      11,    2,  113,    2, 0x09 /* Protected */,
      13,    0,  118,    2, 0x09 /* Protected */,
      14,    0,  119,    2, 0x09 /* Protected */,
      15,    0,  120,    2, 0x09 /* Protected */,
      16,    0,  121,    2, 0x09 /* Protected */,
      17,    0,  122,    2, 0x09 /* Protected */,
      18,    0,  123,    2, 0x09 /* Protected */,
      19,    0,  124,    2, 0x09 /* Protected */,
      20,    0,  125,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiBranches::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiBranches *_t = static_cast<GuiBranches *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->renameBranches((*reinterpret_cast< const docstring(*)>(_a[1])),(*reinterpret_cast< const docstring(*)>(_a[2]))); break;
        case 2: _t->okPressed(); break;
        case 3: _t->on_newBranchLE_textChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->on_addBranchPB_pressed(); break;
        case 5: _t->on_removePB_pressed(); break;
        case 6: _t->on_renamePB_pressed(); break;
        case 7: _t->on_activatePB_pressed(); break;
        case 8: _t->on_branchesTW_itemDoubleClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: _t->on_branchesTW_itemSelectionChanged(); break;
        case 10: _t->on_colorPB_clicked(); break;
        case 11: _t->on_resetColorPB_clicked(); break;
        case 12: _t->on_suffixPB_pressed(); break;
        case 13: _t->on_unknownPB_pressed(); break;
        case 14: _t->addUnknown(); break;
        case 15: _t->addAllUnknown(); break;
        case 16: _t->unknownBranchSelChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiBranches::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiBranches::changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiBranches::*_t)(docstring const & , docstring const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiBranches::renameBranches)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiBranches::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiBranches::okPressed)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiBranches::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiBranches.data,
      qt_meta_data_lyx__frontend__GuiBranches,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiBranches::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiBranches::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiBranches.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::BranchesUi"))
        return static_cast< Ui::BranchesUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::GuiBranches::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiBranches::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void lyx::frontend::GuiBranches::renameBranches(docstring const & _t1, docstring const & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void lyx::frontend::GuiBranches::okPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
