/********************************************************************************
** Form generated from reading UI file 'RefUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REFUI_H
#define UI_REFUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_RefUi
{
public:
    QGridLayout *gridLayout_2;
    QTreeWidget *refsTW;
    QHBoxLayout *horizontalLayout_4;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QLabel *findKeysLA;
    QLabel *refsL;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *filterBarL;
    QCheckBox *csFindCB;
    QComboBox *bufferCO;
    QHBoxLayout *hboxLayout;
    QLabel *SortLA;
    QComboBox *sortingCO;
    QCheckBox *groupCB;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QLabel *referenceL;
    QLineEdit *referenceED;
    QPushButton *gotoPB;
    QHBoxLayout *horizontalLayout_3;
    QLabel *typeLA;
    QComboBox *typeCO;
    QHBoxLayout *hboxLayout1;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *horizontalLayout9;
    QCheckBox *pluralCB;
    QCheckBox *capsCB;
    QCheckBox *noprefixCB;
    QCheckBox *nolinkCB;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *RefUi)
    {
        if (RefUi->objectName().isEmpty())
            RefUi->setObjectName(QStringLiteral("RefUi"));
        RefUi->resize(435, 539);
        RefUi->setSizeGripEnabled(true);
        gridLayout_2 = new QGridLayout(RefUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        refsTW = new QTreeWidget(RefUi);
        refsTW->setObjectName(QStringLiteral("refsTW"));
        refsTW->setColumnCount(2);
        refsTW->header()->setDefaultSectionSize(200);
        refsTW->header()->setStretchLastSection(true);

        gridLayout_2->addWidget(refsTW, 2, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));

        gridLayout_2->addLayout(horizontalLayout_4, 7, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        findKeysLA = new QLabel(RefUi);
        findKeysLA->setObjectName(QStringLiteral("findKeysLA"));
        findKeysLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        verticalLayout->addWidget(findKeysLA);

        refsL = new QLabel(RefUi);
        refsL->setObjectName(QStringLiteral("refsL"));

        verticalLayout->addWidget(refsL);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        filterBarL = new QHBoxLayout();
        filterBarL->setObjectName(QStringLiteral("filterBarL"));

        horizontalLayout->addLayout(filterBarL);

        csFindCB = new QCheckBox(RefUi);
        csFindCB->setObjectName(QStringLiteral("csFindCB"));

        horizontalLayout->addWidget(csFindCB);


        verticalLayout_2->addLayout(horizontalLayout);

        bufferCO = new QComboBox(RefUi);
        bufferCO->setObjectName(QStringLiteral("bufferCO"));
        QSizePolicy sizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bufferCO->sizePolicy().hasHeightForWidth());
        bufferCO->setSizePolicy(sizePolicy);
        bufferCO->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
        bufferCO->setMinimumContentsLength(0);

        verticalLayout_2->addWidget(bufferCO);


        gridLayout->addLayout(verticalLayout_2, 0, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        SortLA = new QLabel(RefUi);
        SortLA->setObjectName(QStringLiteral("SortLA"));

        hboxLayout->addWidget(SortLA);

        sortingCO = new QComboBox(RefUi);
        sortingCO->setObjectName(QStringLiteral("sortingCO"));

        hboxLayout->addWidget(sortingCO);

        groupCB = new QCheckBox(RefUi);
        groupCB->setObjectName(QStringLiteral("groupCB"));

        hboxLayout->addWidget(groupCB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(hboxLayout, 3, 0, 1, 1);

        label = new QLabel(RefUi);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        referenceL = new QLabel(RefUi);
        referenceL->setObjectName(QStringLiteral("referenceL"));
        referenceL->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(referenceL);

        referenceED = new QLineEdit(RefUi);
        referenceED->setObjectName(QStringLiteral("referenceED"));

        horizontalLayout_2->addWidget(referenceED);

        gotoPB = new QPushButton(RefUi);
        gotoPB->setObjectName(QStringLiteral("gotoPB"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gotoPB->sizePolicy().hasHeightForWidth());
        gotoPB->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(gotoPB);


        gridLayout_2->addLayout(horizontalLayout_2, 4, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        typeLA = new QLabel(RefUi);
        typeLA->setObjectName(QStringLiteral("typeLA"));
        typeLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(typeLA);

        typeCO = new QComboBox(RefUi);
        typeCO->setObjectName(QStringLiteral("typeCO"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(typeCO->sizePolicy().hasHeightForWidth());
        typeCO->setSizePolicy(sizePolicy2);

        horizontalLayout_3->addWidget(typeCO);


        gridLayout_2->addLayout(horizontalLayout_3, 5, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(RefUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hboxLayout1->addWidget(buttonBox);


        gridLayout_2->addLayout(hboxLayout1, 8, 0, 1, 1);

        horizontalLayout9 = new QHBoxLayout();
        horizontalLayout9->setObjectName(QStringLiteral("horizontalLayout9"));
        pluralCB = new QCheckBox(RefUi);
        pluralCB->setObjectName(QStringLiteral("pluralCB"));

        horizontalLayout9->addWidget(pluralCB);

        capsCB = new QCheckBox(RefUi);
        capsCB->setObjectName(QStringLiteral("capsCB"));

        horizontalLayout9->addWidget(capsCB);

        noprefixCB = new QCheckBox(RefUi);
        noprefixCB->setObjectName(QStringLiteral("noprefixCB"));

        horizontalLayout9->addWidget(noprefixCB);

        nolinkCB = new QCheckBox(RefUi);
        nolinkCB->setObjectName(QStringLiteral("nolinkCB"));

        horizontalLayout9->addWidget(nolinkCB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout9->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout9, 6, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        refsL->setBuddy(bufferCO);
        SortLA->setBuddy(sortingCO);
        label->setBuddy(refsTW);
        referenceL->setBuddy(referenceED);
        typeLA->setBuddy(typeCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(refsTW, csFindCB);
        QWidget::setTabOrder(csFindCB, groupCB);
        QWidget::setTabOrder(groupCB, referenceED);
        QWidget::setTabOrder(referenceED, typeCO);

        retranslateUi(RefUi);

        QMetaObject::connectSlotsByName(RefUi);
    } // setupUi

    void retranslateUi(QDialog *RefUi)
    {
        RefUi->setWindowTitle(QString());
        QTreeWidgetItem *___qtreewidgetitem = refsTW->headerItem();
        ___qtreewidgetitem->setText(1, lyx::qt_("Reference counter value", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, lyx::qt_("Label", Q_NULLPTR));
        findKeysLA->setText(lyx::qt_("&Filter:", Q_NULLPTR));
        refsL->setText(lyx::qt_("&In[[buffer]]:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        csFindCB->setToolTip(lyx::qt_("Filter case-sensitively", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        csFindCB->setText(lyx::qt_("Case Sensiti&ve", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bufferCO->setToolTip(lyx::qt_("The (sub-)document from which the available labels are displayed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        SortLA->setText(lyx::qt_("So&rt:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        sortingCO->setToolTip(lyx::qt_("Sorting of the list of available labels", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        groupCB->setToolTip(lyx::qt_("Group the list of available labels by prefix (e.g. \"sec:\")", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupCB->setText(lyx::qt_("Grou&p", Q_NULLPTR));
        label->setText(lyx::qt_("Available &Labels:", Q_NULLPTR));
        referenceL->setText(lyx::qt_("Sele&cted Label:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        referenceED->setToolTip(lyx::qt_("Select a label from the list above or enter a label manually", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        gotoPB->setToolTip(lyx::qt_("Jump to the selected label", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        gotoPB->setText(lyx::qt_("&Go to Label", Q_NULLPTR));
        typeLA->setText(lyx::qt_("Reference For&mat:", Q_NULLPTR));
        typeCO->clear();
        typeCO->insertItems(0, QStringList()
         << lyx::qt_("<reference>", Q_NULLPTR)
         << lyx::qt_("(<reference>)", Q_NULLPTR)
         << lyx::qt_("<page>", Q_NULLPTR)
         << lyx::qt_("on page <page>", Q_NULLPTR)
         << lyx::qt_("<reference> on page <page>", Q_NULLPTR)
         << lyx::qt_("Formatted reference", Q_NULLPTR)
         << lyx::qt_("Textual reference", Q_NULLPTR)
         << lyx::qt_("Label only", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        typeCO->setToolTip(lyx::qt_("Adjust the style of the cross-reference", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        pluralCB->setToolTip(lyx::qt_("Use plural form of formatted reference. (Works only for formatted references, and only if you are using refstyle.)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pluralCB->setText(lyx::qt_("Plural", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        capsCB->setToolTip(lyx::qt_("Use capitalized form of formatted reference. (Works only for formatted references, and only if you are using refstyle.)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        capsCB->setText(lyx::qt_("Capitalized", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        noprefixCB->setToolTip(lyx::qt_("Do not output part of label before \":\"", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        noprefixCB->setText(lyx::qt_("No Prefix", Q_NULLPTR));
        nolinkCB->setText(lyx::qt_("No Hyperlink", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class RefUi: public Ui_RefUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_REFUI_H
