/********************************************************************************
** Form generated from reading UI file 'PhantomUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PHANTOMUI_H
#define UI_PHANTOMUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PhantomUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *PhantomBG;
    QVBoxLayout *vboxLayout;
    QRadioButton *phantomRB;
    QRadioButton *hphantomRB;
    QRadioButton *vphantomRB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PhantomUi)
    {
        if (PhantomUi->objectName().isEmpty())
            PhantomUi->setObjectName(QStringLiteral("PhantomUi"));
        PhantomUi->resize(221, 196);
        PhantomUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(PhantomUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        PhantomBG = new QGroupBox(PhantomUi);
        PhantomBG->setObjectName(QStringLiteral("PhantomBG"));
        PhantomBG->setFlat(true);
        vboxLayout = new QVBoxLayout(PhantomBG);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        phantomRB = new QRadioButton(PhantomBG);
        phantomRB->setObjectName(QStringLiteral("phantomRB"));

        vboxLayout->addWidget(phantomRB);

        hphantomRB = new QRadioButton(PhantomBG);
        hphantomRB->setObjectName(QStringLiteral("hphantomRB"));

        vboxLayout->addWidget(hphantomRB);

        vphantomRB = new QRadioButton(PhantomBG);
        vphantomRB->setObjectName(QStringLiteral("vphantomRB"));

        vboxLayout->addWidget(vphantomRB);


        gridLayout->addWidget(PhantomBG, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(PhantomUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);

        QWidget::setTabOrder(phantomRB, hphantomRB);
        QWidget::setTabOrder(hphantomRB, vphantomRB);

        retranslateUi(PhantomUi);

        QMetaObject::connectSlotsByName(PhantomUi);
    } // setupUi

    void retranslateUi(QDialog *PhantomUi)
    {
        PhantomUi->setWindowTitle(QString());
        PhantomBG->setTitle(lyx::qt_("Type", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        phantomRB->setToolTip(lyx::qt_("Horizontal and vertical space of the phantom content", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        phantomRB->setText(lyx::qt_("Phanto&m", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        hphantomRB->setToolTip(lyx::qt_("Horizontal space of the phantom content", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        hphantomRB->setText(lyx::qt_("&Horizontal Phantom", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        vphantomRB->setToolTip(lyx::qt_("Vertical space of the phantom content", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        vphantomRB->setText(lyx::qt_("Verti&cal Phantom", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PhantomUi: public Ui_PhantomUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PHANTOMUI_H
