/********************************************************************************
** Form generated from reading UI file 'ExternalUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTERNALUI_H
#define UI_EXTERNALUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ExternalUi
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tab;
    QWidget *filetab;
    QGridLayout *gridLayout1;
    QLineEdit *fileED;
    QLabel *fileLA;
    QPushButton *browsePB;
    QCheckBox *draftCB;
    QGroupBox *GroupBox3;
    QGridLayout *gridLayout2;
    QTextBrowser *externalTB;
    QSpacerItem *spacerItem;
    QComboBox *externalCO;
    QWidget *lyxviewtab;
    QVBoxLayout *vboxLayout;
    QGroupBox *optionsGB;
    QGridLayout *gridLayout3;
    QLineEdit *extraED;
    QLabel *optionLA;
    QComboBox *extraFormatCO;
    QLabel *formatLA;
    QGroupBox *displayGB;
    QGridLayout *gridLayout4;
    QLabel *scaleLA;
    QLineEdit *displayscaleED;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QWidget *sizetab;
    QGridLayout *gridLayout5;
    QGroupBox *rotationGB;
    QGridLayout *gridLayout6;
    QSpacerItem *spacerItem3;
    QGridLayout *gridLayout7;
    QLineEdit *angleED;
    QLabel *originLA;
    QComboBox *originCO;
    QLabel *angleLA;
    QGroupBox *scaleGB;
    QGridLayout *gridLayout8;
    lyx::frontend::LengthCombo *heightUnitCO;
    lyx::frontend::LengthCombo *widthUnitCO;
    QLineEdit *heightED;
    QLineEdit *widthED;
    QLabel *widthLA;
    QCheckBox *aspectratioCB;
    QLabel *heightLA;
    QGroupBox *cropGB;
    QGridLayout *gridLayout9;
    QCheckBox *clipCB;
    QLabel *lbLA;
    QLineEdit *ytED;
    QLabel *xLA;
    QLabel *rtLA;
    QPushButton *getbbPB;
    QLineEdit *xlED;
    QSpacerItem *spacerItem4;
    QLineEdit *ybED;
    QLabel *yLA;
    QLineEdit *xrED;
    lyx::frontend::LengthCombo *xrUnitCO;
    lyx::frontend::LengthCombo *ytUnitCO;
    lyx::frontend::LengthCombo *xlUnitCO;
    lyx::frontend::LengthCombo *ybUnitCO;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ExternalUi)
    {
        if (ExternalUi->objectName().isEmpty())
            ExternalUi->setObjectName(QStringLiteral("ExternalUi"));
        ExternalUi->resize(574, 601);
        ExternalUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(ExternalUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        tab = new QTabWidget(ExternalUi);
        tab->setObjectName(QStringLiteral("tab"));
        filetab = new QWidget();
        filetab->setObjectName(QStringLiteral("filetab"));
        gridLayout1 = new QGridLayout(filetab);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        fileED = new QLineEdit(filetab);
        fileED->setObjectName(QStringLiteral("fileED"));

        gridLayout1->addWidget(fileED, 0, 1, 1, 1);

        fileLA = new QLabel(filetab);
        fileLA->setObjectName(QStringLiteral("fileLA"));

        gridLayout1->addWidget(fileLA, 0, 0, 1, 1);

        browsePB = new QPushButton(filetab);
        browsePB->setObjectName(QStringLiteral("browsePB"));

        gridLayout1->addWidget(browsePB, 0, 2, 1, 1);

        draftCB = new QCheckBox(filetab);
        draftCB->setObjectName(QStringLiteral("draftCB"));

        gridLayout1->addWidget(draftCB, 2, 0, 1, 3);

        GroupBox3 = new QGroupBox(filetab);
        GroupBox3->setObjectName(QStringLiteral("GroupBox3"));
        GroupBox3->setFlat(true);
        gridLayout2 = new QGridLayout(GroupBox3);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        externalTB = new QTextBrowser(GroupBox3);
        externalTB->setObjectName(QStringLiteral("externalTB"));

        gridLayout2->addWidget(externalTB, 1, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        gridLayout2->addItem(spacerItem, 0, 1, 1, 1);

        externalCO = new QComboBox(GroupBox3);
        externalCO->setObjectName(QStringLiteral("externalCO"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(externalCO->sizePolicy().hasHeightForWidth());
        externalCO->setSizePolicy(sizePolicy);

        gridLayout2->addWidget(externalCO, 0, 0, 1, 1);


        gridLayout1->addWidget(GroupBox3, 1, 0, 1, 3);

        tab->addTab(filetab, QString());
        lyxviewtab = new QWidget();
        lyxviewtab->setObjectName(QStringLiteral("lyxviewtab"));
        vboxLayout = new QVBoxLayout(lyxviewtab);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        optionsGB = new QGroupBox(lyxviewtab);
        optionsGB->setObjectName(QStringLiteral("optionsGB"));
        optionsGB->setFlat(true);
        gridLayout3 = new QGridLayout(optionsGB);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        extraED = new QLineEdit(optionsGB);
        extraED->setObjectName(QStringLiteral("extraED"));

        gridLayout3->addWidget(extraED, 1, 1, 1, 1);

        optionLA = new QLabel(optionsGB);
        optionLA->setObjectName(QStringLiteral("optionLA"));

        gridLayout3->addWidget(optionLA, 0, 1, 1, 1);

        extraFormatCO = new QComboBox(optionsGB);
        extraFormatCO->setObjectName(QStringLiteral("extraFormatCO"));

        gridLayout3->addWidget(extraFormatCO, 1, 0, 1, 1);

        formatLA = new QLabel(optionsGB);
        formatLA->setObjectName(QStringLiteral("formatLA"));
        formatLA->setTextFormat(Qt::AutoText);

        gridLayout3->addWidget(formatLA, 0, 0, 1, 1);


        vboxLayout->addWidget(optionsGB);

        displayGB = new QGroupBox(lyxviewtab);
        displayGB->setObjectName(QStringLiteral("displayGB"));
        displayGB->setFlat(true);
        displayGB->setCheckable(true);
        gridLayout4 = new QGridLayout(displayGB);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        scaleLA = new QLabel(displayGB);
        scaleLA->setObjectName(QStringLiteral("scaleLA"));

        gridLayout4->addWidget(scaleLA, 0, 0, 1, 1);

        displayscaleED = new QLineEdit(displayGB);
        displayscaleED->setObjectName(QStringLiteral("displayscaleED"));
        displayscaleED->setEnabled(true);
        sizePolicy.setHeightForWidth(displayscaleED->sizePolicy().hasHeightForWidth());
        displayscaleED->setSizePolicy(sizePolicy);

        gridLayout4->addWidget(displayscaleED, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout4->addItem(spacerItem1, 0, 2, 1, 1);


        vboxLayout->addWidget(displayGB);

        spacerItem2 = new QSpacerItem(81, 196, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem2);

        tab->addTab(lyxviewtab, QString());
        sizetab = new QWidget();
        sizetab->setObjectName(QStringLiteral("sizetab"));
        gridLayout5 = new QGridLayout(sizetab);
        gridLayout5->setSpacing(6);
        gridLayout5->setObjectName(QStringLiteral("gridLayout5"));
        gridLayout5->setContentsMargins(9, 9, 9, 9);
        rotationGB = new QGroupBox(sizetab);
        rotationGB->setObjectName(QStringLiteral("rotationGB"));
        rotationGB->setFlat(true);
        gridLayout6 = new QGridLayout(rotationGB);
        gridLayout6->setSpacing(6);
        gridLayout6->setObjectName(QStringLiteral("gridLayout6"));
        gridLayout6->setContentsMargins(9, 9, 9, 9);
        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout6->addItem(spacerItem3, 0, 1, 1, 1);

        gridLayout7 = new QGridLayout();
        gridLayout7->setSpacing(6);
        gridLayout7->setObjectName(QStringLiteral("gridLayout7"));
        gridLayout7->setContentsMargins(0, 0, 0, 0);
        angleED = new QLineEdit(rotationGB);
        angleED->setObjectName(QStringLiteral("angleED"));
        sizePolicy.setHeightForWidth(angleED->sizePolicy().hasHeightForWidth());
        angleED->setSizePolicy(sizePolicy);

        gridLayout7->addWidget(angleED, 0, 1, 1, 1);

        originLA = new QLabel(rotationGB);
        originLA->setObjectName(QStringLiteral("originLA"));

        gridLayout7->addWidget(originLA, 1, 0, 1, 1);

        originCO = new QComboBox(rotationGB);
        originCO->setObjectName(QStringLiteral("originCO"));

        gridLayout7->addWidget(originCO, 1, 1, 1, 1);

        angleLA = new QLabel(rotationGB);
        angleLA->setObjectName(QStringLiteral("angleLA"));

        gridLayout7->addWidget(angleLA, 0, 0, 1, 1);


        gridLayout6->addLayout(gridLayout7, 0, 0, 1, 1);


        gridLayout5->addWidget(rotationGB, 1, 0, 1, 1);

        scaleGB = new QGroupBox(sizetab);
        scaleGB->setObjectName(QStringLiteral("scaleGB"));
        scaleGB->setFlat(true);
        gridLayout8 = new QGridLayout(scaleGB);
        gridLayout8->setSpacing(6);
        gridLayout8->setObjectName(QStringLiteral("gridLayout8"));
        gridLayout8->setContentsMargins(9, 9, 9, 9);
        heightUnitCO = new lyx::frontend::LengthCombo(scaleGB);
        heightUnitCO->setObjectName(QStringLiteral("heightUnitCO"));

        gridLayout8->addWidget(heightUnitCO, 1, 2, 1, 1);

        widthUnitCO = new lyx::frontend::LengthCombo(scaleGB);
        widthUnitCO->setObjectName(QStringLiteral("widthUnitCO"));

        gridLayout8->addWidget(widthUnitCO, 0, 2, 1, 1);

        heightED = new QLineEdit(scaleGB);
        heightED->setObjectName(QStringLiteral("heightED"));
        heightED->setEnabled(true);

        gridLayout8->addWidget(heightED, 1, 1, 1, 1);

        widthED = new QLineEdit(scaleGB);
        widthED->setObjectName(QStringLiteral("widthED"));
        widthED->setEnabled(true);

        gridLayout8->addWidget(widthED, 0, 1, 1, 1);

        widthLA = new QLabel(scaleGB);
        widthLA->setObjectName(QStringLiteral("widthLA"));
        widthLA->setEnabled(true);

        gridLayout8->addWidget(widthLA, 0, 0, 1, 1);

        aspectratioCB = new QCheckBox(scaleGB);
        aspectratioCB->setObjectName(QStringLiteral("aspectratioCB"));
        aspectratioCB->setEnabled(true);

        gridLayout8->addWidget(aspectratioCB, 2, 1, 1, 2);

        heightLA = new QLabel(scaleGB);
        heightLA->setObjectName(QStringLiteral("heightLA"));
        heightLA->setEnabled(true);

        gridLayout8->addWidget(heightLA, 1, 0, 1, 1);


        gridLayout5->addWidget(scaleGB, 0, 0, 1, 1);

        cropGB = new QGroupBox(sizetab);
        cropGB->setObjectName(QStringLiteral("cropGB"));
        cropGB->setFlat(true);
        gridLayout9 = new QGridLayout(cropGB);
        gridLayout9->setSpacing(6);
        gridLayout9->setObjectName(QStringLiteral("gridLayout9"));
        gridLayout9->setContentsMargins(9, 9, 9, 9);
        clipCB = new QCheckBox(cropGB);
        clipCB->setObjectName(QStringLiteral("clipCB"));

        gridLayout9->addWidget(clipCB, 0, 0, 1, 2);

        lbLA = new QLabel(cropGB);
        lbLA->setObjectName(QStringLiteral("lbLA"));

        gridLayout9->addWidget(lbLA, 3, 0, 1, 1);

        ytED = new QLineEdit(cropGB);
        ytED->setObjectName(QStringLiteral("ytED"));

        gridLayout9->addWidget(ytED, 2, 3, 1, 1);

        xLA = new QLabel(cropGB);
        xLA->setObjectName(QStringLiteral("xLA"));

        gridLayout9->addWidget(xLA, 1, 1, 1, 1);

        rtLA = new QLabel(cropGB);
        rtLA->setObjectName(QStringLiteral("rtLA"));

        gridLayout9->addWidget(rtLA, 2, 0, 1, 1);

        getbbPB = new QPushButton(cropGB);
        getbbPB->setObjectName(QStringLiteral("getbbPB"));

        gridLayout9->addWidget(getbbPB, 0, 3, 1, 1);

        xlED = new QLineEdit(cropGB);
        xlED->setObjectName(QStringLiteral("xlED"));

        gridLayout9->addWidget(xlED, 3, 1, 1, 1);

        spacerItem4 = new QSpacerItem(43, 18, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout9->addItem(spacerItem4, 0, 2, 1, 1);

        ybED = new QLineEdit(cropGB);
        ybED->setObjectName(QStringLiteral("ybED"));

        gridLayout9->addWidget(ybED, 3, 3, 1, 1);

        yLA = new QLabel(cropGB);
        yLA->setObjectName(QStringLiteral("yLA"));

        gridLayout9->addWidget(yLA, 1, 3, 1, 1);

        xrED = new QLineEdit(cropGB);
        xrED->setObjectName(QStringLiteral("xrED"));

        gridLayout9->addWidget(xrED, 2, 1, 1, 1);

        xrUnitCO = new lyx::frontend::LengthCombo(cropGB);
        xrUnitCO->setObjectName(QStringLiteral("xrUnitCO"));

        gridLayout9->addWidget(xrUnitCO, 2, 2, 1, 1);

        ytUnitCO = new lyx::frontend::LengthCombo(cropGB);
        ytUnitCO->setObjectName(QStringLiteral("ytUnitCO"));

        gridLayout9->addWidget(ytUnitCO, 2, 4, 1, 1);

        xlUnitCO = new lyx::frontend::LengthCombo(cropGB);
        xlUnitCO->setObjectName(QStringLiteral("xlUnitCO"));

        gridLayout9->addWidget(xlUnitCO, 3, 2, 1, 1);

        ybUnitCO = new lyx::frontend::LengthCombo(cropGB);
        ybUnitCO->setObjectName(QStringLiteral("ybUnitCO"));

        gridLayout9->addWidget(ybUnitCO, 3, 4, 1, 1);


        gridLayout5->addWidget(cropGB, 2, 0, 1, 1);

        tab->addTab(sizetab, QString());

        gridLayout->addWidget(tab, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(ExternalUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        fileLA->setBuddy(fileED);
        optionLA->setBuddy(extraED);
        formatLA->setBuddy(extraFormatCO);
        scaleLA->setBuddy(displayscaleED);
        originLA->setBuddy(originCO);
        angleLA->setBuddy(angleED);
        widthLA->setBuddy(widthED);
        heightLA->setBuddy(heightED);
        lbLA->setBuddy(xlED);
        rtLA->setBuddy(xrED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(tab, fileED);
        QWidget::setTabOrder(fileED, browsePB);
        QWidget::setTabOrder(browsePB, externalCO);
        QWidget::setTabOrder(externalCO, externalTB);
        QWidget::setTabOrder(externalTB, draftCB);
        QWidget::setTabOrder(draftCB, angleED);
        QWidget::setTabOrder(angleED, originCO);

        retranslateUi(ExternalUi);

        tab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ExternalUi);
    } // setupUi

    void retranslateUi(QDialog *ExternalUi)
    {
        ExternalUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        tab->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        fileED->setToolTip(lyx::qt_("Filename", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        fileLA->setToolTip(lyx::qt_("Filename", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fileLA->setText(lyx::qt_("&File:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        browsePB->setToolTip(lyx::qt_("Select a file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        browsePB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
        draftCB->setText(lyx::qt_("&Draft", Q_NULLPTR));
        GroupBox3->setTitle(lyx::qt_("&Template", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        externalCO->setToolTip(lyx::qt_("Available templates", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tab->setTabText(tab->indexOf(filetab), lyx::qt_("F&ile", Q_NULLPTR));
        optionsGB->setTitle(lyx::qt_("LaTeX Options", Q_NULLPTR));
        optionLA->setText(lyx::qt_("O&ption:", Q_NULLPTR));
        formatLA->setText(lyx::qt_("For&mat:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        displayGB->setToolTip(lyx::qt_("Enable LyX to preview this material; only if graphics previewing is not disabled at application level (see Preference dialog).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        displayGB->setTitle(lyx::qt_("&Show in LyX", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        scaleLA->setToolTip(lyx::qt_("Percentage to scale by in LyX", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        scaleLA->setText(lyx::qt_("Sca&le on Screen (%):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        displayscaleED->setToolTip(lyx::qt_("Percentage to scale by in LyX", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tab->setTabText(tab->indexOf(lyxviewtab), lyx::qt_("LaTe&X and LyX options", Q_NULLPTR));
        rotationGB->setTitle(lyx::qt_("Rotate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        angleED->setToolTip(lyx::qt_("Angle to rotate image by", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        angleED->setText(QString());
#ifndef QT_NO_TOOLTIP
        originLA->setToolTip(lyx::qt_("The origin of the rotation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        originLA->setText(lyx::qt_("Ori&gin:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        originCO->setToolTip(lyx::qt_("The origin of the rotation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        angleLA->setToolTip(lyx::qt_("Angle to rotate image by", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        angleLA->setText(lyx::qt_("A&ngle:", Q_NULLPTR));
        scaleGB->setTitle(lyx::qt_("Scale", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        heightED->setToolTip(lyx::qt_("Height of image in output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        widthED->setToolTip(lyx::qt_("Width of image in output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        widthLA->setText(lyx::qt_("&Width:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        aspectratioCB->setToolTip(lyx::qt_("Maintain aspect ratio with largest dimension", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        aspectratioCB->setText(lyx::qt_("&Maintain aspect ratio", Q_NULLPTR));
        heightLA->setText(lyx::qt_("&Height:", Q_NULLPTR));
        cropGB->setTitle(lyx::qt_("Crop", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        clipCB->setToolTip(lyx::qt_("Clip to bounding box values", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        clipCB->setText(lyx::qt_("Clip to &bounding box", Q_NULLPTR));
        lbLA->setText(lyx::qt_("Left botto&m:", Q_NULLPTR));
        xLA->setText(lyx::qt_("x", Q_NULLPTR));
        rtLA->setText(lyx::qt_("Right &top:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        getbbPB->setToolTip(lyx::qt_("Get bounding box from the (EPS) file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        getbbPB->setText(lyx::qt_("&Get from File", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        xlED->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        yLA->setText(lyx::qt_("y", Q_NULLPTR));
        tab->setTabText(tab->indexOf(sizetab), lyx::qt_("Si&ze and Rotation", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ExternalUi: public Ui_ExternalUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EXTERNALUI_H
