/********************************************************************************
** Form generated from reading UI file 'PrintindexUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRINTINDEXUI_H
#define UI_PRINTINDEXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrintindexUi
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *vboxLayout;
    QLabel *indicesLA;
    QComboBox *indicesCO;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *subindexCB;
    QCheckBox *literalCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PrintindexUi)
    {
        if (PrintindexUi->objectName().isEmpty())
            PrintindexUi->setObjectName(QStringLiteral("PrintindexUi"));
        PrintindexUi->resize(287, 150);
        PrintindexUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(PrintindexUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        indicesLA = new QLabel(PrintindexUi);
        indicesLA->setObjectName(QStringLiteral("indicesLA"));

        vboxLayout->addWidget(indicesLA);

        indicesCO = new QComboBox(PrintindexUi);
        indicesCO->setObjectName(QStringLiteral("indicesCO"));

        vboxLayout->addWidget(indicesCO);


        gridLayout->addLayout(vboxLayout, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        subindexCB = new QCheckBox(PrintindexUi);
        subindexCB->setObjectName(QStringLiteral("subindexCB"));

        horizontalLayout_2->addWidget(subindexCB);

        literalCB = new QCheckBox(PrintindexUi);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        horizontalLayout_2->addWidget(literalCB);


        gridLayout->addLayout(horizontalLayout_2, 1, 0, 1, 1);

        buttonBox = new QDialogButtonBox(PrintindexUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        indicesLA->setBuddy(indicesCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(PrintindexUi);

        QMetaObject::connectSlotsByName(PrintindexUi);
    } // setupUi

    void retranslateUi(QDialog *PrintindexUi)
    {
        PrintindexUi->setWindowTitle(QString());
        indicesLA->setText(lyx::qt_("Available i&ndexes:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indicesCO->setToolTip(lyx::qt_("Select the index that shall be printed at this place of the document.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        subindexCB->setToolTip(lyx::qt_("Check if this index should be part (e.g., a section) of the former one.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        subindexCB->setText(lyx::qt_("&Subindex", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass index names literally to LaTeX. Check this if you want to use LaTeX code in index names.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrintindexUi: public Ui_PrintindexUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PRINTINDEXUI_H
