/****************************************************************************
** Meta object code from reading C++ file 'FileMonitor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/lyx-2.4.4/src/support/FileMonitor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FileMonitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__support__FileMonitorGuard_t {
    QByteArrayData data[8];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__support__FileMonitorGuard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__support__FileMonitorGuard_t qt_meta_stringdata_lyx__support__FileMonitorGuard = {
    {
QT_MOC_LITERAL(0, 0, 30), // "lyx::support::FileMonitorGuard"
QT_MOC_LITERAL(1, 31, 11), // "fileChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 6), // "exists"
QT_MOC_LITERAL(4, 51, 7), // "refresh"
QT_MOC_LITERAL(5, 59, 4), // "emit"
QT_MOC_LITERAL(6, 64, 12), // "notifyChange"
QT_MOC_LITERAL(7, 77, 4) // "path"

    },
    "lyx::support::FileMonitorGuard\0"
    "fileChanged\0\0exists\0refresh\0emit\0"
    "notifyChange\0path"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__support__FileMonitorGuard[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   37,    2, 0x0a /* Public */,
       4,    0,   40,    2, 0x2a /* Public | MethodCloned */,
       6,    1,   41,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,

       0        // eod
};

void lyx::support::FileMonitorGuard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileMonitorGuard *_t = static_cast<FileMonitorGuard *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->refresh((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->refresh(); break;
        case 3: _t->notifyChange((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileMonitorGuard::*_t)(bool ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileMonitorGuard::fileChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::support::FileMonitorGuard::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_lyx__support__FileMonitorGuard.data,
      qt_meta_data_lyx__support__FileMonitorGuard,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::support::FileMonitorGuard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::support::FileMonitorGuard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__support__FileMonitorGuard.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int lyx::support::FileMonitorGuard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void lyx::support::FileMonitorGuard::fileChanged(bool _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::support::FileMonitorGuard *>(this), &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_lyx__support__FileMonitor_t {
    QByteArrayData data[6];
    char stringdata0[80];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__support__FileMonitor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__support__FileMonitor_t qt_meta_stringdata_lyx__support__FileMonitor = {
    {
QT_MOC_LITERAL(0, 0, 25), // "lyx::support::FileMonitor"
QT_MOC_LITERAL(1, 26, 11), // "fileChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 6), // "exists"
QT_MOC_LITERAL(4, 46, 7), // "changed"
QT_MOC_LITERAL(5, 54, 25) // "connectToFileMonitorGuard"

    },
    "lyx::support::FileMonitor\0fileChanged\0"
    "\0exists\0changed\0connectToFileMonitorGuard"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__support__FileMonitor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   32,    2, 0x09 /* Protected */,
       5,    0,   35,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,

       0        // eod
};

void lyx::support::FileMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileMonitor *_t = static_cast<FileMonitor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->connectToFileMonitorGuard(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileMonitor::*_t)(bool ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileMonitor::fileChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::support::FileMonitor::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_lyx__support__FileMonitor.data,
      qt_meta_data_lyx__support__FileMonitor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::support::FileMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::support::FileMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__support__FileMonitor.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int lyx::support::FileMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void lyx::support::FileMonitor::fileChanged(bool _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< lyx::support::FileMonitor *>(this), &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_lyx__support__ActiveFileMonitor_t {
    QByteArrayData data[5];
    char stringdata0[73];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__support__ActiveFileMonitor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__support__ActiveFileMonitor_t qt_meta_stringdata_lyx__support__ActiveFileMonitor = {
    {
QT_MOC_LITERAL(0, 0, 31), // "lyx::support::ActiveFileMonitor"
QT_MOC_LITERAL(1, 32, 13), // "checkModified"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 11), // "setCooldown"
QT_MOC_LITERAL(4, 59, 13) // "clearCooldown"

    },
    "lyx::support::ActiveFileMonitor\0"
    "checkModified\0\0setCooldown\0clearCooldown"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__support__ActiveFileMonitor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    0,   30,    2, 0x08 /* Private */,
       4,    0,   31,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::support::ActiveFileMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ActiveFileMonitor *_t = static_cast<ActiveFileMonitor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->checkModified(); break;
        case 1: _t->setCooldown(); break;
        case 2: _t->clearCooldown(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::support::ActiveFileMonitor::staticMetaObject = {
    { &FileMonitor::staticMetaObject, qt_meta_stringdata_lyx__support__ActiveFileMonitor.data,
      qt_meta_data_lyx__support__ActiveFileMonitor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::support::ActiveFileMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::support::ActiveFileMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__support__ActiveFileMonitor.stringdata0))
        return static_cast<void*>(this);
    return FileMonitor::qt_metacast(_clname);
}

int lyx::support::ActiveFileMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FileMonitor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
