/********************************************************************************
** Form generated from reading UI file 'FontUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTUI_H
#define UI_FONTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "CategorizedCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_FontUi
{
public:
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer;
    QGridLayout *gridLayout_2;
    QLabel *fontsDefaultLA;
    QHBoxLayout *horizontalLayout;
    QComboBox *fontsDefaultCO;
    QLabel *BaseSizeLA;
    QComboBox *fontsizeCO;
    QSpacerItem *horizontalSpacer;
    QLabel *fontencLA;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *fontencCO;
    QLineEdit *fontencLE;
    QLabel *fontsRomanLA;
    QHBoxLayout *horizontalLayout_8;
    lyx::frontend::CategorizedCombo *fontsRomanCO;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *fontScCB;
    QHBoxLayout *horizontalLayout_9;
    QCheckBox *fontOsfCB;
    QSpacerItem *horizontalSpacer_7;
    QHBoxLayout *horizontalLayout_5;
    QLabel *fontspecRomanLA;
    QLineEdit *fontspecRomanLE;
    QLabel *fontsSansLA;
    QHBoxLayout *horizontalLayout_6;
    lyx::frontend::CategorizedCombo *fontsSansCO;
    QSpacerItem *horizontalSpacer_2;
    QLabel *scaleSansLA;
    QSpinBox *scaleSansSB;
    QHBoxLayout *horizontalLayout_10;
    QCheckBox *fontSansOsfCB;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_3;
    QLabel *fontspecSansLA;
    QLineEdit *fontspecSansLE;
    QLabel *fontsTypewriterLA;
    QHBoxLayout *horizontalLayout_7;
    lyx::frontend::CategorizedCombo *fontsTypewriterCO;
    QSpacerItem *horizontalSpacer_3;
    QLabel *scaleTypewriterLA;
    QSpinBox *scaleTypewriterSB;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *fontTypewriterOsfCB;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_4;
    QLabel *fontspecTypewriterLA;
    QLineEdit *fontspecTypewriterLE;
    QLabel *fontsMathLA;
    QComboBox *fontsMathCO;
    QLabel *cjkFontLA;
    QLineEdit *cjkFontLE;
    QCheckBox *microtypeCB;
    QCheckBox *osFontsCB;
    QCheckBox *dashesCB;

    void setupUi(QWidget *FontUi)
    {
        if (FontUi->objectName().isEmpty())
            FontUi->setObjectName(QStringLiteral("FontUi"));
        FontUi->resize(568, 565);
        gridLayout_3 = new QGridLayout(FontUi);
        gridLayout_3->setSpacing(6);
        gridLayout_3->setContentsMargins(11, 11, 11, 11);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 4, 0, 1, 1);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        fontsDefaultLA = new QLabel(FontUi);
        fontsDefaultLA->setObjectName(QStringLiteral("fontsDefaultLA"));

        gridLayout_2->addWidget(fontsDefaultLA, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        fontsDefaultCO = new QComboBox(FontUi);
        fontsDefaultCO->setObjectName(QStringLiteral("fontsDefaultCO"));

        horizontalLayout->addWidget(fontsDefaultCO);

        BaseSizeLA = new QLabel(FontUi);
        BaseSizeLA->setObjectName(QStringLiteral("BaseSizeLA"));

        horizontalLayout->addWidget(BaseSizeLA);

        fontsizeCO = new QComboBox(FontUi);
        fontsizeCO->setObjectName(QStringLiteral("fontsizeCO"));

        horizontalLayout->addWidget(fontsizeCO);

        horizontalSpacer = new QSpacerItem(59, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout, 0, 1, 1, 1);

        fontencLA = new QLabel(FontUi);
        fontencLA->setObjectName(QStringLiteral("fontencLA"));

        gridLayout_2->addWidget(fontencLA, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        fontencCO = new QComboBox(FontUi);
        fontencCO->setObjectName(QStringLiteral("fontencCO"));

        horizontalLayout_2->addWidget(fontencCO);

        fontencLE = new QLineEdit(FontUi);
        fontencLE->setObjectName(QStringLiteral("fontencLE"));

        horizontalLayout_2->addWidget(fontencLE);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        fontsRomanLA = new QLabel(FontUi);
        fontsRomanLA->setObjectName(QStringLiteral("fontsRomanLA"));

        gridLayout_2->addWidget(fontsRomanLA, 2, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(6);
        horizontalLayout_8->setObjectName(QStringLiteral("horizontalLayout_8"));
        fontsRomanCO = new lyx::frontend::CategorizedCombo(FontUi);
        fontsRomanCO->setObjectName(QStringLiteral("fontsRomanCO"));

        horizontalLayout_8->addWidget(fontsRomanCO);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_4);

        fontScCB = new QCheckBox(FontUi);
        fontScCB->setObjectName(QStringLiteral("fontScCB"));

        horizontalLayout_8->addWidget(fontScCB);


        gridLayout_2->addLayout(horizontalLayout_8, 2, 1, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setSpacing(6);
        horizontalLayout_9->setObjectName(QStringLiteral("horizontalLayout_9"));
        fontOsfCB = new QCheckBox(FontUi);
        fontOsfCB->setObjectName(QStringLiteral("fontOsfCB"));

        horizontalLayout_9->addWidget(fontOsfCB);

        horizontalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_7);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(6);
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        fontspecRomanLA = new QLabel(FontUi);
        fontspecRomanLA->setObjectName(QStringLiteral("fontspecRomanLA"));

        horizontalLayout_5->addWidget(fontspecRomanLA);

        fontspecRomanLE = new QLineEdit(FontUi);
        fontspecRomanLE->setObjectName(QStringLiteral("fontspecRomanLE"));

        horizontalLayout_5->addWidget(fontspecRomanLE);


        horizontalLayout_9->addLayout(horizontalLayout_5);


        gridLayout_2->addLayout(horizontalLayout_9, 3, 1, 1, 1);

        fontsSansLA = new QLabel(FontUi);
        fontsSansLA->setObjectName(QStringLiteral("fontsSansLA"));

        gridLayout_2->addWidget(fontsSansLA, 4, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(6);
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        fontsSansCO = new lyx::frontend::CategorizedCombo(FontUi);
        fontsSansCO->setObjectName(QStringLiteral("fontsSansCO"));

        horizontalLayout_6->addWidget(fontsSansCO);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);

        scaleSansLA = new QLabel(FontUi);
        scaleSansLA->setObjectName(QStringLiteral("scaleSansLA"));

        horizontalLayout_6->addWidget(scaleSansLA);

        scaleSansSB = new QSpinBox(FontUi);
        scaleSansSB->setObjectName(QStringLiteral("scaleSansSB"));
        scaleSansSB->setMinimum(10);
        scaleSansSB->setMaximum(200);

        horizontalLayout_6->addWidget(scaleSansSB);


        gridLayout_2->addLayout(horizontalLayout_6, 4, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(6);
        horizontalLayout_10->setObjectName(QStringLiteral("horizontalLayout_10"));
        fontSansOsfCB = new QCheckBox(FontUi);
        fontSansOsfCB->setObjectName(QStringLiteral("fontSansOsfCB"));

        horizontalLayout_10->addWidget(fontSansOsfCB);

        horizontalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        fontspecSansLA = new QLabel(FontUi);
        fontspecSansLA->setObjectName(QStringLiteral("fontspecSansLA"));

        horizontalLayout_3->addWidget(fontspecSansLA);

        fontspecSansLE = new QLineEdit(FontUi);
        fontspecSansLE->setObjectName(QStringLiteral("fontspecSansLE"));

        horizontalLayout_3->addWidget(fontspecSansLE);


        horizontalLayout_10->addLayout(horizontalLayout_3);


        gridLayout_2->addLayout(horizontalLayout_10, 5, 1, 1, 1);

        fontsTypewriterLA = new QLabel(FontUi);
        fontsTypewriterLA->setObjectName(QStringLiteral("fontsTypewriterLA"));

        gridLayout_2->addWidget(fontsTypewriterLA, 6, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        fontsTypewriterCO = new lyx::frontend::CategorizedCombo(FontUi);
        fontsTypewriterCO->setObjectName(QStringLiteral("fontsTypewriterCO"));

        horizontalLayout_7->addWidget(fontsTypewriterCO);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_3);

        scaleTypewriterLA = new QLabel(FontUi);
        scaleTypewriterLA->setObjectName(QStringLiteral("scaleTypewriterLA"));

        horizontalLayout_7->addWidget(scaleTypewriterLA);

        scaleTypewriterSB = new QSpinBox(FontUi);
        scaleTypewriterSB->setObjectName(QStringLiteral("scaleTypewriterSB"));
        scaleTypewriterSB->setMinimum(10);
        scaleTypewriterSB->setMaximum(200);

        horizontalLayout_7->addWidget(scaleTypewriterSB);


        gridLayout_2->addLayout(horizontalLayout_7, 6, 1, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(6);
        horizontalLayout_11->setObjectName(QStringLiteral("horizontalLayout_11"));
        fontTypewriterOsfCB = new QCheckBox(FontUi);
        fontTypewriterOsfCB->setObjectName(QStringLiteral("fontTypewriterOsfCB"));

        horizontalLayout_11->addWidget(fontTypewriterOsfCB);

        horizontalSpacer_6 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_6);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        fontspecTypewriterLA = new QLabel(FontUi);
        fontspecTypewriterLA->setObjectName(QStringLiteral("fontspecTypewriterLA"));

        horizontalLayout_4->addWidget(fontspecTypewriterLA);

        fontspecTypewriterLE = new QLineEdit(FontUi);
        fontspecTypewriterLE->setObjectName(QStringLiteral("fontspecTypewriterLE"));

        horizontalLayout_4->addWidget(fontspecTypewriterLE);


        horizontalLayout_11->addLayout(horizontalLayout_4);


        gridLayout_2->addLayout(horizontalLayout_11, 7, 1, 1, 1);

        fontsMathLA = new QLabel(FontUi);
        fontsMathLA->setObjectName(QStringLiteral("fontsMathLA"));

        gridLayout_2->addWidget(fontsMathLA, 8, 0, 1, 1);

        fontsMathCO = new QComboBox(FontUi);
        fontsMathCO->setObjectName(QStringLiteral("fontsMathCO"));

        gridLayout_2->addWidget(fontsMathCO, 8, 1, 1, 1);

        cjkFontLA = new QLabel(FontUi);
        cjkFontLA->setObjectName(QStringLiteral("cjkFontLA"));

        gridLayout_2->addWidget(cjkFontLA, 9, 0, 1, 1);

        cjkFontLE = new QLineEdit(FontUi);
        cjkFontLE->setObjectName(QStringLiteral("cjkFontLE"));

        gridLayout_2->addWidget(cjkFontLE, 9, 1, 1, 1);


        gridLayout_3->addLayout(gridLayout_2, 1, 0, 1, 1);

        microtypeCB = new QCheckBox(FontUi);
        microtypeCB->setObjectName(QStringLiteral("microtypeCB"));

        gridLayout_3->addWidget(microtypeCB, 2, 0, 1, 1);

        osFontsCB = new QCheckBox(FontUi);
        osFontsCB->setObjectName(QStringLiteral("osFontsCB"));

        gridLayout_3->addWidget(osFontsCB, 0, 0, 1, 1);

        dashesCB = new QCheckBox(FontUi);
        dashesCB->setObjectName(QStringLiteral("dashesCB"));

        gridLayout_3->addWidget(dashesCB, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        fontsDefaultLA->setBuddy(fontsDefaultCO);
        BaseSizeLA->setBuddy(fontsizeCO);
        fontencLA->setBuddy(fontencCO);
        fontsRomanLA->setBuddy(fontsRomanCO);
        fontspecRomanLA->setBuddy(fontspecRomanLE);
        fontsSansLA->setBuddy(fontsSansCO);
        scaleSansLA->setBuddy(scaleSansSB);
        fontspecSansLA->setBuddy(fontspecSansLE);
        fontsTypewriterLA->setBuddy(fontsTypewriterCO);
        scaleTypewriterLA->setBuddy(scaleTypewriterSB);
        fontspecTypewriterLA->setBuddy(fontspecTypewriterLE);
        fontsMathLA->setBuddy(fontsMathCO);
        cjkFontLA->setBuddy(cjkFontLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(osFontsCB, fontsDefaultCO);
        QWidget::setTabOrder(fontsDefaultCO, fontsizeCO);
        QWidget::setTabOrder(fontsizeCO, fontencCO);
        QWidget::setTabOrder(fontencCO, fontencLE);
        QWidget::setTabOrder(fontencLE, fontsRomanCO);
        QWidget::setTabOrder(fontsRomanCO, fontsSansCO);
        QWidget::setTabOrder(fontsSansCO, scaleSansSB);
        QWidget::setTabOrder(scaleSansSB, fontsTypewriterCO);
        QWidget::setTabOrder(fontsTypewriterCO, scaleTypewriterSB);
        QWidget::setTabOrder(scaleTypewriterSB, cjkFontLE);

        retranslateUi(FontUi);

        QMetaObject::connectSlotsByName(FontUi);
    } // setupUi

    void retranslateUi(QWidget *FontUi)
    {
        FontUi->setWindowTitle(lyx::qt_("FontUi", Q_NULLPTR));
        fontsDefaultLA->setText(lyx::qt_("&Default family:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsDefaultCO->setToolTip(lyx::qt_("Select the default family for the document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        BaseSizeLA->setText(lyx::qt_("&Base size:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsizeCO->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        fontencLA->setText(lyx::qt_("&LaTeX font encoding:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontencLE->setToolTip(lyx::qt_("Specify the font encoding (e.g., T1).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontsRomanLA->setText(lyx::qt_("&Roman:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsRomanCO->setToolTip(lyx::qt_("Select the roman (serif) typeface. To filter the list of fonts, just start typing while the list is expanded.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        fontScCB->setToolTip(lyx::qt_("Use a real small caps shape, if the font provides one", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontScCB->setText(lyx::qt_("Use true s&mall caps", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontOsfCB->setToolTip(lyx::qt_("Use old style instead of lining figures", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontOsfCB->setText(lyx::qt_("Use &old style figures", Q_NULLPTR));
        fontspecRomanLA->setText(lyx::qt_("Options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontspecRomanLE->setToolTip(lyx::qt_("Here you can insert additional options (as provided by the font package)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontsSansLA->setText(lyx::qt_("&Sans Serif:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsSansCO->setToolTip(lyx::qt_("Select the Sans Serif (grotesque) typeface. To filter the list of fonts, just start typing while the list is expanded.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        scaleSansLA->setText(lyx::qt_("S&cale (%):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        scaleSansSB->setToolTip(lyx::qt_("Scale the Sans Serif font to match the base font's dimensions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        fontSansOsfCB->setToolTip(lyx::qt_("Use old style instead of lining figures", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontSansOsfCB->setText(lyx::qt_("Use old st&yle figures", Q_NULLPTR));
        fontspecSansLA->setText(lyx::qt_("Options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontspecSansLE->setToolTip(lyx::qt_("Here you can insert additional options (as provided by the font package)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontsTypewriterLA->setText(lyx::qt_("&Typewriter:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsTypewriterCO->setToolTip(lyx::qt_("Select the typewriter (monospaced) typeface. To filter the list of fonts, just start typing while the list is expanded.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        scaleTypewriterLA->setText(lyx::qt_("Sc&ale (%):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        scaleTypewriterSB->setToolTip(lyx::qt_("Scale the Typewriter font to match the base font's dimensions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        fontTypewriterOsfCB->setToolTip(lyx::qt_("Use old style instead of lining figures", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontTypewriterOsfCB->setText(lyx::qt_("Use old style &figures", Q_NULLPTR));
        fontspecTypewriterLA->setText(lyx::qt_("Options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontspecTypewriterLE->setToolTip(lyx::qt_("Here you can insert additional options (as provided by the font package)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontsMathLA->setText(lyx::qt_("&Math:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsMathCO->setToolTip(lyx::qt_("Select the math typeface", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        cjkFontLA->setText(lyx::qt_("C&JK:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        cjkFontLE->setToolTip(lyx::qt_("Input the font to be used for Chinese, Japanese or Korean (CJK) script", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        microtypeCB->setToolTip(lyx::qt_("Activate extensions such as character protrusion and font expansion via the microtype package", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        microtypeCB->setText(lyx::qt_("Enable micr&o-typographic extensions", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        osFontsCB->setToolTip(lyx::qt_("Use OpenType and TrueType fonts with the fontspec package (requires XeTeX or LuaTeX)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        osFontsCB->setText(lyx::qt_("&Use non-TeX fonts (via XeTeX/LuaTeX)", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        dashesCB->setToolTip(lyx::qt_("By default, a line break can occur after en- and em-dashes. Checking this box prevents that.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        dashesCB->setText(lyx::qt_("Disallow l&ine breaks after dashes", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class FontUi: public Ui_FontUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FONTUI_H
