/********************************************************************************
** Form generated from reading UI file 'ChangeTrackingUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANGETRACKINGUI_H
#define UI_CHANGETRACKINGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ChangeTrackingUi
{
public:
    QGridLayout *gridLayout;
    QCheckBox *trackChangesCB;
    QCheckBox *outputChangesCB;
    QCheckBox *changeBarsCB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ChangeTrackingUi)
    {
        if (ChangeTrackingUi->objectName().isEmpty())
            ChangeTrackingUi->setObjectName(QStringLiteral("ChangeTrackingUi"));
        ChangeTrackingUi->resize(401, 140);
        gridLayout = new QGridLayout(ChangeTrackingUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        trackChangesCB = new QCheckBox(ChangeTrackingUi);
        trackChangesCB->setObjectName(QStringLiteral("trackChangesCB"));

        gridLayout->addWidget(trackChangesCB, 0, 0, 1, 1);

        outputChangesCB = new QCheckBox(ChangeTrackingUi);
        outputChangesCB->setObjectName(QStringLiteral("outputChangesCB"));

        gridLayout->addWidget(outputChangesCB, 1, 0, 1, 1);

        changeBarsCB = new QCheckBox(ChangeTrackingUi);
        changeBarsCB->setObjectName(QStringLiteral("changeBarsCB"));

        gridLayout->addWidget(changeBarsCB, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 32, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);


        retranslateUi(ChangeTrackingUi);

        QMetaObject::connectSlotsByName(ChangeTrackingUi);
    } // setupUi

    void retranslateUi(QWidget *ChangeTrackingUi)
    {
        ChangeTrackingUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        trackChangesCB->setToolTip(lyx::qt_("If checked, additions and deletions will be tracked in the document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        trackChangesCB->setText(lyx::qt_("&Track changes", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        outputChangesCB->setToolTip(lyx::qt_("If checked, changes will be shown in the PDF/DVI/PS output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        outputChangesCB->setText(lyx::qt_("&Show changes in output", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        changeBarsCB->setToolTip(lyx::qt_("Use change bars in addition to change tracking markup", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        changeBarsCB->setText(lyx::qt_("Use change &bars in output", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ChangeTrackingUi: public Ui_ChangeTrackingUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHANGETRACKINGUI_H
