/********************************************************************************
** Form generated from reading UI file 'CitationUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CITATIONUI_H
#define UI_CITATIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_CitationUi
{
public:
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_6;
    QHBoxLayout *horizontalLayout_5;
    QLabel *findKeysLA;
    QHBoxLayout *filterBarL;
    QComboBox *fieldsCO;
    QComboBox *entriesCO;
    QPushButton *searchOptionsPB;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_3;
    QLabel *availableKeysLA;
    QListView *availableLV;
    QVBoxLayout *verticalLayout;
    QLabel *spacerLA;
    QPushButton *addPB;
    QPushButton *deletePB;
    QSpacerItem *spacerItem;
    QPushButton *upPB;
    QPushButton *downPB;
    QVBoxLayout *verticalLayout_4;
    QLabel *selectedKeysLA;
    QTableView *selectedLV;
    QTextEdit *infoML;
    QGroupBox *FormattingGB;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QVBoxLayout *verticalLayout_5;
    QLabel *citationStyleLA;
    QLabel *textBeforeLA;
    QVBoxLayout *verticalLayout_6;
    QComboBox *citationStyleCO;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *textBeforeED;
    QLabel *textAfterLA;
    QLineEdit *textAfterED;
    QHBoxLayout *hboxLayout;
    QCheckBox *literalCB;
    QSpacerItem *spacerItem1;
    QCheckBox *forceuppercaseCB;
    QCheckBox *starredCB;
    QHBoxLayout *hboxLayout1;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CitationUi)
    {
        if (CitationUi->objectName().isEmpty())
            CitationUi->setObjectName(QStringLiteral("CitationUi"));
        CitationUi->resize(614, 522);
        CitationUi->setSizeGripEnabled(true);
        gridLayout_3 = new QGridLayout(CitationUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        findKeysLA = new QLabel(CitationUi);
        findKeysLA->setObjectName(QStringLiteral("findKeysLA"));
        findKeysLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_5->addWidget(findKeysLA);

        filterBarL = new QHBoxLayout();
        filterBarL->setObjectName(QStringLiteral("filterBarL"));

        horizontalLayout_5->addLayout(filterBarL);


        horizontalLayout_6->addLayout(horizontalLayout_5);

        fieldsCO = new QComboBox(CitationUi);
        fieldsCO->setObjectName(QStringLiteral("fieldsCO"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fieldsCO->sizePolicy().hasHeightForWidth());
        fieldsCO->setSizePolicy(sizePolicy);
        fieldsCO->setMaxVisibleItems(16);
        fieldsCO->setInsertPolicy(QComboBox::NoInsert);
        fieldsCO->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_6->addWidget(fieldsCO);

        entriesCO = new QComboBox(CitationUi);
        entriesCO->setObjectName(QStringLiteral("entriesCO"));
        sizePolicy.setHeightForWidth(entriesCO->sizePolicy().hasHeightForWidth());
        entriesCO->setSizePolicy(sizePolicy);
        entriesCO->setInsertPolicy(QComboBox::NoInsert);
        entriesCO->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_6->addWidget(entriesCO);

        searchOptionsPB = new QPushButton(CitationUi);
        searchOptionsPB->setObjectName(QStringLiteral("searchOptionsPB"));
        searchOptionsPB->setAutoDefault(false);

        horizontalLayout_6->addWidget(searchOptionsPB);


        gridLayout_3->addLayout(horizontalLayout_6, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        availableKeysLA = new QLabel(CitationUi);
        availableKeysLA->setObjectName(QStringLiteral("availableKeysLA"));

        verticalLayout_3->addWidget(availableKeysLA);

        availableLV = new QListView(CitationUi);
        availableLV->setObjectName(QStringLiteral("availableLV"));
        availableLV->setEditTriggers(QAbstractItemView::NoEditTriggers);

        verticalLayout_3->addWidget(availableLV);


        horizontalLayout->addLayout(verticalLayout_3);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        spacerLA = new QLabel(CitationUi);
        spacerLA->setObjectName(QStringLiteral("spacerLA"));

        verticalLayout->addWidget(spacerLA);

        addPB = new QPushButton(CitationUi);
        addPB->setObjectName(QStringLiteral("addPB"));
        addPB->setAutoDefault(false);

        verticalLayout->addWidget(addPB);

        deletePB = new QPushButton(CitationUi);
        deletePB->setObjectName(QStringLiteral("deletePB"));
        deletePB->setAutoDefault(false);

        verticalLayout->addWidget(deletePB);

        spacerItem = new QSpacerItem(77, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        upPB = new QPushButton(CitationUi);
        upPB->setObjectName(QStringLiteral("upPB"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(upPB->sizePolicy().hasHeightForWidth());
        upPB->setSizePolicy(sizePolicy1);
        QIcon icon;
        icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        upPB->setIcon(icon);
        upPB->setAutoDefault(false);

        verticalLayout->addWidget(upPB);

        downPB = new QPushButton(CitationUi);
        downPB->setObjectName(QStringLiteral("downPB"));
        sizePolicy1.setHeightForWidth(downPB->sizePolicy().hasHeightForWidth());
        downPB->setSizePolicy(sizePolicy1);
        downPB->setIcon(icon);
        downPB->setAutoDefault(false);

        verticalLayout->addWidget(downPB);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        selectedKeysLA = new QLabel(CitationUi);
        selectedKeysLA->setObjectName(QStringLiteral("selectedKeysLA"));

        verticalLayout_4->addWidget(selectedKeysLA);

        selectedLV = new QTableView(CitationUi);
        selectedLV->setObjectName(QStringLiteral("selectedLV"));

        verticalLayout_4->addWidget(selectedLV);


        horizontalLayout->addLayout(verticalLayout_4);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        infoML = new QTextEdit(CitationUi);
        infoML->setObjectName(QStringLiteral("infoML"));
        infoML->setMaximumSize(QSize(16777215, 60));
        infoML->setAcceptDrops(false);
        infoML->setReadOnly(true);

        gridLayout->addWidget(infoML, 1, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout);


        gridLayout_3->addLayout(verticalLayout_2, 1, 0, 1, 1);

        FormattingGB = new QGroupBox(CitationUi);
        FormattingGB->setObjectName(QStringLiteral("FormattingGB"));
        FormattingGB->setFlat(true);
        gridLayout_2 = new QGridLayout(FormattingGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        citationStyleLA = new QLabel(FormattingGB);
        citationStyleLA->setObjectName(QStringLiteral("citationStyleLA"));

        verticalLayout_5->addWidget(citationStyleLA);

        textBeforeLA = new QLabel(FormattingGB);
        textBeforeLA->setObjectName(QStringLiteral("textBeforeLA"));

        verticalLayout_5->addWidget(textBeforeLA);


        horizontalLayout_3->addLayout(verticalLayout_5);

        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setObjectName(QStringLiteral("verticalLayout_6"));
        citationStyleCO = new QComboBox(FormattingGB);
        citationStyleCO->setObjectName(QStringLiteral("citationStyleCO"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(citationStyleCO->sizePolicy().hasHeightForWidth());
        citationStyleCO->setSizePolicy(sizePolicy2);

        verticalLayout_6->addWidget(citationStyleCO);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        textBeforeED = new QLineEdit(FormattingGB);
        textBeforeED->setObjectName(QStringLiteral("textBeforeED"));

        horizontalLayout_2->addWidget(textBeforeED);

        textAfterLA = new QLabel(FormattingGB);
        textAfterLA->setObjectName(QStringLiteral("textAfterLA"));

        horizontalLayout_2->addWidget(textAfterLA);

        textAfterED = new QLineEdit(FormattingGB);
        textAfterED->setObjectName(QStringLiteral("textAfterED"));

        horizontalLayout_2->addWidget(textAfterED);


        verticalLayout_6->addLayout(horizontalLayout_2);


        horizontalLayout_3->addLayout(verticalLayout_6);


        gridLayout_2->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        literalCB = new QCheckBox(FormattingGB);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        hboxLayout->addWidget(literalCB);

        spacerItem1 = new QSpacerItem(21, 26, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);

        forceuppercaseCB = new QCheckBox(FormattingGB);
        forceuppercaseCB->setObjectName(QStringLiteral("forceuppercaseCB"));

        hboxLayout->addWidget(forceuppercaseCB);

        starredCB = new QCheckBox(FormattingGB);
        starredCB->setObjectName(QStringLiteral("starredCB"));

        hboxLayout->addWidget(starredCB);


        gridLayout_2->addLayout(hboxLayout, 1, 0, 1, 1);


        gridLayout_3->addWidget(FormattingGB, 2, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(CitationUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hboxLayout1->addWidget(buttonBox);


        gridLayout_3->addLayout(hboxLayout1, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        availableKeysLA->setBuddy(availableLV);
        selectedKeysLA->setBuddy(selectedLV);
        citationStyleLA->setBuddy(citationStyleCO);
        textBeforeLA->setBuddy(textBeforeED);
        textAfterLA->setBuddy(textAfterED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(fieldsCO, entriesCO);
        QWidget::setTabOrder(entriesCO, searchOptionsPB);
        QWidget::setTabOrder(searchOptionsPB, availableLV);
        QWidget::setTabOrder(availableLV, addPB);
        QWidget::setTabOrder(addPB, deletePB);
        QWidget::setTabOrder(deletePB, upPB);
        QWidget::setTabOrder(upPB, downPB);
        QWidget::setTabOrder(downPB, citationStyleCO);
        QWidget::setTabOrder(citationStyleCO, textBeforeED);
        QWidget::setTabOrder(textBeforeED, textAfterED);
        QWidget::setTabOrder(textAfterED, forceuppercaseCB);
        QWidget::setTabOrder(forceuppercaseCB, starredCB);
        QWidget::setTabOrder(starredCB, infoML);

        retranslateUi(CitationUi);

        QMetaObject::connectSlotsByName(CitationUi);
    } // setupUi

    void retranslateUi(QDialog *CitationUi)
    {
        CitationUi->setWindowTitle(QString());
        findKeysLA->setText(lyx::qt_("&Filter:", Q_NULLPTR));
        fieldsCO->clear();
        fieldsCO->insertItems(0, QStringList()
         << lyx::qt_("All fields", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        fieldsCO->setToolTip(lyx::qt_("Select the fields on which the filter applies", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        entriesCO->clear();
        entriesCO->insertItems(0, QStringList()
         << lyx::qt_("All entry types", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        entriesCO->setToolTip(lyx::qt_("Select the entry types on which the filter applies", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        searchOptionsPB->setToolTip(lyx::qt_("Click for more filter options", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        searchOptionsPB->setText(lyx::qt_("O&ptions", Q_NULLPTR));
        availableKeysLA->setText(lyx::qt_("A&vailable Citations:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        availableLV->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        addPB->setToolTip(lyx::qt_("Click or press Enter to add the selected citation to the list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addPB->setText(lyx::qt_("&Add", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        deletePB->setToolTip(lyx::qt_("Click or press Delete to delete the selected citation from the list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        deletePB->setText(lyx::qt_("&Delete", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        upPB->setToolTip(lyx::qt_("Move the selected citation up (Ctrl-Up)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        upPB->setText(lyx::qt_("&Up", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        downPB->setToolTip(lyx::qt_("Move the selected citation down (Ctrl-Down)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        downPB->setText(lyx::qt_("Do&wn", Q_NULLPTR));
        selectedKeysLA->setText(lyx::qt_("Selected &Citations:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        selectedLV->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        infoML->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        FormattingGB->setTitle(lyx::qt_("Formatting", Q_NULLPTR));
        citationStyleLA->setText(lyx::qt_("Citation st&yle:", Q_NULLPTR));
        textBeforeLA->setText(lyx::qt_("Text befo&re:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citationStyleCO->setToolTip(lyx::qt_("Citation style to use, if different styles are provided", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        textBeforeED->setToolTip(lyx::qt_("Text that precedes the reference (e.g., \"cf.\"), if the current citation style supports this.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        textAfterLA->setText(lyx::qt_("&Text after:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        textAfterED->setToolTip(lyx::qt_("Text that follows the reference (e.g., pages), if the current citation style supports this.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass content of `Text before' and `Text after' fields literally to LaTeX. Check this if you want to enter LaTeX code.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        forceuppercaseCB->setToolTip(lyx::qt_("Force upper case in names (\"Del Piero\", not \"del Piero\"), if the current citation style supports this.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        forceuppercaseCB->setText(lyx::qt_("Force upcas&ing", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        starredCB->setToolTip(lyx::qt_("Always list all authors (rather than using \"et al.\"), if the current citation style supports this.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        starredCB->setText(lyx::qt_("All aut&hors", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class CitationUi: public Ui_CitationUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CITATIONUI_H
