/********************************************************************************
** Form generated from reading UI file 'SpellcheckerUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPELLCHECKERUI_H
#define UI_SPELLCHECKERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SpellcheckerUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *languageLA;
    QComboBox *languageCO;
    QFrame *line;
    QLabel *TextLabel3;
    QLineEdit *wordED;
    QPushButton *skipPB;
    QLabel *TextLabel1;
    QPushButton *skipAllPB;
    QComboBox *replaceCO;
    QPushButton *replacePB;
    QLabel *TextLabel2;
    QPushButton *replaceAllPB;
    QListWidget *suggestionsLW;
    QPushButton *ignorePB;
    QPushButton *ignoreAllPB;
    QPushButton *addPB;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SpellcheckerUi)
    {
        if (SpellcheckerUi->objectName().isEmpty())
            SpellcheckerUi->setObjectName(QStringLiteral("SpellcheckerUi"));
        SpellcheckerUi->resize(400, 488);
        SpellcheckerUi->setMinimumSize(QSize(260, 320));
        gridLayout = new QGridLayout(SpellcheckerUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        languageLA = new QLabel(SpellcheckerUi);
        languageLA->setObjectName(QStringLiteral("languageLA"));

        horizontalLayout->addWidget(languageLA);

        languageCO = new QComboBox(SpellcheckerUi);
        languageCO->setObjectName(QStringLiteral("languageCO"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(100);
        sizePolicy.setVerticalStretch(32);
        sizePolicy.setHeightForWidth(languageCO->sizePolicy().hasHeightForWidth());
        languageCO->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(languageCO);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 2);

        line = new QFrame(SpellcheckerUi);
        line->setObjectName(QStringLiteral("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 2);

        TextLabel3 = new QLabel(SpellcheckerUi);
        TextLabel3->setObjectName(QStringLiteral("TextLabel3"));

        gridLayout->addWidget(TextLabel3, 2, 0, 1, 1);

        wordED = new QLineEdit(SpellcheckerUi);
        wordED->setObjectName(QStringLiteral("wordED"));

        gridLayout->addWidget(wordED, 3, 0, 1, 1);

        skipPB = new QPushButton(SpellcheckerUi);
        skipPB->setObjectName(QStringLiteral("skipPB"));

        gridLayout->addWidget(skipPB, 3, 1, 1, 1);

        TextLabel1 = new QLabel(SpellcheckerUi);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));

        gridLayout->addWidget(TextLabel1, 4, 0, 1, 1);

        skipAllPB = new QPushButton(SpellcheckerUi);
        skipAllPB->setObjectName(QStringLiteral("skipAllPB"));

        gridLayout->addWidget(skipAllPB, 4, 1, 1, 1);

        replaceCO = new QComboBox(SpellcheckerUi);
        replaceCO->setObjectName(QStringLiteral("replaceCO"));
        replaceCO->setFocusPolicy(Qt::StrongFocus);
        replaceCO->setEditable(true);
        replaceCO->setInsertPolicy(QComboBox::InsertAtTop);
        replaceCO->setDuplicatesEnabled(false);

        gridLayout->addWidget(replaceCO, 5, 0, 1, 1);

        replacePB = new QPushButton(SpellcheckerUi);
        replacePB->setObjectName(QStringLiteral("replacePB"));

        gridLayout->addWidget(replacePB, 5, 1, 1, 1);

        TextLabel2 = new QLabel(SpellcheckerUi);
        TextLabel2->setObjectName(QStringLiteral("TextLabel2"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(TextLabel2->sizePolicy().hasHeightForWidth());
        TextLabel2->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(TextLabel2, 6, 0, 1, 1);

        replaceAllPB = new QPushButton(SpellcheckerUi);
        replaceAllPB->setObjectName(QStringLiteral("replaceAllPB"));

        gridLayout->addWidget(replaceAllPB, 6, 1, 1, 1);

        suggestionsLW = new QListWidget(SpellcheckerUi);
        suggestionsLW->setObjectName(QStringLiteral("suggestionsLW"));

        gridLayout->addWidget(suggestionsLW, 7, 0, 4, 1);

        ignorePB = new QPushButton(SpellcheckerUi);
        ignorePB->setObjectName(QStringLiteral("ignorePB"));

        gridLayout->addWidget(ignorePB, 7, 1, 1, 1);

        ignoreAllPB = new QPushButton(SpellcheckerUi);
        ignoreAllPB->setObjectName(QStringLiteral("ignoreAllPB"));

        gridLayout->addWidget(ignoreAllPB, 8, 1, 1, 1);

        addPB = new QPushButton(SpellcheckerUi);
        addPB->setObjectName(QStringLiteral("addPB"));

        gridLayout->addWidget(addPB, 9, 1, 1, 1);

        spacerItem = new QSpacerItem(74, 98, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 10, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        languageLA->setBuddy(languageCO);
        TextLabel3->setBuddy(wordED);
        TextLabel1->setBuddy(replaceCO);
        TextLabel2->setBuddy(suggestionsLW);
#endif // QT_NO_SHORTCUT

        retranslateUi(SpellcheckerUi);

        QMetaObject::connectSlotsByName(SpellcheckerUi);
    } // setupUi

    void retranslateUi(QWidget *SpellcheckerUi)
    {
        SpellcheckerUi->setWindowTitle(lyx::qt_("Spell Checker", Q_NULLPTR));
        languageLA->setText(lyx::qt_("&Language:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languageCO->setToolTip(lyx::qt_("The checked language. Switching this alters the language of the checked word.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        TextLabel3->setText(lyx::qt_("Unknown &word:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        wordED->setToolTip(lyx::qt_("Current word", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        skipPB->setToolTip(lyx::qt_("Skip this match and go to next misspelling", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        skipPB->setText(lyx::qt_("S&kip", Q_NULLPTR));
        TextLabel1->setText(lyx::qt_("Repla&cement:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        skipAllPB->setToolTip(lyx::qt_("Skips all occurrences of this word within the current session.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        skipAllPB->setText(lyx::qt_("Skip A&ll", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replaceCO->setToolTip(lyx::qt_("Replace with selected word", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        replacePB->setToolTip(lyx::qt_("Replace word with current choice", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replacePB->setText(lyx::qt_("&Replace", Q_NULLPTR));
        TextLabel2->setText(lyx::qt_("S&uggestions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replaceAllPB->setToolTip(lyx::qt_("Replace all occurrences of the word in the document with current choice", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replaceAllPB->setText(lyx::qt_("Re&place All", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ignorePB->setToolTip(lyx::qt_("Ignore this occurrence of the word permanently (saved as a text property).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ignorePB->setText(lyx::qt_("Ign&ore", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ignoreAllPB->setToolTip(lyx::qt_("Ignore all occurrences of this word within this document. This persists beyond the current session.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ignoreAllPB->setText(lyx::qt_("I&gnore All", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        addPB->setToolTip(lyx::qt_("Add the word to your personal dictionary", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addPB->setText(lyx::qt_("&Add[[Spellchecker]]", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SpellcheckerUi: public Ui_SpellcheckerUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SPELLCHECKERUI_H
