/********************************************************************************
** Form generated from reading UI file 'DocumentUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOCUMENTUI_H
#define UI_DOCUMENTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include "PanelStack.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_DocumentUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *hboxLayout1;
    QPushButton *defaultPB;
    QPushButton *savePB;
    QSpacerItem *spacerItem;
    lyx::frontend::PanelStack *docPS;

    void setupUi(QDialog *DocumentUi)
    {
        if (DocumentUi->objectName().isEmpty())
            DocumentUi->setObjectName(QStringLiteral("DocumentUi"));
        DocumentUi->resize(436, 169);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DocumentUi->sizePolicy().hasHeightForWidth());
        DocumentUi->setSizePolicy(sizePolicy);
        DocumentUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(DocumentUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(DocumentUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        defaultPB = new QPushButton(DocumentUi);
        defaultPB->setObjectName(QStringLiteral("defaultPB"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(defaultPB->sizePolicy().hasHeightForWidth());
        defaultPB->setSizePolicy(sizePolicy1);

        hboxLayout1->addWidget(defaultPB);

        savePB = new QPushButton(DocumentUi);
        savePB->setObjectName(QStringLiteral("savePB"));
        sizePolicy1.setHeightForWidth(savePB->sizePolicy().hasHeightForWidth());
        savePB->setSizePolicy(sizePolicy1);

        hboxLayout1->addWidget(savePB);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout1, 1, 0, 1, 1);

        docPS = new lyx::frontend::PanelStack(DocumentUi);
        docPS->setObjectName(QStringLiteral("docPS"));

        gridLayout->addWidget(docPS, 0, 0, 1, 1);

        QWidget::setTabOrder(docPS, defaultPB);
        QWidget::setTabOrder(defaultPB, savePB);

        retranslateUi(DocumentUi);

        QMetaObject::connectSlotsByName(DocumentUi);
    } // setupUi

    void retranslateUi(QDialog *DocumentUi)
    {
        DocumentUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        defaultPB->setToolTip(lyx::qt_("Reset to the default settings for the document class", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultPB->setText(lyx::qt_("Use Class Defaults", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        savePB->setToolTip(lyx::qt_("Save settings as defaults for new documents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        savePB->setText(lyx::qt_("Save as Document Defaults", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DocumentUi: public Ui_DocumentUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOCUMENTUI_H
