/****************************************************************************
** Meta object code from reading C++ file 'GuiProgress.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiProgress.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiProgress.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiProgress_t {
    QByteArrayData data[32];
    char stringdata0[413];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiProgress_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiProgress_t qt_meta_stringdata_lyx__frontend__GuiProgress = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiProgress"
QT_MOC_LITERAL(1, 27, 14), // "processStarted"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 15), // "processFinished"
QT_MOC_LITERAL(4, 59, 13), // "appendMessage"
QT_MOC_LITERAL(5, 73, 11), // "appendError"
QT_MOC_LITERAL(6, 85, 13), // "clearMessages"
QT_MOC_LITERAL(7, 99, 19), // "appendLyXErrMessage"
QT_MOC_LITERAL(8, 119, 4), // "text"
QT_MOC_LITERAL(9, 124, 16), // "clearMessageText"
QT_MOC_LITERAL(10, 141, 22), // "updateStatusBarMessage"
QT_MOC_LITERAL(11, 164, 12), // "triggerFlush"
QT_MOC_LITERAL(12, 177, 7), // "warning"
QT_MOC_LITERAL(13, 185, 5), // "title"
QT_MOC_LITERAL(14, 191, 7), // "message"
QT_MOC_LITERAL(15, 199, 13), // "toggleWarning"
QT_MOC_LITERAL(16, 213, 3), // "msg"
QT_MOC_LITERAL(17, 217, 9), // "formatted"
QT_MOC_LITERAL(18, 227, 5), // "error"
QT_MOC_LITERAL(19, 233, 7), // "details"
QT_MOC_LITERAL(20, 241, 11), // "information"
QT_MOC_LITERAL(21, 253, 16), // "doProcessStarted"
QT_MOC_LITERAL(22, 270, 17), // "doProcessFinished"
QT_MOC_LITERAL(23, 288, 15), // "doAppendMessage"
QT_MOC_LITERAL(24, 304, 13), // "doAppendError"
QT_MOC_LITERAL(25, 318, 15), // "doClearMessages"
QT_MOC_LITERAL(26, 334, 9), // "doWarning"
QT_MOC_LITERAL(27, 344, 15), // "doToggleWarning"
QT_MOC_LITERAL(28, 360, 7), // "doError"
QT_MOC_LITERAL(29, 368, 13), // "doInformation"
QT_MOC_LITERAL(30, 382, 16), // "updateWithLyXErr"
QT_MOC_LITERAL(31, 399, 13) // "startFlushing"

    },
    "lyx::frontend::GuiProgress\0processStarted\0"
    "\0processFinished\0appendMessage\0"
    "appendError\0clearMessages\0appendLyXErrMessage\0"
    "text\0clearMessageText\0updateStatusBarMessage\0"
    "triggerFlush\0warning\0title\0message\0"
    "toggleWarning\0msg\0formatted\0error\0"
    "details\0information\0doProcessStarted\0"
    "doProcessFinished\0doAppendMessage\0"
    "doAppendError\0doClearMessages\0doWarning\0"
    "doToggleWarning\0doError\0doInformation\0"
    "updateWithLyXErr\0startFlushing"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiProgress[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  139,    2, 0x06 /* Public */,
       3,    1,  142,    2, 0x06 /* Public */,
       4,    1,  145,    2, 0x06 /* Public */,
       5,    1,  148,    2, 0x06 /* Public */,
       6,    0,  151,    2, 0x06 /* Public */,
       7,    1,  152,    2, 0x06 /* Public */,
       9,    0,  155,    2, 0x06 /* Public */,
      10,    1,  156,    2, 0x06 /* Public */,
      11,    0,  159,    2, 0x06 /* Public */,
      12,    2,  160,    2, 0x06 /* Public */,
      15,    3,  165,    2, 0x06 /* Public */,
      18,    3,  172,    2, 0x06 /* Public */,
      18,    2,  179,    2, 0x26 /* Public | MethodCloned */,
      20,    2,  184,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    1,  189,    2, 0x08 /* Private */,
      22,    1,  192,    2, 0x08 /* Private */,
      23,    1,  195,    2, 0x08 /* Private */,
      24,    1,  198,    2, 0x08 /* Private */,
      25,    0,  201,    2, 0x08 /* Private */,
      26,    2,  202,    2, 0x08 /* Private */,
      27,    3,  207,    2, 0x08 /* Private */,
      28,    3,  214,    2, 0x08 /* Private */,
      29,    2,  221,    2, 0x08 /* Private */,
      30,    0,  226,    2, 0x08 /* Private */,
      31,    0,  227,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   13,   16,   17,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   13,   14,   19,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   13,   16,   17,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiProgress::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiProgress *_t = static_cast<GuiProgress *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->processStarted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->processFinished((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->appendMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->appendError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->clearMessages(); break;
        case 5: _t->appendLyXErrMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->clearMessageText(); break;
        case 7: _t->updateStatusBarMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->triggerFlush(); break;
        case 9: _t->warning((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 10: _t->toggleWarning((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 11: _t->error((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 12: _t->error((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->information((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 14: _t->doProcessStarted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->doProcessFinished((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->doAppendMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->doAppendError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->doClearMessages(); break;
        case 19: _t->doWarning((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 20: _t->doToggleWarning((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 21: _t->doError((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 22: _t->doInformation((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->updateWithLyXErr(); break;
        case 24: _t->startFlushing(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::processStarted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::processFinished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::appendMessage)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::appendError)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::clearMessages)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::appendLyXErrMessage)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::clearMessageText)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::updateStatusBarMessage)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::triggerFlush)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & , QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::warning)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & , QString const & , QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::toggleWarning)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & , QString const & , QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::error)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (GuiProgress::*_t)(QString const & , QString const & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiProgress::information)) {
                *result = 13;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiProgress::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiProgress.data,
      qt_meta_data_lyx__frontend__GuiProgress,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiProgress::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiProgress::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiProgress.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "lyx::support::ProgressInterface"))
        return static_cast< lyx::support::ProgressInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int lyx::frontend::GuiProgress::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiProgress::processStarted(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void lyx::frontend::GuiProgress::processFinished(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void lyx::frontend::GuiProgress::appendMessage(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void lyx::frontend::GuiProgress::appendError(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void lyx::frontend::GuiProgress::clearMessages()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void lyx::frontend::GuiProgress::appendLyXErrMessage(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void lyx::frontend::GuiProgress::clearMessageText()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void lyx::frontend::GuiProgress::updateStatusBarMessage(QString const & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void lyx::frontend::GuiProgress::triggerFlush()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void lyx::frontend::GuiProgress::warning(QString const & _t1, QString const & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void lyx::frontend::GuiProgress::toggleWarning(QString const & _t1, QString const & _t2, QString const & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void lyx::frontend::GuiProgress::error(QString const & _t1, QString const & _t2, QString const & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 13
void lyx::frontend::GuiProgress::information(QString const & _t1, QString const & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
