/********************************************************************************
** Form generated from reading UI file 'HSpaceUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HSPACEUI_H
#define UI_HSPACEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_HSpaceUi
{
public:
    QGridLayout *gridLayout;
    QComboBox *fillPatternCO;
    QLabel *spacingL;
    QComboBox *spacingCO;
    QLabel *valueL;
    QLineEdit *valueLE;
    lyx::frontend::LengthCombo *unitCO;
    QLabel *fillPatternL;
    QLabel *keepL;
    QCheckBox *keepCB;

    void setupUi(QWidget *HSpaceUi)
    {
        if (HSpaceUi->objectName().isEmpty())
            HSpaceUi->setObjectName(QStringLiteral("HSpaceUi"));
        HSpaceUi->resize(329, 148);
        HSpaceUi->setProperty("sizeGripEnabled", QVariant(true));
        gridLayout = new QGridLayout(HSpaceUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        fillPatternCO = new QComboBox(HSpaceUi);
        fillPatternCO->setObjectName(QStringLiteral("fillPatternCO"));

        gridLayout->addWidget(fillPatternCO, 2, 1, 1, 1);

        spacingL = new QLabel(HSpaceUi);
        spacingL->setObjectName(QStringLiteral("spacingL"));

        gridLayout->addWidget(spacingL, 0, 0, 1, 1);

        spacingCO = new QComboBox(HSpaceUi);
        spacingCO->setObjectName(QStringLiteral("spacingCO"));

        gridLayout->addWidget(spacingCO, 0, 1, 1, 2);

        valueL = new QLabel(HSpaceUi);
        valueL->setObjectName(QStringLiteral("valueL"));

        gridLayout->addWidget(valueL, 1, 0, 1, 1);

        valueLE = new QLineEdit(HSpaceUi);
        valueLE->setObjectName(QStringLiteral("valueLE"));
        valueLE->setEnabled(false);

        gridLayout->addWidget(valueLE, 1, 1, 1, 1);

        unitCO = new lyx::frontend::LengthCombo(HSpaceUi);
        unitCO->setObjectName(QStringLiteral("unitCO"));

        gridLayout->addWidget(unitCO, 1, 2, 1, 1);

        fillPatternL = new QLabel(HSpaceUi);
        fillPatternL->setObjectName(QStringLiteral("fillPatternL"));

        gridLayout->addWidget(fillPatternL, 2, 0, 1, 1);

        keepL = new QLabel(HSpaceUi);
        keepL->setObjectName(QStringLiteral("keepL"));

        gridLayout->addWidget(keepL, 3, 0, 1, 1);

        keepCB = new QCheckBox(HSpaceUi);
        keepCB->setObjectName(QStringLiteral("keepCB"));

        gridLayout->addWidget(keepCB, 3, 1, 1, 2);

#ifndef QT_NO_SHORTCUT
        spacingL->setBuddy(spacingCO);
        valueL->setBuddy(valueLE);
        fillPatternL->setBuddy(fillPatternCO);
        keepL->setBuddy(keepCB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(spacingCO, valueLE);
        QWidget::setTabOrder(valueLE, keepCB);

        retranslateUi(HSpaceUi);

        QMetaObject::connectSlotsByName(HSpaceUi);
    } // setupUi

    void retranslateUi(QWidget *HSpaceUi)
    {
        HSpaceUi->setWindowTitle(QString());
        fillPatternCO->clear();
        fillPatternCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("...............", Q_NULLPTR)
         << lyx::qt_("________", Q_NULLPTR)
         << lyx::qt_("<-----------", Q_NULLPTR)
         << lyx::qt_("----------->", Q_NULLPTR)
         << lyx::qt_("\\-----v-----/", Q_NULLPTR)
         << lyx::qt_("/-----^-----\\", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        fillPatternCO->setToolTip(lyx::qt_("Select a fill pattern style for HFills", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        spacingL->setText(lyx::qt_("&Spacing:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        spacingCO->setToolTip(lyx::qt_("Supported spacing types", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valueL->setText(lyx::qt_("&Value:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        valueLE->setToolTip(lyx::qt_("Custom value. Needs spacing type \"Custom\".", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fillPatternL->setText(lyx::qt_("&Fill Pattern:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keepL->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        keepL->setText(lyx::qt_("&Non-Breaking:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keepCB->setToolTip(lyx::qt_("Prevent automatic line break at the space", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        keepCB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class HSpaceUi: public Ui_HSpaceUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HSPACEUI_H
