/********************************************************************************
** Form generated from reading UI file 'ErrorListUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERRORLISTUI_H
#define UI_ERRORLISTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ErrorListUi
{
public:
    QGridLayout *gridLayout;
    QListWidget *errorsLW;
    QTextBrowser *descriptionTB;
    QLabel *descriptionLabel;
    QLabel *errorsLabel;
    QPushButton *viewLogPB;
    QSpacerItem *spacerItem;
    QPushButton *showAnywayPB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ErrorListUi)
    {
        if (ErrorListUi->objectName().isEmpty())
            ErrorListUi->setObjectName(QStringLiteral("ErrorListUi"));
        ErrorListUi->resize(447, 422);
        ErrorListUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(ErrorListUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        errorsLW = new QListWidget(ErrorListUi);
        errorsLW->setObjectName(QStringLiteral("errorsLW"));

        gridLayout->addWidget(errorsLW, 1, 0, 1, 5);

        descriptionTB = new QTextBrowser(ErrorListUi);
        descriptionTB->setObjectName(QStringLiteral("descriptionTB"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(descriptionTB->sizePolicy().hasHeightForWidth());
        descriptionTB->setSizePolicy(sizePolicy);

        gridLayout->addWidget(descriptionTB, 3, 0, 1, 5);

        descriptionLabel = new QLabel(ErrorListUi);
        descriptionLabel->setObjectName(QStringLiteral("descriptionLabel"));

        gridLayout->addWidget(descriptionLabel, 2, 0, 1, 2);

        errorsLabel = new QLabel(ErrorListUi);
        errorsLabel->setObjectName(QStringLiteral("errorsLabel"));

        gridLayout->addWidget(errorsLabel, 0, 0, 1, 2);

        viewLogPB = new QPushButton(ErrorListUi);
        viewLogPB->setObjectName(QStringLiteral("viewLogPB"));

        gridLayout->addWidget(viewLogPB, 4, 0, 1, 1);

        spacerItem = new QSpacerItem(121, 30, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 4, 2, 1, 1);

        showAnywayPB = new QPushButton(ErrorListUi);
        showAnywayPB->setObjectName(QStringLiteral("showAnywayPB"));

        gridLayout->addWidget(showAnywayPB, 4, 1, 1, 1);

        buttonBox = new QDialogButtonBox(ErrorListUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        gridLayout->addWidget(buttonBox, 4, 3, 1, 1);

#ifndef QT_NO_SHORTCUT
        errorsLabel->setBuddy(errorsLW);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(errorsLW, descriptionTB);

        retranslateUi(ErrorListUi);

        QMetaObject::connectSlotsByName(ErrorListUi);
    } // setupUi

    void retranslateUi(QDialog *ErrorListUi)
    {
        ErrorListUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        errorsLW->setToolTip(lyx::qt_("Selecting an error will show the error message in the panel below and the cursor will jump to the location in the document where the error occurred.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        descriptionTB->setToolTip(lyx::qt_("For more information, refer to the complete log.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        descriptionLabel->setText(lyx::qt_("Description:", Q_NULLPTR));
        errorsLabel->setText(lyx::qt_("&Errors:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        viewLogPB->setToolTip(lyx::qt_("Open the LaTeX Log File dialog", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        viewLogPB->setText(lyx::qt_("View Complete &Log...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        showAnywayPB->setToolTip(lyx::qt_("Attempt to show the output even if there were compilation errors", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        showAnywayPB->setText(lyx::qt_("Show Output &Anyway", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ErrorListUi: public Ui_ErrorListUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ERRORLISTUI_H
