/********************************************************************************
** Form generated from reading UI file 'ShowFileUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHOWFILEUI_H
#define UI_SHOWFILEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTextBrowser>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ShowFileUi
{
public:
    QGridLayout *gridLayout;
    QTextBrowser *textTB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ShowFileUi)
    {
        if (ShowFileUi->objectName().isEmpty())
            ShowFileUi->setObjectName(QStringLiteral("ShowFileUi"));
        ShowFileUi->resize(301, 259);
        ShowFileUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(ShowFileUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        textTB = new QTextBrowser(ShowFileUi);
        textTB->setObjectName(QStringLiteral("textTB"));

        gridLayout->addWidget(textTB, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ShowFileUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);


        retranslateUi(ShowFileUi);

        QMetaObject::connectSlotsByName(ShowFileUi);
    } // setupUi

    void retranslateUi(QDialog *ShowFileUi)
    {
        ShowFileUi->setWindowTitle(QString());
    } // retranslateUi

};

namespace Ui {
    class ShowFileUi: public Ui_ShowFileUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHOWFILEUI_H
