/********************************************************************************
** Form generated from reading UI file 'LocalLayoutUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOCALLAYOUTUI_H
#define UI_LOCALLAYOUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LocalLayoutUi
{
public:
    QGridLayout *gridLayout_2;
    QTextEdit *locallayoutTE;
    QGridLayout *gridLayout;
    QPushButton *validatePB;
    QLabel *validLB;
    QSpacerItem *horizontalSpacer;
    QPushButton *editPB;
    QPushButton *convertPB;
    QLabel *convertLB;

    void setupUi(QWidget *LocalLayoutUi)
    {
        if (LocalLayoutUi->objectName().isEmpty())
            LocalLayoutUi->setObjectName(QStringLiteral("LocalLayoutUi"));
        LocalLayoutUi->resize(331, 376);
        gridLayout_2 = new QGridLayout(LocalLayoutUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        locallayoutTE = new QTextEdit(LocalLayoutUi);
        locallayoutTE->setObjectName(QStringLiteral("locallayoutTE"));
        locallayoutTE->setAcceptRichText(false);

        gridLayout_2->addWidget(locallayoutTE, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        validatePB = new QPushButton(LocalLayoutUi);
        validatePB->setObjectName(QStringLiteral("validatePB"));

        gridLayout->addWidget(validatePB, 0, 0, 1, 1);

        validLB = new QLabel(LocalLayoutUi);
        validLB->setObjectName(QStringLiteral("validLB"));
        validLB->setContextMenuPolicy(Qt::NoContextMenu);
        validLB->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(validLB, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        editPB = new QPushButton(LocalLayoutUi);
        editPB->setObjectName(QStringLiteral("editPB"));

        gridLayout->addWidget(editPB, 0, 3, 1, 1);

        convertPB = new QPushButton(LocalLayoutUi);
        convertPB->setObjectName(QStringLiteral("convertPB"));

        gridLayout->addWidget(convertPB, 1, 0, 1, 1);

        convertLB = new QLabel(LocalLayoutUi);
        convertLB->setObjectName(QStringLiteral("convertLB"));
        convertLB->setContextMenuPolicy(Qt::NoContextMenu);
        convertLB->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(convertLB, 1, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 1, 0, 1, 1);


        retranslateUi(LocalLayoutUi);

        QMetaObject::connectSlotsByName(LocalLayoutUi);
    } // setupUi

    void retranslateUi(QWidget *LocalLayoutUi)
    {
        LocalLayoutUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        locallayoutTE->setToolTip(lyx::qt_("Document-specific layout information", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_STATUSTIP
        locallayoutTE->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
#ifndef QT_NO_TOOLTIP
        validatePB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        validatePB->setText(lyx::qt_("&Validate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        validLB->setToolTip(lyx::qt_("Errors reported in terminal.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        validLB->setText(QString());
#ifndef QT_NO_TOOLTIP
        editPB->setToolTip(lyx::qt_("Editor for LaTeX (plain) format will be used", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        editPB->setText(lyx::qt_("&Edit Externally", Q_NULLPTR));
        convertPB->setText(lyx::qt_("Convert", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        convertLB->setToolTip(lyx::qt_("Errors reported in terminal.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        convertLB->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class LocalLayoutUi: public Ui_LocalLayoutUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LOCALLAYOUTUI_H
