/********************************************************************************
** Form generated from reading UI file 'IncludeUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INCLUDEUI_H
#define UI_INCLUDEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTextEdit>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_IncludeUi
{
public:
    QGridLayout *gridLayout_3;
    QGridLayout *gridLayout_2;
    QPushButton *browsePB;
    QLabel *TextLabel1;
    QComboBox *typeCO;
    QPushButton *editPB;
    QLineEdit *filenameED;
    QLabel *filenameLA;
    QHBoxLayout *hboxLayout;
    QCheckBox *visiblespaceCB;
    QCheckBox *previewCB;
    QSpacerItem *horizontalSpacer;
    QGroupBox *listingsGB;
    QGridLayout *gridLayout;
    QLineEdit *labelLE;
    QLabel *labelLabel;
    QTextEdit *listingsED;
    QTextBrowser *listingsTB;
    QLabel *captionLabel;
    QLabel *label;
    QLineEdit *captionLE;
    QCheckBox *bypassCB;
    QLabel *label_3;
    QCheckBox *literalCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *IncludeUi)
    {
        if (IncludeUi->objectName().isEmpty())
            IncludeUi->setObjectName(QStringLiteral("IncludeUi"));
        IncludeUi->resize(362, 449);
        IncludeUi->setSizeGripEnabled(true);
        gridLayout_3 = new QGridLayout(IncludeUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        browsePB = new QPushButton(IncludeUi);
        browsePB->setObjectName(QStringLiteral("browsePB"));

        gridLayout_2->addWidget(browsePB, 0, 3, 1, 1);

        TextLabel1 = new QLabel(IncludeUi);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));

        gridLayout_2->addWidget(TextLabel1, 1, 0, 1, 2);

        typeCO = new QComboBox(IncludeUi);
        typeCO->setObjectName(QStringLiteral("typeCO"));

        gridLayout_2->addWidget(typeCO, 1, 2, 1, 1);

        editPB = new QPushButton(IncludeUi);
        editPB->setObjectName(QStringLiteral("editPB"));

        gridLayout_2->addWidget(editPB, 1, 3, 1, 1);

        filenameED = new QLineEdit(IncludeUi);
        filenameED->setObjectName(QStringLiteral("filenameED"));

        gridLayout_2->addWidget(filenameED, 0, 2, 1, 1);

        filenameLA = new QLabel(IncludeUi);
        filenameLA->setObjectName(QStringLiteral("filenameLA"));

        gridLayout_2->addWidget(filenameLA, 0, 0, 1, 2);


        gridLayout_3->addLayout(gridLayout_2, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        visiblespaceCB = new QCheckBox(IncludeUi);
        visiblespaceCB->setObjectName(QStringLiteral("visiblespaceCB"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(visiblespaceCB->sizePolicy().hasHeightForWidth());
        visiblespaceCB->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(visiblespaceCB);

        previewCB = new QCheckBox(IncludeUi);
        previewCB->setObjectName(QStringLiteral("previewCB"));
        sizePolicy.setHeightForWidth(previewCB->sizePolicy().hasHeightForWidth());
        previewCB->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(previewCB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        gridLayout_3->addLayout(hboxLayout, 1, 0, 1, 1);

        listingsGB = new QGroupBox(IncludeUi);
        listingsGB->setObjectName(QStringLiteral("listingsGB"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(listingsGB->sizePolicy().hasHeightForWidth());
        listingsGB->setSizePolicy(sizePolicy1);
        listingsGB->setFlat(true);
        gridLayout = new QGridLayout(listingsGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        labelLE = new QLineEdit(listingsGB);
        labelLE->setObjectName(QStringLiteral("labelLE"));

        gridLayout->addWidget(labelLE, 1, 1, 1, 1);

        labelLabel = new QLabel(listingsGB);
        labelLabel->setObjectName(QStringLiteral("labelLabel"));

        gridLayout->addWidget(labelLabel, 1, 0, 1, 1);

        listingsED = new QTextEdit(listingsGB);
        listingsED->setObjectName(QStringLiteral("listingsED"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(listingsED->sizePolicy().hasHeightForWidth());
        listingsED->setSizePolicy(sizePolicy2);
        listingsED->setMinimumSize(QSize(0, 0));

        gridLayout->addWidget(listingsED, 4, 1, 1, 1);

        listingsTB = new QTextBrowser(listingsGB);
        listingsTB->setObjectName(QStringLiteral("listingsTB"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(listingsTB->sizePolicy().hasHeightForWidth());
        listingsTB->setSizePolicy(sizePolicy3);
        listingsTB->setMinimumSize(QSize(0, 0));
        listingsTB->setMaximumSize(QSize(120, 16777215));
        listingsTB->viewport()->setProperty("cursor", QVariant(QCursor(Qt::ArrowCursor)));
        listingsTB->setFocusPolicy(Qt::NoFocus);
        listingsTB->setAcceptDrops(true);
        listingsTB->setFrameShape(QFrame::NoFrame);
        listingsTB->setFrameShadow(QFrame::Plain);
        listingsTB->setLineWidth(0);
        listingsTB->setAcceptRichText(false);

        gridLayout->addWidget(listingsTB, 4, 0, 1, 1);

        captionLabel = new QLabel(listingsGB);
        captionLabel->setObjectName(QStringLiteral("captionLabel"));

        gridLayout->addWidget(captionLabel, 0, 0, 1, 1);

        label = new QLabel(listingsGB);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 2, 0, 1, 1);

        captionLE = new QLineEdit(listingsGB);
        captionLE->setObjectName(QStringLiteral("captionLE"));
        captionLE->setMinimumSize(QSize(150, 0));

        gridLayout->addWidget(captionLE, 0, 1, 1, 1);

        bypassCB = new QCheckBox(listingsGB);
        bypassCB->setObjectName(QStringLiteral("bypassCB"));

        gridLayout->addWidget(bypassCB, 5, 0, 1, 2);

        label_3 = new QLabel(listingsGB);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        literalCB = new QCheckBox(listingsGB);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        gridLayout->addWidget(literalCB, 2, 1, 1, 1);


        gridLayout_3->addWidget(listingsGB, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(IncludeUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_3->addWidget(buttonBox, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        TextLabel1->setBuddy(typeCO);
        filenameLA->setBuddy(filenameED);
        labelLabel->setBuddy(labelLE);
        captionLabel->setBuddy(captionLE);
        label_3->setBuddy(listingsED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(filenameED, browsePB);
        QWidget::setTabOrder(browsePB, typeCO);
        QWidget::setTabOrder(typeCO, editPB);
        QWidget::setTabOrder(editPB, visiblespaceCB);
        QWidget::setTabOrder(visiblespaceCB, previewCB);
        QWidget::setTabOrder(previewCB, captionLE);
        QWidget::setTabOrder(captionLE, labelLE);
        QWidget::setTabOrder(labelLE, listingsTB);
        QWidget::setTabOrder(listingsTB, listingsED);

        retranslateUi(IncludeUi);

        QMetaObject::connectSlotsByName(IncludeUi);
    } // setupUi

    void retranslateUi(QDialog *IncludeUi)
    {
        IncludeUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        browsePB->setToolTip(lyx::qt_("Select a file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        browsePB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
        TextLabel1->setText(lyx::qt_("I&nclude Type:", Q_NULLPTR));
        typeCO->clear();
        typeCO->insertItems(0, QStringList()
         << lyx::qt_("Include", Q_NULLPTR)
         << lyx::qt_("Input", Q_NULLPTR)
         << lyx::qt_("Verbatim", Q_NULLPTR)
         << lyx::qt_("Program Listing", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        editPB->setToolTip(lyx::qt_("Edit the file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        editPB->setText(lyx::qt_("&Edit", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        filenameED->setToolTip(lyx::qt_("File name to include. (You can create a new file by entering the name of one that does not yet exist.)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        filenameLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        filenameLA->setText(lyx::qt_("&File:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        visiblespaceCB->setToolTip(lyx::qt_("Underline spaces in generated output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        visiblespaceCB->setText(lyx::qt_("&Mark spaces in output", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        previewCB->setToolTip(lyx::qt_("Show LaTeX preview", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        previewCB->setText(lyx::qt_("&Show preview", Q_NULLPTR));
        listingsGB->setTitle(lyx::qt_("Listing Parameters", Q_NULLPTR));
        labelLabel->setText(lyx::qt_("&Label:", Q_NULLPTR));
        captionLabel->setText(lyx::qt_("&Caption:", Q_NULLPTR));
        label->setText(QString());
#ifndef QT_NO_TOOLTIP
        bypassCB->setToolTip(lyx::qt_("Check it to enter parameters that are not recognizable by LyX", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bypassCB->setText(lyx::qt_("&Bypass validation", Q_NULLPTR));
        label_3->setText(lyx::qt_("&More parameters", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass content of the `Caption' field literally to LaTeX. Check this if you want to enter LaTeX code.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class IncludeUi: public Ui_IncludeUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INCLUDEUI_H
