/********************************************************************************
** Form generated from reading UI file 'CounterUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COUNTERUI_H
#define UI_COUNTERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_CounterUi
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *counterLA;
    QComboBox *counterCB;
    QLabel *actionLA;
    QHBoxLayout *horizontalLayout;
    QComboBox *actionCB;
    QSpinBox *valueSB;
    QCheckBox *lyxonlyXB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CounterUi)
    {
        if (CounterUi->objectName().isEmpty())
            CounterUi->setObjectName(QStringLiteral("CounterUi"));
        CounterUi->resize(383, 154);
        gridLayout_2 = new QGridLayout(CounterUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        counterLA = new QLabel(CounterUi);
        counterLA->setObjectName(QStringLiteral("counterLA"));

        gridLayout->addWidget(counterLA, 0, 0, 1, 1);

        counterCB = new QComboBox(CounterUi);
        counterCB->setObjectName(QStringLiteral("counterCB"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(counterCB->sizePolicy().hasHeightForWidth());
        counterCB->setSizePolicy(sizePolicy);

        gridLayout->addWidget(counterCB, 0, 1, 1, 1);

        actionLA = new QLabel(CounterUi);
        actionLA->setObjectName(QStringLiteral("actionLA"));

        gridLayout->addWidget(actionLA, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        actionCB = new QComboBox(CounterUi);
        actionCB->setObjectName(QStringLiteral("actionCB"));
        sizePolicy.setHeightForWidth(actionCB->sizePolicy().hasHeightForWidth());
        actionCB->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(actionCB);

        valueSB = new QSpinBox(CounterUi);
        valueSB->setObjectName(QStringLiteral("valueSB"));
        valueSB->setMaximum(10000);

        horizontalLayout->addWidget(valueSB);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        lyxonlyXB = new QCheckBox(CounterUi);
        lyxonlyXB->setObjectName(QStringLiteral("lyxonlyXB"));
        lyxonlyXB->setLayoutDirection(Qt::LeftToRight);

        gridLayout->addWidget(lyxonlyXB, 2, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        counterLA->setBuddy(counterCB);
        actionLA->setBuddy(actionCB);
#endif // QT_NO_SHORTCUT

        retranslateUi(CounterUi);

        QMetaObject::connectSlotsByName(CounterUi);
    } // setupUi

    void retranslateUi(QWidget *CounterUi)
    {
        CounterUi->setWindowTitle(QString());
        counterLA->setText(lyx::qt_("C&ounter:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        counterCB->setToolTip(lyx::qt_("Select counter to modify", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        actionLA->setText(lyx::qt_("&Action:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionCB->setToolTip(lyx::qt_("Select the action to perform on selected counter", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        lyxonlyXB->setToolTip(lyx::qt_("If checked, modification affects the counter only in the LyX workarea, not in the output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        lyxonlyXB->setText(lyx::qt_("&Workarea only", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class CounterUi: public Ui_CounterUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COUNTERUI_H
