/********************************************************************************
** Form generated from reading UI file 'PrefUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFUI_H
#define UI_PREFUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *useSystemThemeIconsCB;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *uiFilePB;
    QComboBox *iconSetCO;
    QLabel *iconSetLA;
    QLabel *uiFileLA;
    QLineEdit *uiFileED;
    QLabel *uiStyleLA;
    QComboBox *uiStyleCO;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QGroupBox *pixmapCacheGB_2;
    QGridLayout *gridLayout1;
    QCheckBox *tooltipCB;
    QGroupBox *documentsGB;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lastfilesLA;
    QSpinBox *lastfilesSB;
    QSpacerItem *spacerItem;
    QGroupBox *fullscreenGB;
    QGridLayout *gridLayout_5;
    QCheckBox *toggleMenubarCB;
    QCheckBox *toggleScrollbarCB;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *toggleStatusbarCB;
    QCheckBox *toggleTabbarCB;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *toggleToolbarsCB;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *PrefUi)
    {
        if (PrefUi->objectName().isEmpty())
            PrefUi->setObjectName(QStringLiteral("PrefUi"));
        PrefUi->resize(556, 502);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefUi->sizePolicy().hasHeightForWidth());
        PrefUi->setSizePolicy(sizePolicy);
        gridLayout_4 = new QGridLayout(PrefUi);
        gridLayout_4->setSpacing(4);
        gridLayout_4->setContentsMargins(9, 9, 9, 9);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        groupBox = new QGroupBox(PrefUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setSpacing(4);
        gridLayout_3->setContentsMargins(9, 9, 9, 9);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(4);
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        useSystemThemeIconsCB = new QCheckBox(groupBox);
        useSystemThemeIconsCB->setObjectName(QStringLiteral("useSystemThemeIconsCB"));

        horizontalLayout_4->addWidget(useSystemThemeIconsCB);


        gridLayout_3->addLayout(horizontalLayout_4, 1, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(4);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(4);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));

        gridLayout->addLayout(horizontalLayout, 1, 2, 1, 1);

        uiFilePB = new QPushButton(groupBox);
        uiFilePB->setObjectName(QStringLiteral("uiFilePB"));

        gridLayout->addWidget(uiFilePB, 0, 2, 1, 1);

        iconSetCO = new QComboBox(groupBox);
        iconSetCO->setObjectName(QStringLiteral("iconSetCO"));

        gridLayout->addWidget(iconSetCO, 1, 1, 1, 1);

        iconSetLA = new QLabel(groupBox);
        iconSetLA->setObjectName(QStringLiteral("iconSetLA"));

        gridLayout->addWidget(iconSetLA, 1, 0, 1, 1);

        uiFileLA = new QLabel(groupBox);
        uiFileLA->setObjectName(QStringLiteral("uiFileLA"));

        gridLayout->addWidget(uiFileLA, 0, 0, 1, 1);

        uiFileED = new QLineEdit(groupBox);
        uiFileED->setObjectName(QStringLiteral("uiFileED"));

        gridLayout->addWidget(uiFileED, 0, 1, 1, 1);

        uiStyleLA = new QLabel(groupBox);
        uiStyleLA->setObjectName(QStringLiteral("uiStyleLA"));

        gridLayout->addWidget(uiStyleLA, 2, 0, 1, 1);

        uiStyleCO = new QComboBox(groupBox);
        uiStyleCO->setObjectName(QStringLiteral("uiStyleCO"));

        gridLayout->addWidget(uiStyleCO, 2, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(4);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));

        gridLayout->addLayout(horizontalLayout_2, 2, 2, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        gridLayout_3->addLayout(gridLayout, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 1, 1, 1);


        gridLayout_4->addWidget(groupBox, 0, 0, 1, 1);

        pixmapCacheGB_2 = new QGroupBox(PrefUi);
        pixmapCacheGB_2->setObjectName(QStringLiteral("pixmapCacheGB_2"));
        pixmapCacheGB_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        pixmapCacheGB_2->setFlat(true);
        gridLayout1 = new QGridLayout(pixmapCacheGB_2);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        tooltipCB = new QCheckBox(pixmapCacheGB_2);
        tooltipCB->setObjectName(QStringLiteral("tooltipCB"));

        gridLayout1->addWidget(tooltipCB, 0, 0, 1, 1);


        gridLayout_4->addWidget(pixmapCacheGB_2, 1, 0, 1, 1);

        documentsGB = new QGroupBox(PrefUi);
        documentsGB->setObjectName(QStringLiteral("documentsGB"));
        documentsGB->setFlat(true);
        gridLayout_2 = new QGridLayout(documentsGB);
        gridLayout_2->setSpacing(4);
        gridLayout_2->setContentsMargins(9, 9, 9, 9);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(4);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        lastfilesLA = new QLabel(documentsGB);
        lastfilesLA->setObjectName(QStringLiteral("lastfilesLA"));

        horizontalLayout_3->addWidget(lastfilesLA);

        lastfilesSB = new QSpinBox(documentsGB);
        lastfilesSB->setObjectName(QStringLiteral("lastfilesSB"));
        lastfilesSB->setMaximum(9);

        horizontalLayout_3->addWidget(lastfilesSB);

        spacerItem = new QSpacerItem(48, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(spacerItem);


        gridLayout_2->addLayout(horizontalLayout_3, 0, 0, 1, 1);


        gridLayout_4->addWidget(documentsGB, 2, 0, 1, 1);

        fullscreenGB = new QGroupBox(PrefUi);
        fullscreenGB->setObjectName(QStringLiteral("fullscreenGB"));
        fullscreenGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        fullscreenGB->setFlat(true);
        gridLayout_5 = new QGridLayout(fullscreenGB);
        gridLayout_5->setSpacing(4);
        gridLayout_5->setContentsMargins(9, 9, 9, 9);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        toggleMenubarCB = new QCheckBox(fullscreenGB);
        toggleMenubarCB->setObjectName(QStringLiteral("toggleMenubarCB"));

        gridLayout_5->addWidget(toggleMenubarCB, 0, 2, 1, 1);

        toggleScrollbarCB = new QCheckBox(fullscreenGB);
        toggleScrollbarCB->setObjectName(QStringLiteral("toggleScrollbarCB"));

        gridLayout_5->addWidget(toggleScrollbarCB, 0, 4, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        toggleStatusbarCB = new QCheckBox(fullscreenGB);
        toggleStatusbarCB->setObjectName(QStringLiteral("toggleStatusbarCB"));

        gridLayout_5->addWidget(toggleStatusbarCB, 1, 0, 1, 1);

        toggleTabbarCB = new QCheckBox(fullscreenGB);
        toggleTabbarCB->setObjectName(QStringLiteral("toggleTabbarCB"));

        gridLayout_5->addWidget(toggleTabbarCB, 1, 2, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(146, 38, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_4, 0, 5, 2, 1);

        horizontalSpacer_6 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_6, 1, 1, 1, 1);

        toggleToolbarsCB = new QCheckBox(fullscreenGB);
        toggleToolbarsCB->setObjectName(QStringLiteral("toggleToolbarsCB"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(toggleToolbarsCB->sizePolicy().hasHeightForWidth());
        toggleToolbarsCB->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(toggleToolbarsCB, 0, 0, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_7, 0, 3, 1, 1);


        gridLayout_4->addWidget(fullscreenGB, 3, 0, 1, 1);

        spacerItem1 = new QSpacerItem(395, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem1, 4, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        iconSetLA->setBuddy(iconSetCO);
        uiFileLA->setBuddy(uiFileED);
        uiStyleLA->setBuddy(uiStyleCO);
        lastfilesLA->setBuddy(lastfilesSB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(uiFileED, uiFilePB);
        QWidget::setTabOrder(uiFilePB, iconSetCO);
        QWidget::setTabOrder(iconSetCO, useSystemThemeIconsCB);
        QWidget::setTabOrder(useSystemThemeIconsCB, tooltipCB);

        retranslateUi(PrefUi);

        QMetaObject::connectSlotsByName(PrefUi);
    } // setupUi

    void retranslateUi(QWidget *PrefUi)
    {
        PrefUi->setWindowTitle(QString());
        groupBox->setTitle(lyx::qt_("General Look && Feel", Q_NULLPTR));
        useSystemThemeIconsCB->setText(lyx::qt_("Use icons from system's &theme", Q_NULLPTR));
        uiFilePB->setText(lyx::qt_("Bro&wse...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        iconSetCO->setToolTip(lyx::qt_("The icon set to use. Warning: normal size of icons may be wrong until you save the preferences and restart LyX.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        iconSetLA->setText(lyx::qt_("&Icon set:", Q_NULLPTR));
        uiFileLA->setText(lyx::qt_("&User interface file:", Q_NULLPTR));
        uiStyleLA->setText(lyx::qt_("User interface &style:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        uiStyleCO->setToolTip(lyx::qt_("You can set a custom style here. Note that only certain styles may support dark mode, e.g. fusion on Windows.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pixmapCacheGB_2->setTitle(lyx::qt_("Context Help", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        tooltipCB->setToolTip(lyx::qt_("Checking this allows the automatic display of helpful comments for insets in the main work area of an edited document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tooltipCB->setText(lyx::qt_("&Enable tool tips in main work area", Q_NULLPTR));
        documentsGB->setTitle(lyx::qt_("Menus", Q_NULLPTR));
        lastfilesLA->setText(lyx::qt_("&Maximum last files:", Q_NULLPTR));
        fullscreenGB->setTitle(lyx::qt_("Fullscreen", Q_NULLPTR));
        toggleMenubarCB->setText(lyx::qt_("Hide &menubar", Q_NULLPTR));
        toggleScrollbarCB->setText(lyx::qt_("Hide scr&ollbar", Q_NULLPTR));
        toggleStatusbarCB->setText(lyx::qt_("Hide sta&tusbar", Q_NULLPTR));
        toggleTabbarCB->setText(lyx::qt_("H&ide tabbar", Q_NULLPTR));
        toggleToolbarsCB->setText(lyx::qt_("&Hide toolbars", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefUi: public Ui_PrefUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFUI_H
