/********************************************************************************
** Form generated from reading UI file 'PreambleUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREAMBLEUI_H
#define UI_PREAMBLEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PreambleUi
{
public:
    QGridLayout *gridLayout;
    QLineEdit *findLE;
    QPushButton *findButtonPB;
    QPushButton *editPB;
    QTextEdit *preambleTE;

    void setupUi(QWidget *PreambleUi)
    {
        if (PreambleUi->objectName().isEmpty())
            PreambleUi->setObjectName(QStringLiteral("PreambleUi"));
        PreambleUi->resize(377, 278);
        gridLayout = new QGridLayout(PreambleUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(11, 11, 11, 11);
        findLE = new QLineEdit(PreambleUi);
        findLE->setObjectName(QStringLiteral("findLE"));

        gridLayout->addWidget(findLE, 1, 0, 1, 1);

        findButtonPB = new QPushButton(PreambleUi);
        findButtonPB->setObjectName(QStringLiteral("findButtonPB"));

        gridLayout->addWidget(findButtonPB, 1, 1, 1, 1);

        editPB = new QPushButton(PreambleUi);
        editPB->setObjectName(QStringLiteral("editPB"));

        gridLayout->addWidget(editPB, 1, 2, 1, 1);

        preambleTE = new QTextEdit(PreambleUi);
        preambleTE->setObjectName(QStringLiteral("preambleTE"));
        preambleTE->setAcceptRichText(false);

        gridLayout->addWidget(preambleTE, 0, 0, 1, 3);


        retranslateUi(PreambleUi);

        QMetaObject::connectSlotsByName(PreambleUi);
    } // setupUi

    void retranslateUi(QWidget *PreambleUi)
    {
        PreambleUi->setWindowTitle(QString());
        findLE->setPlaceholderText(lyx::qt_("Find in preamble", Q_NULLPTR));
        findButtonPB->setText(lyx::qt_("&Find", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        editPB->setToolTip(lyx::qt_("Editor for LaTeX (plain) format will be used", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        editPB->setText(lyx::qt_("&Edit Externally", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PreambleUi: public Ui_PreambleUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREAMBLEUI_H
