/********************************************************************************
** Form generated from reading UI file 'ParagraphUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARAGRAPHUI_H
#define UI_PARAGRAPHUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ParagraphUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLineEdit *linespacingValue;
    QComboBox *linespacing;
    QGroupBox *aligmentGB;
    QGridLayout *gridLayout2;
    QRadioButton *alignJustRB;
    QRadioButton *alignLeftRB;
    QRadioButton *alignCenterRB;
    QRadioButton *alignRightRB;
    QRadioButton *alignDefaultRB;
    QGroupBox *labelwidthGB;
    QGridLayout *gridLayout3;
    QLabel *TextLabel2;
    QLineEdit *labelWidth;
    QCheckBox *noindentCB;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QCheckBox *synchronizedViewCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ParagraphUi)
    {
        if (ParagraphUi->objectName().isEmpty())
            ParagraphUi->setObjectName(QStringLiteral("ParagraphUi"));
        ParagraphUi->resize(487, 303);
        ParagraphUi->setFocusPolicy(Qt::NoFocus);
        gridLayout = new QGridLayout(ParagraphUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        groupBox = new QGroupBox(ParagraphUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        linespacingValue = new QLineEdit(groupBox);
        linespacingValue->setObjectName(QStringLiteral("linespacingValue"));
        linespacingValue->setEnabled(false);

        gridLayout1->addWidget(linespacingValue, 0, 1, 1, 1);

        linespacing = new QComboBox(groupBox);
        linespacing->setObjectName(QStringLiteral("linespacing"));

        gridLayout1->addWidget(linespacing, 0, 0, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);

        aligmentGB = new QGroupBox(ParagraphUi);
        aligmentGB->setObjectName(QStringLiteral("aligmentGB"));
        aligmentGB->setFlat(true);
        gridLayout2 = new QGridLayout(aligmentGB);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        alignJustRB = new QRadioButton(aligmentGB);
        alignJustRB->setObjectName(QStringLiteral("alignJustRB"));

        gridLayout2->addWidget(alignJustRB, 1, 0, 1, 1);

        alignLeftRB = new QRadioButton(aligmentGB);
        alignLeftRB->setObjectName(QStringLiteral("alignLeftRB"));

        gridLayout2->addWidget(alignLeftRB, 2, 0, 1, 1);

        alignCenterRB = new QRadioButton(aligmentGB);
        alignCenterRB->setObjectName(QStringLiteral("alignCenterRB"));

        gridLayout2->addWidget(alignCenterRB, 3, 0, 1, 1);

        alignRightRB = new QRadioButton(aligmentGB);
        alignRightRB->setObjectName(QStringLiteral("alignRightRB"));

        gridLayout2->addWidget(alignRightRB, 4, 0, 1, 1);

        alignDefaultRB = new QRadioButton(aligmentGB);
        alignDefaultRB->setObjectName(QStringLiteral("alignDefaultRB"));

        gridLayout2->addWidget(alignDefaultRB, 0, 0, 1, 1);


        gridLayout->addWidget(aligmentGB, 0, 1, 3, 2);

        labelwidthGB = new QGroupBox(ParagraphUi);
        labelwidthGB->setObjectName(QStringLiteral("labelwidthGB"));
        labelwidthGB->setEnabled(false);
        labelwidthGB->setFlat(true);
        gridLayout3 = new QGridLayout(labelwidthGB);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        TextLabel2 = new QLabel(labelwidthGB);
        TextLabel2->setObjectName(QStringLiteral("TextLabel2"));

        gridLayout3->addWidget(TextLabel2, 0, 0, 1, 1);

        labelWidth = new QLineEdit(labelwidthGB);
        labelWidth->setObjectName(QStringLiteral("labelWidth"));

        gridLayout3->addWidget(labelWidth, 0, 1, 1, 1);


        gridLayout->addWidget(labelwidthGB, 1, 0, 1, 1);

        noindentCB = new QCheckBox(ParagraphUi);
        noindentCB->setObjectName(QStringLiteral("noindentCB"));

        gridLayout->addWidget(noindentCB, 2, 0, 1, 1);

        spacerItem = new QSpacerItem(351, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 3, 0, 1, 3);

        spacerItem1 = new QSpacerItem(281, 31, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 4, 0, 2, 2);

        synchronizedViewCB = new QCheckBox(ParagraphUi);
        synchronizedViewCB->setObjectName(QStringLiteral("synchronizedViewCB"));
        synchronizedViewCB->setLayoutDirection(Qt::LeftToRight);

        gridLayout->addWidget(synchronizedViewCB, 5, 2, 1, 1);

        buttonBox = new QDialogButtonBox(ParagraphUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 6, 0, 1, 3);

#ifndef QT_NO_SHORTCUT
        TextLabel2->setBuddy(labelWidth);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(linespacing, linespacingValue);
        QWidget::setTabOrder(linespacingValue, labelWidth);
        QWidget::setTabOrder(labelWidth, noindentCB);
        QWidget::setTabOrder(noindentCB, alignDefaultRB);
        QWidget::setTabOrder(alignDefaultRB, alignJustRB);
        QWidget::setTabOrder(alignJustRB, alignLeftRB);
        QWidget::setTabOrder(alignLeftRB, alignCenterRB);
        QWidget::setTabOrder(alignCenterRB, alignRightRB);
        QWidget::setTabOrder(alignRightRB, synchronizedViewCB);

        retranslateUi(ParagraphUi);

        QMetaObject::connectSlotsByName(ParagraphUi);
    } // setupUi

    void retranslateUi(QDialog *ParagraphUi)
    {
        ParagraphUi->setWindowTitle(QString());
        groupBox->setTitle(lyx::qt_("Line &spacing", Q_NULLPTR));
        linespacing->clear();
        linespacing->insertItems(0, QStringList()
         << lyx::qt_("Default", Q_NULLPTR)
         << lyx::qt_("Single", Q_NULLPTR)
         << lyx::qt_("1.5", Q_NULLPTR)
         << lyx::qt_("Double", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
        aligmentGB->setTitle(lyx::qt_("Alignment", Q_NULLPTR));
        alignJustRB->setText(lyx::qt_("&Justified", Q_NULLPTR));
        alignLeftRB->setText(lyx::qt_("&Left", Q_NULLPTR));
        alignCenterRB->setText(lyx::qt_("&Center", Q_NULLPTR));
        alignRightRB->setText(lyx::qt_("Ri&ght", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignDefaultRB->setToolTip(lyx::qt_("Use the default alignment for this paragraph, whatever it is.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignDefaultRB->setText(lyx::qt_("Paragraph's &Default", Q_NULLPTR));
        labelwidthGB->setTitle(lyx::qt_("Label Width", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        TextLabel2->setToolTip(lyx::qt_("This text defines the width of the paragraph label", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        TextLabel2->setText(lyx::qt_("Lo&ngest label", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        labelWidth->setToolTip(lyx::qt_("This text defines the width of the paragraph label", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        noindentCB->setText(lyx::qt_("&Do not indent paragraph", Q_NULLPTR));
        synchronizedViewCB->setText(lyx::qt_("I&mmediate Apply", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ParagraphUi: public Ui_ParagraphUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PARAGRAPHUI_H
