/********************************************************************************
** Form generated from reading UI file 'BranchUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRANCHUI_H
#define UI_BRANCHUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BranchUi
{
public:
    QGridLayout *gridLayout;
    QLabel *branchLA;
    QComboBox *branchCO;
    QCheckBox *invertedCB;

    void setupUi(QWidget *BranchUi)
    {
        if (BranchUi->objectName().isEmpty())
            BranchUi->setObjectName(QStringLiteral("BranchUi"));
        BranchUi->resize(259, 62);
        gridLayout = new QGridLayout(BranchUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        branchLA = new QLabel(BranchUi);
        branchLA->setObjectName(QStringLiteral("branchLA"));

        gridLayout->addWidget(branchLA, 0, 0, 1, 1);

        branchCO = new QComboBox(BranchUi);
        branchCO->setObjectName(QStringLiteral("branchCO"));

        gridLayout->addWidget(branchCO, 0, 1, 1, 1);

        invertedCB = new QCheckBox(BranchUi);
        invertedCB->setObjectName(QStringLiteral("invertedCB"));

        gridLayout->addWidget(invertedCB, 1, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        branchLA->setBuddy(branchCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(BranchUi);

        QMetaObject::connectSlotsByName(BranchUi);
    } // setupUi

    void retranslateUi(QWidget *BranchUi)
    {
        BranchUi->setWindowTitle(QString());
        branchLA->setText(lyx::qt_("&Available branches:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        branchCO->setToolTip(lyx::qt_("Select your branch", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        invertedCB->setText(lyx::qt_("Inverted", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BranchUi: public Ui_BranchUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BRANCHUI_H
