/********************************************************************************
** Form generated from reading UI file 'PDFSupportUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PDFSUPPORTUI_H
#define UI_PDFSUPPORTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PDFSupportUi
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *use_hyperrefGB;
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout2;
    QLabel *titleL;
    QLineEdit *titleLE;
    QLabel *authorL;
    QLineEdit *authorLE;
    QLabel *subjectL;
    QLineEdit *subjectLE;
    QLabel *keywordsL;
    QLineEdit *keywordsLE;
    QVBoxLayout *vboxLayout;
    QCheckBox *pdfusetitleCB;
    QCheckBox *fullscreenCB;
    QWidget *tab_2;
    QGridLayout *gridLayout3;
    QSpacerItem *spacerItem2;
    QVBoxLayout *vboxLayout1;
    QCheckBox *breaklinksCB;
    QCheckBox *pdfborderCB;
    QCheckBox *colorlinksCB;
    QLabel *label;
    QComboBox *backrefCO;
    QSpacerItem *spacerItem3;
    QWidget *tab_3;
    QGridLayout *gridLayout4;
    QGroupBox *bookmarksGB;
    QGridLayout *gridLayout5;
    QCheckBox *bookmarksnumberedCB;
    QCheckBox *bookmarksopenGB;
    QHBoxLayout *hboxLayout;
    QLabel *bookmarksopenlevelLA;
    QSpinBox *bookmarksopenlevelSB;
    QSpacerItem *spacerItem4;
    QSpacerItem *spacerItem5;
    QWidget *tab_4;
    QGridLayout *gridLayout_9;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_8;
    QTextEdit *optionsTE;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_7;
    QTextEdit *metadataTE;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *PDFSupportUi)
    {
        if (PDFSupportUi->objectName().isEmpty())
            PDFSupportUi->setObjectName(QStringLiteral("PDFSupportUi"));
        PDFSupportUi->resize(485, 530);
        gridLayout_2 = new QGridLayout(PDFSupportUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        use_hyperrefGB = new QGroupBox(PDFSupportUi);
        use_hyperrefGB->setObjectName(QStringLiteral("use_hyperrefGB"));
        use_hyperrefGB->setFocusPolicy(Qt::StrongFocus);
        use_hyperrefGB->setFlat(true);
        use_hyperrefGB->setCheckable(true);
        use_hyperrefGB->setChecked(false);
        gridLayout = new QGridLayout(use_hyperrefGB);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        tabWidget = new QTabWidget(use_hyperrefGB);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout1 = new QGridLayout(tab);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout1->addItem(spacerItem, 2, 0, 1, 1);

        spacerItem1 = new QSpacerItem(181, 41, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem1, 1, 1, 1, 1);

        groupBox_2 = new QGroupBox(tab);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setFlat(true);
        gridLayout2 = new QGridLayout(groupBox_2);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(9, -1, -1, -1);
        titleL = new QLabel(groupBox_2);
        titleL->setObjectName(QStringLiteral("titleL"));

        gridLayout2->addWidget(titleL, 0, 0, 1, 1);

        titleLE = new QLineEdit(groupBox_2);
        titleLE->setObjectName(QStringLiteral("titleLE"));

        gridLayout2->addWidget(titleLE, 0, 1, 1, 1);

        authorL = new QLabel(groupBox_2);
        authorL->setObjectName(QStringLiteral("authorL"));

        gridLayout2->addWidget(authorL, 1, 0, 1, 1);

        authorLE = new QLineEdit(groupBox_2);
        authorLE->setObjectName(QStringLiteral("authorLE"));

        gridLayout2->addWidget(authorLE, 1, 1, 1, 1);

        subjectL = new QLabel(groupBox_2);
        subjectL->setObjectName(QStringLiteral("subjectL"));

        gridLayout2->addWidget(subjectL, 2, 0, 1, 1);

        subjectLE = new QLineEdit(groupBox_2);
        subjectLE->setObjectName(QStringLiteral("subjectLE"));

        gridLayout2->addWidget(subjectLE, 2, 1, 1, 1);

        keywordsL = new QLabel(groupBox_2);
        keywordsL->setObjectName(QStringLiteral("keywordsL"));

        gridLayout2->addWidget(keywordsL, 3, 0, 1, 1);

        keywordsLE = new QLineEdit(groupBox_2);
        keywordsLE->setObjectName(QStringLiteral("keywordsLE"));

        gridLayout2->addWidget(keywordsLE, 3, 1, 1, 1);


        gridLayout1->addWidget(groupBox_2, 0, 0, 1, 2);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        pdfusetitleCB = new QCheckBox(tab);
        pdfusetitleCB->setObjectName(QStringLiteral("pdfusetitleCB"));

        vboxLayout->addWidget(pdfusetitleCB);

        fullscreenCB = new QCheckBox(tab);
        fullscreenCB->setObjectName(QStringLiteral("fullscreenCB"));

        vboxLayout->addWidget(fullscreenCB);


        gridLayout1->addLayout(vboxLayout, 1, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout3 = new QGridLayout(tab_2);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout3->addItem(spacerItem2, 1, 0, 1, 1);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        breaklinksCB = new QCheckBox(tab_2);
        breaklinksCB->setObjectName(QStringLiteral("breaklinksCB"));

        vboxLayout1->addWidget(breaklinksCB);

        pdfborderCB = new QCheckBox(tab_2);
        pdfborderCB->setObjectName(QStringLiteral("pdfborderCB"));
        pdfborderCB->setTristate(false);

        vboxLayout1->addWidget(pdfborderCB);

        colorlinksCB = new QCheckBox(tab_2);
        colorlinksCB->setObjectName(QStringLiteral("colorlinksCB"));

        vboxLayout1->addWidget(colorlinksCB);

        label = new QLabel(tab_2);
        label->setObjectName(QStringLiteral("label"));

        vboxLayout1->addWidget(label);

        backrefCO = new QComboBox(tab_2);
        backrefCO->setObjectName(QStringLiteral("backrefCO"));

        vboxLayout1->addWidget(backrefCO);


        gridLayout3->addLayout(vboxLayout1, 0, 0, 1, 1);

        spacerItem3 = new QSpacerItem(151, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout3->addItem(spacerItem3, 0, 1, 1, 1);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        gridLayout4 = new QGridLayout(tab_3);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        bookmarksGB = new QGroupBox(tab_3);
        bookmarksGB->setObjectName(QStringLiteral("bookmarksGB"));
        bookmarksGB->setFlat(true);
        bookmarksGB->setCheckable(true);
        bookmarksGB->setChecked(true);
        gridLayout5 = new QGridLayout(bookmarksGB);
        gridLayout5->setSpacing(6);
        gridLayout5->setObjectName(QStringLiteral("gridLayout5"));
        gridLayout5->setContentsMargins(9, 9, 9, 9);
        bookmarksnumberedCB = new QCheckBox(bookmarksGB);
        bookmarksnumberedCB->setObjectName(QStringLiteral("bookmarksnumberedCB"));

        gridLayout5->addWidget(bookmarksnumberedCB, 0, 0, 1, 2);

        bookmarksopenGB = new QCheckBox(bookmarksGB);
        bookmarksopenGB->setObjectName(QStringLiteral("bookmarksopenGB"));

        gridLayout5->addWidget(bookmarksopenGB, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        bookmarksopenlevelLA = new QLabel(bookmarksGB);
        bookmarksopenlevelLA->setObjectName(QStringLiteral("bookmarksopenlevelLA"));

        hboxLayout->addWidget(bookmarksopenlevelLA);

        bookmarksopenlevelSB = new QSpinBox(bookmarksGB);
        bookmarksopenlevelSB->setObjectName(QStringLiteral("bookmarksopenlevelSB"));

        hboxLayout->addWidget(bookmarksopenlevelSB);


        gridLayout5->addLayout(hboxLayout, 2, 0, 1, 1);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout5->addItem(spacerItem4, 2, 1, 1, 1);


        gridLayout4->addWidget(bookmarksGB, 0, 0, 1, 1);

        spacerItem5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout4->addItem(spacerItem5, 1, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QStringLiteral("tab_4"));
        gridLayout_9 = new QGridLayout(tab_4);
        gridLayout_9->setObjectName(QStringLiteral("gridLayout_9"));
        groupBox_3 = new QGroupBox(tab_4);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        gridLayout_8 = new QGridLayout(groupBox_3);
        gridLayout_8->setObjectName(QStringLiteral("gridLayout_8"));
        optionsTE = new QTextEdit(groupBox_3);
        optionsTE->setObjectName(QStringLiteral("optionsTE"));
        optionsTE->setAcceptRichText(false);

        gridLayout_8->addWidget(optionsTE, 0, 0, 1, 1);


        gridLayout_9->addWidget(groupBox_3, 0, 0, 1, 1);

        tabWidget->addTab(tab_4, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);


        gridLayout_2->addWidget(use_hyperrefGB, 0, 0, 1, 1);

        groupBox = new QGroupBox(PDFSupportUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_7 = new QGridLayout(groupBox);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        metadataTE = new QTextEdit(groupBox);
        metadataTE->setObjectName(QStringLiteral("metadataTE"));
        metadataTE->setAcceptRichText(false);

        gridLayout_7->addWidget(metadataTE, 0, 0, 1, 1);


        gridLayout_2->addWidget(groupBox, 1, 0, 1, 1);

        spacerItem6 = new QSpacerItem(402, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(spacerItem6, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        titleL->setBuddy(titleLE);
        authorL->setBuddy(authorLE);
        subjectL->setBuddy(subjectLE);
        keywordsL->setBuddy(keywordsLE);
        label->setBuddy(backrefCO);
        bookmarksopenlevelLA->setBuddy(bookmarksopenlevelSB);
#endif // QT_NO_SHORTCUT

        retranslateUi(PDFSupportUi);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PDFSupportUi);
    } // setupUi

    void retranslateUi(QWidget *PDFSupportUi)
    {
        PDFSupportUi->setWindowTitle(lyx::qt_("Form", Q_NULLPTR));
        use_hyperrefGB->setTitle(lyx::qt_("&Use hyperref support", Q_NULLPTR));
        groupBox_2->setTitle(lyx::qt_("Header Information", Q_NULLPTR));
        titleL->setText(lyx::qt_("&Title:", Q_NULLPTR));
        authorL->setText(lyx::qt_("&Author:", Q_NULLPTR));
        subjectL->setText(lyx::qt_("Sub&ject:", Q_NULLPTR));
        keywordsL->setText(lyx::qt_("&Keywords:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pdfusetitleCB->setToolTip(lyx::qt_("If not stated explicitly, fill title and author from appropriate environments", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pdfusetitleCB->setText(lyx::qt_("Automatically fi&ll header", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fullscreenCB->setToolTip(lyx::qt_("Enable fullscreen PDF presentation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fullscreenCB->setText(lyx::qt_("Load in &fullscreen mode", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab), lyx::qt_("&General", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        breaklinksCB->setToolTip(lyx::qt_("Allows link text to break across lines.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        breaklinksCB->setText(lyx::qt_("B&reak links over lines", Q_NULLPTR));
        pdfborderCB->setText(lyx::qt_("No &frames around links", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorlinksCB->setToolTip(lyx::qt_("Mutually exclusive with frames around links, see manual.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorlinksCB->setText(lyx::qt_("C&olor links", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        label->setToolTip(lyx::qt_("Bibliographical backreferences", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label->setText(lyx::qt_("B&ackreferences:", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), lyx::qt_("H&yperlinks", Q_NULLPTR));
        bookmarksGB->setTitle(lyx::qt_("G&enerate bookmarks (toc)", Q_NULLPTR));
        bookmarksnumberedCB->setText(lyx::qt_("&Numbered bookmarks", Q_NULLPTR));
        bookmarksopenGB->setText(lyx::qt_("&Open bookmark tree", Q_NULLPTR));
        bookmarksopenlevelLA->setText(lyx::qt_("&Level:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bookmarksopenlevelSB->setToolTip(lyx::qt_("Number of levels", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tabWidget->setTabText(tabWidget->indexOf(tab_3), lyx::qt_("&Bookmarks", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupBox_3->setToolTip(lyx::qt_("Additional hyperref options (comma-separated) to be passed via \\hypersetup.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_3->setTitle(lyx::qt_("Hyperse&tup", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), lyx::qt_("Additional O&ptions", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupBox->setToolTip(lyx::qt_("Document metadata and PDF settings (as specified in LaTeX 06/2022 and later)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(lyx::qt_("Document &Metadata", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PDFSupportUi: public Ui_PDFSupportUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PDFSUPPORTUI_H
