/********************************************************************************
** Form generated from reading UI file 'PageLayoutUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PAGELAYOUTUI_H
#define UI_PAGELAYOUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PageLayoutUi
{
public:
    QGridLayout *gridLayout_3;
    QGroupBox *paperFormatGB;
    QGridLayout *gridLayout;
    QLabel *papersizeL;
    QComboBox *papersizeCO;
    QSpacerItem *spacerItem;
    QLabel *paperheightL;
    QLineEdit *paperheightLE;
    lyx::frontend::LengthCombo *paperheightUnitCO;
    QLabel *paperwidthL;
    QLineEdit *paperwidthLE;
    lyx::frontend::LengthCombo *paperwidthUnitCO;
    QLabel *label_3;
    QRadioButton *portraitRB;
    QRadioButton *landscapeRB;
    QGroupBox *pageLayoutGB;
    QGridLayout *gridLayout_2;
    QLabel *pagestyleL;
    QComboBox *pagestyleCO;
    QSpacerItem *spacerItem1;
    QCheckBox *facingPagesCB;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *PageLayoutUi)
    {
        if (PageLayoutUi->objectName().isEmpty())
            PageLayoutUi->setObjectName(QStringLiteral("PageLayoutUi"));
        PageLayoutUi->resize(362, 287);
        gridLayout_3 = new QGridLayout(PageLayoutUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        paperFormatGB = new QGroupBox(PageLayoutUi);
        paperFormatGB->setObjectName(QStringLiteral("paperFormatGB"));
        paperFormatGB->setFlat(true);
        gridLayout = new QGridLayout(paperFormatGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        papersizeL = new QLabel(paperFormatGB);
        papersizeL->setObjectName(QStringLiteral("papersizeL"));

        gridLayout->addWidget(papersizeL, 0, 0, 1, 1);

        papersizeCO = new QComboBox(paperFormatGB);
        papersizeCO->setObjectName(QStringLiteral("papersizeCO"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(papersizeCO->sizePolicy().hasHeightForWidth());
        papersizeCO->setSizePolicy(sizePolicy);
        papersizeCO->setMaxVisibleItems(20);

        gridLayout->addWidget(papersizeCO, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(43, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 3, 1, 1);

        paperheightL = new QLabel(paperFormatGB);
        paperheightL->setObjectName(QStringLiteral("paperheightL"));
        paperheightL->setEnabled(false);

        gridLayout->addWidget(paperheightL, 1, 0, 1, 1);

        paperheightLE = new QLineEdit(paperFormatGB);
        paperheightLE->setObjectName(QStringLiteral("paperheightLE"));
        paperheightLE->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(paperheightLE->sizePolicy().hasHeightForWidth());
        paperheightLE->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(paperheightLE, 1, 1, 1, 1);

        paperheightUnitCO = new lyx::frontend::LengthCombo(paperFormatGB);
        paperheightUnitCO->setObjectName(QStringLiteral("paperheightUnitCO"));

        gridLayout->addWidget(paperheightUnitCO, 1, 2, 1, 1);

        paperwidthL = new QLabel(paperFormatGB);
        paperwidthL->setObjectName(QStringLiteral("paperwidthL"));
        paperwidthL->setEnabled(false);

        gridLayout->addWidget(paperwidthL, 2, 0, 1, 1);

        paperwidthLE = new QLineEdit(paperFormatGB);
        paperwidthLE->setObjectName(QStringLiteral("paperwidthLE"));
        paperwidthLE->setEnabled(false);
        sizePolicy1.setHeightForWidth(paperwidthLE->sizePolicy().hasHeightForWidth());
        paperwidthLE->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(paperwidthLE, 2, 1, 1, 1);

        paperwidthUnitCO = new lyx::frontend::LengthCombo(paperFormatGB);
        paperwidthUnitCO->setObjectName(QStringLiteral("paperwidthUnitCO"));

        gridLayout->addWidget(paperwidthUnitCO, 2, 2, 1, 1);

        label_3 = new QLabel(paperFormatGB);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        portraitRB = new QRadioButton(paperFormatGB);
        portraitRB->setObjectName(QStringLiteral("portraitRB"));
        portraitRB->setChecked(true);

        gridLayout->addWidget(portraitRB, 3, 1, 1, 1);

        landscapeRB = new QRadioButton(paperFormatGB);
        landscapeRB->setObjectName(QStringLiteral("landscapeRB"));

        gridLayout->addWidget(landscapeRB, 4, 1, 1, 1);


        gridLayout_3->addWidget(paperFormatGB, 0, 0, 1, 1);

        pageLayoutGB = new QGroupBox(PageLayoutUi);
        pageLayoutGB->setObjectName(QStringLiteral("pageLayoutGB"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pageLayoutGB->sizePolicy().hasHeightForWidth());
        pageLayoutGB->setSizePolicy(sizePolicy2);
        pageLayoutGB->setFlat(true);
        gridLayout_2 = new QGridLayout(pageLayoutGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        pagestyleL = new QLabel(pageLayoutGB);
        pagestyleL->setObjectName(QStringLiteral("pagestyleL"));

        gridLayout_2->addWidget(pagestyleL, 0, 0, 1, 1);

        pagestyleCO = new QComboBox(pageLayoutGB);
        pagestyleCO->setObjectName(QStringLiteral("pagestyleCO"));
        sizePolicy.setHeightForWidth(pagestyleCO->sizePolicy().hasHeightForWidth());
        pagestyleCO->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(pagestyleCO, 0, 1, 1, 2);

        spacerItem1 = new QSpacerItem(168, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(spacerItem1, 0, 3, 1, 1);

        facingPagesCB = new QCheckBox(pageLayoutGB);
        facingPagesCB->setObjectName(QStringLiteral("facingPagesCB"));

        gridLayout_2->addWidget(facingPagesCB, 1, 0, 1, 3);


        gridLayout_3->addWidget(pageLayoutGB, 1, 0, 1, 1);

        spacerItem2 = new QSpacerItem(51, 131, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(spacerItem2, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        papersizeL->setBuddy(papersizeCO);
        paperheightL->setBuddy(paperheightLE);
        paperwidthL->setBuddy(paperwidthLE);
        label_3->setBuddy(portraitRB);
        pagestyleL->setBuddy(pagestyleCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(papersizeCO, paperheightLE);
        QWidget::setTabOrder(paperheightLE, paperheightUnitCO);
        QWidget::setTabOrder(paperheightUnitCO, paperwidthLE);
        QWidget::setTabOrder(paperwidthLE, paperwidthUnitCO);
        QWidget::setTabOrder(paperwidthUnitCO, portraitRB);
        QWidget::setTabOrder(portraitRB, landscapeRB);
        QWidget::setTabOrder(landscapeRB, pagestyleCO);
        QWidget::setTabOrder(pagestyleCO, facingPagesCB);

        retranslateUi(PageLayoutUi);

        QMetaObject::connectSlotsByName(PageLayoutUi);
    } // setupUi

    void retranslateUi(QWidget *PageLayoutUi)
    {
        PageLayoutUi->setWindowTitle(QString());
        paperFormatGB->setTitle(lyx::qt_("Paper Format", Q_NULLPTR));
        papersizeL->setText(lyx::qt_("&Format:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        papersizeCO->setToolTip(lyx::qt_("Choose a particular paper size, or set your own with \"Custom\"", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        paperheightL->setText(lyx::qt_("&Height:", Q_NULLPTR));
        paperwidthL->setText(lyx::qt_("&Width:", Q_NULLPTR));
        label_3->setText(lyx::qt_("&Orientation:", Q_NULLPTR));
        portraitRB->setText(lyx::qt_("&Portrait", Q_NULLPTR));
        landscapeRB->setText(lyx::qt_("&Landscape", Q_NULLPTR));
        pageLayoutGB->setTitle(lyx::qt_("Page Layout", Q_NULLPTR));
        pagestyleL->setText(lyx::qt_("Page &style:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pagestyleCO->setToolTip(lyx::qt_("Style used for the page header and footer", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        facingPagesCB->setToolTip(lyx::qt_("Lay out the page for double-sided printing", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        facingPagesCB->setText(lyx::qt_("&Two-sided document", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PageLayoutUi: public Ui_PageLayoutUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PAGELAYOUTUI_H
