/********************************************************************************
** Form generated from reading UI file 'BulletsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BULLETSUI_H
#define UI_BULLETSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BulletsUi
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    QListWidget *levelLW;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QComboBox *bulletpaneCO;
    QSpacerItem *spacerItem;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QStackedWidget *bulletpaneSW;
    QGridLayout *gridLayout;
    QCheckBox *customCB;
    QLineEdit *customLE;
    QLabel *sizeL;
    QComboBox *bulletsizeCO;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *BulletsUi)
    {
        if (BulletsUi->objectName().isEmpty())
            BulletsUi->setObjectName(QStringLiteral("BulletsUi"));
        BulletsUi->resize(414, 380);
        gridLayout_2 = new QGridLayout(BulletsUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label = new QLabel(BulletsUi);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        levelLW = new QListWidget(BulletsUi);
        levelLW->setObjectName(QStringLiteral("levelLW"));
        levelLW->setMaximumSize(QSize(96, 16777215));

        gridLayout_2->addWidget(levelLW, 1, 0, 4, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        label_2 = new QLabel(BulletsUi);
        label_2->setObjectName(QStringLiteral("label_2"));

        horizontalLayout_2->addWidget(label_2);

        bulletpaneCO = new QComboBox(BulletsUi);
        bulletpaneCO->setObjectName(QStringLiteral("bulletpaneCO"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bulletpaneCO->sizePolicy().hasHeightForWidth());
        bulletpaneCO->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(bulletpaneCO);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(16, 271, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(spacerItem, 1, 2, 4, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        bulletpaneSW = new QStackedWidget(BulletsUi);
        bulletpaneSW->setObjectName(QStringLiteral("bulletpaneSW"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bulletpaneSW->sizePolicy().hasHeightForWidth());
        bulletpaneSW->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(bulletpaneSW);


        gridLayout_2->addLayout(horizontalLayout, 2, 1, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        customCB = new QCheckBox(BulletsUi);
        customCB->setObjectName(QStringLiteral("customCB"));

        gridLayout->addWidget(customCB, 0, 0, 1, 1);

        customLE = new QLineEdit(BulletsUi);
        customLE->setObjectName(QStringLiteral("customLE"));
        customLE->setEnabled(false);

        gridLayout->addWidget(customLE, 0, 1, 1, 1);

        sizeL = new QLabel(BulletsUi);
        sizeL->setObjectName(QStringLiteral("sizeL"));
        sizeL->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(sizeL, 1, 0, 1, 1);

        bulletsizeCO = new QComboBox(BulletsUi);
        bulletsizeCO->setObjectName(QStringLiteral("bulletsizeCO"));
        sizePolicy.setHeightForWidth(bulletsizeCO->sizePolicy().hasHeightForWidth());
        bulletsizeCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(bulletsizeCO, 1, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 3, 1, 1, 1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(spacerItem1, 4, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        label->setBuddy(levelLW);
        label_2->setBuddy(bulletpaneCO);
        sizeL->setBuddy(bulletsizeCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(levelLW, bulletpaneCO);
        QWidget::setTabOrder(bulletpaneCO, bulletpaneSW);
        QWidget::setTabOrder(bulletpaneSW, customCB);
        QWidget::setTabOrder(customCB, customLE);
        QWidget::setTabOrder(customLE, bulletsizeCO);

        retranslateUi(BulletsUi);
        QObject::connect(customCB, SIGNAL(toggled(bool)), customLE, SLOT(setEnabled(bool)));
        QObject::connect(customCB, SIGNAL(toggled(bool)), label_2, SLOT(setDisabled(bool)));
        QObject::connect(customCB, SIGNAL(toggled(bool)), bulletpaneCO, SLOT(setDisabled(bool)));
        QObject::connect(customCB, SIGNAL(toggled(bool)), bulletpaneSW, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(BulletsUi);
    } // setupUi

    void retranslateUi(QWidget *BulletsUi)
    {
        label->setText(lyx::qt_("&Level:", Q_NULLPTR));
        label_2->setText(lyx::qt_("&Font:", Q_NULLPTR));
        customCB->setText(lyx::qt_("&Custom bullet:", Q_NULLPTR));
        sizeL->setText(lyx::qt_("Si&ze:", Q_NULLPTR));
        bulletsizeCO->clear();
        bulletsizeCO->insertItems(0, QStringList()
         << lyx::qt_("Default", Q_NULLPTR)
         << lyx::qt_("Tiny", Q_NULLPTR)
         << lyx::qt_("Smallest", Q_NULLPTR)
         << lyx::qt_("Smaller", Q_NULLPTR)
         << lyx::qt_("Small", Q_NULLPTR)
         << lyx::qt_("Normal", Q_NULLPTR)
         << lyx::qt_("Large", Q_NULLPTR)
         << lyx::qt_("Larger", Q_NULLPTR)
         << lyx::qt_("Largest", Q_NULLPTR)
         << lyx::qt_("Huge", Q_NULLPTR)
         << lyx::qt_("Huger", Q_NULLPTR)
        );
        Q_UNUSED(BulletsUi);
    } // retranslateUi

};

namespace Ui {
    class BulletsUi: public Ui_BulletsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BULLETSUI_H
