/********************************************************************************
** Form generated from reading UI file 'PrefScreenFontsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFSCREENFONTSUI_H
#define UI_PREFSCREENFONTSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "GuiFontExample.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefScreenFontsUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout1;
    QComboBox *screenSansCO;
    GuiFontExample *screenSansFE;
    QLabel *screenSansLA;
    GuiFontExample *screenRomanFE;
    QComboBox *screenRomanCO;
    QLabel *screenTypewriterLA;
    QLabel *screenRomanLA;
    GuiFontExample *screenTypewriterFE;
    QComboBox *screenTypewriterCO;
    QHBoxLayout *hboxLayout1;
    QGridLayout *gridLayout2;
    QLabel *screenZoomLA;
    QSpinBox *screenZoomSB;
    QSpacerItem *spacerItem;
    QGroupBox *GroupBox3;
    QGridLayout *gridLayout3;
    QLineEdit *screenTinyED;
    QLineEdit *screenHugerED;
    QLineEdit *screenSmallestED;
    QLineEdit *screenSmallerED;
    QLineEdit *screenSmallED;
    QLineEdit *screenNormalED;
    QLineEdit *screenLargeED;
    QLineEdit *screenLargerED;
    QLineEdit *screenLargestED;
    QLabel *screenLargeLA;
    QLabel *screenLargerLA;
    QLabel *screenLargestLA;
    QLineEdit *screenHugeED;
    QLabel *screenHugeLA;
    QLabel *screenHugestLA;
    QLabel *screenSmallestLA;
    QLabel *screenSmallerLA;
    QLabel *screenSmallLA;
    QLabel *screenNormalLA;
    QLabel *screenTinyLA;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *PrefScreenFontsUi)
    {
        if (PrefScreenFontsUi->objectName().isEmpty())
            PrefScreenFontsUi->setObjectName(QStringLiteral("PrefScreenFontsUi"));
        PrefScreenFontsUi->resize(470, 454);
        gridLayout = new QGridLayout(PrefScreenFontsUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        screenSansCO = new QComboBox(PrefScreenFontsUi);
        screenSansCO->setObjectName(QStringLiteral("screenSansCO"));
        screenSansCO->setMaxVisibleItems(20);
        screenSansCO->setDuplicatesEnabled(false);

        gridLayout1->addWidget(screenSansCO, 1, 1, 1, 1);

        screenSansFE = new GuiFontExample(PrefScreenFontsUi);
        screenSansFE->setObjectName(QStringLiteral("screenSansFE"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(screenSansFE->sizePolicy().hasHeightForWidth());
        screenSansFE->setSizePolicy(sizePolicy);
        screenSansFE->setMinimumSize(QSize(60, 0));

        gridLayout1->addWidget(screenSansFE, 1, 2, 1, 1);

        screenSansLA = new QLabel(PrefScreenFontsUi);
        screenSansLA->setObjectName(QStringLiteral("screenSansLA"));

        gridLayout1->addWidget(screenSansLA, 1, 0, 1, 1);

        screenRomanFE = new GuiFontExample(PrefScreenFontsUi);
        screenRomanFE->setObjectName(QStringLiteral("screenRomanFE"));
        sizePolicy.setHeightForWidth(screenRomanFE->sizePolicy().hasHeightForWidth());
        screenRomanFE->setSizePolicy(sizePolicy);
        screenRomanFE->setMinimumSize(QSize(60, 0));

        gridLayout1->addWidget(screenRomanFE, 0, 2, 1, 1);

        screenRomanCO = new QComboBox(PrefScreenFontsUi);
        screenRomanCO->setObjectName(QStringLiteral("screenRomanCO"));
        screenRomanCO->setMaxVisibleItems(20);
        screenRomanCO->setDuplicatesEnabled(false);

        gridLayout1->addWidget(screenRomanCO, 0, 1, 1, 1);

        screenTypewriterLA = new QLabel(PrefScreenFontsUi);
        screenTypewriterLA->setObjectName(QStringLiteral("screenTypewriterLA"));

        gridLayout1->addWidget(screenTypewriterLA, 2, 0, 1, 1);

        screenRomanLA = new QLabel(PrefScreenFontsUi);
        screenRomanLA->setObjectName(QStringLiteral("screenRomanLA"));

        gridLayout1->addWidget(screenRomanLA, 0, 0, 1, 1);

        screenTypewriterFE = new GuiFontExample(PrefScreenFontsUi);
        screenTypewriterFE->setObjectName(QStringLiteral("screenTypewriterFE"));
        sizePolicy.setHeightForWidth(screenTypewriterFE->sizePolicy().hasHeightForWidth());
        screenTypewriterFE->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(screenTypewriterFE, 2, 2, 1, 1);

        screenTypewriterCO = new QComboBox(PrefScreenFontsUi);
        screenTypewriterCO->setObjectName(QStringLiteral("screenTypewriterCO"));
        screenTypewriterCO->setMaxVisibleItems(20);
        screenTypewriterCO->setDuplicatesEnabled(false);

        gridLayout1->addWidget(screenTypewriterCO, 2, 1, 1, 1);


        hboxLayout->addLayout(gridLayout1);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        screenZoomLA = new QLabel(PrefScreenFontsUi);
        screenZoomLA->setObjectName(QStringLiteral("screenZoomLA"));

        gridLayout2->addWidget(screenZoomLA, 0, 0, 1, 1);

        screenZoomSB = new QSpinBox(PrefScreenFontsUi);
        screenZoomSB->setObjectName(QStringLiteral("screenZoomSB"));
        screenZoomSB->setMaximum(999);

        gridLayout2->addWidget(screenZoomSB, 0, 1, 1, 1);


        hboxLayout1->addLayout(gridLayout2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout1, 1, 0, 1, 1);

        GroupBox3 = new QGroupBox(PrefScreenFontsUi);
        GroupBox3->setObjectName(QStringLiteral("GroupBox3"));
        gridLayout3 = new QGridLayout(GroupBox3);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        screenTinyED = new QLineEdit(GroupBox3);
        screenTinyED->setObjectName(QStringLiteral("screenTinyED"));

        gridLayout3->addWidget(screenTinyED, 0, 1, 1, 1);

        screenHugerED = new QLineEdit(GroupBox3);
        screenHugerED->setObjectName(QStringLiteral("screenHugerED"));

        gridLayout3->addWidget(screenHugerED, 4, 3, 1, 1);

        screenSmallestED = new QLineEdit(GroupBox3);
        screenSmallestED->setObjectName(QStringLiteral("screenSmallestED"));

        gridLayout3->addWidget(screenSmallestED, 1, 1, 1, 1);

        screenSmallerED = new QLineEdit(GroupBox3);
        screenSmallerED->setObjectName(QStringLiteral("screenSmallerED"));

        gridLayout3->addWidget(screenSmallerED, 2, 1, 1, 1);

        screenSmallED = new QLineEdit(GroupBox3);
        screenSmallED->setObjectName(QStringLiteral("screenSmallED"));

        gridLayout3->addWidget(screenSmallED, 3, 1, 1, 1);

        screenNormalED = new QLineEdit(GroupBox3);
        screenNormalED->setObjectName(QStringLiteral("screenNormalED"));

        gridLayout3->addWidget(screenNormalED, 4, 1, 1, 1);

        screenLargeED = new QLineEdit(GroupBox3);
        screenLargeED->setObjectName(QStringLiteral("screenLargeED"));

        gridLayout3->addWidget(screenLargeED, 0, 3, 1, 1);

        screenLargerED = new QLineEdit(GroupBox3);
        screenLargerED->setObjectName(QStringLiteral("screenLargerED"));

        gridLayout3->addWidget(screenLargerED, 1, 3, 1, 1);

        screenLargestED = new QLineEdit(GroupBox3);
        screenLargestED->setObjectName(QStringLiteral("screenLargestED"));

        gridLayout3->addWidget(screenLargestED, 2, 3, 1, 1);

        screenLargeLA = new QLabel(GroupBox3);
        screenLargeLA->setObjectName(QStringLiteral("screenLargeLA"));

        gridLayout3->addWidget(screenLargeLA, 0, 2, 1, 1);

        screenLargerLA = new QLabel(GroupBox3);
        screenLargerLA->setObjectName(QStringLiteral("screenLargerLA"));

        gridLayout3->addWidget(screenLargerLA, 1, 2, 1, 1);

        screenLargestLA = new QLabel(GroupBox3);
        screenLargestLA->setObjectName(QStringLiteral("screenLargestLA"));

        gridLayout3->addWidget(screenLargestLA, 2, 2, 1, 1);

        screenHugeED = new QLineEdit(GroupBox3);
        screenHugeED->setObjectName(QStringLiteral("screenHugeED"));

        gridLayout3->addWidget(screenHugeED, 3, 3, 1, 1);

        screenHugeLA = new QLabel(GroupBox3);
        screenHugeLA->setObjectName(QStringLiteral("screenHugeLA"));

        gridLayout3->addWidget(screenHugeLA, 3, 2, 1, 1);

        screenHugestLA = new QLabel(GroupBox3);
        screenHugestLA->setObjectName(QStringLiteral("screenHugestLA"));

        gridLayout3->addWidget(screenHugestLA, 4, 2, 1, 1);

        screenSmallestLA = new QLabel(GroupBox3);
        screenSmallestLA->setObjectName(QStringLiteral("screenSmallestLA"));

        gridLayout3->addWidget(screenSmallestLA, 1, 0, 1, 1);

        screenSmallerLA = new QLabel(GroupBox3);
        screenSmallerLA->setObjectName(QStringLiteral("screenSmallerLA"));

        gridLayout3->addWidget(screenSmallerLA, 2, 0, 1, 1);

        screenSmallLA = new QLabel(GroupBox3);
        screenSmallLA->setObjectName(QStringLiteral("screenSmallLA"));

        gridLayout3->addWidget(screenSmallLA, 3, 0, 1, 1);

        screenNormalLA = new QLabel(GroupBox3);
        screenNormalLA->setObjectName(QStringLiteral("screenNormalLA"));

        gridLayout3->addWidget(screenNormalLA, 4, 0, 1, 1);

        screenTinyLA = new QLabel(GroupBox3);
        screenTinyLA->setObjectName(QStringLiteral("screenTinyLA"));

        gridLayout3->addWidget(screenTinyLA, 0, 0, 1, 1);


        gridLayout->addWidget(GroupBox3, 2, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 2, 1, 1, 1);

        spacerItem2 = new QSpacerItem(20, 6, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem2, 4, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        screenSansLA->setBuddy(screenSansCO);
        screenTypewriterLA->setBuddy(screenTypewriterCO);
        screenRomanLA->setBuddy(screenRomanCO);
        screenZoomLA->setBuddy(screenZoomSB);
        screenLargeLA->setBuddy(screenLargeED);
        screenLargerLA->setBuddy(screenLargerED);
        screenLargestLA->setBuddy(screenLargestED);
        screenHugeLA->setBuddy(screenHugeED);
        screenHugestLA->setBuddy(screenHugerED);
        screenSmallestLA->setBuddy(screenSmallestED);
        screenSmallerLA->setBuddy(screenSmallerED);
        screenSmallLA->setBuddy(screenSmallED);
        screenNormalLA->setBuddy(screenNormalED);
        screenTinyLA->setBuddy(screenTinyED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(screenRomanCO, screenSansCO);
        QWidget::setTabOrder(screenSansCO, screenTypewriterCO);
        QWidget::setTabOrder(screenTypewriterCO, screenZoomSB);
        QWidget::setTabOrder(screenZoomSB, screenTinyED);
        QWidget::setTabOrder(screenTinyED, screenSmallestED);
        QWidget::setTabOrder(screenSmallestED, screenSmallerED);
        QWidget::setTabOrder(screenSmallerED, screenSmallED);
        QWidget::setTabOrder(screenSmallED, screenNormalED);
        QWidget::setTabOrder(screenNormalED, screenLargeED);
        QWidget::setTabOrder(screenLargeED, screenLargerED);
        QWidget::setTabOrder(screenLargerED, screenLargestED);
        QWidget::setTabOrder(screenLargestED, screenHugeED);
        QWidget::setTabOrder(screenHugeED, screenHugerED);

        retranslateUi(PrefScreenFontsUi);

        QMetaObject::connectSlotsByName(PrefScreenFontsUi);
    } // setupUi

    void retranslateUi(QWidget *PrefScreenFontsUi)
    {
        PrefScreenFontsUi->setWindowTitle(QString());
        screenSansLA->setText(lyx::qt_("Sans Seri&f:", Q_NULLPTR));
        screenTypewriterLA->setText(lyx::qt_("T&ypewriter:", Q_NULLPTR));
        screenRomanLA->setText(lyx::qt_("R&oman:", Q_NULLPTR));
        screenZoomLA->setText(lyx::qt_("Default &zoom %:", Q_NULLPTR));
        GroupBox3->setTitle(lyx::qt_("Font Sizes", Q_NULLPTR));
        screenLargeLA->setText(lyx::qt_("&Large:", Q_NULLPTR));
        screenLargerLA->setText(lyx::qt_("&Larger:", Q_NULLPTR));
        screenLargestLA->setText(lyx::qt_("&Largest:", Q_NULLPTR));
        screenHugeLA->setText(lyx::qt_("&Huge:", Q_NULLPTR));
        screenHugestLA->setText(lyx::qt_("&Hugest:", Q_NULLPTR));
        screenSmallestLA->setText(lyx::qt_("S&mallest:", Q_NULLPTR));
        screenSmallerLA->setText(lyx::qt_("S&maller:", Q_NULLPTR));
        screenSmallLA->setText(lyx::qt_("S&mall:", Q_NULLPTR));
        screenNormalLA->setText(lyx::qt_("&Normal:", Q_NULLPTR));
        screenTinyLA->setText(lyx::qt_("&Tiny:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefScreenFontsUi: public Ui_PrefScreenFontsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFSCREENFONTSUI_H
