/********************************************************************************
** Form generated from reading UI file 'PrintNomenclUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRINTNOMENCLUI_H
#define UI_PRINTNOMENCLUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrintNomenclUi
{
public:
    QGridLayout *gridLayout;
    QLabel *setWidthLA;
    QComboBox *setWidthCO;
    QLabel *valueLA;
    QLineEdit *valueLE;
    lyx::frontend::LengthCombo *unitLC;

    void setupUi(QWidget *PrintNomenclUi)
    {
        if (PrintNomenclUi->objectName().isEmpty())
            PrintNomenclUi->setObjectName(QStringLiteral("PrintNomenclUi"));
        PrintNomenclUi->resize(336, 80);
        gridLayout = new QGridLayout(PrintNomenclUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        setWidthLA = new QLabel(PrintNomenclUi);
        setWidthLA->setObjectName(QStringLiteral("setWidthLA"));

        gridLayout->addWidget(setWidthLA, 0, 0, 1, 2);

        setWidthCO = new QComboBox(PrintNomenclUi);
        setWidthCO->setObjectName(QStringLiteral("setWidthCO"));

        gridLayout->addWidget(setWidthCO, 0, 2, 1, 2);

        valueLA = new QLabel(PrintNomenclUi);
        valueLA->setObjectName(QStringLiteral("valueLA"));

        gridLayout->addWidget(valueLA, 1, 0, 1, 2);

        valueLE = new QLineEdit(PrintNomenclUi);
        valueLE->setObjectName(QStringLiteral("valueLE"));
        valueLE->setEnabled(false);

        gridLayout->addWidget(valueLE, 1, 2, 1, 1);

        unitLC = new lyx::frontend::LengthCombo(PrintNomenclUi);
        unitLC->setObjectName(QStringLiteral("unitLC"));

        gridLayout->addWidget(unitLC, 1, 3, 1, 1);

#ifndef QT_NO_SHORTCUT
        setWidthLA->setBuddy(setWidthCO);
        valueLA->setBuddy(valueLE);
#endif // QT_NO_SHORTCUT

        retranslateUi(PrintNomenclUi);

        QMetaObject::connectSlotsByName(PrintNomenclUi);
    } // setupUi

    void retranslateUi(QWidget *PrintNomenclUi)
    {
        PrintNomenclUi->setWindowTitle(lyx::qt_("Nomenclature settings", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        setWidthLA->setToolTip(lyx::qt_("Define hanging indentation/label length for the nomenclature list.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        setWidthLA->setText(lyx::qt_("&List Indentation:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        setWidthCO->setToolTip(lyx::qt_("Define hanging indentation/label length for the nomenclature list.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valueLA->setText(lyx::qt_("Custom &Width:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        valueLE->setToolTip(lyx::qt_("Custom value. \"List Indentation\" needs to be set to \"Custom\".", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class PrintNomenclUi: public Ui_PrintNomenclUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PRINTNOMENCLUI_H
