/********************************************************************************
** Form generated from reading UI file 'ERTUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERTUI_H
#define UI_ERTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ERTUi
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ertBG;
    QVBoxLayout *vboxLayout1;
    QRadioButton *collapsedRB;
    QRadioButton *openRB;

    void setupUi(QWidget *ERTUi)
    {
        if (ERTUi->objectName().isEmpty())
            ERTUi->setObjectName(QStringLiteral("ERTUi"));
        ERTUi->resize(175, 135);
        ERTUi->setProperty("sizeGripEnabled", QVariant(true));
        vboxLayout = new QVBoxLayout(ERTUi);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        ertBG = new QGroupBox(ERTUi);
        ertBG->setObjectName(QStringLiteral("ertBG"));
        vboxLayout1 = new QVBoxLayout(ertBG);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(11, 11, 11, 11);
        collapsedRB = new QRadioButton(ertBG);
        collapsedRB->setObjectName(QStringLiteral("collapsedRB"));

        vboxLayout1->addWidget(collapsedRB);

        openRB = new QRadioButton(ertBG);
        openRB->setObjectName(QStringLiteral("openRB"));

        vboxLayout1->addWidget(openRB);


        vboxLayout->addWidget(ertBG);


        retranslateUi(ERTUi);

        QMetaObject::connectSlotsByName(ERTUi);
    } // setupUi

    void retranslateUi(QWidget *ERTUi)
    {
        ERTUi->setWindowTitle(QString());
        ertBG->setTitle(lyx::qt_("Display", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        collapsedRB->setToolTip(lyx::qt_("Show ERT button only", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        collapsedRB->setText(lyx::qt_("&Collapsed", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        openRB->setToolTip(lyx::qt_("Show ERT contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        openRB->setText(lyx::qt_("[[is]]O&pen", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ERTUi: public Ui_ERTUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ERTUI_H
