/********************************************************************************
** Form generated from reading UI file 'DelimiterUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DELIMITERUI_H
#define UI_DELIMITERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_DelimiterUi
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    QComboBox *sizeCO;
    QSpacerItem *spacerItem1;
    QLabel *texCodeL;
    QHBoxLayout *hboxLayout2;
    QListWidget *leftLW;
    QListWidget *rightLW;
    QHBoxLayout *horizontalLayout;
    QCheckBox *matchCB;
    QPushButton *swapPB;

    void setupUi(QDialog *DelimiterUi)
    {
        if (DelimiterUi->objectName().isEmpty())
            DelimiterUi->setObjectName(QStringLiteral("DelimiterUi"));
        DelimiterUi->resize(306, 352);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DelimiterUi->sizePolicy().hasHeightForWidth());
        DelimiterUi->setSizePolicy(sizePolicy);
        DelimiterUi->setMinimumSize(QSize(300, 330));
        DelimiterUi->setMaximumSize(QSize(16777215, 16777215));
        DelimiterUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(DelimiterUi);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        spacerItem = new QSpacerItem(50, 28, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(DelimiterUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout1->addLayout(hboxLayout, 5, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        label = new QLabel(DelimiterUi);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout1->addWidget(label);

        sizeCO = new QComboBox(DelimiterUi);
        sizeCO->setObjectName(QStringLiteral("sizeCO"));
        sizePolicy1.setHeightForWidth(sizeCO->sizePolicy().hasHeightForWidth());
        sizeCO->setSizePolicy(sizePolicy1);

        hboxLayout1->addWidget(sizeCO);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        gridLayout1->addLayout(hboxLayout1, 4, 0, 1, 1);

        texCodeL = new QLabel(DelimiterUi);
        texCodeL->setObjectName(QStringLiteral("texCodeL"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(texCodeL->sizePolicy().hasHeightForWidth());
        texCodeL->setSizePolicy(sizePolicy2);
        texCodeL->setTextFormat(Qt::AutoText);
        texCodeL->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        texCodeL->setWordWrap(false);

        gridLayout1->addWidget(texCodeL, 1, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        leftLW = new QListWidget(DelimiterUi);
        leftLW->setObjectName(QStringLiteral("leftLW"));
        sizePolicy.setHeightForWidth(leftLW->sizePolicy().hasHeightForWidth());
        leftLW->setSizePolicy(sizePolicy);
        leftLW->setMinimumSize(QSize(60, 0));
        leftLW->setMaximumSize(QSize(140, 16777215));
        leftLW->setIconSize(QSize(16, 16));
        leftLW->setResizeMode(QListView::Adjust);
        leftLW->setSpacing(2);

        hboxLayout2->addWidget(leftLW);

        rightLW = new QListWidget(DelimiterUi);
        rightLW->setObjectName(QStringLiteral("rightLW"));
        sizePolicy.setHeightForWidth(rightLW->sizePolicy().hasHeightForWidth());
        rightLW->setSizePolicy(sizePolicy);
        rightLW->setMinimumSize(QSize(60, 0));
        rightLW->setMaximumSize(QSize(139, 16777215));
        rightLW->setIconSize(QSize(16, 16));
        rightLW->setResizeMode(QListView::Adjust);
        rightLW->setSpacing(2);

        hboxLayout2->addWidget(rightLW);


        gridLayout1->addLayout(hboxLayout2, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        matchCB = new QCheckBox(DelimiterUi);
        matchCB->setObjectName(QStringLiteral("matchCB"));
        sizePolicy2.setHeightForWidth(matchCB->sizePolicy().hasHeightForWidth());
        matchCB->setSizePolicy(sizePolicy2);
        matchCB->setChecked(true);

        horizontalLayout->addWidget(matchCB);

        swapPB = new QPushButton(DelimiterUi);
        swapPB->setObjectName(QStringLiteral("swapPB"));
        sizePolicy2.setHeightForWidth(swapPB->sizePolicy().hasHeightForWidth());
        swapPB->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(swapPB);


        gridLayout1->addLayout(horizontalLayout, 2, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        label->setBuddy(sizeCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(leftLW, rightLW);
        QWidget::setTabOrder(rightLW, matchCB);
        QWidget::setTabOrder(matchCB, swapPB);
        QWidget::setTabOrder(swapPB, sizeCO);

        retranslateUi(DelimiterUi);

        leftLW->setCurrentRow(-1);


        QMetaObject::connectSlotsByName(DelimiterUi);
    } // setupUi

    void retranslateUi(QDialog *DelimiterUi)
    {
        DelimiterUi->setWindowTitle(QString());
        label->setText(lyx::qt_("Si&ze:", Q_NULLPTR));
        texCodeL->setText(lyx::qt_("TeX Code: ", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        matchCB->setToolTip(lyx::qt_("Match delimiter types", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        matchCB->setText(lyx::qt_("&Keep matched", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        swapPB->setToolTip(lyx::qt_("Swap left and right delimiter type (while reversing to the appropriate direction)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        swapPB->setText(lyx::qt_("S&wap && Reverse", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DelimiterUi: public Ui_DelimiterUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DELIMITERUI_H
