/****************************************************************************
** Meta object code from reading C++ file 'GuiSetBorder.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiSetBorder.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiSetBorder.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GuiSetBorder_t {
    QByteArrayData data[29];
    char stringdata0[377];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GuiSetBorder_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GuiSetBorder_t qt_meta_stringdata_GuiSetBorder = {
    {
QT_MOC_LITERAL(0, 0, 12), // "GuiSetBorder"
QT_MOC_LITERAL(1, 13, 8), // "rightSet"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 7), // "leftSet"
QT_MOC_LITERAL(4, 31, 6), // "topSet"
QT_MOC_LITERAL(5, 38, 9), // "bottomSet"
QT_MOC_LITERAL(6, 48, 8), // "topLTSet"
QT_MOC_LITERAL(7, 57, 11), // "bottomLTSet"
QT_MOC_LITERAL(8, 69, 8), // "topRTSet"
QT_MOC_LITERAL(9, 78, 11), // "bottomRTSet"
QT_MOC_LITERAL(10, 90, 7), // "clicked"
QT_MOC_LITERAL(11, 98, 14), // "setLeftEnabled"
QT_MOC_LITERAL(12, 113, 15), // "setRightEnabled"
QT_MOC_LITERAL(13, 129, 13), // "setTopEnabled"
QT_MOC_LITERAL(14, 143, 16), // "setBottomEnabled"
QT_MOC_LITERAL(15, 160, 21), // "setTopLeftTrimEnabled"
QT_MOC_LITERAL(16, 182, 22), // "setTopRightTrimEnabled"
QT_MOC_LITERAL(17, 205, 24), // "setBottomLeftTrimEnabled"
QT_MOC_LITERAL(18, 230, 25), // "setBottomRightTrimEnabled"
QT_MOC_LITERAL(19, 256, 7), // "setLeft"
QT_MOC_LITERAL(20, 264, 11), // "BorderState"
QT_MOC_LITERAL(21, 276, 8), // "setRight"
QT_MOC_LITERAL(22, 285, 6), // "setTop"
QT_MOC_LITERAL(23, 292, 9), // "setBottom"
QT_MOC_LITERAL(24, 302, 14), // "setTopLeftTrim"
QT_MOC_LITERAL(25, 317, 15), // "setTopRightTrim"
QT_MOC_LITERAL(26, 333, 17), // "setBottomLeftTrim"
QT_MOC_LITERAL(27, 351, 18), // "setBottomRightTrim"
QT_MOC_LITERAL(28, 370, 6) // "setAll"

    },
    "GuiSetBorder\0rightSet\0\0leftSet\0topSet\0"
    "bottomSet\0topLTSet\0bottomLTSet\0topRTSet\0"
    "bottomRTSet\0clicked\0setLeftEnabled\0"
    "setRightEnabled\0setTopEnabled\0"
    "setBottomEnabled\0setTopLeftTrimEnabled\0"
    "setTopRightTrimEnabled\0setBottomLeftTrimEnabled\0"
    "setBottomRightTrimEnabled\0setLeft\0"
    "BorderState\0setRight\0setTop\0setBottom\0"
    "setTopLeftTrim\0setTopRightTrim\0"
    "setBottomLeftTrim\0setBottomRightTrim\0"
    "setAll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GuiSetBorder[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  144,    2, 0x06 /* Public */,
       3,    0,  145,    2, 0x06 /* Public */,
       4,    0,  146,    2, 0x06 /* Public */,
       5,    0,  147,    2, 0x06 /* Public */,
       6,    0,  148,    2, 0x06 /* Public */,
       7,    0,  149,    2, 0x06 /* Public */,
       8,    0,  150,    2, 0x06 /* Public */,
       9,    0,  151,    2, 0x06 /* Public */,
      10,    0,  152,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,  153,    2, 0x0a /* Public */,
      12,    1,  156,    2, 0x0a /* Public */,
      13,    1,  159,    2, 0x0a /* Public */,
      14,    1,  162,    2, 0x0a /* Public */,
      15,    1,  165,    2, 0x0a /* Public */,
      16,    1,  168,    2, 0x0a /* Public */,
      17,    1,  171,    2, 0x0a /* Public */,
      18,    1,  174,    2, 0x0a /* Public */,
      19,    1,  177,    2, 0x0a /* Public */,
      21,    1,  180,    2, 0x0a /* Public */,
      22,    1,  183,    2, 0x0a /* Public */,
      23,    1,  186,    2, 0x0a /* Public */,
      24,    1,  189,    2, 0x0a /* Public */,
      25,    1,  192,    2, 0x0a /* Public */,
      26,    1,  195,    2, 0x0a /* Public */,
      27,    1,  198,    2, 0x0a /* Public */,
      28,    1,  201,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 20,    2,

       0        // eod
};

void GuiSetBorder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiSetBorder *_t = static_cast<GuiSetBorder *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->rightSet(); break;
        case 1: _t->leftSet(); break;
        case 2: _t->topSet(); break;
        case 3: _t->bottomSet(); break;
        case 4: _t->topLTSet(); break;
        case 5: _t->bottomLTSet(); break;
        case 6: _t->topRTSet(); break;
        case 7: _t->bottomRTSet(); break;
        case 8: _t->clicked(); break;
        case 9: _t->setLeftEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->setRightEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setTopEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setBottomEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setTopLeftTrimEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setTopRightTrimEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setBottomLeftTrimEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->setBottomRightTrimEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setLeft((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 18: _t->setRight((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 19: _t->setTop((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 20: _t->setBottom((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 21: _t->setTopLeftTrim((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 22: _t->setTopRightTrim((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 23: _t->setBottomLeftTrim((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 24: _t->setBottomRightTrim((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        case 25: _t->setAll((*reinterpret_cast< BorderState(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::rightSet)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::leftSet)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::topSet)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::bottomSet)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::topLTSet)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::bottomLTSet)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::topRTSet)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::bottomRTSet)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (GuiSetBorder::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSetBorder::clicked)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject GuiSetBorder::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_GuiSetBorder.data,
      qt_meta_data_GuiSetBorder,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GuiSetBorder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GuiSetBorder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GuiSetBorder.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int GuiSetBorder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void GuiSetBorder::rightSet()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GuiSetBorder::leftSet()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GuiSetBorder::topSet()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GuiSetBorder::bottomSet()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GuiSetBorder::topLTSet()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GuiSetBorder::bottomLTSet()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GuiSetBorder::topRTSet()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void GuiSetBorder::bottomRTSet()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GuiSetBorder::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
