/********************************************************************************
** Form generated from reading UI file 'PrefColorsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFCOLORSUI_H
#define UI_PREFCOLORSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefColorsUi
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *horizontalSpacer;
    QGridLayout *gridLayout;
    QListWidget *lyxObjectsLW;
    QPushButton *colorChangePB;
    QPushButton *colorResetPB;
    QPushButton *colorResetAllPB;
    QSpacerItem *spacerItem;
    QCheckBox *syscolorsCB;

    void setupUi(QWidget *PrefColorsUi)
    {
        if (PrefColorsUi->objectName().isEmpty())
            PrefColorsUi->setObjectName(QStringLiteral("PrefColorsUi"));
        PrefColorsUi->resize(397, 254);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefColorsUi->sizePolicy().hasHeightForWidth());
        PrefColorsUi->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(PrefColorsUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 1, 1, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        lyxObjectsLW = new QListWidget(PrefColorsUi);
        lyxObjectsLW->setObjectName(QStringLiteral("lyxObjectsLW"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lyxObjectsLW->sizePolicy().hasHeightForWidth());
        lyxObjectsLW->setSizePolicy(sizePolicy1);
        lyxObjectsLW->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);

        gridLayout->addWidget(lyxObjectsLW, 0, 0, 5, 1);

        colorChangePB = new QPushButton(PrefColorsUi);
        colorChangePB->setObjectName(QStringLiteral("colorChangePB"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(colorChangePB->sizePolicy().hasHeightForWidth());
        colorChangePB->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(colorChangePB, 0, 1, 1, 1);

        colorResetPB = new QPushButton(PrefColorsUi);
        colorResetPB->setObjectName(QStringLiteral("colorResetPB"));

        gridLayout->addWidget(colorResetPB, 1, 1, 1, 1);

        colorResetAllPB = new QPushButton(PrefColorsUi);
        colorResetAllPB->setObjectName(QStringLiteral("colorResetAllPB"));

        gridLayout->addWidget(colorResetAllPB, 4, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 2);

        syscolorsCB = new QCheckBox(PrefColorsUi);
        syscolorsCB->setObjectName(QStringLiteral("syscolorsCB"));

        gridLayout_2->addWidget(syscolorsCB, 1, 0, 1, 1);


        retranslateUi(PrefColorsUi);

        QMetaObject::connectSlotsByName(PrefColorsUi);
    } // setupUi

    void retranslateUi(QWidget *PrefColorsUi)
    {
        PrefColorsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        colorChangePB->setToolTip(lyx::qt_("Change the selected color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorChangePB->setText(lyx::qt_("A&lter...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorResetPB->setToolTip(lyx::qt_("Reset the selected color to its original value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorResetPB->setText(lyx::qt_("Restore &Default", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorResetAllPB->setToolTip(lyx::qt_("Reset all colors to their original value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorResetAllPB->setText(lyx::qt_("Restore A&ll", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        syscolorsCB->setToolTip(lyx::qt_("Use the color scheme of your Operating System/Desktop Environment", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        syscolorsCB->setText(lyx::qt_("&Use system colors", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefColorsUi: public Ui_PrefColorsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFCOLORSUI_H
