/****************************************************************************
** Meta object code from reading C++ file 'GuiSelectionManager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiSelectionManager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiSelectionManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiSelectionManager_t {
    QByteArrayData data[19];
    char stringdata0[261];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiSelectionManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiSelectionManager_t qt_meta_stringdata_lyx__frontend__GuiSelectionManager = {
    {
QT_MOC_LITERAL(0, 0, 34), // "lyx::frontend::GuiSelectionMa..."
QT_MOC_LITERAL(1, 35, 16), // "selectionChanged"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 10), // "updateHook"
QT_MOC_LITERAL(4, 64, 6), // "okHook"
QT_MOC_LITERAL(5, 71, 16), // "availableChanged"
QT_MOC_LITERAL(6, 88, 3), // "idx"
QT_MOC_LITERAL(7, 92, 15), // "selectedChanged"
QT_MOC_LITERAL(8, 108, 14), // "QItemSelection"
QT_MOC_LITERAL(9, 123, 3), // "qis"
QT_MOC_LITERAL(10, 127, 14), // "selectedEdited"
QT_MOC_LITERAL(11, 142, 13), // "addPB_clicked"
QT_MOC_LITERAL(12, 156, 16), // "deletePB_clicked"
QT_MOC_LITERAL(13, 173, 12), // "upPB_clicked"
QT_MOC_LITERAL(14, 186, 14), // "downPB_clicked"
QT_MOC_LITERAL(15, 201, 25), // "availableLV_doubleClicked"
QT_MOC_LITERAL(16, 227, 11), // "eventFilter"
QT_MOC_LITERAL(17, 239, 7), // "QEvent*"
QT_MOC_LITERAL(18, 247, 13) // "updateButtons"

    },
    "lyx::frontend::GuiSelectionManager\0"
    "selectionChanged\0\0updateHook\0okHook\0"
    "availableChanged\0idx\0selectedChanged\0"
    "QItemSelection\0qis\0selectedEdited\0"
    "addPB_clicked\0deletePB_clicked\0"
    "upPB_clicked\0downPB_clicked\0"
    "availableLV_doubleClicked\0eventFilter\0"
    "QEvent*\0updateButtons"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiSelectionManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x06 /* Public */,
       3,    0,   90,    2, 0x06 /* Public */,
       4,    0,   91,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    2,   92,    2, 0x09 /* Protected */,
       7,    2,   97,    2, 0x09 /* Protected */,
       5,    2,  102,    2, 0x09 /* Protected */,
       7,    2,  107,    2, 0x09 /* Protected */,
      10,    0,  112,    2, 0x09 /* Protected */,
      11,    0,  113,    2, 0x09 /* Protected */,
      12,    0,  114,    2, 0x09 /* Protected */,
      13,    0,  115,    2, 0x09 /* Protected */,
      14,    0,  116,    2, 0x09 /* Protected */,
      15,    1,  117,    2, 0x09 /* Protected */,
      16,    2,  120,    2, 0x09 /* Protected */,
      18,    0,  125,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    6,    2,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    6,    2,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 8,    9,    2,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 8,    9,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 17,    2,    2,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiSelectionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiSelectionManager *_t = static_cast<GuiSelectionManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        case 1: _t->updateHook(); break;
        case 2: _t->okHook(); break;
        case 3: _t->availableChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 4: _t->selectedChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 5: _t->availableChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 6: _t->selectedChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 7: _t->selectedEdited(); break;
        case 8: _t->addPB_clicked(); break;
        case 9: _t->deletePB_clicked(); break;
        case 10: _t->upPB_clicked(); break;
        case 11: _t->downPB_clicked(); break;
        case 12: _t->availableLV_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 13: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->updateButtons(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiSelectionManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSelectionManager::selectionChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiSelectionManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSelectionManager::updateHook)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GuiSelectionManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSelectionManager::okHook)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiSelectionManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiSelectionManager.data,
      qt_meta_data_lyx__frontend__GuiSelectionManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiSelectionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiSelectionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiSelectionManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int lyx::frontend::GuiSelectionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiSelectionManager::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void lyx::frontend::GuiSelectionManager::updateHook()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void lyx::frontend::GuiSelectionManager::okHook()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
