/********************************************************************************
** Form generated from reading UI file 'BoxUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOXUI_H
#define UI_BOXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BoxUi
{
public:
    QGridLayout *gridLayout_5;
    QGroupBox *TypesizeGB;
    QGridLayout *gridLayout_3;
    QLineEdit *widthED;
    lyx::frontend::LengthCombo *widthUnitsLC;
    QCheckBox *heightCB;
    QCheckBox *widthCB;
    QLabel *innerBoxLA;
    QComboBox *innerBoxCO;
    QCheckBox *pagebreakCB;
    lyx::frontend::LengthCombo *heightUnitsLC;
    QLineEdit *heightED;
    QGroupBox *AlignmentGB;
    QGridLayout *gridLayout_2;
    QLabel *halignLA;
    QLabel *ialignLA;
    QLabel *label;
    QLabel *valignLA;
    QComboBox *ialignCO;
    QComboBox *valignCO;
    QComboBox *halignCO;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *DecorationGB;
    QGridLayout *gridLayout;
    QComboBox *typeCO;
    QLineEdit *thicknessED;
    QLabel *thicknessLA;
    QLineEdit *separationED;
    QLabel *separationLA;
    QLabel *typeLA;
    QLabel *shadowsizeLA;
    lyx::frontend::LengthCombo *thicknessUnitsLC;
    lyx::frontend::LengthCombo *separationUnitsLC;
    lyx::frontend::LengthCombo *shadowsizeUnitsLC;
    QLineEdit *shadowsizeED;
    QGroupBox *colorGB;
    QGridLayout *gridLayout_4;
    QSpacerItem *verticalSpacer;
    QLabel *backgroundColorLA;
    QLabel *frameColorLA;
    QComboBox *backgroundColorCO;
    QComboBox *frameColorCO;

    void setupUi(QWidget *BoxUi)
    {
        if (BoxUi->objectName().isEmpty())
            BoxUi->setObjectName(QStringLiteral("BoxUi"));
        BoxUi->resize(531, 381);
        BoxUi->setProperty("sizeGripEnabled", QVariant(true));
        gridLayout_5 = new QGridLayout(BoxUi);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        TypesizeGB = new QGroupBox(BoxUi);
        TypesizeGB->setObjectName(QStringLiteral("TypesizeGB"));
        TypesizeGB->setFlat(true);
        gridLayout_3 = new QGridLayout(TypesizeGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        widthED = new QLineEdit(TypesizeGB);
        widthED->setObjectName(QStringLiteral("widthED"));

        gridLayout_3->addWidget(widthED, 1, 1, 1, 1);

        widthUnitsLC = new lyx::frontend::LengthCombo(TypesizeGB);
        widthUnitsLC->setObjectName(QStringLiteral("widthUnitsLC"));

        gridLayout_3->addWidget(widthUnitsLC, 1, 2, 1, 1);

        heightCB = new QCheckBox(TypesizeGB);
        heightCB->setObjectName(QStringLiteral("heightCB"));
        heightCB->setChecked(false);
        heightCB->setTristate(false);

        gridLayout_3->addWidget(heightCB, 2, 0, 1, 1);

        widthCB = new QCheckBox(TypesizeGB);
        widthCB->setObjectName(QStringLiteral("widthCB"));
        widthCB->setChecked(false);
        widthCB->setTristate(false);

        gridLayout_3->addWidget(widthCB, 1, 0, 1, 1);

        innerBoxLA = new QLabel(TypesizeGB);
        innerBoxLA->setObjectName(QStringLiteral("innerBoxLA"));

        gridLayout_3->addWidget(innerBoxLA, 0, 0, 1, 1);

        innerBoxCO = new QComboBox(TypesizeGB);
        innerBoxCO->setObjectName(QStringLiteral("innerBoxCO"));

        gridLayout_3->addWidget(innerBoxCO, 0, 1, 1, 2);

        pagebreakCB = new QCheckBox(TypesizeGB);
        pagebreakCB->setObjectName(QStringLiteral("pagebreakCB"));

        gridLayout_3->addWidget(pagebreakCB, 3, 0, 1, 2);

        heightUnitsLC = new lyx::frontend::LengthCombo(TypesizeGB);
        heightUnitsLC->setObjectName(QStringLiteral("heightUnitsLC"));
        heightUnitsLC->setEnabled(false);

        gridLayout_3->addWidget(heightUnitsLC, 2, 2, 1, 1);

        heightED = new QLineEdit(TypesizeGB);
        heightED->setObjectName(QStringLiteral("heightED"));
        heightED->setEnabled(false);

        gridLayout_3->addWidget(heightED, 2, 1, 1, 1);


        gridLayout_5->addWidget(TypesizeGB, 0, 0, 1, 1);

        AlignmentGB = new QGroupBox(BoxUi);
        AlignmentGB->setObjectName(QStringLiteral("AlignmentGB"));
        AlignmentGB->setFlat(true);
        gridLayout_2 = new QGridLayout(AlignmentGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        halignLA = new QLabel(AlignmentGB);
        halignLA->setObjectName(QStringLiteral("halignLA"));

        gridLayout_2->addWidget(halignLA, 0, 2, 1, 1);

        ialignLA = new QLabel(AlignmentGB);
        ialignLA->setObjectName(QStringLiteral("ialignLA"));

        gridLayout_2->addWidget(ialignLA, 0, 1, 1, 1);

        label = new QLabel(AlignmentGB);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 1, 0, 1, 1);

        valignLA = new QLabel(AlignmentGB);
        valignLA->setObjectName(QStringLiteral("valignLA"));

        gridLayout_2->addWidget(valignLA, 2, 0, 1, 1);

        ialignCO = new QComboBox(AlignmentGB);
        ialignCO->setObjectName(QStringLiteral("ialignCO"));
        ialignCO->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ialignCO->sizePolicy().hasHeightForWidth());
        ialignCO->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(ialignCO, 1, 1, 1, 1);

        valignCO = new QComboBox(AlignmentGB);
        valignCO->setObjectName(QStringLiteral("valignCO"));
        valignCO->setEnabled(true);

        gridLayout_2->addWidget(valignCO, 2, 1, 1, 1);

        halignCO = new QComboBox(AlignmentGB);
        halignCO->setObjectName(QStringLiteral("halignCO"));
        halignCO->setEnabled(true);
        sizePolicy.setHeightForWidth(halignCO->sizePolicy().hasHeightForWidth());
        halignCO->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(halignCO, 1, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 3, 1, 1, 1);


        gridLayout_5->addWidget(AlignmentGB, 0, 1, 1, 1);

        DecorationGB = new QGroupBox(BoxUi);
        DecorationGB->setObjectName(QStringLiteral("DecorationGB"));
        DecorationGB->setFlat(true);
        gridLayout = new QGridLayout(DecorationGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        typeCO = new QComboBox(DecorationGB);
        typeCO->setObjectName(QStringLiteral("typeCO"));

        gridLayout->addWidget(typeCO, 0, 1, 1, 2);

        thicknessED = new QLineEdit(DecorationGB);
        thicknessED->setObjectName(QStringLiteral("thicknessED"));
        thicknessED->setEnabled(false);

        gridLayout->addWidget(thicknessED, 1, 1, 1, 1);

        thicknessLA = new QLabel(DecorationGB);
        thicknessLA->setObjectName(QStringLiteral("thicknessLA"));

        gridLayout->addWidget(thicknessLA, 1, 0, 1, 1);

        separationED = new QLineEdit(DecorationGB);
        separationED->setObjectName(QStringLiteral("separationED"));
        separationED->setEnabled(false);

        gridLayout->addWidget(separationED, 2, 1, 1, 1);

        separationLA = new QLabel(DecorationGB);
        separationLA->setObjectName(QStringLiteral("separationLA"));

        gridLayout->addWidget(separationLA, 2, 0, 1, 1);

        typeLA = new QLabel(DecorationGB);
        typeLA->setObjectName(QStringLiteral("typeLA"));

        gridLayout->addWidget(typeLA, 0, 0, 1, 1);

        shadowsizeLA = new QLabel(DecorationGB);
        shadowsizeLA->setObjectName(QStringLiteral("shadowsizeLA"));

        gridLayout->addWidget(shadowsizeLA, 3, 0, 1, 1);

        thicknessUnitsLC = new lyx::frontend::LengthCombo(DecorationGB);
        thicknessUnitsLC->setObjectName(QStringLiteral("thicknessUnitsLC"));
        thicknessUnitsLC->setEnabled(false);

        gridLayout->addWidget(thicknessUnitsLC, 1, 2, 1, 1);

        separationUnitsLC = new lyx::frontend::LengthCombo(DecorationGB);
        separationUnitsLC->setObjectName(QStringLiteral("separationUnitsLC"));
        separationUnitsLC->setEnabled(false);

        gridLayout->addWidget(separationUnitsLC, 2, 2, 1, 1);

        shadowsizeUnitsLC = new lyx::frontend::LengthCombo(DecorationGB);
        shadowsizeUnitsLC->setObjectName(QStringLiteral("shadowsizeUnitsLC"));
        shadowsizeUnitsLC->setEnabled(false);

        gridLayout->addWidget(shadowsizeUnitsLC, 3, 2, 1, 1);

        shadowsizeED = new QLineEdit(DecorationGB);
        shadowsizeED->setObjectName(QStringLiteral("shadowsizeED"));
        shadowsizeED->setEnabled(false);

        gridLayout->addWidget(shadowsizeED, 3, 1, 1, 1);


        gridLayout_5->addWidget(DecorationGB, 1, 0, 1, 1);

        colorGB = new QGroupBox(BoxUi);
        colorGB->setObjectName(QStringLiteral("colorGB"));
        colorGB->setFlat(true);
        gridLayout_4 = new QGridLayout(colorGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 2, 2, 1, 1);

        backgroundColorLA = new QLabel(colorGB);
        backgroundColorLA->setObjectName(QStringLiteral("backgroundColorLA"));

        gridLayout_4->addWidget(backgroundColorLA, 1, 0, 1, 1);

        frameColorLA = new QLabel(colorGB);
        frameColorLA->setObjectName(QStringLiteral("frameColorLA"));

        gridLayout_4->addWidget(frameColorLA, 0, 0, 1, 1);

        backgroundColorCO = new QComboBox(colorGB);
        backgroundColorCO->setObjectName(QStringLiteral("backgroundColorCO"));

        gridLayout_4->addWidget(backgroundColorCO, 1, 1, 1, 2);

        frameColorCO = new QComboBox(colorGB);
        frameColorCO->setObjectName(QStringLiteral("frameColorCO"));

        gridLayout_4->addWidget(frameColorCO, 0, 1, 1, 2);


        gridLayout_5->addWidget(colorGB, 1, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        innerBoxLA->setBuddy(innerBoxCO);
        label->setBuddy(ialignCO);
        valignLA->setBuddy(valignCO);
        thicknessLA->setBuddy(thicknessED);
        separationLA->setBuddy(separationED);
        typeLA->setBuddy(typeCO);
        shadowsizeLA->setBuddy(shadowsizeED);
        backgroundColorLA->setBuddy(backgroundColorCO);
        frameColorLA->setBuddy(frameColorCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(innerBoxCO, widthCB);
        QWidget::setTabOrder(widthCB, widthED);
        QWidget::setTabOrder(widthED, widthUnitsLC);
        QWidget::setTabOrder(widthUnitsLC, heightCB);
        QWidget::setTabOrder(heightCB, heightED);
        QWidget::setTabOrder(heightED, heightUnitsLC);
        QWidget::setTabOrder(heightUnitsLC, pagebreakCB);
        QWidget::setTabOrder(pagebreakCB, ialignCO);
        QWidget::setTabOrder(ialignCO, halignCO);
        QWidget::setTabOrder(halignCO, valignCO);
        QWidget::setTabOrder(valignCO, typeCO);
        QWidget::setTabOrder(typeCO, thicknessED);
        QWidget::setTabOrder(thicknessED, thicknessUnitsLC);
        QWidget::setTabOrder(thicknessUnitsLC, separationED);
        QWidget::setTabOrder(separationED, separationUnitsLC);
        QWidget::setTabOrder(separationUnitsLC, shadowsizeED);
        QWidget::setTabOrder(shadowsizeED, shadowsizeUnitsLC);

        retranslateUi(BoxUi);
        QObject::connect(heightCB, SIGNAL(toggled(bool)), heightED, SLOT(setEnabled(bool)));
        QObject::connect(heightCB, SIGNAL(toggled(bool)), heightUnitsLC, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(BoxUi);
    } // setupUi

    void retranslateUi(QWidget *BoxUi)
    {
        BoxUi->setWindowTitle(QString());
        TypesizeGB->setTitle(lyx::qt_("Type and Size", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widthED->setToolTip(lyx::qt_("Width value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        heightCB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        heightCB->setText(lyx::qt_("&Height:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widthCB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        widthCB->setText(lyx::qt_("&Width:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        innerBoxLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        innerBoxLA->setText(lyx::qt_("Inner Bo&x:", Q_NULLPTR));
        innerBoxCO->clear();
        innerBoxCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("Parbox", Q_NULLPTR)
         << lyx::qt_("Minipage", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        innerBoxCO->setToolTip(lyx::qt_("Inner box type", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        pagebreakCB->setToolTip(lyx::qt_("Check this if the box should break across pages", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pagebreakCB->setText(lyx::qt_("Allow &page breaks", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        heightED->setToolTip(lyx::qt_("Height value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        AlignmentGB->setTitle(lyx::qt_("Alignment", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        halignLA->setToolTip(lyx::qt_("Horizontal alignment of the content inside the box", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        halignLA->setText(lyx::qt_("Horizontal", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ialignLA->setToolTip(lyx::qt_("Vertical alignment of the content inside the box", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ialignLA->setText(lyx::qt_("Vertical", Q_NULLPTR));
        label->setText(lyx::qt_("Co&ntent:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        valignLA->setToolTip(lyx::qt_("Vertical alignment of the box (with regard to baseline)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valignLA->setText(lyx::qt_("&Box:", Q_NULLPTR));
        ialignCO->clear();
        ialignCO->insertItems(0, QStringList()
         << lyx::qt_("Top", Q_NULLPTR)
         << lyx::qt_("Middle", Q_NULLPTR)
         << lyx::qt_("Bottom", Q_NULLPTR)
         << lyx::qt_("Stretch", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        ialignCO->setToolTip(lyx::qt_("Vertical alignment of the content inside the box", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valignCO->clear();
        valignCO->insertItems(0, QStringList()
         << lyx::qt_("Top", Q_NULLPTR)
         << lyx::qt_("Middle", Q_NULLPTR)
         << lyx::qt_("Bottom", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        valignCO->setToolTip(lyx::qt_("Vertical alignment of the box (with regard to baseline)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        halignCO->clear();
        halignCO->insertItems(0, QStringList()
         << lyx::qt_("Left", Q_NULLPTR)
         << lyx::qt_("Center", Q_NULLPTR)
         << lyx::qt_("Right", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        halignCO->setToolTip(lyx::qt_("Horizontal alignment of the content inside the box", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        DecorationGB->setTitle(lyx::qt_("Decoration", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        typeCO->setToolTip(lyx::qt_("Decoration box types", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        thicknessED->setToolTip(lyx::qt_("Thickness value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        thicknessLA->setText(lyx::qt_("&Line thickness:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        separationED->setToolTip(lyx::qt_("Separation value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        separationLA->setText(lyx::qt_("Box s&eparation:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        typeLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        typeLA->setText(lyx::qt_("&Decoration:", Q_NULLPTR));
        shadowsizeLA->setText(lyx::qt_("&Shadow size:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        shadowsizeED->setToolTip(lyx::qt_("Size value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorGB->setTitle(lyx::qt_("Color", Q_NULLPTR));
        backgroundColorLA->setText(lyx::qt_("Back&ground:", Q_NULLPTR));
        frameColorLA->setText(lyx::qt_("&Frame:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BoxUi: public Ui_BoxUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOXUI_H
