/********************************************************************************
** Form generated from reading UI file 'CompareHistoryUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPAREHISTORYUI_H
#define UI_COMPAREHISTORYUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_CompareHistoryUi
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *revbackRB;
    QSpinBox *revbackSB;
    QSpacerItem *horizontalSpacer;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QRadioButton *betweenrevRB;
    QLabel *oldL;
    QSpinBox *rev1SB;
    QLabel *newL;
    QSpinBox *rev2SB;
    QHBoxLayout *horizontalLayout_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *CompareHistoryUi)
    {
        if (CompareHistoryUi->objectName().isEmpty())
            CompareHistoryUi->setObjectName(QStringLiteral("CompareHistoryUi"));
        CompareHistoryUi->resize(444, 184);
        CompareHistoryUi->setProperty("sizeGripEnabled", QVariant(true));
        verticalLayout = new QVBoxLayout(CompareHistoryUi);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox = new QGroupBox(CompareHistoryUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        revbackRB = new QRadioButton(groupBox);
        revbackRB->setObjectName(QStringLiteral("revbackRB"));
        revbackRB->setChecked(true);

        horizontalLayout_2->addWidget(revbackRB);

        revbackSB = new QSpinBox(groupBox);
        revbackSB->setObjectName(QStringLiteral("revbackSB"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(revbackSB->sizePolicy().hasHeightForWidth());
        revbackSB->setSizePolicy(sizePolicy);
        revbackSB->setMinimumSize(QSize(80, 0));
        revbackSB->setMinimum(0);

        horizontalLayout_2->addWidget(revbackSB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout_2);

        line = new QFrame(groupBox);
        line->setObjectName(QStringLiteral("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout_2->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        betweenrevRB = new QRadioButton(groupBox);
        betweenrevRB->setObjectName(QStringLiteral("betweenrevRB"));

        horizontalLayout->addWidget(betweenrevRB);

        oldL = new QLabel(groupBox);
        oldL->setObjectName(QStringLiteral("oldL"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(oldL->sizePolicy().hasHeightForWidth());
        oldL->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(oldL);

        rev1SB = new QSpinBox(groupBox);
        rev1SB->setObjectName(QStringLiteral("rev1SB"));
        sizePolicy.setHeightForWidth(rev1SB->sizePolicy().hasHeightForWidth());
        rev1SB->setSizePolicy(sizePolicy);
        rev1SB->setMinimumSize(QSize(80, 0));
        rev1SB->setMinimum(1);
        rev1SB->setMaximum(1);

        horizontalLayout->addWidget(rev1SB);

        newL = new QLabel(groupBox);
        newL->setObjectName(QStringLiteral("newL"));
        sizePolicy1.setHeightForWidth(newL->sizePolicy().hasHeightForWidth());
        newL->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(newL);

        rev2SB = new QSpinBox(groupBox);
        rev2SB->setObjectName(QStringLiteral("rev2SB"));
        sizePolicy.setHeightForWidth(rev2SB->sizePolicy().hasHeightForWidth());
        rev2SB->setSizePolicy(sizePolicy);
        rev2SB->setMinimumSize(QSize(80, 0));
        rev2SB->setMinimum(1);

        horizontalLayout->addWidget(rev2SB);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout->addWidget(groupBox);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        buttonBox = new QDialogButtonBox(CompareHistoryUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_3->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_3);


        retranslateUi(CompareHistoryUi);

        QMetaObject::connectSlotsByName(CompareHistoryUi);
    } // setupUi

    void retranslateUi(QWidget *CompareHistoryUi)
    {
        CompareHistoryUi->setWindowTitle(QString());
        groupBox->setTitle(lyx::qt_("Compare Revisions", Q_NULLPTR));
        revbackRB->setText(lyx::qt_("Revisions ba&ck", Q_NULLPTR));
        betweenrevRB->setText(lyx::qt_("&Between revisions", Q_NULLPTR));
        oldL->setText(lyx::qt_("Old:", Q_NULLPTR));
        newL->setText(lyx::qt_("New:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class CompareHistoryUi: public Ui_CompareHistoryUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMPAREHISTORYUI_H
