/********************************************************************************
** Form generated from reading UI file 'PrefFileformatsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFFILEFORMATSUI_H
#define UI_PREFFILEFORMATSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefFileformatsUi
{
public:
    QGridLayout *gridLayout_2;
    QLabel *formatsLA;
    QComboBox *formatsCB;
    QPushButton *formatNewPB;
    QPushButton *formatRemovePB;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *documentCB;
    QCheckBox *exportMenuCB;
    QCheckBox *vectorCB;
    QLabel *formatLA;
    QLineEdit *formatED;
    QLabel *extensionsLA;
    QLineEdit *extensionsED;
    QLabel *mimeLA;
    QLineEdit *mimeED;
    QLabel *shortcutLA;
    QLineEdit *shortcutED;
    QLabel *editorLA;
    QComboBox *editorCO;
    QLineEdit *editorED;
    QLabel *viewerLA;
    QComboBox *viewerCO;
    QLineEdit *viewerED;
    QLabel *label;
    QLineEdit *copierED;
    QGroupBox *defaultFormatGB;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_3;
    QComboBox *defaultOTFFormatCB;
    QSpacerItem *horizontalSpacer_4;
    QComboBox *defaultFormatCB;
    QComboBox *defaultPlatexFormatCB;
    QLabel *defaultOTFFormatLA;
    QLabel *defaultFormatLA;
    QLabel *defaultPLatexFormatLA;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *PrefFileformatsUi)
    {
        if (PrefFileformatsUi->objectName().isEmpty())
            PrefFileformatsUi->setObjectName(QStringLiteral("PrefFileformatsUi"));
        PrefFileformatsUi->resize(496, 584);
        gridLayout_2 = new QGridLayout(PrefFileformatsUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        formatsLA = new QLabel(PrefFileformatsUi);
        formatsLA->setObjectName(QStringLiteral("formatsLA"));

        gridLayout_2->addWidget(formatsLA, 0, 0, 1, 1);

        formatsCB = new QComboBox(PrefFileformatsUi);
        formatsCB->setObjectName(QStringLiteral("formatsCB"));
        formatsCB->setEditable(true);
        formatsCB->setMaxVisibleItems(20);
        formatsCB->setInsertPolicy(QComboBox::InsertAtCurrent);
        formatsCB->setMinimumContentsLength(1);

        gridLayout_2->addWidget(formatsCB, 0, 1, 1, 1);

        formatNewPB = new QPushButton(PrefFileformatsUi);
        formatNewPB->setObjectName(QStringLiteral("formatNewPB"));

        gridLayout_2->addWidget(formatNewPB, 0, 3, 1, 1);

        formatRemovePB = new QPushButton(PrefFileformatsUi);
        formatRemovePB->setObjectName(QStringLiteral("formatRemovePB"));

        gridLayout_2->addWidget(formatRemovePB, 0, 4, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 5, 1, 1);

        documentCB = new QCheckBox(PrefFileformatsUi);
        documentCB->setObjectName(QStringLiteral("documentCB"));

        gridLayout_2->addWidget(documentCB, 1, 1, 1, 2);

        exportMenuCB = new QCheckBox(PrefFileformatsUi);
        exportMenuCB->setObjectName(QStringLiteral("exportMenuCB"));

        gridLayout_2->addWidget(exportMenuCB, 2, 1, 1, 2);

        vectorCB = new QCheckBox(PrefFileformatsUi);
        vectorCB->setObjectName(QStringLiteral("vectorCB"));

        gridLayout_2->addWidget(vectorCB, 3, 1, 1, 2);

        formatLA = new QLabel(PrefFileformatsUi);
        formatLA->setObjectName(QStringLiteral("formatLA"));

        gridLayout_2->addWidget(formatLA, 4, 0, 1, 1);

        formatED = new QLineEdit(PrefFileformatsUi);
        formatED->setObjectName(QStringLiteral("formatED"));

        gridLayout_2->addWidget(formatED, 4, 1, 1, 2);

        extensionsLA = new QLabel(PrefFileformatsUi);
        extensionsLA->setObjectName(QStringLiteral("extensionsLA"));

        gridLayout_2->addWidget(extensionsLA, 5, 0, 1, 1);

        extensionsED = new QLineEdit(PrefFileformatsUi);
        extensionsED->setObjectName(QStringLiteral("extensionsED"));

        gridLayout_2->addWidget(extensionsED, 5, 1, 1, 2);

        mimeLA = new QLabel(PrefFileformatsUi);
        mimeLA->setObjectName(QStringLiteral("mimeLA"));

        gridLayout_2->addWidget(mimeLA, 6, 0, 1, 1);

        mimeED = new QLineEdit(PrefFileformatsUi);
        mimeED->setObjectName(QStringLiteral("mimeED"));

        gridLayout_2->addWidget(mimeED, 6, 1, 1, 2);

        shortcutLA = new QLabel(PrefFileformatsUi);
        shortcutLA->setObjectName(QStringLiteral("shortcutLA"));

        gridLayout_2->addWidget(shortcutLA, 7, 0, 1, 1);

        shortcutED = new QLineEdit(PrefFileformatsUi);
        shortcutED->setObjectName(QStringLiteral("shortcutED"));

        gridLayout_2->addWidget(shortcutED, 7, 1, 1, 2);

        editorLA = new QLabel(PrefFileformatsUi);
        editorLA->setObjectName(QStringLiteral("editorLA"));

        gridLayout_2->addWidget(editorLA, 8, 0, 1, 1);

        editorCO = new QComboBox(PrefFileformatsUi);
        editorCO->setObjectName(QStringLiteral("editorCO"));
        editorCO->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        gridLayout_2->addWidget(editorCO, 8, 1, 1, 1);

        editorED = new QLineEdit(PrefFileformatsUi);
        editorED->setObjectName(QStringLiteral("editorED"));

        gridLayout_2->addWidget(editorED, 8, 2, 1, 2);

        viewerLA = new QLabel(PrefFileformatsUi);
        viewerLA->setObjectName(QStringLiteral("viewerLA"));

        gridLayout_2->addWidget(viewerLA, 9, 0, 1, 1);

        viewerCO = new QComboBox(PrefFileformatsUi);
        viewerCO->setObjectName(QStringLiteral("viewerCO"));
        viewerCO->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        gridLayout_2->addWidget(viewerCO, 9, 1, 1, 1);

        viewerED = new QLineEdit(PrefFileformatsUi);
        viewerED->setObjectName(QStringLiteral("viewerED"));

        gridLayout_2->addWidget(viewerED, 9, 2, 1, 2);

        label = new QLabel(PrefFileformatsUi);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 10, 0, 1, 1);

        copierED = new QLineEdit(PrefFileformatsUi);
        copierED->setObjectName(QStringLiteral("copierED"));

        gridLayout_2->addWidget(copierED, 10, 1, 1, 2);

        defaultFormatGB = new QGroupBox(PrefFileformatsUi);
        defaultFormatGB->setObjectName(QStringLiteral("defaultFormatGB"));
        defaultFormatGB->setFlat(true);
        gridLayout = new QGridLayout(defaultFormatGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalSpacer = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 2, 3, 1, 1);

        defaultOTFFormatCB = new QComboBox(defaultFormatGB);
        defaultOTFFormatCB->setObjectName(QStringLiteral("defaultOTFFormatCB"));

        gridLayout->addWidget(defaultOTFFormatCB, 2, 1, 1, 2);

        horizontalSpacer_4 = new QSpacerItem(148, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 6, 1, 1);

        defaultFormatCB = new QComboBox(defaultFormatGB);
        defaultFormatCB->setObjectName(QStringLiteral("defaultFormatCB"));

        gridLayout->addWidget(defaultFormatCB, 0, 1, 1, 2);

        defaultPlatexFormatCB = new QComboBox(defaultFormatGB);
        defaultPlatexFormatCB->setObjectName(QStringLiteral("defaultPlatexFormatCB"));

        gridLayout->addWidget(defaultPlatexFormatCB, 0, 5, 1, 1);

        defaultOTFFormatLA = new QLabel(defaultFormatGB);
        defaultOTFFormatLA->setObjectName(QStringLiteral("defaultOTFFormatLA"));

        gridLayout->addWidget(defaultOTFFormatLA, 2, 0, 1, 1);

        defaultFormatLA = new QLabel(defaultFormatGB);
        defaultFormatLA->setObjectName(QStringLiteral("defaultFormatLA"));

        gridLayout->addWidget(defaultFormatLA, 0, 0, 1, 1);

        defaultPLatexFormatLA = new QLabel(defaultFormatGB);
        defaultPLatexFormatLA->setObjectName(QStringLiteral("defaultPLatexFormatLA"));

        gridLayout->addWidget(defaultPLatexFormatLA, 0, 4, 1, 1);


        gridLayout_2->addWidget(defaultFormatGB, 11, 0, 1, 5);

        spacerItem = new QSpacerItem(124, 21, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(spacerItem, 12, 1, 1, 3);

#ifndef QT_NO_SHORTCUT
        formatsLA->setBuddy(formatsCB);
        formatLA->setBuddy(formatED);
        extensionsLA->setBuddy(extensionsED);
        mimeLA->setBuddy(mimeED);
        shortcutLA->setBuddy(shortcutED);
        editorLA->setBuddy(editorCO);
        viewerLA->setBuddy(viewerCO);
        label->setBuddy(copierED);
        defaultOTFFormatLA->setBuddy(defaultFormatCB);
        defaultFormatLA->setBuddy(defaultFormatCB);
        defaultPLatexFormatLA->setBuddy(defaultPlatexFormatCB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(formatsCB, formatNewPB);
        QWidget::setTabOrder(formatNewPB, formatRemovePB);
        QWidget::setTabOrder(formatRemovePB, documentCB);
        QWidget::setTabOrder(documentCB, exportMenuCB);
        QWidget::setTabOrder(exportMenuCB, vectorCB);
        QWidget::setTabOrder(vectorCB, formatED);
        QWidget::setTabOrder(formatED, extensionsED);
        QWidget::setTabOrder(extensionsED, shortcutED);
        QWidget::setTabOrder(shortcutED, editorCO);
        QWidget::setTabOrder(editorCO, editorED);
        QWidget::setTabOrder(editorED, viewerCO);
        QWidget::setTabOrder(viewerCO, viewerED);
        QWidget::setTabOrder(viewerED, mimeED);
        QWidget::setTabOrder(mimeED, copierED);

        retranslateUi(PrefFileformatsUi);

        QMetaObject::connectSlotsByName(PrefFileformatsUi);
    } // setupUi

    void retranslateUi(QWidget *PrefFileformatsUi)
    {
        PrefFileformatsUi->setWindowTitle(QString());
        formatsLA->setText(lyx::qt_("&Format:", Q_NULLPTR));
        formatNewPB->setText(lyx::qt_("&New...", Q_NULLPTR));
        formatRemovePB->setText(lyx::qt_("Re&move", Q_NULLPTR));
        documentCB->setText(lyx::qt_("&Document format", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        exportMenuCB->setToolTip(lyx::qt_("Check this to show the current format in the File > Export menu", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        exportMenuCB->setText(lyx::qt_("Sho&w in export menu", Q_NULLPTR));
        vectorCB->setText(lyx::qt_("Vector &graphics format", Q_NULLPTR));
        formatLA->setText(lyx::qt_("S&hort name:", Q_NULLPTR));
        extensionsLA->setText(lyx::qt_("E&xtensions:", Q_NULLPTR));
        mimeLA->setText(lyx::qt_("&MIME:", Q_NULLPTR));
        shortcutLA->setText(lyx::qt_("Shortc&ut:", Q_NULLPTR));
        editorLA->setText(lyx::qt_("Ed&itor:", Q_NULLPTR));
        viewerLA->setText(lyx::qt_("&Viewer:", Q_NULLPTR));
        label->setText(lyx::qt_("Co&pier:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultFormatGB->setToolTip(lyx::qt_("Specification of the default output formats when using specific LaTeX variants", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultFormatGB->setTitle(lyx::qt_("Default Output Formats", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultOTFFormatCB->setToolTip(lyx::qt_("The default output format for documents using non-TeX fonts", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        defaultFormatCB->setToolTip(lyx::qt_("This is the default output format for LyX documents, except for DocBook classes, documents that use non-TeX fonts and Japanese documents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        defaultPlatexFormatCB->setToolTip(lyx::qt_("The default output format for Japanese documents (using pLaTeX)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultOTFFormatLA->setText(lyx::qt_("With n&on-TeX fonts:", Q_NULLPTR));
        defaultFormatLA->setText(lyx::qt_("With &TeX fonts:", Q_NULLPTR));
        defaultPLatexFormatLA->setText(lyx::qt_("&Japanese:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefFileformatsUi: public Ui_PrefFileformatsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFFILEFORMATSUI_H
