/********************************************************************************
** Form generated from reading UI file 'IndexUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INDEXUI_H
#define UI_INDEXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_IndexUi
{
public:
    QGridLayout *gridLayout_3;
    QGroupBox *indicesGB;
    QGridLayout *gridLayout;
    QComboBox *indicesCO;
    QSpacerItem *horizontalSpacer;
    QGroupBox *paginationGB;
    QGridLayout *gridLayout_2;
    QLabel *rangeLA;
    QComboBox *rangeCO;
    QSpacerItem *horizontalSpacer_2;
    QLabel *pageFormatLA;
    QComboBox *pageFormatCO;
    QLineEdit *pageFormatLE;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *IndexUi)
    {
        if (IndexUi->objectName().isEmpty())
            IndexUi->setObjectName(QStringLiteral("IndexUi"));
        IndexUi->resize(384, 288);
        IndexUi->setSizeGripEnabled(true);
        gridLayout_3 = new QGridLayout(IndexUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        indicesGB = new QGroupBox(IndexUi);
        indicesGB->setObjectName(QStringLiteral("indicesGB"));
        gridLayout = new QGridLayout(indicesGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        indicesCO = new QComboBox(indicesGB);
        indicesCO->setObjectName(QStringLiteral("indicesCO"));

        gridLayout->addWidget(indicesCO, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);


        gridLayout_3->addWidget(indicesGB, 0, 0, 1, 1);

        paginationGB = new QGroupBox(IndexUi);
        paginationGB->setObjectName(QStringLiteral("paginationGB"));
        gridLayout_2 = new QGridLayout(paginationGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        rangeLA = new QLabel(paginationGB);
        rangeLA->setObjectName(QStringLiteral("rangeLA"));

        gridLayout_2->addWidget(rangeLA, 0, 0, 1, 1);

        rangeCO = new QComboBox(paginationGB);
        rangeCO->setObjectName(QStringLiteral("rangeCO"));

        gridLayout_2->addWidget(rangeCO, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(112, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        pageFormatLA = new QLabel(paginationGB);
        pageFormatLA->setObjectName(QStringLiteral("pageFormatLA"));

        gridLayout_2->addWidget(pageFormatLA, 1, 0, 1, 1);

        pageFormatCO = new QComboBox(paginationGB);
        pageFormatCO->setObjectName(QStringLiteral("pageFormatCO"));

        gridLayout_2->addWidget(pageFormatCO, 1, 1, 1, 1);

        pageFormatLE = new QLineEdit(paginationGB);
        pageFormatLE->setObjectName(QStringLiteral("pageFormatLE"));

        gridLayout_2->addWidget(pageFormatLE, 1, 2, 1, 1);


        gridLayout_3->addWidget(paginationGB, 1, 0, 1, 1);

        buttonBox = new QDialogButtonBox(IndexUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_3->addWidget(buttonBox, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        rangeLA->setBuddy(rangeCO);
        pageFormatLA->setBuddy(pageFormatCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(IndexUi);

        QMetaObject::connectSlotsByName(IndexUi);
    } // setupUi

    void retranslateUi(QDialog *IndexUi)
    {
        IndexUi->setWindowTitle(QString());
        indicesGB->setTitle(lyx::qt_("Available I&ndexes", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indicesCO->setToolTip(lyx::qt_("Select the index this entry should be listed in.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        paginationGB->setTitle(lyx::qt_("&Pagination", Q_NULLPTR));
        rangeLA->setText(lyx::qt_("Page &Range:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rangeCO->setToolTip(lyx::qt_("If the entry spans multiple pages, you can start or end the range here", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pageFormatLA->setText(lyx::qt_("&Format:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        pageFormatCO->setToolTip(lyx::qt_("Customize the format of the page number here. Note that the format is not used with \"See\" and \"See also\" references.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        pageFormatLE->setToolTip(lyx::qt_("Enter custom command here (without leading backslash).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class IndexUi: public Ui_IndexUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INDEXUI_H
