/****************************************************************************
** Meta object code from reading C++ file 'GuiSpellchecker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiSpellchecker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiSpellchecker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__SpellcheckerWidget_t {
    QByteArrayData data[14];
    char stringdata0[280];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__SpellcheckerWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__SpellcheckerWidget_t qt_meta_stringdata_lyx__frontend__SpellcheckerWidget = {
    {
QT_MOC_LITERAL(0, 0, 33), // "lyx::frontend::SpellcheckerWi..."
QT_MOC_LITERAL(1, 34, 23), // "on_replaceAllPB_clicked"
QT_MOC_LITERAL(2, 58, 0), // ""
QT_MOC_LITERAL(3, 59, 28), // "on_suggestionsLW_itemClicked"
QT_MOC_LITERAL(4, 88, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(5, 105, 24), // "on_replaceCO_highlighted"
QT_MOC_LITERAL(6, 130, 5), // "index"
QT_MOC_LITERAL(7, 136, 23), // "on_languageCO_activated"
QT_MOC_LITERAL(8, 160, 22), // "on_ignoreAllPB_clicked"
QT_MOC_LITERAL(9, 183, 20), // "on_skipAllPB_clicked"
QT_MOC_LITERAL(10, 204, 16), // "on_addPB_clicked"
QT_MOC_LITERAL(11, 221, 17), // "on_skipPB_clicked"
QT_MOC_LITERAL(12, 239, 19), // "on_ignorePB_clicked"
QT_MOC_LITERAL(13, 259, 20) // "on_replacePB_clicked"

    },
    "lyx::frontend::SpellcheckerWidget\0"
    "on_replaceAllPB_clicked\0\0"
    "on_suggestionsLW_itemClicked\0"
    "QListWidgetItem*\0on_replaceCO_highlighted\0"
    "index\0on_languageCO_activated\0"
    "on_ignoreAllPB_clicked\0on_skipAllPB_clicked\0"
    "on_addPB_clicked\0on_skipPB_clicked\0"
    "on_ignorePB_clicked\0on_replacePB_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__SpellcheckerWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x08 /* Private */,
       3,    1,   65,    2, 0x08 /* Private */,
       5,    1,   68,    2, 0x08 /* Private */,
       7,    1,   71,    2, 0x08 /* Private */,
       8,    0,   74,    2, 0x08 /* Private */,
       9,    0,   75,    2, 0x08 /* Private */,
      10,    0,   76,    2, 0x08 /* Private */,
      11,    0,   77,    2, 0x08 /* Private */,
      12,    0,   78,    2, 0x08 /* Private */,
      13,    0,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::SpellcheckerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SpellcheckerWidget *_t = static_cast<SpellcheckerWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_replaceAllPB_clicked(); break;
        case 1: _t->on_suggestionsLW_itemClicked((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->on_replaceCO_highlighted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_languageCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_ignoreAllPB_clicked(); break;
        case 5: _t->on_skipAllPB_clicked(); break;
        case 6: _t->on_addPB_clicked(); break;
        case 7: _t->on_skipPB_clicked(); break;
        case 8: _t->on_ignorePB_clicked(); break;
        case 9: _t->on_replacePB_clicked(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::SpellcheckerWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__SpellcheckerWidget.data,
      qt_meta_data_lyx__frontend__SpellcheckerWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::SpellcheckerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::SpellcheckerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__SpellcheckerWidget.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int lyx::frontend::SpellcheckerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__GuiSpellchecker_t {
    QByteArrayData data[1];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiSpellchecker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiSpellchecker_t qt_meta_stringdata_lyx__frontend__GuiSpellchecker = {
    {
QT_MOC_LITERAL(0, 0, 30) // "lyx::frontend::GuiSpellchecker"

    },
    "lyx::frontend::GuiSpellchecker"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiSpellchecker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void lyx::frontend::GuiSpellchecker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::GuiSpellchecker::staticMetaObject = {
    { &DockView::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiSpellchecker.data,
      qt_meta_data_lyx__frontend__GuiSpellchecker,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiSpellchecker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiSpellchecker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiSpellchecker.stringdata0))
        return static_cast<void*>(this);
    return DockView::qt_metacast(_clname);
}

int lyx::frontend::GuiSpellchecker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockView::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
