/********************************************************************************
** Form generated from reading UI file 'PrefShortcutsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFSHORTCUTSUI_H
#define UI_PREFSHORTCUTSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefShortcuts
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *modifyPB;
    QPushButton *removePB;
    QPushButton *newPB;
    QTreeWidget *shortcutsTW;
    QLineEdit *bindFileED;
    QPushButton *bindFilePB;
    QLabel *bindFileLA;
    QHBoxLayout *hboxLayout1;
    QLabel *shortcutsLBL;
    QLineEdit *searchLE;

    void setupUi(QWidget *PrefShortcuts)
    {
        if (PrefShortcuts->objectName().isEmpty())
            PrefShortcuts->setObjectName(QStringLiteral("PrefShortcuts"));
        PrefShortcuts->resize(409, 494);
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(1), static_cast<QSizePolicy::Policy>(1));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefShortcuts->sizePolicy().hasHeightForWidth());
        PrefShortcuts->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(PrefShortcuts);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        spacerItem = new QSpacerItem(131, 27, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        modifyPB = new QPushButton(PrefShortcuts);
        modifyPB->setObjectName(QStringLiteral("modifyPB"));

        hboxLayout->addWidget(modifyPB);

        removePB = new QPushButton(PrefShortcuts);
        removePB->setObjectName(QStringLiteral("removePB"));

        hboxLayout->addWidget(removePB);

        newPB = new QPushButton(PrefShortcuts);
        newPB->setObjectName(QStringLiteral("newPB"));

        hboxLayout->addWidget(newPB);


        gridLayout->addLayout(hboxLayout, 3, 0, 1, 3);

        shortcutsTW = new QTreeWidget(PrefShortcuts);
        shortcutsTW->setObjectName(QStringLiteral("shortcutsTW"));

        gridLayout->addWidget(shortcutsTW, 2, 0, 1, 3);

        bindFileED = new QLineEdit(PrefShortcuts);
        bindFileED->setObjectName(QStringLiteral("bindFileED"));

        gridLayout->addWidget(bindFileED, 0, 1, 1, 1);

        bindFilePB = new QPushButton(PrefShortcuts);
        bindFilePB->setObjectName(QStringLiteral("bindFilePB"));

        gridLayout->addWidget(bindFilePB, 0, 2, 1, 1);

        bindFileLA = new QLabel(PrefShortcuts);
        bindFileLA->setObjectName(QStringLiteral("bindFileLA"));

        gridLayout->addWidget(bindFileLA, 0, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        shortcutsLBL = new QLabel(PrefShortcuts);
        shortcutsLBL->setObjectName(QStringLiteral("shortcutsLBL"));

        hboxLayout1->addWidget(shortcutsLBL);

        searchLE = new QLineEdit(PrefShortcuts);
        searchLE->setObjectName(QStringLiteral("searchLE"));

        hboxLayout1->addWidget(searchLE);


        gridLayout->addLayout(hboxLayout1, 1, 0, 1, 3);

#ifndef QT_NO_SHORTCUT
        bindFileLA->setBuddy(bindFileED);
        shortcutsLBL->setBuddy(searchLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(bindFileED, bindFilePB);
        QWidget::setTabOrder(bindFilePB, searchLE);
        QWidget::setTabOrder(searchLE, shortcutsTW);
        QWidget::setTabOrder(shortcutsTW, removePB);
        QWidget::setTabOrder(removePB, newPB);

        retranslateUi(PrefShortcuts);

        QMetaObject::connectSlotsByName(PrefShortcuts);
    } // setupUi

    void retranslateUi(QWidget *PrefShortcuts)
    {
        PrefShortcuts->setWindowTitle(QString());
        modifyPB->setText(lyx::qt_("&Modify", Q_NULLPTR));
        removePB->setText(lyx::qt_("Remo&ve", Q_NULLPTR));
        newPB->setText(lyx::qt_("&New", Q_NULLPTR));
        bindFilePB->setText(lyx::qt_("Br&owse...", Q_NULLPTR));
        bindFileLA->setText(lyx::qt_("&Bind file:", Q_NULLPTR));
        shortcutsLBL->setText(lyx::qt_("Show ke&y-bindings containing:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefShortcuts: public Ui_PrefShortcuts {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFSHORTCUTSUI_H
