/********************************************************************************
** Form generated from reading UI file 'ListingsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTINGSUI_H
#define UI_LISTINGSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ListingsUi
{
public:
    QGridLayout *gridLayout_9;
    QTabWidget *listingsTW;
    QWidget *tab;
    QGridLayout *gridLayout_6;
    QGroupBox *placementGB;
    QGridLayout *gridLayout;
    QCheckBox *inlineCB;
    QCheckBox *floatCB;
    QLabel *captionL_5;
    QLineEdit *placementLE;
    QGroupBox *numberstyleGB;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QComboBox *numberSideCO;
    QLabel *stepnumberL;
    QLineEdit *numberStepLE;
    QLabel *numberfontsizeL;
    QComboBox *numberFontSizeCO;
    QGroupBox *basicstyleGB;
    QGridLayout *gridLayout_5;
    QLabel *fontsize_label_3;
    QComboBox *fontsizeCO;
    QLabel *fontstyle_label_3;
    QComboBox *fontstyleCO;
    QCheckBox *breaklinesCB;
    QCheckBox *spaceCB;
    QCheckBox *spaceInStringCB;
    QLabel *tabsizeL;
    QSpinBox *tabsizeSB;
    QCheckBox *extendedcharsCB;
    QGroupBox *languageGB;
    QGridLayout *gridLayout_3;
    QLabel *languageLBL;
    QComboBox *languageCO;
    QLabel *dialectLBL;
    QComboBox *dialectCO;
    QGroupBox *rangeGB;
    QGridLayout *gridLayout_4;
    QLabel *numberfontsizeL_3;
    QLineEdit *firstlineLE;
    QLabel *numberfontsizeL_2;
    QLineEdit *lastlineLE;
    QWidget *tab_2;
    QGridLayout *gridLayout_8;
    QGroupBox *listingsGB;
    QGridLayout *gridLayout_7;
    QSplitter *splitter;
    QTextBrowser *listingsTB;
    QTextEdit *listingsED;
    QCheckBox *bypassCB;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ListingsUi)
    {
        if (ListingsUi->objectName().isEmpty())
            ListingsUi->setObjectName(QStringLiteral("ListingsUi"));
        ListingsUi->resize(753, 397);
        gridLayout_9 = new QGridLayout(ListingsUi);
        gridLayout_9->setObjectName(QStringLiteral("gridLayout_9"));
        listingsTW = new QTabWidget(ListingsUi);
        listingsTW->setObjectName(QStringLiteral("listingsTW"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout_6 = new QGridLayout(tab);
        gridLayout_6->setObjectName(QStringLiteral("gridLayout_6"));
        placementGB = new QGroupBox(tab);
        placementGB->setObjectName(QStringLiteral("placementGB"));
        placementGB->setFlat(true);
        gridLayout = new QGridLayout(placementGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        inlineCB = new QCheckBox(placementGB);
        inlineCB->setObjectName(QStringLiteral("inlineCB"));

        gridLayout->addWidget(inlineCB, 0, 0, 1, 2);

        floatCB = new QCheckBox(placementGB);
        floatCB->setObjectName(QStringLiteral("floatCB"));

        gridLayout->addWidget(floatCB, 1, 0, 1, 2);

        captionL_5 = new QLabel(placementGB);
        captionL_5->setObjectName(QStringLiteral("captionL_5"));
        captionL_5->setWordWrap(false);

        gridLayout->addWidget(captionL_5, 2, 0, 1, 1);

        placementLE = new QLineEdit(placementGB);
        placementLE->setObjectName(QStringLiteral("placementLE"));

        gridLayout->addWidget(placementLE, 2, 1, 1, 1);


        gridLayout_6->addWidget(placementGB, 0, 0, 1, 1);

        numberstyleGB = new QGroupBox(tab);
        numberstyleGB->setObjectName(QStringLiteral("numberstyleGB"));
        numberstyleGB->setFlat(true);
        gridLayout_2 = new QGridLayout(numberstyleGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        label = new QLabel(numberstyleGB);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        numberSideCO = new QComboBox(numberstyleGB);
        numberSideCO->setObjectName(QStringLiteral("numberSideCO"));

        gridLayout_2->addWidget(numberSideCO, 0, 1, 1, 1);

        stepnumberL = new QLabel(numberstyleGB);
        stepnumberL->setObjectName(QStringLiteral("stepnumberL"));
        stepnumberL->setWordWrap(false);

        gridLayout_2->addWidget(stepnumberL, 1, 0, 1, 1);

        numberStepLE = new QLineEdit(numberstyleGB);
        numberStepLE->setObjectName(QStringLiteral("numberStepLE"));
        numberStepLE->setAlignment(Qt::AlignLeading);

        gridLayout_2->addWidget(numberStepLE, 1, 1, 1, 1);

        numberfontsizeL = new QLabel(numberstyleGB);
        numberfontsizeL->setObjectName(QStringLiteral("numberfontsizeL"));
        numberfontsizeL->setWordWrap(false);

        gridLayout_2->addWidget(numberfontsizeL, 2, 0, 1, 1);

        numberFontSizeCO = new QComboBox(numberstyleGB);
        numberFontSizeCO->setObjectName(QStringLiteral("numberFontSizeCO"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(numberFontSizeCO->sizePolicy().hasHeightForWidth());
        numberFontSizeCO->setSizePolicy(sizePolicy);
        numberFontSizeCO->setEditable(false);
        numberFontSizeCO->setDuplicatesEnabled(false);

        gridLayout_2->addWidget(numberFontSizeCO, 2, 1, 1, 1);


        gridLayout_6->addWidget(numberstyleGB, 0, 1, 1, 1);

        basicstyleGB = new QGroupBox(tab);
        basicstyleGB->setObjectName(QStringLiteral("basicstyleGB"));
        basicstyleGB->setFlat(true);
        gridLayout_5 = new QGridLayout(basicstyleGB);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        fontsize_label_3 = new QLabel(basicstyleGB);
        fontsize_label_3->setObjectName(QStringLiteral("fontsize_label_3"));
        fontsize_label_3->setWordWrap(false);

        gridLayout_5->addWidget(fontsize_label_3, 0, 0, 1, 1);

        fontsizeCO = new QComboBox(basicstyleGB);
        fontsizeCO->setObjectName(QStringLiteral("fontsizeCO"));
        sizePolicy.setHeightForWidth(fontsizeCO->sizePolicy().hasHeightForWidth());
        fontsizeCO->setSizePolicy(sizePolicy);
        fontsizeCO->setEditable(false);
        fontsizeCO->setDuplicatesEnabled(false);

        gridLayout_5->addWidget(fontsizeCO, 0, 1, 1, 1);

        fontstyle_label_3 = new QLabel(basicstyleGB);
        fontstyle_label_3->setObjectName(QStringLiteral("fontstyle_label_3"));
        fontstyle_label_3->setWordWrap(false);

        gridLayout_5->addWidget(fontstyle_label_3, 1, 0, 1, 1);

        fontstyleCO = new QComboBox(basicstyleGB);
        fontstyleCO->setObjectName(QStringLiteral("fontstyleCO"));
        sizePolicy.setHeightForWidth(fontstyleCO->sizePolicy().hasHeightForWidth());
        fontstyleCO->setSizePolicy(sizePolicy);
        fontstyleCO->setEditable(false);
        fontstyleCO->setDuplicatesEnabled(false);

        gridLayout_5->addWidget(fontstyleCO, 1, 1, 1, 1);

        breaklinesCB = new QCheckBox(basicstyleGB);
        breaklinesCB->setObjectName(QStringLiteral("breaklinesCB"));
#ifndef QT_NO_SHORTCUT
        breaklinesCB->setShortcut(276824130);
#endif // QT_NO_SHORTCUT

        gridLayout_5->addWidget(breaklinesCB, 2, 0, 1, 2);

        spaceCB = new QCheckBox(basicstyleGB);
        spaceCB->setObjectName(QStringLiteral("spaceCB"));
#ifndef QT_NO_SHORTCUT
        spaceCB->setShortcut(276824147);
#endif // QT_NO_SHORTCUT

        gridLayout_5->addWidget(spaceCB, 3, 0, 1, 2);

        spaceInStringCB = new QCheckBox(basicstyleGB);
        spaceInStringCB->setObjectName(QStringLiteral("spaceInStringCB"));
#ifndef QT_NO_SHORTCUT
        spaceInStringCB->setShortcut(276824147);
#endif // QT_NO_SHORTCUT

        gridLayout_5->addWidget(spaceInStringCB, 4, 0, 1, 2);

        tabsizeL = new QLabel(basicstyleGB);
        tabsizeL->setObjectName(QStringLiteral("tabsizeL"));

        gridLayout_5->addWidget(tabsizeL, 5, 0, 1, 1);

        tabsizeSB = new QSpinBox(basicstyleGB);
        tabsizeSB->setObjectName(QStringLiteral("tabsizeSB"));

        gridLayout_5->addWidget(tabsizeSB, 5, 1, 1, 1);

        extendedcharsCB = new QCheckBox(basicstyleGB);
        extendedcharsCB->setObjectName(QStringLiteral("extendedcharsCB"));
        extendedcharsCB->setEnabled(true);
#ifndef QT_NO_SHORTCUT
        extendedcharsCB->setShortcut(276824133);
#endif // QT_NO_SHORTCUT

        gridLayout_5->addWidget(extendedcharsCB, 6, 0, 1, 2);


        gridLayout_6->addWidget(basicstyleGB, 0, 2, 2, 1);

        languageGB = new QGroupBox(tab);
        languageGB->setObjectName(QStringLiteral("languageGB"));
        languageGB->setFlat(true);
        gridLayout_3 = new QGridLayout(languageGB);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        languageLBL = new QLabel(languageGB);
        languageLBL->setObjectName(QStringLiteral("languageLBL"));

        gridLayout_3->addWidget(languageLBL, 0, 0, 1, 1);

        languageCO = new QComboBox(languageGB);
        languageCO->setObjectName(QStringLiteral("languageCO"));

        gridLayout_3->addWidget(languageCO, 0, 1, 1, 1);

        dialectLBL = new QLabel(languageGB);
        dialectLBL->setObjectName(QStringLiteral("dialectLBL"));

        gridLayout_3->addWidget(dialectLBL, 1, 0, 1, 1);

        dialectCO = new QComboBox(languageGB);
        dialectCO->setObjectName(QStringLiteral("dialectCO"));

        gridLayout_3->addWidget(dialectCO, 1, 1, 1, 1);


        gridLayout_6->addWidget(languageGB, 1, 0, 1, 1);

        rangeGB = new QGroupBox(tab);
        rangeGB->setObjectName(QStringLiteral("rangeGB"));
        rangeGB->setFlat(true);
        gridLayout_4 = new QGridLayout(rangeGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        numberfontsizeL_3 = new QLabel(rangeGB);
        numberfontsizeL_3->setObjectName(QStringLiteral("numberfontsizeL_3"));
        numberfontsizeL_3->setWordWrap(false);

        gridLayout_4->addWidget(numberfontsizeL_3, 0, 0, 1, 1);

        firstlineLE = new QLineEdit(rangeGB);
        firstlineLE->setObjectName(QStringLiteral("firstlineLE"));
        firstlineLE->setAlignment(Qt::AlignLeading);

        gridLayout_4->addWidget(firstlineLE, 0, 1, 1, 1);

        numberfontsizeL_2 = new QLabel(rangeGB);
        numberfontsizeL_2->setObjectName(QStringLiteral("numberfontsizeL_2"));
        numberfontsizeL_2->setWordWrap(false);

        gridLayout_4->addWidget(numberfontsizeL_2, 1, 0, 1, 1);

        lastlineLE = new QLineEdit(rangeGB);
        lastlineLE->setObjectName(QStringLiteral("lastlineLE"));
        lastlineLE->setAlignment(Qt::AlignLeading);

        gridLayout_4->addWidget(lastlineLE, 1, 1, 1, 1);


        gridLayout_6->addWidget(rangeGB, 1, 1, 1, 1);

        listingsTW->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout_8 = new QGridLayout(tab_2);
        gridLayout_8->setObjectName(QStringLiteral("gridLayout_8"));
        listingsGB = new QGroupBox(tab_2);
        listingsGB->setObjectName(QStringLiteral("listingsGB"));
        sizePolicy.setHeightForWidth(listingsGB->sizePolicy().hasHeightForWidth());
        listingsGB->setSizePolicy(sizePolicy);
        listingsGB->setFlat(true);
        gridLayout_7 = new QGridLayout(listingsGB);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        splitter = new QSplitter(listingsGB);
        splitter->setObjectName(QStringLiteral("splitter"));
        splitter->setOrientation(Qt::Horizontal);
        listingsTB = new QTextBrowser(splitter);
        listingsTB->setObjectName(QStringLiteral("listingsTB"));
        listingsTB->setMaximumSize(QSize(16777215, 16777215));
        listingsTB->setAcceptDrops(false);
        listingsTB->setFrameShape(QFrame::Box);
        listingsTB->setFrameShadow(QFrame::Plain);
        listingsTB->setAcceptRichText(false);
        splitter->addWidget(listingsTB);
        listingsED = new QTextEdit(splitter);
        listingsED->setObjectName(QStringLiteral("listingsED"));
        sizePolicy.setHeightForWidth(listingsED->sizePolicy().hasHeightForWidth());
        listingsED->setSizePolicy(sizePolicy);
        splitter->addWidget(listingsED);

        gridLayout_7->addWidget(splitter, 0, 0, 1, 1);

        bypassCB = new QCheckBox(listingsGB);
        bypassCB->setObjectName(QStringLiteral("bypassCB"));

        gridLayout_7->addWidget(bypassCB, 1, 0, 1, 1);


        gridLayout_8->addWidget(listingsGB, 0, 0, 1, 1);

        listingsTW->addTab(tab_2, QString());

        gridLayout_9->addWidget(listingsTW, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        buttonBox = new QDialogButtonBox(ListingsUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        gridLayout_9->addLayout(horizontalLayout, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        captionL_5->setBuddy(placementLE);
        label->setBuddy(numberSideCO);
        stepnumberL->setBuddy(numberStepLE);
        numberfontsizeL->setBuddy(numberFontSizeCO);
        fontsize_label_3->setBuddy(fontsizeCO);
        fontstyle_label_3->setBuddy(fontstyleCO);
        tabsizeL->setBuddy(tabsizeSB);
        languageLBL->setBuddy(languageCO);
        dialectLBL->setBuddy(dialectCO);
        numberfontsizeL_3->setBuddy(firstlineLE);
        numberfontsizeL_2->setBuddy(lastlineLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(listingsTW, inlineCB);
        QWidget::setTabOrder(inlineCB, floatCB);
        QWidget::setTabOrder(floatCB, placementLE);
        QWidget::setTabOrder(placementLE, languageCO);
        QWidget::setTabOrder(languageCO, dialectCO);
        QWidget::setTabOrder(dialectCO, numberSideCO);
        QWidget::setTabOrder(numberSideCO, numberStepLE);
        QWidget::setTabOrder(numberStepLE, numberFontSizeCO);
        QWidget::setTabOrder(numberFontSizeCO, firstlineLE);
        QWidget::setTabOrder(firstlineLE, lastlineLE);
        QWidget::setTabOrder(lastlineLE, fontsizeCO);
        QWidget::setTabOrder(fontsizeCO, fontstyleCO);
        QWidget::setTabOrder(fontstyleCO, breaklinesCB);
        QWidget::setTabOrder(breaklinesCB, spaceCB);
        QWidget::setTabOrder(spaceCB, spaceInStringCB);
        QWidget::setTabOrder(spaceInStringCB, extendedcharsCB);
        QWidget::setTabOrder(extendedcharsCB, listingsTB);
        QWidget::setTabOrder(listingsTB, listingsED);

        retranslateUi(ListingsUi);

        listingsTW->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ListingsUi);
    } // setupUi

    void retranslateUi(QDialog *ListingsUi)
    {
        ListingsUi->setWindowTitle(lyx::qt_("Listing", Q_NULLPTR));
        placementGB->setTitle(lyx::qt_("Placement", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inlineCB->setToolTip(lyx::qt_("Check for inline listings", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        inlineCB->setText(lyx::qt_("&Inline listing", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        floatCB->setToolTip(lyx::qt_("Check for floating listings", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        floatCB->setText(lyx::qt_("&Float", Q_NULLPTR));
        captionL_5->setText(lyx::qt_("Pla&cement:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        placementLE->setToolTip(lyx::qt_("Specify placement (htbp) for floating listings", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        numberstyleGB->setTitle(lyx::qt_("Line numbering", Q_NULLPTR));
        label->setText(lyx::qt_("&Side:", Q_NULLPTR));
        numberSideCO->clear();
        numberSideCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("Left", Q_NULLPTR)
         << lyx::qt_("Right", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        numberSideCO->setToolTip(lyx::qt_("On which side should line numbers be printed?", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        stepnumberL->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        stepnumberL->setText(lyx::qt_("S&tep:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        numberStepLE->setToolTip(lyx::qt_("Difference between two numbered lines", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_STATUSTIP
        numberStepLE->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
        numberStepLE->setText(QString());
        numberfontsizeL->setText(lyx::qt_("Font si&ze:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        numberFontSizeCO->setToolTip(lyx::qt_("Choose the font size for line numbers", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        basicstyleGB->setTitle(lyx::qt_("Style", Q_NULLPTR));
        fontsize_label_3->setText(lyx::qt_("F&ont size:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontsizeCO->setToolTip(lyx::qt_("The content's base font size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontstyle_label_3->setText(lyx::qt_("Font Famil&y:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontstyleCO->setToolTip(lyx::qt_("The content's base font style", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        breaklinesCB->setToolTip(lyx::qt_("Break lines longer than the linewidth", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        breaklinesCB->setText(lyx::qt_("&Break long lines", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        spaceCB->setToolTip(lyx::qt_("Make spaces visible by a special symbol", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        spaceCB->setText(lyx::qt_("S&pace as symbol", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        spaceInStringCB->setToolTip(lyx::qt_("Make spaces in strings visible by a special symbol", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        spaceInStringCB->setText(lyx::qt_("Space i&n string as symbol", Q_NULLPTR));
        tabsizeL->setText(lyx::qt_("Tab&ulator size:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        extendedcharsCB->setToolTip(lyx::qt_("Use extended character table", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        extendedcharsCB->setText(lyx::qt_("&Extended character table", Q_NULLPTR));
        languageGB->setTitle(lyx::qt_("Language[[Programming]]", Q_NULLPTR));
        languageLBL->setText(lyx::qt_("Lan&guage[[Programming]]:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languageCO->setToolTip(lyx::qt_("Select the programming language", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        dialectLBL->setText(lyx::qt_("&Dialect:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        dialectCO->setToolTip(lyx::qt_("Select the dialect of the programming language, if available", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rangeGB->setTitle(lyx::qt_("Range", Q_NULLPTR));
        numberfontsizeL_3->setText(lyx::qt_("Fi&rst line:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        firstlineLE->setToolTip(lyx::qt_("The first line to be printed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        firstlineLE->setText(QString());
        numberfontsizeL_2->setText(lyx::qt_("&Last line:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lastlineLE->setToolTip(lyx::qt_("The last line to be printed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        lastlineLE->setText(QString());
        listingsTW->setTabText(listingsTW->indexOf(tab), lyx::qt_("&Main Settings", Q_NULLPTR));
        listingsGB->setTitle(lyx::qt_("More Parameters", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        listingsTB->setToolTip(lyx::qt_("Feedback window", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        listingsED->setToolTip(lyx::qt_("Input listing parameters here. Enter ? for a list of parameters.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        bypassCB->setToolTip(lyx::qt_("Check it to enter parameters that are not recognizable by LyX", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bypassCB->setText(lyx::qt_("&Bypass validation", Q_NULLPTR));
        listingsTW->setTabText(listingsTW->indexOf(tab_2), lyx::qt_("Ad&vanced", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ListingsUi: public Ui_ListingsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LISTINGSUI_H
