/********************************************************************************
** Form generated from reading UI file 'NoteUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTEUI_H
#define UI_NOTEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_NoteUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *NoteBG;
    QVBoxLayout *vboxLayout;
    QRadioButton *noteRB;
    QRadioButton *commentRB;
    QRadioButton *greyedoutRB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NoteUi)
    {
        if (NoteUi->objectName().isEmpty())
            NoteUi->setObjectName(QStringLiteral("NoteUi"));
        NoteUi->resize(202, 196);
        NoteUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(NoteUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        NoteBG = new QGroupBox(NoteUi);
        NoteBG->setObjectName(QStringLiteral("NoteBG"));
        vboxLayout = new QVBoxLayout(NoteBG);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        noteRB = new QRadioButton(NoteBG);
        noteRB->setObjectName(QStringLiteral("noteRB"));

        vboxLayout->addWidget(noteRB);

        commentRB = new QRadioButton(NoteBG);
        commentRB->setObjectName(QStringLiteral("commentRB"));

        vboxLayout->addWidget(commentRB);

        greyedoutRB = new QRadioButton(NoteBG);
        greyedoutRB->setObjectName(QStringLiteral("greyedoutRB"));

        vboxLayout->addWidget(greyedoutRB);


        gridLayout->addWidget(NoteBG, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(NoteUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);

        QWidget::setTabOrder(noteRB, commentRB);
        QWidget::setTabOrder(commentRB, greyedoutRB);

        retranslateUi(NoteUi);

        QMetaObject::connectSlotsByName(NoteUi);
    } // setupUi

    void retranslateUi(QDialog *NoteUi)
    {
        NoteUi->setWindowTitle(QString());
        NoteBG->setTitle(lyx::qt_("Type", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        noteRB->setToolTip(lyx::qt_("LyX internal only", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        noteRB->setText(lyx::qt_("LyX &Note", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        commentRB->setToolTip(lyx::qt_("Export to LaTeX/Docbook but don't print", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        commentRB->setText(lyx::qt_("&Comment", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        greyedoutRB->setToolTip(lyx::qt_("Print as grey text", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        greyedoutRB->setText(lyx::qt_("&Greyed out", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NoteUi: public Ui_NoteUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NOTEUI_H
