/********************************************************************************
** Form generated from reading UI file 'LogUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGUI_H
#define UI_LOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LogUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *logTypeLA;
    QComboBox *logTypeCO;
    QSpacerItem *spacerItem;
    QTextBrowser *logTB;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *spacerItem1;
    QPushButton *nextErrorPB;
    QPushButton *nextWarningPB;
    QHBoxLayout *horizontalLayout_3;
    QLabel *findLA;
    QLineEdit *findLE;
    QPushButton *findPB;
    QPushButton *openDirPB;
    QSpacerItem *spacerItem2;
    QPushButton *updatePB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LogUi)
    {
        if (LogUi->objectName().isEmpty())
            LogUi->setObjectName(QStringLiteral("LogUi"));
        LogUi->resize(452, 474);
        LogUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(LogUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        logTypeLA = new QLabel(LogUi);
        logTypeLA->setObjectName(QStringLiteral("logTypeLA"));

        horizontalLayout->addWidget(logTypeLA);

        logTypeCO = new QComboBox(LogUi);
        logTypeCO->setObjectName(QStringLiteral("logTypeCO"));

        horizontalLayout->addWidget(logTypeCO);

        spacerItem = new QSpacerItem(161, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacerItem);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 3);

        logTB = new QTextBrowser(LogUi);
        logTB->setObjectName(QStringLiteral("logTB"));

        gridLayout->addWidget(logTB, 1, 0, 1, 4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        spacerItem1 = new QSpacerItem(201, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacerItem1);

        nextErrorPB = new QPushButton(LogUi);
        nextErrorPB->setObjectName(QStringLiteral("nextErrorPB"));
        nextErrorPB->setAutoDefault(false);

        horizontalLayout_2->addWidget(nextErrorPB);

        nextWarningPB = new QPushButton(LogUi);
        nextWarningPB->setObjectName(QStringLiteral("nextWarningPB"));
        nextWarningPB->setAutoDefault(false);

        horizontalLayout_2->addWidget(nextWarningPB);


        gridLayout->addLayout(horizontalLayout_2, 2, 0, 1, 4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        findLA = new QLabel(LogUi);
        findLA->setObjectName(QStringLiteral("findLA"));

        horizontalLayout_3->addWidget(findLA);

        findLE = new QLineEdit(LogUi);
        findLE->setObjectName(QStringLiteral("findLE"));

        horizontalLayout_3->addWidget(findLE);

        findPB = new QPushButton(LogUi);
        findPB->setObjectName(QStringLiteral("findPB"));
        findPB->setAutoDefault(false);

        horizontalLayout_3->addWidget(findPB);


        gridLayout->addLayout(horizontalLayout_3, 3, 0, 1, 4);

        openDirPB = new QPushButton(LogUi);
        openDirPB->setObjectName(QStringLiteral("openDirPB"));
        openDirPB->setAutoDefault(false);

        gridLayout->addWidget(openDirPB, 4, 0, 1, 1);

        spacerItem2 = new QSpacerItem(111, 26, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem2, 4, 1, 1, 1);

        updatePB = new QPushButton(LogUi);
        updatePB->setObjectName(QStringLiteral("updatePB"));
        updatePB->setAutoDefault(false);

        gridLayout->addWidget(updatePB, 4, 2, 1, 1);

        buttonBox = new QDialogButtonBox(LogUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 4, 3, 1, 1);

#ifndef QT_NO_SHORTCUT
        logTypeLA->setBuddy(logTypeCO);
        findLA->setBuddy(findLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(logTB, openDirPB);
        QWidget::setTabOrder(openDirPB, updatePB);

        retranslateUi(LogUi);

        QMetaObject::connectSlotsByName(LogUi);
    } // setupUi

    void retranslateUi(QDialog *LogUi)
    {
        LogUi->setWindowTitle(QString());
        logTypeLA->setText(lyx::qt_("Log &Type:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nextErrorPB->setToolTip(lyx::qt_("Jump to the next error message.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nextErrorPB->setText(lyx::qt_("Next &Error", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nextWarningPB->setToolTip(lyx::qt_("Jump to the next warning message.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nextWarningPB->setText(lyx::qt_("Next &Warning", Q_NULLPTR));
        findLA->setText(lyx::qt_("&Find:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        findLE->setToolTip(lyx::qt_("Hit Enter or click 'Find Next' to search", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        findPB->setText(lyx::qt_("Find &Next", Q_NULLPTR));
        openDirPB->setText(lyx::qt_("&Open Containing Directory", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        updatePB->setToolTip(lyx::qt_("Update the display", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        updatePB->setText(lyx::qt_("&Update", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LogUi: public Ui_LogUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LOGUI_H
