/********************************************************************************
** Form generated from reading UI file 'WrapUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WRAPUI_H
#define UI_WRAPUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_WrapUi
{
public:
    QGridLayout *gridLayout;
    QLabel *valignLA;
    QComboBox *valignCO;
    QCheckBox *floatCB;
    QLabel *widthLA;
    QLineEdit *widthED;
    lyx::frontend::LengthCombo *widthUnitLC;
    QCheckBox *overhangCB;
    QLineEdit *overhangED;
    lyx::frontend::LengthCombo *overhangUnitLC;
    QCheckBox *linesCB;
    QSpinBox *linesSB;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *WrapUi)
    {
        if (WrapUi->objectName().isEmpty())
            WrapUi->setObjectName(QStringLiteral("WrapUi"));
        WrapUi->resize(405, 219);
        WrapUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(WrapUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        valignLA = new QLabel(WrapUi);
        valignLA->setObjectName(QStringLiteral("valignLA"));

        gridLayout->addWidget(valignLA, 0, 0, 1, 1);

        valignCO = new QComboBox(WrapUi);
        valignCO->setObjectName(QStringLiteral("valignCO"));

        gridLayout->addWidget(valignCO, 0, 1, 1, 2);

        floatCB = new QCheckBox(WrapUi);
        floatCB->setObjectName(QStringLiteral("floatCB"));

        gridLayout->addWidget(floatCB, 0, 3, 1, 1);

        widthLA = new QLabel(WrapUi);
        widthLA->setObjectName(QStringLiteral("widthLA"));

        gridLayout->addWidget(widthLA, 1, 0, 1, 1);

        widthED = new QLineEdit(WrapUi);
        widthED->setObjectName(QStringLiteral("widthED"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(widthED->sizePolicy().hasHeightForWidth());
        widthED->setSizePolicy(sizePolicy);

        gridLayout->addWidget(widthED, 1, 1, 1, 2);

        widthUnitLC = new lyx::frontend::LengthCombo(WrapUi);
        widthUnitLC->setObjectName(QStringLiteral("widthUnitLC"));
        sizePolicy.setHeightForWidth(widthUnitLC->sizePolicy().hasHeightForWidth());
        widthUnitLC->setSizePolicy(sizePolicy);
        widthUnitLC->setMinimumSize(QSize(40, 22));
        widthUnitLC->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(widthUnitLC, 1, 3, 1, 1);

        overhangCB = new QCheckBox(WrapUi);
        overhangCB->setObjectName(QStringLiteral("overhangCB"));
        overhangCB->setChecked(false);

        gridLayout->addWidget(overhangCB, 2, 0, 1, 1);

        overhangED = new QLineEdit(WrapUi);
        overhangED->setObjectName(QStringLiteral("overhangED"));
        overhangED->setEnabled(false);
        sizePolicy.setHeightForWidth(overhangED->sizePolicy().hasHeightForWidth());
        overhangED->setSizePolicy(sizePolicy);

        gridLayout->addWidget(overhangED, 2, 1, 1, 2);

        overhangUnitLC = new lyx::frontend::LengthCombo(WrapUi);
        overhangUnitLC->setObjectName(QStringLiteral("overhangUnitLC"));
        overhangUnitLC->setEnabled(false);
        sizePolicy.setHeightForWidth(overhangUnitLC->sizePolicy().hasHeightForWidth());
        overhangUnitLC->setSizePolicy(sizePolicy);
        overhangUnitLC->setMinimumSize(QSize(0, 0));
        overhangUnitLC->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(overhangUnitLC, 2, 3, 1, 1);

        linesCB = new QCheckBox(WrapUi);
        linesCB->setObjectName(QStringLiteral("linesCB"));

        gridLayout->addWidget(linesCB, 3, 0, 1, 1);

        linesSB = new QSpinBox(WrapUi);
        linesSB->setObjectName(QStringLiteral("linesSB"));
        linesSB->setEnabled(false);

        gridLayout->addWidget(linesSB, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 3, 2, 1, 1);

        buttonBox = new QDialogButtonBox(WrapUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 4);

#ifndef QT_NO_SHORTCUT
        valignLA->setBuddy(valignCO);
        widthLA->setBuddy(widthED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(valignCO, floatCB);
        QWidget::setTabOrder(floatCB, widthED);
        QWidget::setTabOrder(widthED, widthUnitLC);
        QWidget::setTabOrder(widthUnitLC, overhangCB);
        QWidget::setTabOrder(overhangCB, overhangED);
        QWidget::setTabOrder(overhangED, overhangUnitLC);
        QWidget::setTabOrder(overhangUnitLC, linesCB);
        QWidget::setTabOrder(linesCB, linesSB);

        retranslateUi(WrapUi);
        QObject::connect(overhangCB, SIGNAL(toggled(bool)), overhangED, SLOT(setEnabled(bool)));
        QObject::connect(overhangCB, SIGNAL(toggled(bool)), overhangUnitLC, SLOT(setEnabled(bool)));
        QObject::connect(linesCB, SIGNAL(toggled(bool)), linesSB, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(WrapUi);
    } // setupUi

    void retranslateUi(QDialog *WrapUi)
    {
        WrapUi->setWindowTitle(QString());
        valignLA->setText(lyx::qt_("Pla&cement:", Q_NULLPTR));
        valignCO->clear();
        valignCO->insertItems(0, QStringList()
         << lyx::qt_("Outer (default)", Q_NULLPTR)
         << lyx::qt_("Inner", Q_NULLPTR)
         << lyx::qt_("Left", Q_NULLPTR)
         << lyx::qt_("Right", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        valignCO->setToolTip(lyx::qt_("Horizontal placement", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        floatCB->setToolTip(lyx::qt_("Check this to allow flexible placement", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        floatCB->setText(lyx::qt_("Allow &floating", Q_NULLPTR));
        widthLA->setText(lyx::qt_("Wid&th:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        widthED->setToolTip(lyx::qt_("Width value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        widthUnitLC->setToolTip(lyx::qt_("Unit of width value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        overhangCB->setToolTip(lyx::qt_("use overhang", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        overhangCB->setText(lyx::qt_("Over&hang:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        overhangED->setToolTip(lyx::qt_("Overhang value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        overhangUnitLC->setToolTip(lyx::qt_("Unit of overhang value", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        linesCB->setToolTip(lyx::qt_("use number of lines", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        linesCB->setText(lyx::qt_("&Line span:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        linesSB->setToolTip(lyx::qt_("number of needed lines", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class WrapUi: public Ui_WrapUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WRAPUI_H
