/********************************************************************************
** Form generated from reading UI file 'WorkAreaUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WORKAREAUI_H
#define UI_WORKAREAUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_WorkAreaUi
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *notificationFrame;
    QHBoxLayout *horizontalLayout_2;
    QLabel *externalModificationLabel;
    QSpacerItem *horizontalSpacer;
    QPushButton *reloadPB;
    QPushButton *ignorePB;

    void setupUi(QWidget *WorkAreaUi)
    {
        if (WorkAreaUi->objectName().isEmpty())
            WorkAreaUi->setObjectName(QStringLiteral("WorkAreaUi"));
        WorkAreaUi->resize(818, 69);
        verticalLayout = new QVBoxLayout(WorkAreaUi);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        notificationFrame = new QFrame(WorkAreaUi);
        notificationFrame->setObjectName(QStringLiteral("notificationFrame"));
        notificationFrame->setContextMenuPolicy(Qt::NoContextMenu);
        notificationFrame->setAutoFillBackground(true);
        notificationFrame->setFrameShape(QFrame::NoFrame);
        notificationFrame->setFrameShadow(QFrame::Plain);
        notificationFrame->setLineWidth(0);
        notificationFrame->setMidLineWidth(0);
        horizontalLayout_2 = new QHBoxLayout(notificationFrame);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(-1, 10, -1, 10);
        externalModificationLabel = new QLabel(notificationFrame);
        externalModificationLabel->setObjectName(QStringLiteral("externalModificationLabel"));
        externalModificationLabel->setText(QStringLiteral("<b>externalModificationLabel</b>"));
        externalModificationLabel->setWordWrap(true);

        horizontalLayout_2->addWidget(externalModificationLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        reloadPB = new QPushButton(notificationFrame);
        reloadPB->setObjectName(QStringLiteral("reloadPB"));

        horizontalLayout_2->addWidget(reloadPB);

        ignorePB = new QPushButton(notificationFrame);
        ignorePB->setObjectName(QStringLiteral("ignorePB"));

        horizontalLayout_2->addWidget(ignorePB);

        horizontalLayout_2->setStretch(0, 1);

        verticalLayout->addWidget(notificationFrame);


        retranslateUi(WorkAreaUi);

        QMetaObject::connectSlotsByName(WorkAreaUi);
    } // setupUi

    void retranslateUi(QWidget *WorkAreaUi)
    {
        reloadPB->setText(lyx::qt_("&Reload", Q_NULLPTR));
        ignorePB->setText(lyx::qt_("&Ignore", Q_NULLPTR));
        Q_UNUSED(WorkAreaUi);
    } // retranslateUi

};

namespace Ui {
    class WorkAreaUi: public Ui_WorkAreaUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WORKAREAUI_H
