/********************************************************************************
** Form generated from reading UI file 'PrefIdentityUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFIDENTITYUI_H
#define UI_PREFIDENTITYUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefIdentityUi
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *nameLA;
    QHBoxLayout *horizontalLayout;
    QLineEdit *nameED;
    QLabel *initialsLA;
    QLineEdit *initialsED;
    QLabel *emailLA;
    QLineEdit *emailED;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *PrefIdentityUi)
    {
        if (PrefIdentityUi->objectName().isEmpty())
            PrefIdentityUi->setObjectName(QStringLiteral("PrefIdentityUi"));
        PrefIdentityUi->resize(433, 135);
        gridLayout_2 = new QGridLayout(PrefIdentityUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        nameLA = new QLabel(PrefIdentityUi);
        nameLA->setObjectName(QStringLiteral("nameLA"));

        gridLayout->addWidget(nameLA, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        nameED = new QLineEdit(PrefIdentityUi);
        nameED->setObjectName(QStringLiteral("nameED"));

        horizontalLayout->addWidget(nameED);

        initialsLA = new QLabel(PrefIdentityUi);
        initialsLA->setObjectName(QStringLiteral("initialsLA"));

        horizontalLayout->addWidget(initialsLA);

        initialsED = new QLineEdit(PrefIdentityUi);
        initialsED->setObjectName(QStringLiteral("initialsED"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(initialsED->sizePolicy().hasHeightForWidth());
        initialsED->setSizePolicy(sizePolicy);
        initialsED->setMaximumSize(QSize(50, 16777215));

        horizontalLayout->addWidget(initialsED);


        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 1);

        emailLA = new QLabel(PrefIdentityUi);
        emailLA->setObjectName(QStringLiteral("emailLA"));

        gridLayout->addWidget(emailLA, 1, 0, 1, 1);

        emailED = new QLineEdit(PrefIdentityUi);
        emailED->setObjectName(QStringLiteral("emailED"));

        gridLayout->addWidget(emailED, 1, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(spacerItem, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        nameLA->setBuddy(nameED);
        initialsLA->setBuddy(initialsED);
        emailLA->setBuddy(emailED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(nameED, emailED);

        retranslateUi(PrefIdentityUi);

        QMetaObject::connectSlotsByName(PrefIdentityUi);
    } // setupUi

    void retranslateUi(QWidget *PrefIdentityUi)
    {
        PrefIdentityUi->setWindowTitle(QString());
        nameLA->setText(lyx::qt_("&Name:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nameED->setToolTip(lyx::qt_("Your name", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        initialsLA->setText(lyx::qt_("&Initials:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        initialsED->setToolTip(lyx::qt_("Initials of your name", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        emailLA->setText(lyx::qt_("&E-mail:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        emailED->setToolTip(lyx::qt_("Your E-mail address", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class PrefIdentityUi: public Ui_PrefIdentityUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFIDENTITYUI_H
