/****************************************************************************
** Meta object code from reading C++ file 'FindAndReplace.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/FindAndReplace.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FindAndReplace.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget_t {
    QByteArrayData data[11];
    char stringdata0[220];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget_t qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget = {
    {
QT_MOC_LITERAL(0, 0, 35), // "lyx::frontend::FindAndReplace..."
QT_MOC_LITERAL(1, 36, 19), // "dockLocationChanged"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 18), // "Qt::DockWidgetArea"
QT_MOC_LITERAL(4, 76, 4), // "area"
QT_MOC_LITERAL(5, 81, 21), // "on_findNextPB_clicked"
QT_MOC_LITERAL(6, 103, 20), // "on_replacePB_clicked"
QT_MOC_LITERAL(7, 124, 23), // "on_replaceallPB_clicked"
QT_MOC_LITERAL(8, 148, 23), // "on_searchbackCB_clicked"
QT_MOC_LITERAL(9, 172, 22), // "on_selectAllPB_clicked"
QT_MOC_LITERAL(10, 195, 24) // "on_deselectAllPB_clicked"

    },
    "lyx::frontend::FindAndReplaceWidget\0"
    "dockLocationChanged\0\0Qt::DockWidgetArea\0"
    "area\0on_findNextPB_clicked\0"
    "on_replacePB_clicked\0on_replaceallPB_clicked\0"
    "on_searchbackCB_clicked\0on_selectAllPB_clicked\0"
    "on_deselectAllPB_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__FindAndReplaceWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x0a /* Public */,
       5,    0,   52,    2, 0x09 /* Protected */,
       6,    0,   53,    2, 0x09 /* Protected */,
       7,    0,   54,    2, 0x09 /* Protected */,
       8,    0,   55,    2, 0x09 /* Protected */,
       9,    0,   56,    2, 0x09 /* Protected */,
      10,    0,   57,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::FindAndReplaceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FindAndReplaceWidget *_t = static_cast<FindAndReplaceWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dockLocationChanged((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        case 1: _t->on_findNextPB_clicked(); break;
        case 2: _t->on_replacePB_clicked(); break;
        case 3: _t->on_replaceallPB_clicked(); break;
        case 4: _t->on_searchbackCB_clicked(); break;
        case 5: _t->on_selectAllPB_clicked(); break;
        case 6: _t->on_deselectAllPB_clicked(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::FindAndReplaceWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget.data,
      qt_meta_data_lyx__frontend__FindAndReplaceWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::FindAndReplaceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::FindAndReplaceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__FindAndReplaceWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::FindAndReplaceUi"))
        return static_cast< Ui::FindAndReplaceUi*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int lyx::frontend::FindAndReplaceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__FindAndReplace_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__FindAndReplace_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__FindAndReplace_t qt_meta_stringdata_lyx__frontend__FindAndReplace = {
    {
QT_MOC_LITERAL(0, 0, 29) // "lyx::frontend::FindAndReplace"

    },
    "lyx::frontend::FindAndReplace"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__FindAndReplace[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void lyx::frontend::FindAndReplace::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::FindAndReplace::staticMetaObject = {
    { &DockView::staticMetaObject, qt_meta_stringdata_lyx__frontend__FindAndReplace.data,
      qt_meta_data_lyx__frontend__FindAndReplace,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::FindAndReplace::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::FindAndReplace::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__FindAndReplace.stringdata0))
        return static_cast<void*>(this);
    return DockView::qt_metacast(_clname);
}

int lyx::frontend::FindAndReplace::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockView::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
