/********************************************************************************
** Form generated from reading UI file 'PrefOutputUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFOUTPUTUI_H
#define UI_PREFOUTPUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefOutputUi
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QComboBox *dviCB;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_2;
    QComboBox *pdfCB;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLineEdit *printerPaperTypeED;
    QLabel *printerPaperTypeLA;
    QLineEdit *printerPaperSizeED;
    QLabel *printerPaperSizeLA;
    QLineEdit *printerLandscapeED;
    QLabel *printerLandscapeLA;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_6;
    QLabel *plaintextLinelengthLA;
    QSpinBox *plaintextLinelengthSB;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_4;
    QComboBox *overwriteCO;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PrefOutputUi)
    {
        if (PrefOutputUi->objectName().isEmpty())
            PrefOutputUi->setObjectName(QStringLiteral("PrefOutputUi"));
        PrefOutputUi->resize(356, 442);
        verticalLayout_3 = new QVBoxLayout(PrefOutputUi);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        groupBox = new QGroupBox(PrefOutputUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        groupBox->setCheckable(false);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        label = new QLabel(groupBox);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(label);

        dviCB = new QComboBox(groupBox);
        dviCB->setObjectName(QStringLiteral("dviCB"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(dviCB->sizePolicy().hasHeightForWidth());
        dviCB->setSizePolicy(sizePolicy1);
        dviCB->setEditable(true);
        dviCB->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_3->addWidget(dviCB);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(label_2);

        pdfCB = new QComboBox(groupBox);
        pdfCB->setObjectName(QStringLiteral("pdfCB"));
        sizePolicy1.setHeightForWidth(pdfCB->sizePolicy().hasHeightForWidth());
        pdfCB->setSizePolicy(sizePolicy1);
        pdfCB->setEditable(true);
        pdfCB->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_5->addWidget(pdfCB);


        verticalLayout->addLayout(horizontalLayout_5);


        verticalLayout_3->addWidget(groupBox);

        groupBox_2 = new QGroupBox(PrefOutputUi);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setFlat(true);
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        printerPaperTypeED = new QLineEdit(groupBox_2);
        printerPaperTypeED->setObjectName(QStringLiteral("printerPaperTypeED"));

        gridLayout->addWidget(printerPaperTypeED, 1, 2, 1, 1);

        printerPaperTypeLA = new QLabel(groupBox_2);
        printerPaperTypeLA->setObjectName(QStringLiteral("printerPaperTypeLA"));

        gridLayout->addWidget(printerPaperTypeLA, 1, 0, 1, 1);

        printerPaperSizeED = new QLineEdit(groupBox_2);
        printerPaperSizeED->setObjectName(QStringLiteral("printerPaperSizeED"));

        gridLayout->addWidget(printerPaperSizeED, 2, 2, 1, 1);

        printerPaperSizeLA = new QLabel(groupBox_2);
        printerPaperSizeLA->setObjectName(QStringLiteral("printerPaperSizeLA"));

        gridLayout->addWidget(printerPaperSizeLA, 2, 0, 1, 1);

        printerLandscapeED = new QLineEdit(groupBox_2);
        printerLandscapeED->setObjectName(QStringLiteral("printerLandscapeED"));

        gridLayout->addWidget(printerLandscapeED, 0, 2, 1, 1);

        printerLandscapeLA = new QLabel(groupBox_2);
        printerLandscapeLA->setObjectName(QStringLiteral("printerLandscapeLA"));

        gridLayout->addWidget(printerLandscapeLA, 0, 0, 1, 1);


        verticalLayout_3->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(PrefOutputUi);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        plaintextLinelengthLA = new QLabel(groupBox_3);
        plaintextLinelengthLA->setObjectName(QStringLiteral("plaintextLinelengthLA"));

        horizontalLayout_6->addWidget(plaintextLinelengthLA);

        plaintextLinelengthSB = new QSpinBox(groupBox_3);
        plaintextLinelengthSB->setObjectName(QStringLiteral("plaintextLinelengthSB"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(plaintextLinelengthSB->sizePolicy().hasHeightForWidth());
        plaintextLinelengthSB->setSizePolicy(sizePolicy2);
        plaintextLinelengthSB->setMaximum(120);

        horizontalLayout_6->addWidget(plaintextLinelengthSB);


        verticalLayout_2->addLayout(horizontalLayout_6);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QStringLiteral("horizontalLayout_8"));
        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName(QStringLiteral("label_4"));

        horizontalLayout_8->addWidget(label_4);

        overwriteCO = new QComboBox(groupBox_3);
        overwriteCO->setObjectName(QStringLiteral("overwriteCO"));

        horizontalLayout_8->addWidget(overwriteCO);


        verticalLayout_2->addLayout(horizontalLayout_8);


        verticalLayout_3->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 43, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

#ifndef QT_NO_SHORTCUT
        label->setBuddy(dviCB);
        label_2->setBuddy(pdfCB);
        printerPaperTypeLA->setBuddy(printerPaperTypeED);
        printerPaperSizeLA->setBuddy(printerPaperSizeED);
        printerLandscapeLA->setBuddy(printerLandscapeED);
        plaintextLinelengthLA->setBuddy(plaintextLinelengthSB);
        label_4->setBuddy(overwriteCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(PrefOutputUi);

        QMetaObject::connectSlotsByName(PrefOutputUi);
    } // setupUi

    void retranslateUi(QWidget *PrefOutputUi)
    {
        PrefOutputUi->setWindowTitle(QString());
        groupBox->setTitle(lyx::qt_("Forward Search", Q_NULLPTR));
        label->setText(lyx::qt_("DV&I command:", Q_NULLPTR));
        label_2->setText(lyx::qt_("&PDF command:", Q_NULLPTR));
        groupBox_2->setTitle(lyx::qt_("Dvips Options", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        printerPaperTypeED->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        printerPaperTypeLA->setText(lyx::qt_("Paper t&ype:", Q_NULLPTR));
        printerPaperSizeLA->setText(lyx::qt_("Paper si&ze:", Q_NULLPTR));
        printerLandscapeLA->setText(lyx::qt_("Lan&dscape:", Q_NULLPTR));
        groupBox_3->setTitle(lyx::qt_("Other Options", Q_NULLPTR));
        plaintextLinelengthLA->setText(lyx::qt_("Output &line length:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        plaintextLinelengthSB->setToolTip(lyx::qt_("The maximum line length of exported plain text/LaTeX/SGML files. If set to 0, paragraphs are output in a single line; if the line length is > 0, paragraphs are separated by a blank line.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_4->setText(lyx::qt_("&Overwrite on export:", Q_NULLPTR));
        overwriteCO->clear();
        overwriteCO->insertItems(0, QStringList()
         << lyx::qt_("Ask permission", Q_NULLPTR)
         << lyx::qt_("Main file only", Q_NULLPTR)
         << lyx::qt_("All files", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        overwriteCO->setToolTip(lyx::qt_("What to do when existing files are going to be overwritten on export.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class PrefOutputUi: public Ui_PrefOutputUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFOUTPUTUI_H
