/********************************************************************************
** Form generated from reading UI file 'MasterChildUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MASTERCHILDUI_H
#define UI_MASTERCHILDUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_MasterChildUi
{
public:
    QGridLayout *gridLayout_3;
    QGroupBox *includeonlyGB;
    QGridLayout *gridLayout_2;
    QRadioButton *includeonlyRB;
    QRadioButton *includeallRB;
    QGroupBox *maintainGB;
    QGridLayout *gridLayout;
    QRadioButton *maintainCRNoneRB;
    QRadioButton *maintainCRMostlyRB;
    QRadioButton *maintainCRStrictRB;
    QTreeWidget *childrenTW;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *MasterChildUi)
    {
        if (MasterChildUi->objectName().isEmpty())
            MasterChildUi->setObjectName(QStringLiteral("MasterChildUi"));
        MasterChildUi->resize(359, 444);
        gridLayout_3 = new QGridLayout(MasterChildUi);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        includeonlyGB = new QGroupBox(MasterChildUi);
        includeonlyGB->setObjectName(QStringLiteral("includeonlyGB"));
        includeonlyGB->setFlat(true);
        gridLayout_2 = new QGridLayout(includeonlyGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        includeonlyRB = new QRadioButton(includeonlyGB);
        buttonGroup = new QButtonGroup(MasterChildUi);
        buttonGroup->setObjectName(QStringLiteral("buttonGroup"));
        buttonGroup->addButton(includeonlyRB);
        includeonlyRB->setObjectName(QStringLiteral("includeonlyRB"));

        gridLayout_2->addWidget(includeonlyRB, 1, 0, 1, 1);

        includeallRB = new QRadioButton(includeonlyGB);
        buttonGroup->addButton(includeallRB);
        includeallRB->setObjectName(QStringLiteral("includeallRB"));

        gridLayout_2->addWidget(includeallRB, 0, 0, 1, 1);

        maintainGB = new QGroupBox(includeonlyGB);
        maintainGB->setObjectName(QStringLiteral("maintainGB"));
        gridLayout = new QGridLayout(maintainGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        maintainCRNoneRB = new QRadioButton(maintainGB);
        maintainCRNoneRB->setObjectName(QStringLiteral("maintainCRNoneRB"));

        gridLayout->addWidget(maintainCRNoneRB, 0, 0, 1, 1);

        maintainCRMostlyRB = new QRadioButton(maintainGB);
        maintainCRMostlyRB->setObjectName(QStringLiteral("maintainCRMostlyRB"));

        gridLayout->addWidget(maintainCRMostlyRB, 1, 0, 1, 1);

        maintainCRStrictRB = new QRadioButton(maintainGB);
        maintainCRStrictRB->setObjectName(QStringLiteral("maintainCRStrictRB"));

        gridLayout->addWidget(maintainCRStrictRB, 2, 0, 1, 1);


        gridLayout_2->addWidget(maintainGB, 3, 0, 1, 1);

        childrenTW = new QTreeWidget(includeonlyGB);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        childrenTW->setHeaderItem(__qtreewidgetitem);
        childrenTW->setObjectName(QStringLiteral("childrenTW"));

        gridLayout_2->addWidget(childrenTW, 2, 0, 1, 1);


        gridLayout_3->addWidget(includeonlyGB, 0, 0, 1, 1);


        retranslateUi(MasterChildUi);

        QMetaObject::connectSlotsByName(MasterChildUi);
    } // setupUi

    void retranslateUi(QWidget *MasterChildUi)
    {
        MasterChildUi->setWindowTitle(QString());
        includeonlyGB->setTitle(lyx::qt_("Master Document Output", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        includeonlyRB->setToolTip(lyx::qt_("Include only the selected subdocuments in the output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        includeonlyRB->setText(lyx::qt_("Include only &selected children", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        includeallRB->setToolTip(lyx::qt_("Include all subdocuments in the output", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        includeallRB->setText(lyx::qt_("&Include all children", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        maintainGB->setToolTip(lyx::qt_("Here you can set up the handling of counters and references with regard to the excluded child documents.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        maintainGB->setTitle(lyx::qt_("Global Counters && References", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        maintainCRNoneRB->setToolTip(lyx::qt_("All counters and references of excluded child documents will be ignored, thus the counters in the output will differ from an output of the complete document.<br>This is the fastest method. Use this if you do not need correct counter values and references.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        maintainCRNoneRB->setText(lyx::qt_("Do &not maintain (fast)", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        maintainCRMostlyRB->setToolTip(lyx::qt_("Counters and references of excluded child documents will be set up once and adapted if an excluded document has been modified. This sets up counters and references correctly in most cases, but it does not adjust page references to unincluded children that change due to changes of included files.<br>This is significantly faster than \"Strictly maintain\". Use this if you need correct counters and more or less correct references.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        maintainCRMostlyRB->setText(lyx::qt_("Maintain mostl&y (medium)", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        maintainCRStrictRB->setToolTip(lyx::qt_("Assure that all counters and references are identical to the complete document. This can be much slower than the first two methods.<br>Use this if you absolutely need correct counters.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        maintainCRStrictRB->setText(lyx::qt_("Strictly &maintain (slow)", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class MasterChildUi: public Ui_MasterChildUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MASTERCHILDUI_H
