/********************************************************************************
** Form generated from reading UI file 'BranchesUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRANCHESUI_H
#define UI_BRANCHESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BranchesUi
{
public:
    QGridLayout *gridLayout;
    QPushButton *suffixPB;
    QSpacerItem *spacerItem;
    QLabel *availableLB;
    QPushButton *removePB;
    QPushButton *unknownPB;
    QTreeWidget *branchesTW;
    QPushButton *activatePB;
    QPushButton *addBranchPB;
    QPushButton *colorPB;
    QPushButton *renamePB;
    QLabel *newBranchLA;
    QLineEdit *newBranchLE;
    QSpacerItem *spacerItem1;
    QPushButton *resetColorPB;

    void setupUi(QWidget *BranchesUi)
    {
        if (BranchesUi->objectName().isEmpty())
            BranchesUi->setObjectName(QStringLiteral("BranchesUi"));
        BranchesUi->resize(401, 346);
        gridLayout = new QGridLayout(BranchesUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        suffixPB = new QPushButton(BranchesUi);
        suffixPB->setObjectName(QStringLiteral("suffixPB"));

        gridLayout->addWidget(suffixPB, 6, 3, 1, 1);

        spacerItem = new QSpacerItem(83, 51, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 7, 3, 1, 1);

        availableLB = new QLabel(BranchesUi);
        availableLB->setObjectName(QStringLiteral("availableLB"));

        gridLayout->addWidget(availableLB, 1, 0, 1, 3);

        removePB = new QPushButton(BranchesUi);
        removePB->setObjectName(QStringLiteral("removePB"));

        gridLayout->addWidget(removePB, 2, 3, 1, 1);

        unknownPB = new QPushButton(BranchesUi);
        unknownPB->setObjectName(QStringLiteral("unknownPB"));

        gridLayout->addWidget(unknownPB, 9, 2, 1, 2);

        branchesTW = new QTreeWidget(BranchesUi);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        branchesTW->setHeaderItem(__qtreewidgetitem);
        branchesTW->setObjectName(QStringLiteral("branchesTW"));

        gridLayout->addWidget(branchesTW, 2, 0, 7, 3);

        activatePB = new QPushButton(BranchesUi);
        activatePB->setObjectName(QStringLiteral("activatePB"));

        gridLayout->addWidget(activatePB, 8, 3, 1, 1);

        addBranchPB = new QPushButton(BranchesUi);
        addBranchPB->setObjectName(QStringLiteral("addBranchPB"));
        addBranchPB->setEnabled(false);

        gridLayout->addWidget(addBranchPB, 0, 3, 1, 1);

        colorPB = new QPushButton(BranchesUi);
        colorPB->setObjectName(QStringLiteral("colorPB"));

        gridLayout->addWidget(colorPB, 4, 3, 1, 1);

        renamePB = new QPushButton(BranchesUi);
        renamePB->setObjectName(QStringLiteral("renamePB"));

        gridLayout->addWidget(renamePB, 3, 3, 1, 1);

        newBranchLA = new QLabel(BranchesUi);
        newBranchLA->setObjectName(QStringLiteral("newBranchLA"));

        gridLayout->addWidget(newBranchLA, 0, 0, 1, 1);

        newBranchLE = new QLineEdit(BranchesUi);
        newBranchLE->setObjectName(QStringLiteral("newBranchLE"));

        gridLayout->addWidget(newBranchLE, 0, 1, 1, 2);

        spacerItem1 = new QSpacerItem(251, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 9, 0, 1, 2);

        resetColorPB = new QPushButton(BranchesUi);
        resetColorPB->setObjectName(QStringLiteral("resetColorPB"));

        gridLayout->addWidget(resetColorPB, 5, 3, 1, 1);

#ifndef QT_NO_SHORTCUT
        availableLB->setBuddy(branchesTW);
        newBranchLA->setBuddy(newBranchLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(newBranchLE, addBranchPB);
        QWidget::setTabOrder(addBranchPB, branchesTW);
        QWidget::setTabOrder(branchesTW, removePB);
        QWidget::setTabOrder(removePB, renamePB);
        QWidget::setTabOrder(renamePB, colorPB);
        QWidget::setTabOrder(colorPB, suffixPB);
        QWidget::setTabOrder(suffixPB, activatePB);
        QWidget::setTabOrder(activatePB, unknownPB);

        retranslateUi(BranchesUi);

        QMetaObject::connectSlotsByName(BranchesUi);
    } // setupUi

    void retranslateUi(QWidget *BranchesUi)
    {
        BranchesUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        suffixPB->setToolTip(lyx::qt_("Append the name of this branch to the output filename, given the branch is active.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        suffixPB->setText(lyx::qt_("Filename &Suffix", Q_NULLPTR));
        availableLB->setText(lyx::qt_("A&vailable Branches:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        removePB->setToolTip(lyx::qt_("Remove the selected branch", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        removePB->setText(lyx::qt_("&Remove", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        unknownPB->setToolTip(lyx::qt_("Show undefined branches used in this document.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        unknownPB->setText(lyx::qt_("&Undefined Branches", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        activatePB->setToolTip(lyx::qt_("Toggle the selected branch", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        activatePB->setText(lyx::qt_("(&De)activate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        addBranchPB->setToolTip(lyx::qt_("Add a new branch to the list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addBranchPB->setText(lyx::qt_("&Add", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorPB->setToolTip(lyx::qt_("Define or change background color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorPB->setText(lyx::qt_("Alter Co&lor...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        renamePB->setToolTip(lyx::qt_("Change the name of the selected branch", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        renamePB->setText(lyx::qt_("Re&name...", Q_NULLPTR));
        newBranchLA->setText(lyx::qt_("&New:[[branch]]", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        resetColorPB->setToolTip(lyx::qt_("Reset branch color to default (standard background)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        resetColorPB->setText(lyx::qt_("R&eset Color", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BranchesUi: public Ui_BranchesUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BRANCHESUI_H
