/********************************************************************************
** Form generated from reading UI file 'OutputUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OUTPUTUI_H
#define UI_OUTPUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_OutputUi
{
public:
    QGridLayout *gridLayout_5;
    QVBoxLayout *verticalLayout;
    QGroupBox *savingGB;
    QGridLayout *gridLayout7;
    QCheckBox *saveTransientPropertiesCB;
    QGroupBox *outputFormatGB;
    QGridLayout *gridlayout8;
    QHBoxLayout *hboxLayout;
    QLabel *defaultFormatLA;
    QComboBox *defaultFormatCO;
    QSpacerItem *horizontalSpacer;
    QGroupBox *outputOptionsGB;
    QGridLayout *gridLayout_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *mathimgLA;
    QDoubleSpinBox *mathimgSB;
    QSpacerItem *horizontalSpacer_7;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_2;
    QCheckBox *postponeFragileCB;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *outputsyncCB;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout;
    QLabel *synccustomLA;
    QComboBox *synccustomCB;
    QSpacerItem *horizontalSpacer_2;
    QWidget *tab_2;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *strictCB;
    QCheckBox *cssCB;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_5;
    QLabel *mathoutLA;
    QComboBox *mathoutCB;
    QSpacerItem *horizontalSpacer_3;
    QWidget *tab_3;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_6;
    QLabel *tableoutLA;
    QComboBox *tableoutCB;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_7;
    QLabel *mathmlprefixLA;
    QComboBox *mathmlprefixCB;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *shellescapeCB;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *OutputUi)
    {
        if (OutputUi->objectName().isEmpty())
            OutputUi->setObjectName(QStringLiteral("OutputUi"));
        OutputUi->resize(702, 501);
        gridLayout_5 = new QGridLayout(OutputUi);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        savingGB = new QGroupBox(OutputUi);
        savingGB->setObjectName(QStringLiteral("savingGB"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(savingGB->sizePolicy().hasHeightForWidth());
        savingGB->setSizePolicy(sizePolicy);
        savingGB->setFlat(true);
        savingGB->setCheckable(false);
        gridLayout7 = new QGridLayout(savingGB);
        gridLayout7->setObjectName(QStringLiteral("gridLayout7"));
        saveTransientPropertiesCB = new QCheckBox(savingGB);
        saveTransientPropertiesCB->setObjectName(QStringLiteral("saveTransientPropertiesCB"));

        gridLayout7->addWidget(saveTransientPropertiesCB, 0, 0, 1, 1);


        verticalLayout->addWidget(savingGB);

        outputFormatGB = new QGroupBox(OutputUi);
        outputFormatGB->setObjectName(QStringLiteral("outputFormatGB"));
        sizePolicy.setHeightForWidth(outputFormatGB->sizePolicy().hasHeightForWidth());
        outputFormatGB->setSizePolicy(sizePolicy);
        outputFormatGB->setFlat(true);
        gridlayout8 = new QGridLayout(outputFormatGB);
        gridlayout8->setSpacing(6);
        gridlayout8->setObjectName(QStringLiteral("gridlayout8"));
        gridlayout8->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        defaultFormatLA = new QLabel(outputFormatGB);
        defaultFormatLA->setObjectName(QStringLiteral("defaultFormatLA"));

        hboxLayout->addWidget(defaultFormatLA);

        defaultFormatCO = new QComboBox(outputFormatGB);
        defaultFormatCO->setObjectName(QStringLiteral("defaultFormatCO"));

        hboxLayout->addWidget(defaultFormatCO);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        gridlayout8->addLayout(hboxLayout, 0, 0, 1, 1);


        verticalLayout->addWidget(outputFormatGB);

        outputOptionsGB = new QGroupBox(OutputUi);
        outputOptionsGB->setObjectName(QStringLiteral("outputOptionsGB"));
        sizePolicy.setHeightForWidth(outputOptionsGB->sizePolicy().hasHeightForWidth());
        outputOptionsGB->setSizePolicy(sizePolicy);
        gridLayout_4 = new QGridLayout(outputOptionsGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        mathimgLA = new QLabel(outputOptionsGB);
        mathimgLA->setObjectName(QStringLiteral("mathimgLA"));
        QFont font;
        font.setBold(false);
        mathimgLA->setFont(font);

        horizontalLayout_3->addWidget(mathimgLA);

        mathimgSB = new QDoubleSpinBox(outputOptionsGB);
        mathimgSB->setObjectName(QStringLiteral("mathimgSB"));
        mathimgSB->setFont(font);
        mathimgSB->setMinimum(0.1);
        mathimgSB->setMaximum(10);
        mathimgSB->setSingleStep(0.1);
        mathimgSB->setValue(1);

        horizontalLayout_3->addWidget(mathimgSB);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_7);


        gridLayout_4->addLayout(horizontalLayout_3, 1, 0, 1, 1);

        tabWidget = new QTabWidget(outputOptionsGB);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout_2 = new QGridLayout(tab);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        postponeFragileCB = new QCheckBox(tab);
        postponeFragileCB->setObjectName(QStringLiteral("postponeFragileCB"));

        gridLayout_2->addWidget(postponeFragileCB, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        outputsyncCB = new QCheckBox(tab);
        outputsyncCB->setObjectName(QStringLiteral("outputsyncCB"));

        horizontalLayout_2->addWidget(outputsyncCB);

        horizontalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        synccustomLA = new QLabel(tab);
        synccustomLA->setObjectName(QStringLiteral("synccustomLA"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(synccustomLA->sizePolicy().hasHeightForWidth());
        synccustomLA->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(synccustomLA);

        synccustomCB = new QComboBox(tab);
        synccustomCB->setObjectName(QStringLiteral("synccustomCB"));
        synccustomCB->setEditable(true);

        horizontalLayout->addWidget(synccustomCB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        horizontalLayout_2->addLayout(horizontalLayout);


        gridLayout_2->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout_3 = new QGridLayout(tab_2);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        strictCB = new QCheckBox(tab_2);
        strictCB->setObjectName(QStringLiteral("strictCB"));

        horizontalLayout_4->addWidget(strictCB);

        cssCB = new QCheckBox(tab_2);
        cssCB->setObjectName(QStringLiteral("cssCB"));

        horizontalLayout_4->addWidget(cssCB);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_8);


        gridLayout_3->addLayout(horizontalLayout_4, 0, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        mathoutLA = new QLabel(tab_2);
        mathoutLA->setObjectName(QStringLiteral("mathoutLA"));
        mathoutLA->setFont(font);

        horizontalLayout_5->addWidget(mathoutLA);

        mathoutCB = new QComboBox(tab_2);
        mathoutCB->setObjectName(QStringLiteral("mathoutCB"));
        mathoutCB->setFont(font);

        horizontalLayout_5->addWidget(mathoutCB);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        gridLayout_3->addLayout(horizontalLayout_5, 1, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        gridLayout = new QGridLayout(tab_3);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        tableoutLA = new QLabel(tab_3);
        tableoutLA->setObjectName(QStringLiteral("tableoutLA"));
        tableoutLA->setFont(font);

        horizontalLayout_6->addWidget(tableoutLA);

        tableoutCB = new QComboBox(tab_3);
        tableoutCB->setObjectName(QStringLiteral("tableoutCB"));
        QSizePolicy sizePolicy3(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(tableoutCB->sizePolicy().hasHeightForWidth());
        tableoutCB->setSizePolicy(sizePolicy3);
        tableoutCB->setFont(font);

        horizontalLayout_6->addWidget(tableoutCB);

        horizontalSpacer_5 = new QSpacerItem(178, 38, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_5);


        gridLayout->addLayout(horizontalLayout_6, 0, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        mathmlprefixLA = new QLabel(tab_3);
        mathmlprefixLA->setObjectName(QStringLiteral("mathmlprefixLA"));
        mathmlprefixLA->setFont(font);

        horizontalLayout_7->addWidget(mathmlprefixLA);

        mathmlprefixCB = new QComboBox(tab_3);
        mathmlprefixCB->setObjectName(QStringLiteral("mathmlprefixCB"));
        sizePolicy3.setHeightForWidth(mathmlprefixCB->sizePolicy().hasHeightForWidth());
        mathmlprefixCB->setSizePolicy(sizePolicy3);
        mathmlprefixCB->setFont(font);

        horizontalLayout_7->addWidget(mathmlprefixCB);

        horizontalSpacer_6 = new QSpacerItem(148, 28, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_6);


        gridLayout->addLayout(horizontalLayout_7, 1, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());

        gridLayout_4->addWidget(tabWidget, 0, 0, 1, 1);


        verticalLayout->addWidget(outputOptionsGB);

        shellescapeCB = new QCheckBox(OutputUi);
        shellescapeCB->setObjectName(QStringLiteral("shellescapeCB"));

        verticalLayout->addWidget(shellescapeCB);


        gridLayout_5->addLayout(verticalLayout, 0, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_5->addItem(verticalSpacer_4, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        defaultFormatLA->setBuddy(defaultFormatCO);
        mathimgLA->setBuddy(mathimgSB);
        synccustomLA->setBuddy(synccustomCB);
        mathoutLA->setBuddy(tableoutCB);
        tableoutLA->setBuddy(tableoutCB);
        mathmlprefixLA->setBuddy(mathmlprefixCB);
#endif // QT_NO_SHORTCUT

        retranslateUi(OutputUi);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OutputUi);
    } // setupUi

    void retranslateUi(QWidget *OutputUi)
    {
        OutputUi->setWindowTitle(lyx::qt_("Form", Q_NULLPTR));
        savingGB->setTitle(lyx::qt_("LyX Format", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        saveTransientPropertiesCB->setToolTip(lyx::qt_("Save all parameters in the LyX file, including ones that are frequently switched or that are specific to the user (such as the output of the tracked changes, or the document directory path). Disabling this option plays nicer in collaborative settings and with version control systems.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        saveTransientPropertiesCB->setText(lyx::qt_("Save &transient properties", Q_NULLPTR));
        outputFormatGB->setTitle(lyx::qt_("Output Format", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultFormatLA->setToolTip(lyx::qt_("Specify the default output format (for view/update)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultFormatLA->setText(lyx::qt_("De&fault output format:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultFormatCO->setToolTip(lyx::qt_("Specify the default output format (for view/update)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        outputOptionsGB->setTitle(lyx::qt_("Output Options", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        mathimgLA->setToolTip(lyx::qt_("Scaling factor for images that are generated for some LaTeX constructs (e.g., math formulae) in non-LaTeX output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        mathimgLA->setText(lyx::qt_("Scaling of generated &images:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        mathimgSB->setToolTip(lyx::qt_("Scaling factor for images that are generated for some LaTeX constructs (e.g., math formulae) in non-LaTeX output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        postponeFragileCB->setToolTip(lyx::qt_("If this is checked, fragile items such as labels and index entries are moved out of moving arguments such as sections and captions. This prevents LaTeX errors that can happen in such cases. It is recommended to keep this on.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        postponeFragileCB->setText(lyx::qt_("Put fra&gile content out of moving arguments", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        outputsyncCB->setToolTip(lyx::qt_("Enable forward/reverse search between editor and output (e.g., SyncTeX)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        outputsyncCB->setText(lyx::qt_("S&ynchronize with output", Q_NULLPTR));
        synccustomLA->setText(lyx::qt_("C&ustom macro:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        synccustomCB->setToolTip(lyx::qt_("Custom LaTeX preamble macro", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tabWidget->setTabText(tabWidget->indexOf(tab), lyx::qt_("&LaTeX", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        strictCB->setToolTip(lyx::qt_("Whether to comply strictly with XHTML 1.1.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        strictCB->setText(lyx::qt_("&Strict XHTML 1.1", Q_NULLPTR));
        cssCB->setText(lyx::qt_("Write CSS to file", Q_NULLPTR));
        mathoutLA->setText(lyx::qt_("&Math output:", Q_NULLPTR));
        mathoutCB->clear();
        mathoutCB->insertItems(0, QStringList()
         << lyx::qt_("MathML", Q_NULLPTR)
         << lyx::qt_("HTML", Q_NULLPTR)
         << lyx::qt_("Images", Q_NULLPTR)
         << lyx::qt_("LaTeX", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        mathoutCB->setToolTip(lyx::qt_("Format to use for math output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tabWidget->setTabText(tabWidget->indexOf(tab_2), lyx::qt_("&XHTML", Q_NULLPTR));
        tableoutLA->setText(lyx::qt_("&Table output:", Q_NULLPTR));
        tableoutCB->clear();
        tableoutCB->insertItems(0, QStringList()
         << lyx::qt_("HTML", Q_NULLPTR)
         << lyx::qt_("CALS", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        tableoutCB->setToolTip(lyx::qt_("Format to use for math output.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        mathmlprefixLA->setText(lyx::qt_("&MathML namespace prefix:", Q_NULLPTR));
        mathmlprefixCB->clear();
        mathmlprefixCB->insertItems(0, QStringList()
         << lyx::qt_("No prefix (namespace defined inline for each tag)", Q_NULLPTR)
         << lyx::qt_("m (default)", Q_NULLPTR)
         << lyx::qt_("mml", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        mathmlprefixCB->setToolTip(lyx::qt_("Namespace prefix to use for MathML formulae. For instance, with the <code>m</code> prefix, the MathML tags will be output like <code>m:math</code>.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tabWidget->setTabText(tabWidget->indexOf(tab_3), lyx::qt_("&DocBook", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        shellescapeCB->setToolTip(lyx::qt_("Runs the LaTeX backend with the -shell-escape option (Warning: use only when really necessary)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        shellescapeCB->setText(lyx::qt_("&Allow running external programs", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class OutputUi: public Ui_OutputUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OUTPUTUI_H
