/********************************************************************************
** Form generated from reading UI file 'InfoUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INFOUI_H
#define UI_INFOUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_InfoUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *typeLA;
    QComboBox *typeCO;
    QListWidget *infoLW;
    QHBoxLayout *horizontalLayout_3;
    QLabel *fixDateLA;
    QLineEdit *fixDateLE;
    QHBoxLayout *horizontalLayout;
    QLabel *nameLA;
    QLineEdit *nameLE;

    void setupUi(QWidget *InfoUi)
    {
        if (InfoUi->objectName().isEmpty())
            InfoUi->setObjectName(QStringLiteral("InfoUi"));
        InfoUi->resize(320, 311);
        InfoUi->setProperty("sizeGripEnabled", QVariant(true));
        gridLayout = new QGridLayout(InfoUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        typeLA = new QLabel(InfoUi);
        typeLA->setObjectName(QStringLiteral("typeLA"));

        horizontalLayout_2->addWidget(typeLA);

        typeCO = new QComboBox(InfoUi);
        typeCO->setObjectName(QStringLiteral("typeCO"));

        horizontalLayout_2->addWidget(typeCO);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        infoLW = new QListWidget(InfoUi);
        infoLW->setObjectName(QStringLiteral("infoLW"));

        gridLayout->addWidget(infoLW, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        fixDateLA = new QLabel(InfoUi);
        fixDateLA->setObjectName(QStringLiteral("fixDateLA"));

        horizontalLayout_3->addWidget(fixDateLA);

        fixDateLE = new QLineEdit(InfoUi);
        fixDateLE->setObjectName(QStringLiteral("fixDateLE"));

        horizontalLayout_3->addWidget(fixDateLE);


        gridLayout->addLayout(horizontalLayout_3, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        nameLA = new QLabel(InfoUi);
        nameLA->setObjectName(QStringLiteral("nameLA"));

        horizontalLayout->addWidget(nameLA);

        nameLE = new QLineEdit(InfoUi);
        nameLE->setObjectName(QStringLiteral("nameLE"));

        horizontalLayout->addWidget(nameLE);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        typeLA->setBuddy(typeCO);
        fixDateLA->setBuddy(fixDateLE);
        nameLA->setBuddy(nameLE);
#endif // QT_NO_SHORTCUT

        retranslateUi(InfoUi);

        QMetaObject::connectSlotsByName(InfoUi);
    } // setupUi

    void retranslateUi(QWidget *InfoUi)
    {
        InfoUi->setWindowTitle(QString());
        typeLA->setText(lyx::qt_("Infor&mation Type:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        typeCO->setToolTip(lyx::qt_("Select the type of information to be output. Then specify the requested information below.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fixDateLA->setText(lyx::qt_("&Fixed Date:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fixDateLE->setToolTip(lyx::qt_("Here you can enter a fixed date (in ISO format: YYYY-MM-DD)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nameLA->setText(lyx::qt_("&Custom:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class InfoUi: public Ui_InfoUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INFOUI_H
