/****************************************************************************
** Meta object code from reading C++ file 'FancyLineEdit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/FancyLineEdit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FancyLineEdit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__IconButton_t {
    QByteArrayData data[4];
    char stringdata0[54];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__IconButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__IconButton_t qt_meta_stringdata_lyx__frontend__IconButton = {
    {
QT_MOC_LITERAL(0, 0, 25), // "lyx::frontend::IconButton"
QT_MOC_LITERAL(1, 26, 11), // "iconOpacity"
QT_MOC_LITERAL(2, 38, 8), // "autoHide"
QT_MOC_LITERAL(3, 47, 6) // "pixmap"

    },
    "lyx::frontend::IconButton\0iconOpacity\0"
    "autoHide\0pixmap"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__IconButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       3,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Float, 0x00095103,
       2, QMetaType::Bool, 0x00095103,
       3, QMetaType::QPixmap, 0x00095103,

       0        // eod
};

void lyx::frontend::IconButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        IconButton *_t = static_cast<IconButton *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< float*>(_v) = _t->iconOpacity(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->hasAutoHide(); break;
        case 2: *reinterpret_cast< QPixmap*>(_v) = _t->pixmap(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        IconButton *_t = static_cast<IconButton *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIconOpacity(*reinterpret_cast< float*>(_v)); break;
        case 1: _t->setAutoHide(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setPixmap(*reinterpret_cast< QPixmap*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::IconButton::staticMetaObject = {
    { &QAbstractButton::staticMetaObject, qt_meta_stringdata_lyx__frontend__IconButton.data,
      qt_meta_data_lyx__frontend__IconButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::IconButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::IconButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__IconButton.stringdata0))
        return static_cast<void*>(this);
    return QAbstractButton::qt_metacast(_clname);
}

int lyx::frontend::IconButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
   if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__FancyLineEdit_t {
    QByteArrayData data[12];
    char stringdata0[139];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__FancyLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__FancyLineEdit_t qt_meta_stringdata_lyx__frontend__FancyLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 28), // "lyx::frontend::FancyLineEdit"
QT_MOC_LITERAL(1, 29, 13), // "buttonClicked"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 4), // "Side"
QT_MOC_LITERAL(4, 49, 4), // "side"
QT_MOC_LITERAL(5, 54, 17), // "leftButtonClicked"
QT_MOC_LITERAL(6, 72, 18), // "rightButtonClicked"
QT_MOC_LITERAL(7, 91, 11), // "downPressed"
QT_MOC_LITERAL(8, 103, 12), // "checkButtons"
QT_MOC_LITERAL(9, 116, 11), // "iconClicked"
QT_MOC_LITERAL(10, 128, 4), // "Left"
QT_MOC_LITERAL(11, 133, 5) // "Right"

    },
    "lyx::frontend::FancyLineEdit\0buttonClicked\0"
    "\0Side\0side\0leftButtonClicked\0"
    "rightButtonClicked\0downPressed\0"
    "checkButtons\0iconClicked\0Left\0Right"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__FancyLineEdit[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       1,   54, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,
       7,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   50,    2, 0x08 /* Private */,
       9,    0,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

 // enums: name, flags, count, data
       3, 0x0,    2,   58,

 // enum data: key, value
      10, uint(lyx::frontend::FancyLineEdit::Left),
      11, uint(lyx::frontend::FancyLineEdit::Right),

       0        // eod
};

void lyx::frontend::FancyLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FancyLineEdit *_t = static_cast<FancyLineEdit *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->buttonClicked((*reinterpret_cast< Side(*)>(_a[1]))); break;
        case 1: _t->leftButtonClicked(); break;
        case 2: _t->rightButtonClicked(); break;
        case 3: _t->downPressed(); break;
        case 4: _t->checkButtons((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->iconClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FancyLineEdit::*_t)(Side );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FancyLineEdit::buttonClicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FancyLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FancyLineEdit::leftButtonClicked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (FancyLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FancyLineEdit::rightButtonClicked)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (FancyLineEdit::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FancyLineEdit::downPressed)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::FancyLineEdit::staticMetaObject = {
    { &QLineEdit::staticMetaObject, qt_meta_stringdata_lyx__frontend__FancyLineEdit.data,
      qt_meta_data_lyx__frontend__FancyLineEdit,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::FancyLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::FancyLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__FancyLineEdit.stringdata0))
        return static_cast<void*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int lyx::frontend::FancyLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::FancyLineEdit::buttonClicked(Side _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void lyx::frontend::FancyLineEdit::leftButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void lyx::frontend::FancyLineEdit::rightButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void lyx::frontend::FancyLineEdit::downPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
