/********************************************************************************
** Form generated from reading UI file 'FindAndReplaceUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FINDANDREPLACEUI_H
#define UI_FINDANDREPLACEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "GuiWorkArea.h"

QT_BEGIN_NAMESPACE

class Ui_FindAndReplaceUi
{
public:
    QWidget *basicTab;
    QVBoxLayout *dynamicLayoutBasic_;
    QVBoxLayout *findLayout;
    QGridLayout *gridLayout;
    QLabel *findLabel;
    lyx::frontend::EmbeddedWorkArea *find_work_area_;
    QVBoxLayout *replaceLayout;
    QGridLayout *gridLayout_3;
    QLabel *replaceLabel;
    lyx::frontend::EmbeddedWorkArea *replace_work_area_;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *cbVerticalLayout;
    QCheckBox *searchbackCB;
    QCheckBox *wordsCB;
    QCheckBox *caseCB;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *pbVerticalLayout;
    QPushButton *findNextPB;
    QPushButton *replacePB;
    QPushButton *replaceallPB;
    QSpacerItem *verticalSpacer_4;
    QWidget *advancedTab;
    QVBoxLayout *dynamicLayoutAdvanced_;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QRadioButton *CurrentDocument;
    QRadioButton *MasterDocument;
    QRadioButton *OpenDocuments;
    QRadioButton *AllManualsRB;
    QSpacerItem *verticalSpacer;
    QGridLayout *gridLayout_2;
    QCheckBox *expandMacrosCB;
    QCheckBox *OnlyMaths;
    QCheckBox *keepCaseCB;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *ignoreNonOutputCB;
    QSpacerItem *verticalSpacer_5;
    QGroupBox *adhereFormatGB;
    QGridLayout *gridLayout_4;
    QCheckBox *adhereSectioningCB;
    QCheckBox *adhereDeletedCB;
    QCheckBox *adhereFSeriesCB;
    QCheckBox *adhereMarkupCB;
    QCheckBox *adhereFFamilyCB;
    QCheckBox *adhereColorCB;
    QCheckBox *adhereFShapeCB;
    QCheckBox *adhereStrikeCB;
    QCheckBox *adhereLanguageCB;
    QPushButton *deselectAllPB;
    QCheckBox *adhereUnderlineCB;
    QCheckBox *adhereFSizeCB;
    QPushButton *selectAllPB;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QTabWidget *FindAndReplaceUi)
    {
        if (FindAndReplaceUi->objectName().isEmpty())
            FindAndReplaceUi->setObjectName(QStringLiteral("FindAndReplaceUi"));
        FindAndReplaceUi->resize(394, 648);
        basicTab = new QWidget();
        basicTab->setObjectName(QStringLiteral("basicTab"));
        dynamicLayoutBasic_ = new QVBoxLayout(basicTab);
        dynamicLayoutBasic_->setSpacing(0);
        dynamicLayoutBasic_->setObjectName(QStringLiteral("dynamicLayoutBasic_"));
        dynamicLayoutBasic_->setContentsMargins(0, 0, 0, 0);
        findLayout = new QVBoxLayout();
        findLayout->setObjectName(QStringLiteral("findLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(6, 6, 6, -1);
        findLabel = new QLabel(basicTab);
        findLabel->setObjectName(QStringLiteral("findLabel"));

        gridLayout->addWidget(findLabel, 0, 0, 1, 1);


        findLayout->addLayout(gridLayout);

        find_work_area_ = new lyx::frontend::EmbeddedWorkArea(basicTab);
        find_work_area_->setObjectName(QStringLiteral("find_work_area_"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(find_work_area_->sizePolicy().hasHeightForWidth());
        find_work_area_->setSizePolicy(sizePolicy);

        findLayout->addWidget(find_work_area_);


        dynamicLayoutBasic_->addLayout(findLayout);

        replaceLayout = new QVBoxLayout();
        replaceLayout->setObjectName(QStringLiteral("replaceLayout"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        gridLayout_3->setContentsMargins(6, 6, 6, -1);
        replaceLabel = new QLabel(basicTab);
        replaceLabel->setObjectName(QStringLiteral("replaceLabel"));

        gridLayout_3->addWidget(replaceLabel, 0, 0, 1, 1);


        replaceLayout->addLayout(gridLayout_3);

        replace_work_area_ = new lyx::frontend::EmbeddedWorkArea(basicTab);
        replace_work_area_->setObjectName(QStringLiteral("replace_work_area_"));
        sizePolicy.setHeightForWidth(replace_work_area_->sizePolicy().hasHeightForWidth());
        replace_work_area_->setSizePolicy(sizePolicy);

        replaceLayout->addWidget(replace_work_area_);


        dynamicLayoutBasic_->addLayout(replaceLayout);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        cbVerticalLayout = new QVBoxLayout();
        cbVerticalLayout->setSpacing(6);
        cbVerticalLayout->setObjectName(QStringLiteral("cbVerticalLayout"));
        cbVerticalLayout->setContentsMargins(6, 6, 6, 6);
        searchbackCB = new QCheckBox(basicTab);
        searchbackCB->setObjectName(QStringLiteral("searchbackCB"));

        cbVerticalLayout->addWidget(searchbackCB);

        wordsCB = new QCheckBox(basicTab);
        wordsCB->setObjectName(QStringLiteral("wordsCB"));
        wordsCB->setEnabled(true);

        cbVerticalLayout->addWidget(wordsCB);

        caseCB = new QCheckBox(basicTab);
        caseCB->setObjectName(QStringLiteral("caseCB"));

        cbVerticalLayout->addWidget(caseCB);


        horizontalLayout->addLayout(cbVerticalLayout);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pbVerticalLayout = new QVBoxLayout();
        pbVerticalLayout->setSpacing(6);
        pbVerticalLayout->setObjectName(QStringLiteral("pbVerticalLayout"));
        pbVerticalLayout->setContentsMargins(6, 6, 6, 6);
        findNextPB = new QPushButton(basicTab);
        findNextPB->setObjectName(QStringLiteral("findNextPB"));
        findNextPB->setEnabled(true);

        pbVerticalLayout->addWidget(findNextPB);

        replacePB = new QPushButton(basicTab);
        replacePB->setObjectName(QStringLiteral("replacePB"));
        replacePB->setEnabled(true);

        pbVerticalLayout->addWidget(replacePB);

        replaceallPB = new QPushButton(basicTab);
        replaceallPB->setObjectName(QStringLiteral("replaceallPB"));
        replaceallPB->setEnabled(true);

        pbVerticalLayout->addWidget(replaceallPB);


        horizontalLayout->addLayout(pbVerticalLayout);


        verticalLayout_4->addLayout(horizontalLayout);

        verticalSpacer_4 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_4);


        dynamicLayoutBasic_->addLayout(verticalLayout_4);

        dynamicLayoutBasic_->setStretch(0, 1);
        dynamicLayoutBasic_->setStretch(1, 1);
        FindAndReplaceUi->addTab(basicTab, QString());
        advancedTab = new QWidget();
        advancedTab->setObjectName(QStringLiteral("advancedTab"));
        dynamicLayoutAdvanced_ = new QVBoxLayout(advancedTab);
        dynamicLayoutAdvanced_->setObjectName(QStringLiteral("dynamicLayoutAdvanced_"));
        groupBox_2 = new QGroupBox(advancedTab);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        groupBox_2->setAutoFillBackground(false);
        groupBox_2->setFlat(true);
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        CurrentDocument = new QRadioButton(groupBox_2);
        CurrentDocument->setObjectName(QStringLiteral("CurrentDocument"));
        CurrentDocument->setEnabled(true);
        CurrentDocument->setChecked(true);

        verticalLayout->addWidget(CurrentDocument);

        MasterDocument = new QRadioButton(groupBox_2);
        MasterDocument->setObjectName(QStringLiteral("MasterDocument"));
        MasterDocument->setEnabled(true);
        sizePolicy1.setHeightForWidth(MasterDocument->sizePolicy().hasHeightForWidth());
        MasterDocument->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(MasterDocument);

        OpenDocuments = new QRadioButton(groupBox_2);
        OpenDocuments->setObjectName(QStringLiteral("OpenDocuments"));
        OpenDocuments->setEnabled(true);

        verticalLayout->addWidget(OpenDocuments);

        AllManualsRB = new QRadioButton(groupBox_2);
        AllManualsRB->setObjectName(QStringLiteral("AllManualsRB"));
        AllManualsRB->setEnabled(true);

        verticalLayout->addWidget(AllManualsRB);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        dynamicLayoutAdvanced_->addWidget(groupBox_2);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setSizeConstraint(QLayout::SetMinimumSize);
        expandMacrosCB = new QCheckBox(advancedTab);
        expandMacrosCB->setObjectName(QStringLiteral("expandMacrosCB"));
        expandMacrosCB->setEnabled(false);

        gridLayout_2->addWidget(expandMacrosCB, 3, 0, 1, 1);

        OnlyMaths = new QCheckBox(advancedTab);
        OnlyMaths->setObjectName(QStringLiteral("OnlyMaths"));

        gridLayout_2->addWidget(OnlyMaths, 2, 0, 1, 1);

        keepCaseCB = new QCheckBox(advancedTab);
        keepCaseCB->setObjectName(QStringLiteral("keepCaseCB"));

        gridLayout_2->addWidget(keepCaseCB, 1, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer_3, 5, 0, 1, 1);

        ignoreNonOutputCB = new QCheckBox(advancedTab);
        ignoreNonOutputCB->setObjectName(QStringLiteral("ignoreNonOutputCB"));

        gridLayout_2->addWidget(ignoreNonOutputCB, 4, 0, 1, 1);


        dynamicLayoutAdvanced_->addLayout(gridLayout_2);

        verticalSpacer_5 = new QSpacerItem(20, 8, QSizePolicy::Minimum, QSizePolicy::Expanding);

        dynamicLayoutAdvanced_->addItem(verticalSpacer_5);

        adhereFormatGB = new QGroupBox(advancedTab);
        adhereFormatGB->setObjectName(QStringLiteral("adhereFormatGB"));
        adhereFormatGB->setCheckable(true);
        adhereFormatGB->setChecked(false);
        gridLayout_4 = new QGridLayout(adhereFormatGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        adhereSectioningCB = new QCheckBox(adhereFormatGB);
        adhereSectioningCB->setObjectName(QStringLiteral("adhereSectioningCB"));

        gridLayout_4->addWidget(adhereSectioningCB, 4, 1, 1, 1);

        adhereDeletedCB = new QCheckBox(adhereFormatGB);
        adhereDeletedCB->setObjectName(QStringLiteral("adhereDeletedCB"));

        gridLayout_4->addWidget(adhereDeletedCB, 3, 1, 1, 1);

        adhereFSeriesCB = new QCheckBox(adhereFormatGB);
        adhereFSeriesCB->setObjectName(QStringLiteral("adhereFSeriesCB"));

        gridLayout_4->addWidget(adhereFSeriesCB, 3, 0, 1, 1);

        adhereMarkupCB = new QCheckBox(adhereFormatGB);
        adhereMarkupCB->setObjectName(QStringLiteral("adhereMarkupCB"));

        gridLayout_4->addWidget(adhereMarkupCB, 0, 1, 1, 1);

        adhereFFamilyCB = new QCheckBox(adhereFormatGB);
        adhereFFamilyCB->setObjectName(QStringLiteral("adhereFFamilyCB"));

        gridLayout_4->addWidget(adhereFFamilyCB, 2, 0, 1, 1);

        adhereColorCB = new QCheckBox(adhereFormatGB);
        adhereColorCB->setObjectName(QStringLiteral("adhereColorCB"));

        gridLayout_4->addWidget(adhereColorCB, 1, 0, 1, 1);

        adhereFShapeCB = new QCheckBox(adhereFormatGB);
        adhereFShapeCB->setObjectName(QStringLiteral("adhereFShapeCB"));

        gridLayout_4->addWidget(adhereFShapeCB, 4, 0, 1, 1);

        adhereStrikeCB = new QCheckBox(adhereFormatGB);
        adhereStrikeCB->setObjectName(QStringLiteral("adhereStrikeCB"));

        gridLayout_4->addWidget(adhereStrikeCB, 2, 1, 1, 1);

        adhereLanguageCB = new QCheckBox(adhereFormatGB);
        adhereLanguageCB->setObjectName(QStringLiteral("adhereLanguageCB"));

        gridLayout_4->addWidget(adhereLanguageCB, 0, 0, 1, 1);

        deselectAllPB = new QPushButton(adhereFormatGB);
        deselectAllPB->setObjectName(QStringLiteral("deselectAllPB"));

        gridLayout_4->addWidget(deselectAllPB, 7, 1, 1, 1);

        adhereUnderlineCB = new QCheckBox(adhereFormatGB);
        adhereUnderlineCB->setObjectName(QStringLiteral("adhereUnderlineCB"));

        gridLayout_4->addWidget(adhereUnderlineCB, 1, 1, 1, 1);

        adhereFSizeCB = new QCheckBox(adhereFormatGB);
        adhereFSizeCB->setObjectName(QStringLiteral("adhereFSizeCB"));

        gridLayout_4->addWidget(adhereFSizeCB, 5, 0, 1, 1);

        selectAllPB = new QPushButton(adhereFormatGB);
        selectAllPB->setObjectName(QStringLiteral("selectAllPB"));

        gridLayout_4->addWidget(selectAllPB, 7, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer_6, 8, 0, 1, 1);


        dynamicLayoutAdvanced_->addWidget(adhereFormatGB);

        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        dynamicLayoutAdvanced_->addItem(verticalSpacer_2);

        dynamicLayoutAdvanced_->setStretch(4, 1);
        FindAndReplaceUi->addTab(advancedTab, QString());
#ifndef QT_NO_SHORTCUT
        findLabel->setBuddy(find_work_area_);
        replaceLabel->setBuddy(replace_work_area_);
#endif // QT_NO_SHORTCUT

        retranslateUi(FindAndReplaceUi);

        FindAndReplaceUi->setCurrentIndex(0);
        findNextPB->setDefault(true);


        QMetaObject::connectSlotsByName(FindAndReplaceUi);
    } // setupUi

    void retranslateUi(QTabWidget *FindAndReplaceUi)
    {
        FindAndReplaceUi->setWindowTitle(lyx::qt_("TabWidget", Q_NULLPTR));
        findLabel->setText(lyx::qt_("Search fo&r:", Q_NULLPTR));
        replaceLabel->setText(lyx::qt_("Replace &with:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        searchbackCB->setToolTip(lyx::qt_("Shift+Enter search backwards directly", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        searchbackCB->setText(lyx::qt_("Search &backwards", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        wordsCB->setToolTip(lyx::qt_("Restrict search to whole words only", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        wordsCB->setText(lyx::qt_("Wh&ole words", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        caseCB->setToolTip(lyx::qt_("Perform a case-sensitive search", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        caseCB->setText(lyx::qt_("Case &sensitive", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        findNextPB->setToolTip(lyx::qt_("Find next occurrence (Enter, backwards: Shift+Enter)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        findNextPB->setText(lyx::qt_("Find &>", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replacePB->setToolTip(lyx::qt_("Replace and find next occurrence (Enter, backwards: Shift+Enter)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replacePB->setText(lyx::qt_("Rep&lace >", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replaceallPB->setToolTip(lyx::qt_("Replace all occurrences at once", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replaceallPB->setText(lyx::qt_("Replace &All", Q_NULLPTR));
        FindAndReplaceUi->setTabText(FindAndReplaceUi->indexOf(basicTab), lyx::qt_("Sear&ch", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        groupBox_2->setToolTip(lyx::qt_("The scope to which the search horizon is restricted", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_2->setTitle(lyx::qt_("Scope", Q_NULLPTR));
        CurrentDocument->setText(lyx::qt_("C&urrent document", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        MasterDocument->setToolTip(lyx::qt_("Current document and all related documents belonging to the same master document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        MasterDocument->setText(lyx::qt_("&Master document", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        OpenDocuments->setToolTip(lyx::qt_("All open documents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        OpenDocuments->setText(lyx::qt_("&Open documents", Q_NULLPTR));
        AllManualsRB->setText(lyx::qt_("&All manuals", Q_NULLPTR));
        expandMacrosCB->setText(lyx::qt_("E&xpand macros", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        OnlyMaths->setToolTip(lyx::qt_("Restrict search to math environments only", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        OnlyMaths->setText(lyx::qt_("Search onl&y in maths", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keepCaseCB->setToolTip(lyx::qt_("Keep the case of the replacement's first letter as in each matching text first letter", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        keepCaseCB->setText(lyx::qt_("&Preserve first case on replace", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ignoreNonOutputCB->setToolTip(lyx::qt_("Do not search in content that is not output (e.g., notes)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ignoreNonOutputCB->setText(lyx::qt_("Ignore &non-output content", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        adhereFormatGB->setToolTip(lyx::qt_("If the search string is formatted in a non-default way, only find strings formatted like the search string in the checked respects", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        adhereFormatGB->setTitle(lyx::qt_("Adhe&re to search string formatting of", Q_NULLPTR));
        adhereSectioningCB->setText(lyx::qt_("Sectioning markup", Q_NULLPTR));
        adhereDeletedCB->setText(lyx::qt_("Deletion (change)", Q_NULLPTR));
        adhereFSeriesCB->setText(lyx::qt_("Font series[[FindReplaceAdv]]", Q_NULLPTR));
        adhereMarkupCB->setText(lyx::qt_("Emph/noun", Q_NULLPTR));
        adhereFFamilyCB->setText(lyx::qt_("Font family", Q_NULLPTR));
        adhereColorCB->setText(lyx::qt_("Font color", Q_NULLPTR));
        adhereFShapeCB->setText(lyx::qt_("Font shape", Q_NULLPTR));
        adhereStrikeCB->setText(lyx::qt_("Strike-through", Q_NULLPTR));
        adhereLanguageCB->setText(lyx::qt_("Language", Q_NULLPTR));
        deselectAllPB->setText(lyx::qt_("Dese&lect all", Q_NULLPTR));
        adhereUnderlineCB->setText(lyx::qt_("Underlining", Q_NULLPTR));
        adhereFSizeCB->setText(lyx::qt_("Font size", Q_NULLPTR));
        selectAllPB->setText(lyx::qt_("&Select all", Q_NULLPTR));
        FindAndReplaceUi->setTabText(FindAndReplaceUi->indexOf(advancedTab), lyx::qt_("Settin&gs", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class FindAndReplaceUi: public Ui_FindAndReplaceUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FINDANDREPLACEUI_H
