/****************************************************************************
** Meta object code from reading C++ file 'GuiToolbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiToolbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiToolbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__MenuButtonBase_t {
    QByteArrayData data[6];
    char stringdata0[79];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__MenuButtonBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__MenuButtonBase_t qt_meta_stringdata_lyx__frontend__MenuButtonBase = {
    {
QT_MOC_LITERAL(0, 0, 29), // "lyx::frontend::MenuButtonBase"
QT_MOC_LITERAL(1, 30, 15), // "actionTriggered"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 8), // "QAction*"
QT_MOC_LITERAL(4, 56, 6), // "action"
QT_MOC_LITERAL(5, 63, 15) // "updateTriggered"

    },
    "lyx::frontend::MenuButtonBase\0"
    "actionTriggered\0\0QAction*\0action\0"
    "updateTriggered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__MenuButtonBase[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x09 /* Protected */,
       5,    0,   27,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::MenuButtonBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MenuButtonBase *_t = static_cast<MenuButtonBase *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 1: _t->updateTriggered(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::MenuButtonBase::staticMetaObject = {
    { &QToolButton::staticMetaObject, qt_meta_stringdata_lyx__frontend__MenuButtonBase.data,
      qt_meta_data_lyx__frontend__MenuButtonBase,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::MenuButtonBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::MenuButtonBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__MenuButtonBase.stringdata0))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int lyx::frontend::MenuButtonBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__StaticMenuButton_t {
    QByteArrayData data[3];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__StaticMenuButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__StaticMenuButton_t qt_meta_stringdata_lyx__frontend__StaticMenuButton = {
    {
QT_MOC_LITERAL(0, 0, 31), // "lyx::frontend::StaticMenuButton"
QT_MOC_LITERAL(1, 32, 15), // "updateTriggered"
QT_MOC_LITERAL(2, 48, 0) // ""

    },
    "lyx::frontend::StaticMenuButton\0"
    "updateTriggered\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__StaticMenuButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::StaticMenuButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StaticMenuButton *_t = static_cast<StaticMenuButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateTriggered(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::StaticMenuButton::staticMetaObject = {
    { &MenuButtonBase::staticMetaObject, qt_meta_stringdata_lyx__frontend__StaticMenuButton.data,
      qt_meta_data_lyx__frontend__StaticMenuButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::StaticMenuButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::StaticMenuButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__StaticMenuButton.stringdata0))
        return static_cast<void*>(this);
    return MenuButtonBase::qt_metacast(_clname);
}

int lyx::frontend::StaticMenuButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MenuButtonBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__DynamicMenuButton_t {
    QByteArrayData data[3];
    char stringdata0[50];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__DynamicMenuButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__DynamicMenuButton_t qt_meta_stringdata_lyx__frontend__DynamicMenuButton = {
    {
QT_MOC_LITERAL(0, 0, 32), // "lyx::frontend::DynamicMenuButton"
QT_MOC_LITERAL(1, 33, 15), // "updateTriggered"
QT_MOC_LITERAL(2, 49, 0) // ""

    },
    "lyx::frontend::DynamicMenuButton\0"
    "updateTriggered\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__DynamicMenuButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::DynamicMenuButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DynamicMenuButton *_t = static_cast<DynamicMenuButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateTriggered(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::DynamicMenuButton::staticMetaObject = {
    { &MenuButtonBase::staticMetaObject, qt_meta_stringdata_lyx__frontend__DynamicMenuButton.data,
      qt_meta_data_lyx__frontend__DynamicMenuButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::DynamicMenuButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::DynamicMenuButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__DynamicMenuButton.stringdata0))
        return static_cast<void*>(this);
    return MenuButtonBase::qt_metacast(_clname);
}

int lyx::frontend::DynamicMenuButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MenuButtonBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_lyx__frontend__GuiToolbar_t {
    QByteArrayData data[5];
    char stringdata0[55];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiToolbar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiToolbar_t qt_meta_stringdata_lyx__frontend__GuiToolbar = {
    {
QT_MOC_LITERAL(0, 0, 25), // "lyx::frontend::GuiToolbar"
QT_MOC_LITERAL(1, 26, 7), // "updated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 15), // "showContextMenu"
QT_MOC_LITERAL(4, 51, 3) // "pos"

    },
    "lyx::frontend::GuiToolbar\0updated\0\0"
    "showContextMenu\0pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiToolbar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   25,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QPoint,    4,

       0        // eod
};

void lyx::frontend::GuiToolbar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiToolbar *_t = static_cast<GuiToolbar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->showContextMenu((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiToolbar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiToolbar::updated)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiToolbar::staticMetaObject = {
    { &QToolBar::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiToolbar.data,
      qt_meta_data_lyx__frontend__GuiToolbar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiToolbar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiToolbar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiToolbar.stringdata0))
        return static_cast<void*>(this);
    return QToolBar::qt_metacast(_clname);
}

int lyx::frontend::GuiToolbar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiToolbar::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
