/********************************************************************************
** Form generated from reading UI file 'ViewSourceUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIEWSOURCEUI_H
#define UI_VIEWSOURCEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ViewSourceUi
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *layout_;
    QTextEdit *viewSourceTV;
    QGridLayout *gridLayout;
    QLabel *outputFormatLA;
    QSpacerItem *verticalSpacer;
    QCheckBox *autoUpdateCB;
    QCheckBox *masterPerspectiveCB;
    QComboBox *contentsCO;
    QPushButton *updatePB;
    QComboBox *outputFormatCO;

    void setupUi(QWidget *ViewSourceUi)
    {
        if (ViewSourceUi->objectName().isEmpty())
            ViewSourceUi->setObjectName(QStringLiteral("ViewSourceUi"));
        ViewSourceUi->resize(665, 144);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ViewSourceUi->sizePolicy().hasHeightForWidth());
        ViewSourceUi->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(ViewSourceUi);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        layout_ = new QHBoxLayout();
        layout_->setSpacing(0);
        layout_->setObjectName(QStringLiteral("layout_"));
        layout_->setSizeConstraint(QLayout::SetMaximumSize);
        viewSourceTV = new QTextEdit(ViewSourceUi);
        viewSourceTV->setObjectName(QStringLiteral("viewSourceTV"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Ignored);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(viewSourceTV->sizePolicy().hasHeightForWidth());
        viewSourceTV->setSizePolicy(sizePolicy1);
        viewSourceTV->setMinimumSize(QSize(0, 0));
        viewSourceTV->setBaseSize(QSize(0, 0));

        layout_->addWidget(viewSourceTV);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(6, 6, 6, 6);
        outputFormatLA = new QLabel(ViewSourceUi);
        outputFormatLA->setObjectName(QStringLiteral("outputFormatLA"));

        gridLayout->addWidget(outputFormatLA, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 2);

        autoUpdateCB = new QCheckBox(ViewSourceUi);
        autoUpdateCB->setObjectName(QStringLiteral("autoUpdateCB"));
        autoUpdateCB->setChecked(true);

        gridLayout->addWidget(autoUpdateCB, 3, 0, 1, 2);

        masterPerspectiveCB = new QCheckBox(ViewSourceUi);
        masterPerspectiveCB->setObjectName(QStringLiteral("masterPerspectiveCB"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(masterPerspectiveCB->sizePolicy().hasHeightForWidth());
        masterPerspectiveCB->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(masterPerspectiveCB, 2, 0, 1, 2);

        contentsCO = new QComboBox(ViewSourceUi);
        contentsCO->setObjectName(QStringLiteral("contentsCO"));
        sizePolicy2.setHeightForWidth(contentsCO->sizePolicy().hasHeightForWidth());
        contentsCO->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(contentsCO, 1, 0, 1, 2);

        updatePB = new QPushButton(ViewSourceUi);
        updatePB->setObjectName(QStringLiteral("updatePB"));
        updatePB->setEnabled(false);

        gridLayout->addWidget(updatePB, 4, 0, 1, 2);

        outputFormatCO = new QComboBox(ViewSourceUi);
        outputFormatCO->setObjectName(QStringLiteral("outputFormatCO"));
        outputFormatCO->setEnabled(true);
        sizePolicy2.setHeightForWidth(outputFormatCO->sizePolicy().hasHeightForWidth());
        outputFormatCO->setSizePolicy(sizePolicy2);
        outputFormatCO->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(outputFormatCO, 0, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        layout_->addLayout(gridLayout);

        layout_->setStretch(0, 1);

        gridLayout_2->addLayout(layout_, 0, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        outputFormatLA->setBuddy(outputFormatCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(ViewSourceUi);

        QMetaObject::connectSlotsByName(ViewSourceUi);
    } // setupUi

    void retranslateUi(QWidget *ViewSourceUi)
    {
        ViewSourceUi->setWindowTitle(QString());
#ifndef QT_NO_WHATSTHIS
        viewSourceTV->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        outputFormatLA->setText(lyx::qt_("F&ormat:", Q_NULLPTR));
        autoUpdateCB->setText(lyx::qt_("Automatic update", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        masterPerspectiveCB->setToolTip(lyx::qt_("Show the source as the master document gets it", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        masterPerspectiveCB->setText(lyx::qt_("Master's perspective", Q_NULLPTR));
        contentsCO->clear();
        contentsCO->insertItems(0, QStringList()
         << lyx::qt_("Current Paragraph", Q_NULLPTR)
         << lyx::qt_("Complete Source", Q_NULLPTR)
         << lyx::qt_("Preamble Only", Q_NULLPTR)
         << lyx::qt_("Body Only", Q_NULLPTR)
        );
        updatePB->setText(lyx::qt_("&Update", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        outputFormatCO->setToolTip(lyx::qt_("Select the output format", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class ViewSourceUi: public Ui_ViewSourceUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VIEWSOURCEUI_H
