/********************************************************************************
** Form generated from reading UI file 'BranchesUnknownUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRANCHESUNKNOWNUI_H
#define UI_BRANCHESUNKNOWNUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BranchesUnknownUi
{
public:
    QGridLayout *gridLayout;
    QPushButton *addSelectedPB;
    QPushButton *addAllPB;
    QSpacerItem *spacerItem;
    QPushButton *cancelPB;
    QLabel *branchesLA;
    QListWidget *branchesLW;

    void setupUi(QWidget *BranchesUnknownUi)
    {
        if (BranchesUnknownUi->objectName().isEmpty())
            BranchesUnknownUi->setObjectName(QStringLiteral("BranchesUnknownUi"));
        BranchesUnknownUi->resize(401, 234);
        gridLayout = new QGridLayout(BranchesUnknownUi);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        addSelectedPB = new QPushButton(BranchesUnknownUi);
        addSelectedPB->setObjectName(QStringLiteral("addSelectedPB"));

        gridLayout->addWidget(addSelectedPB, 1, 1, 1, 1);

        addAllPB = new QPushButton(BranchesUnknownUi);
        addAllPB->setObjectName(QStringLiteral("addAllPB"));

        gridLayout->addWidget(addAllPB, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 81, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        cancelPB = new QPushButton(BranchesUnknownUi);
        cancelPB->setObjectName(QStringLiteral("cancelPB"));

        gridLayout->addWidget(cancelPB, 4, 1, 1, 1);

        branchesLA = new QLabel(BranchesUnknownUi);
        branchesLA->setObjectName(QStringLiteral("branchesLA"));

        gridLayout->addWidget(branchesLA, 0, 0, 1, 1);

        branchesLW = new QListWidget(BranchesUnknownUi);
        branchesLW->setObjectName(QStringLiteral("branchesLW"));
        branchesLW->setSelectionMode(QAbstractItemView::MultiSelection);

        gridLayout->addWidget(branchesLW, 1, 0, 4, 1);

#ifndef QT_NO_SHORTCUT
        branchesLA->setBuddy(branchesLW);
#endif // QT_NO_SHORTCUT

        retranslateUi(BranchesUnknownUi);

        QMetaObject::connectSlotsByName(BranchesUnknownUi);
    } // setupUi

    void retranslateUi(QWidget *BranchesUnknownUi)
    {
        BranchesUnknownUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        addSelectedPB->setToolTip(lyx::qt_("Add the selected branches to the list.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addSelectedPB->setText(lyx::qt_("&Add Selected", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        addAllPB->setToolTip(lyx::qt_("Add all unknown branches to the list.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addAllPB->setText(lyx::qt_("Add A&ll", Q_NULLPTR));
        cancelPB->setText(lyx::qt_("&Cancel", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        branchesLA->setToolTip(lyx::qt_("Undefined branches used in this document.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        branchesLA->setText(lyx::qt_("&Undefined Branches:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        branchesLW->setToolTip(lyx::qt_("Undefined branches used in this document.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class BranchesUnknownUi: public Ui_BranchesUnknownUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BRANCHESUNKNOWNUI_H
