/********************************************************************************
** Form generated from reading UI file 'ColorUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORUI_H
#define UI_COLORUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ColorUi
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *fontcolorGB;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QPushButton *fontColorPB;
    QSpacerItem *spacerItem;
    QLabel *noteFontColorLA;
    QSpacerItem *spacerItem1;
    QLabel *fontColorLA;
    QPushButton *noteFontColorPB;
    QToolButton *delNoteFontColorTB;
    QToolButton *delFontColorTB;
    QFrame *mainTextCF;
    QFrame *noteFontCF;
    QGroupBox *backgroundGB;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout_2;
    QLabel *boxBackgroundColorLA;
    QSpacerItem *spacerItem2;
    QToolButton *delBoxBackgroundTB;
    QLabel *backgroundColorLA;
    QSpacerItem *spacerItem3;
    QPushButton *backgroundPB;
    QToolButton *delBackgroundTB;
    QPushButton *boxBackgroundPB;
    QFrame *pageBackgroundCF;
    QFrame *boxBackgroundCF;
    QSpacerItem *spacerItem4;

    void setupUi(QWidget *ColorUi)
    {
        if (ColorUi->objectName().isEmpty())
            ColorUi->setObjectName(QStringLiteral("ColorUi"));
        ColorUi->resize(519, 274);
        ColorUi->setContextMenuPolicy(Qt::DefaultContextMenu);
        horizontalLayout = new QHBoxLayout(ColorUi);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        fontcolorGB = new QGroupBox(ColorUi);
        fontcolorGB->setObjectName(QStringLiteral("fontcolorGB"));
        fontcolorGB->setFlat(true);
        verticalLayout = new QVBoxLayout(fontcolorGB);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        fontColorPB = new QPushButton(fontcolorGB);
        fontColorPB->setObjectName(QStringLiteral("fontColorPB"));
        fontColorPB->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(fontColorPB, 0, 2, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 5, 1, 1);

        noteFontColorLA = new QLabel(fontcolorGB);
        noteFontColorLA->setObjectName(QStringLiteral("noteFontColorLA"));

        gridLayout->addWidget(noteFontColorLA, 1, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 1, 5, 1, 1);

        fontColorLA = new QLabel(fontcolorGB);
        fontColorLA->setObjectName(QStringLiteral("fontColorLA"));

        gridLayout->addWidget(fontColorLA, 0, 0, 1, 1);

        noteFontColorPB = new QPushButton(fontcolorGB);
        noteFontColorPB->setObjectName(QStringLiteral("noteFontColorPB"));
        noteFontColorPB->setMaximumSize(QSize(16777215, 16777215));

        gridLayout->addWidget(noteFontColorPB, 1, 2, 1, 1);

        delNoteFontColorTB = new QToolButton(fontcolorGB);
        delNoteFontColorTB->setObjectName(QStringLiteral("delNoteFontColorTB"));
        delNoteFontColorTB->setMinimumSize(QSize(23, 23));
        delNoteFontColorTB->setToolButtonStyle(Qt::ToolButtonTextOnly);
        delNoteFontColorTB->setArrowType(Qt::LeftArrow);

        gridLayout->addWidget(delNoteFontColorTB, 1, 4, 1, 1);

        delFontColorTB = new QToolButton(fontcolorGB);
        delFontColorTB->setObjectName(QStringLiteral("delFontColorTB"));
        delFontColorTB->setMinimumSize(QSize(23, 23));
        delFontColorTB->setToolButtonStyle(Qt::ToolButtonTextOnly);
        delFontColorTB->setArrowType(Qt::LeftArrow);

        gridLayout->addWidget(delFontColorTB, 0, 4, 1, 1);

        mainTextCF = new QFrame(fontcolorGB);
        mainTextCF->setObjectName(QStringLiteral("mainTextCF"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mainTextCF->sizePolicy().hasHeightForWidth());
        mainTextCF->setSizePolicy(sizePolicy);
        mainTextCF->setMinimumSize(QSize(40, 0));
        mainTextCF->setFrameShape(QFrame::Box);
        mainTextCF->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(mainTextCF, 0, 1, 1, 1);

        noteFontCF = new QFrame(fontcolorGB);
        noteFontCF->setObjectName(QStringLiteral("noteFontCF"));
        sizePolicy.setHeightForWidth(noteFontCF->sizePolicy().hasHeightForWidth());
        noteFontCF->setSizePolicy(sizePolicy);
        noteFontCF->setMinimumSize(QSize(40, 0));
        noteFontCF->setFrameShape(QFrame::Box);
        noteFontCF->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(noteFontCF, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);


        verticalLayout_3->addWidget(fontcolorGB);

        backgroundGB = new QGroupBox(ColorUi);
        backgroundGB->setObjectName(QStringLiteral("backgroundGB"));
        backgroundGB->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(backgroundGB);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        boxBackgroundColorLA = new QLabel(backgroundGB);
        boxBackgroundColorLA->setObjectName(QStringLiteral("boxBackgroundColorLA"));

        gridLayout_2->addWidget(boxBackgroundColorLA, 1, 0, 1, 1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(spacerItem2, 1, 5, 1, 1);

        delBoxBackgroundTB = new QToolButton(backgroundGB);
        delBoxBackgroundTB->setObjectName(QStringLiteral("delBoxBackgroundTB"));
        delBoxBackgroundTB->setMinimumSize(QSize(23, 23));
        delBoxBackgroundTB->setToolButtonStyle(Qt::ToolButtonTextOnly);
        delBoxBackgroundTB->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(delBoxBackgroundTB, 1, 4, 1, 1);

        backgroundColorLA = new QLabel(backgroundGB);
        backgroundColorLA->setObjectName(QStringLiteral("backgroundColorLA"));

        gridLayout_2->addWidget(backgroundColorLA, 0, 0, 1, 1);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(spacerItem3, 0, 5, 1, 1);

        backgroundPB = new QPushButton(backgroundGB);
        backgroundPB->setObjectName(QStringLiteral("backgroundPB"));
        backgroundPB->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_2->addWidget(backgroundPB, 0, 2, 1, 1);

        delBackgroundTB = new QToolButton(backgroundGB);
        delBackgroundTB->setObjectName(QStringLiteral("delBackgroundTB"));
        delBackgroundTB->setMinimumSize(QSize(23, 23));
        delBackgroundTB->setToolButtonStyle(Qt::ToolButtonTextOnly);
        delBackgroundTB->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(delBackgroundTB, 0, 4, 1, 1);

        boxBackgroundPB = new QPushButton(backgroundGB);
        boxBackgroundPB->setObjectName(QStringLiteral("boxBackgroundPB"));
        boxBackgroundPB->setMaximumSize(QSize(16777215, 16777215));

        gridLayout_2->addWidget(boxBackgroundPB, 1, 2, 1, 1);

        pageBackgroundCF = new QFrame(backgroundGB);
        pageBackgroundCF->setObjectName(QStringLiteral("pageBackgroundCF"));
        sizePolicy.setHeightForWidth(pageBackgroundCF->sizePolicy().hasHeightForWidth());
        pageBackgroundCF->setSizePolicy(sizePolicy);
        pageBackgroundCF->setMinimumSize(QSize(40, 0));
        pageBackgroundCF->setFrameShape(QFrame::Box);
        pageBackgroundCF->setFrameShadow(QFrame::Plain);

        gridLayout_2->addWidget(pageBackgroundCF, 0, 1, 1, 1);

        boxBackgroundCF = new QFrame(backgroundGB);
        boxBackgroundCF->setObjectName(QStringLiteral("boxBackgroundCF"));
        sizePolicy.setHeightForWidth(boxBackgroundCF->sizePolicy().hasHeightForWidth());
        boxBackgroundCF->setSizePolicy(sizePolicy);
        boxBackgroundCF->setMinimumSize(QSize(40, 0));
        boxBackgroundCF->setFrameShape(QFrame::Box);
        boxBackgroundCF->setFrameShadow(QFrame::Plain);

        gridLayout_2->addWidget(boxBackgroundCF, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);


        verticalLayout_3->addWidget(backgroundGB);

        spacerItem4 = new QSpacerItem(385, 22, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(spacerItem4);


        horizontalLayout->addLayout(verticalLayout_3);

#ifndef QT_NO_SHORTCUT
        noteFontColorLA->setBuddy(fontColorPB);
        fontColorLA->setBuddy(fontColorPB);
        boxBackgroundColorLA->setBuddy(backgroundPB);
        backgroundColorLA->setBuddy(backgroundPB);
#endif // QT_NO_SHORTCUT

        retranslateUi(ColorUi);

        QMetaObject::connectSlotsByName(ColorUi);
    } // setupUi

    void retranslateUi(QWidget *ColorUi)
    {
        ColorUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        ColorUi->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        fontcolorGB->setTitle(lyx::qt_("Font Colors", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fontColorPB->setToolTip(lyx::qt_("Click to change the color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fontColorPB->setText(lyx::qt_("&Change...", Q_NULLPTR));
        noteFontColorLA->setText(lyx::qt_("Greyed-out notes:", Q_NULLPTR));
        fontColorLA->setText(lyx::qt_("Main text:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        noteFontColorPB->setToolTip(lyx::qt_("Click to change the color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        noteFontColorPB->setText(lyx::qt_("C&hange...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        delNoteFontColorTB->setToolTip(lyx::qt_("Revert the color to the default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        delNoteFontColorTB->setText(lyx::qt_("R&eset", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        delFontColorTB->setToolTip(lyx::qt_("Revert the color to the default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        delFontColorTB->setText(lyx::qt_("&Reset", Q_NULLPTR));
        backgroundGB->setTitle(lyx::qt_("Background Colors", Q_NULLPTR));
        boxBackgroundColorLA->setText(lyx::qt_("Shaded boxes:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        delBoxBackgroundTB->setToolTip(lyx::qt_("Revert the color to the default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        delBoxBackgroundTB->setText(lyx::qt_("Rese&t", Q_NULLPTR));
        backgroundColorLA->setText(lyx::qt_("Page:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        backgroundPB->setToolTip(lyx::qt_("Click to change the color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        backgroundPB->setText(lyx::qt_("Ch&ange...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        delBackgroundTB->setToolTip(lyx::qt_("Revert the color to the default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        delBackgroundTB->setText(lyx::qt_("Re&set", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        boxBackgroundPB->setToolTip(lyx::qt_("Click to change the color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        boxBackgroundPB->setText(lyx::qt_("Chan&ge...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ColorUi: public Ui_ColorUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORUI_H
