/********************************************************************************
** Form generated from reading UI file 'PrefSpellcheckerUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFSPELLCHECKERUI_H
#define UI_PREFSPELLCHECKERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefSpellcheckerUi
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QCheckBox *spellcheckNotesCB;
    QLabel *spellcheckerLA;
    QComboBox *spellcheckerCB;
    QCheckBox *compoundWordCB;
    QCheckBox *spellcheckContinuouslyCB;
    QSpacerItem *spacerItem1;
    QLineEdit *escapeCharactersED;
    QLabel *escapeCharactersLA;
    QLineEdit *altLanguageED;
    QLabel *altLanguageLA;

    void setupUi(QWidget *PrefSpellcheckerUi)
    {
        if (PrefSpellcheckerUi->objectName().isEmpty())
            PrefSpellcheckerUi->setObjectName(QStringLiteral("PrefSpellcheckerUi"));
        PrefSpellcheckerUi->resize(400, 224);
        gridLayout = new QGridLayout(PrefSpellcheckerUi);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        spacerItem = new QSpacerItem(0, 21, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 6, 0, 1, 3);

        spellcheckNotesCB = new QCheckBox(PrefSpellcheckerUi);
        spellcheckNotesCB->setObjectName(QStringLiteral("spellcheckNotesCB"));

        gridLayout->addWidget(spellcheckNotesCB, 5, 0, 1, 2);

        spellcheckerLA = new QLabel(PrefSpellcheckerUi);
        spellcheckerLA->setObjectName(QStringLiteral("spellcheckerLA"));

        gridLayout->addWidget(spellcheckerLA, 0, 0, 1, 1);

        spellcheckerCB = new QComboBox(PrefSpellcheckerUi);
        spellcheckerCB->setObjectName(QStringLiteral("spellcheckerCB"));

        gridLayout->addWidget(spellcheckerCB, 0, 1, 1, 1);

        compoundWordCB = new QCheckBox(PrefSpellcheckerUi);
        compoundWordCB->setObjectName(QStringLiteral("compoundWordCB"));

        gridLayout->addWidget(compoundWordCB, 3, 0, 1, 2);

        spellcheckContinuouslyCB = new QCheckBox(PrefSpellcheckerUi);
        spellcheckContinuouslyCB->setObjectName(QStringLiteral("spellcheckContinuouslyCB"));

        gridLayout->addWidget(spellcheckContinuouslyCB, 4, 0, 1, 2);

        spacerItem1 = new QSpacerItem(41, 22, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 3, 2, 1, 1);

        escapeCharactersED = new QLineEdit(PrefSpellcheckerUi);
        escapeCharactersED->setObjectName(QStringLiteral("escapeCharactersED"));

        gridLayout->addWidget(escapeCharactersED, 2, 1, 1, 1);

        escapeCharactersLA = new QLabel(PrefSpellcheckerUi);
        escapeCharactersLA->setObjectName(QStringLiteral("escapeCharactersLA"));

        gridLayout->addWidget(escapeCharactersLA, 2, 0, 1, 1);

        altLanguageED = new QLineEdit(PrefSpellcheckerUi);
        altLanguageED->setObjectName(QStringLiteral("altLanguageED"));

        gridLayout->addWidget(altLanguageED, 1, 1, 1, 1);

        altLanguageLA = new QLabel(PrefSpellcheckerUi);
        altLanguageLA->setObjectName(QStringLiteral("altLanguageLA"));

        gridLayout->addWidget(altLanguageLA, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        spellcheckerLA->setBuddy(spellcheckerCB);
        escapeCharactersLA->setBuddy(escapeCharactersED);
        altLanguageLA->setBuddy(altLanguageED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(spellcheckerCB, altLanguageED);
        QWidget::setTabOrder(altLanguageED, escapeCharactersED);
        QWidget::setTabOrder(escapeCharactersED, compoundWordCB);
        QWidget::setTabOrder(compoundWordCB, spellcheckContinuouslyCB);
        QWidget::setTabOrder(spellcheckContinuouslyCB, spellcheckNotesCB);

        retranslateUi(PrefSpellcheckerUi);

        QMetaObject::connectSlotsByName(PrefSpellcheckerUi);
    } // setupUi

    void retranslateUi(QWidget *PrefSpellcheckerUi)
    {
        PrefSpellcheckerUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        spellcheckNotesCB->setToolTip(lyx::qt_("If unchecked, notes and comments will be excluded from spell checking", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        spellcheckNotesCB->setText(lyx::qt_("Spellcheck &notes and comments", Q_NULLPTR));
        spellcheckerLA->setText(lyx::qt_("&Spellchecker engine:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        compoundWordCB->setToolTip(lyx::qt_("Accept words such as \"diskdrive\"", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        compoundWordCB->setText(lyx::qt_("Accept compound &words", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        spellcheckContinuouslyCB->setToolTip(lyx::qt_("Mark misspelled words with a underline.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        spellcheckContinuouslyCB->setText(lyx::qt_("S&pellcheck continuously", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        escapeCharactersED->setToolTip(lyx::qt_("The characters inserted here are ignored by the spellchecker.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        escapeCharactersLA->setText(lyx::qt_("&Escape characters:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        altLanguageED->setToolTip(lyx::qt_("Override the language used for the spellchecker", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        altLanguageLA->setText(lyx::qt_("Al&ternative language:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefSpellcheckerUi: public Ui_PrefSpellcheckerUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFSPELLCHECKERUI_H
