/****************************************************************************
** Meta object code from reading C++ file 'GuiBibtex.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiBibtex.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiBibtex.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiBibtex_t {
    QByteArrayData data[16];
    char stringdata0[230];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiBibtex_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiBibtex_t qt_meta_stringdata_lyx__frontend__GuiBibtex = {
    {
QT_MOC_LITERAL(0, 0, 24), // "lyx::frontend::GuiBibtex"
QT_MOC_LITERAL(1, 25, 14), // "change_adaptor"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 21), // "on_buttonBox_accepted"
QT_MOC_LITERAL(4, 63, 16), // "browseBstPressed"
QT_MOC_LITERAL(5, 80, 16), // "browseBibPressed"
QT_MOC_LITERAL(6, 97, 13), // "relAbsPressed"
QT_MOC_LITERAL(7, 111, 14), // "inheritPressed"
QT_MOC_LITERAL(8, 126, 17), // "on_editPB_clicked"
QT_MOC_LITERAL(9, 144, 15), // "databaseChanged"
QT_MOC_LITERAL(10, 160, 13), // "rescanClicked"
QT_MOC_LITERAL(11, 174, 10), // "selUpdated"
QT_MOC_LITERAL(12, 185, 13), // "filterPressed"
QT_MOC_LITERAL(13, 199, 13), // "filterChanged"
QT_MOC_LITERAL(14, 213, 4), // "text"
QT_MOC_LITERAL(15, 218, 11) // "resetFilter"

    },
    "lyx::frontend::GuiBibtex\0change_adaptor\0"
    "\0on_buttonBox_accepted\0browseBstPressed\0"
    "browseBibPressed\0relAbsPressed\0"
    "inheritPressed\0on_editPB_clicked\0"
    "databaseChanged\0rescanClicked\0selUpdated\0"
    "filterPressed\0filterChanged\0text\0"
    "resetFilter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiBibtex[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x08 /* Private */,
       3,    0,   80,    2, 0x08 /* Private */,
       4,    0,   81,    2, 0x08 /* Private */,
       5,    0,   82,    2, 0x08 /* Private */,
       6,    0,   83,    2, 0x08 /* Private */,
       7,    0,   84,    2, 0x08 /* Private */,
       8,    0,   85,    2, 0x08 /* Private */,
       9,    0,   86,    2, 0x08 /* Private */,
      10,    0,   87,    2, 0x08 /* Private */,
      11,    0,   88,    2, 0x08 /* Private */,
      12,    0,   89,    2, 0x08 /* Private */,
      13,    1,   90,    2, 0x08 /* Private */,
      15,    0,   93,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiBibtex::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiBibtex *_t = static_cast<GuiBibtex *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->change_adaptor(); break;
        case 1: _t->on_buttonBox_accepted(); break;
        case 2: _t->browseBstPressed(); break;
        case 3: _t->browseBibPressed(); break;
        case 4: _t->relAbsPressed(); break;
        case 5: _t->inheritPressed(); break;
        case 6: _t->on_editPB_clicked(); break;
        case 7: _t->databaseChanged(); break;
        case 8: _t->rescanClicked(); break;
        case 9: _t->selUpdated(); break;
        case 10: _t->filterPressed(); break;
        case 11: _t->filterChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->resetFilter(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiBibtex::staticMetaObject = {
    { &GuiDialog::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiBibtex.data,
      qt_meta_data_lyx__frontend__GuiBibtex,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiBibtex::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiBibtex::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiBibtex.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::BibtexUi"))
        return static_cast< Ui::BibtexUi*>(this);
    return GuiDialog::qt_metacast(_clname);
}

int lyx::frontend::GuiBibtex::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
