/********************************************************************************
** Form generated from reading UI file 'TocUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOCUI_H
#define UI_TOCUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_TocUi
{
public:
    QGridLayout *gridLayout;
    QTreeView *tocTV;
    QHBoxLayout *hboxLayout;
    QToolButton *updateTB;
    QSpacerItem *spacerItem;
    QToolButton *moveOutTB;
    QToolButton *moveInTB;
    QToolButton *moveUpTB;
    QToolButton *moveDownTB;
    QGridLayout *gridLayout_3;
    QSlider *depthSL;
    QVBoxLayout *vboxLayout;
    QCheckBox *sortCB;
    QCheckBox *persistentCB;
    QGridLayout *gridLayout_2;
    QComboBox *activeFilterCO;
    QLabel *activeFilterLA;
    QLabel *filterLA;
    QComboBox *typeCO;
    QHBoxLayout *filterBarL;

    void setupUi(QWidget *TocUi)
    {
        if (TocUi->objectName().isEmpty())
            TocUi->setObjectName(QStringLiteral("TocUi"));
        TocUi->setWindowModality(Qt::NonModal);
        TocUi->resize(290, 437);
        gridLayout = new QGridLayout(TocUi);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tocTV = new QTreeView(TocUi);
        tocTV->setObjectName(QStringLiteral("tocTV"));
        QSizePolicy sizePolicy(QSizePolicy::Ignored, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tocTV->sizePolicy().hasHeightForWidth());
        tocTV->setSizePolicy(sizePolicy);

        gridLayout->addWidget(tocTV, 3, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(6, 6, 6, 6);
        updateTB = new QToolButton(TocUi);
        updateTB->setObjectName(QStringLiteral("updateTB"));
        QIcon icon;
        icon.addFile(QStringLiteral("../../../../lib/images/reload.png"), QSize(), QIcon::Normal, QIcon::Off);
        updateTB->setIcon(icon);
        updateTB->setIconSize(QSize(20, 20));

        hboxLayout->addWidget(updateTB);

        spacerItem = new QSpacerItem(16, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        moveOutTB = new QToolButton(TocUi);
        moveOutTB->setObjectName(QStringLiteral("moveOutTB"));
        QIcon icon1;
        icon1.addFile(QStringLiteral("../../../../lib/images/outline-out.png"), QSize(), QIcon::Normal, QIcon::Off);
        moveOutTB->setIcon(icon1);
        moveOutTB->setIconSize(QSize(20, 20));

        hboxLayout->addWidget(moveOutTB);

        moveInTB = new QToolButton(TocUi);
        moveInTB->setObjectName(QStringLiteral("moveInTB"));
        QIcon icon2;
        icon2.addFile(QStringLiteral("../../../../lib/images/outline-in.png"), QSize(), QIcon::Normal, QIcon::Off);
        moveInTB->setIcon(icon2);
        moveInTB->setIconSize(QSize(20, 20));

        hboxLayout->addWidget(moveInTB);

        moveUpTB = new QToolButton(TocUi);
        moveUpTB->setObjectName(QStringLiteral("moveUpTB"));
        QIcon icon3;
        icon3.addFile(QStringLiteral("../../../../lib/images/outline-up.png"), QSize(), QIcon::Normal, QIcon::Off);
        moveUpTB->setIcon(icon3);
        moveUpTB->setIconSize(QSize(20, 20));

        hboxLayout->addWidget(moveUpTB);

        moveDownTB = new QToolButton(TocUi);
        moveDownTB->setObjectName(QStringLiteral("moveDownTB"));
        QIcon icon4;
        icon4.addFile(QStringLiteral("../../../../lib/images/outline-down.png"), QSize(), QIcon::Normal, QIcon::Off);
        moveDownTB->setIcon(icon4);
        moveDownTB->setIconSize(QSize(20, 20));

        hboxLayout->addWidget(moveDownTB);


        gridLayout->addLayout(hboxLayout, 6, 0, 1, 2);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setSpacing(6);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        gridLayout_3->setContentsMargins(6, 0, 6, 0);
        depthSL = new QSlider(TocUi);
        depthSL->setObjectName(QStringLiteral("depthSL"));
        QSizePolicy sizePolicy1(QSizePolicy::Ignored, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(depthSL->sizePolicy().hasHeightForWidth());
        depthSL->setSizePolicy(sizePolicy1);
        depthSL->setMaximum(5);
        depthSL->setPageStep(1);
        depthSL->setValue(2);
        depthSL->setOrientation(Qt::Horizontal);
        depthSL->setTickPosition(QSlider::TicksBelow);

        gridLayout_3->addWidget(depthSL, 0, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setSizeConstraint(QLayout::SetMinimumSize);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        sortCB = new QCheckBox(TocUi);
        sortCB->setObjectName(QStringLiteral("sortCB"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(sortCB->sizePolicy().hasHeightForWidth());
        sortCB->setSizePolicy(sizePolicy2);
        sortCB->setMinimumSize(QSize(0, 21));

        vboxLayout->addWidget(sortCB);

        persistentCB = new QCheckBox(TocUi);
        persistentCB->setObjectName(QStringLiteral("persistentCB"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(persistentCB->sizePolicy().hasHeightForWidth());
        persistentCB->setSizePolicy(sizePolicy3);
        persistentCB->setMinimumSize(QSize(0, 21));

        vboxLayout->addWidget(persistentCB);


        gridLayout_3->addLayout(vboxLayout, 0, 1, 1, 1);

        gridLayout_3->setColumnStretch(0, 1);

        gridLayout->addLayout(gridLayout_3, 4, 0, 1, 2);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(6);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout_2->setContentsMargins(6, 6, 6, 6);
        activeFilterCO = new QComboBox(TocUi);
        activeFilterCO->setObjectName(QStringLiteral("activeFilterCO"));
        sizePolicy1.setHeightForWidth(activeFilterCO->sizePolicy().hasHeightForWidth());
        activeFilterCO->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(activeFilterCO, 1, 1, 1, 1);

        activeFilterLA = new QLabel(TocUi);
        activeFilterLA->setObjectName(QStringLiteral("activeFilterLA"));

        gridLayout_2->addWidget(activeFilterLA, 1, 0, 1, 1);

        filterLA = new QLabel(TocUi);
        filterLA->setObjectName(QStringLiteral("filterLA"));

        gridLayout_2->addWidget(filterLA, 2, 0, 1, 1);

        typeCO = new QComboBox(TocUi);
        typeCO->setObjectName(QStringLiteral("typeCO"));
        sizePolicy1.setHeightForWidth(typeCO->sizePolicy().hasHeightForWidth());
        typeCO->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(typeCO, 0, 0, 1, 2);

        filterBarL = new QHBoxLayout();
        filterBarL->setObjectName(QStringLiteral("filterBarL"));

        gridLayout_2->addLayout(filterBarL, 2, 1, 1, 1);


        gridLayout->addLayout(gridLayout_2, 0, 0, 1, 2);

#ifndef QT_NO_SHORTCUT
        activeFilterLA->setBuddy(activeFilterCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(TocUi);

        QMetaObject::connectSlotsByName(TocUi);
    } // setupUi

    void retranslateUi(QWidget *TocUi)
    {
        TocUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        updateTB->setToolTip(lyx::qt_("Update navigation tree", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        updateTB->setText(lyx::qt_("...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        moveOutTB->setToolTip(lyx::qt_("Decrease nesting depth of selected item", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        moveOutTB->setText(lyx::qt_("...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        moveInTB->setToolTip(lyx::qt_("Increase nesting depth of selected item", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        moveInTB->setText(lyx::qt_("...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        moveUpTB->setToolTip(lyx::qt_("Move selected item up by one", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        moveUpTB->setText(lyx::qt_("...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        moveDownTB->setToolTip(lyx::qt_("Move selected item down by one", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        moveDownTB->setText(lyx::qt_("...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        depthSL->setToolTip(lyx::qt_("Adjust the depth of the navigation tree", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        sortCB->setText(lyx::qt_("Sort", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        persistentCB->setToolTip(lyx::qt_("Try to keep persistent view of the uncollapsed nodes", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        persistentCB->setText(lyx::qt_("Keep", Q_NULLPTR));
        activeFilterCO->clear();
        activeFilterCO->insertItems(0, QStringList()
         << lyx::qt_("All items", Q_NULLPTR)
         << lyx::qt_("Only output items", Q_NULLPTR)
         << lyx::qt_("Only non-output items", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        activeFilterCO->setToolTip(lyx::qt_("Filter items that are not output (in notes, inactive branches, deleted in change tracking, etc.)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        activeFilterLA->setText(lyx::qt_("Sho&w:", Q_NULLPTR));
        filterLA->setText(lyx::qt_("&Filter:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        typeCO->setToolTip(lyx::qt_("Switch between available lists (table of contents, list of figures, list of tables, and others)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class TocUi: public Ui_TocUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOCUI_H
