/********************************************************************************
** Form generated from reading UI file 'ThesaurusUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THESAURUSUI_H
#define UI_THESAURUSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ThesaurusUi
{
public:
    QGridLayout *gridLayout;
    QLabel *languageLA;
    QComboBox *languageCO;
    QLabel *entryLA;
    QPushButton *lookupPB;
    QLabel *selectionLA;
    QLineEdit *replaceED;
    QPushButton *replacePB;
    QTreeWidget *meaningsTV;
    QDialogButtonBox *buttonBox;
    QComboBox *entryCO;

    void setupUi(QDialog *ThesaurusUi)
    {
        if (ThesaurusUi->objectName().isEmpty())
            ThesaurusUi->setObjectName(QStringLiteral("ThesaurusUi"));
        ThesaurusUi->resize(313, 414);
        ThesaurusUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(ThesaurusUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        languageLA = new QLabel(ThesaurusUi);
        languageLA->setObjectName(QStringLiteral("languageLA"));

        gridLayout->addWidget(languageLA, 0, 0, 1, 1);

        languageCO = new QComboBox(ThesaurusUi);
        languageCO->setObjectName(QStringLiteral("languageCO"));

        gridLayout->addWidget(languageCO, 0, 1, 1, 3);

        entryLA = new QLabel(ThesaurusUi);
        entryLA->setObjectName(QStringLiteral("entryLA"));

        gridLayout->addWidget(entryLA, 1, 0, 1, 1);

        lookupPB = new QPushButton(ThesaurusUi);
        lookupPB->setObjectName(QStringLiteral("lookupPB"));

        gridLayout->addWidget(lookupPB, 1, 3, 1, 1);

        selectionLA = new QLabel(ThesaurusUi);
        selectionLA->setObjectName(QStringLiteral("selectionLA"));

        gridLayout->addWidget(selectionLA, 2, 0, 1, 1);

        replaceED = new QLineEdit(ThesaurusUi);
        replaceED->setObjectName(QStringLiteral("replaceED"));

        gridLayout->addWidget(replaceED, 2, 1, 1, 2);

        replacePB = new QPushButton(ThesaurusUi);
        replacePB->setObjectName(QStringLiteral("replacePB"));

        gridLayout->addWidget(replacePB, 2, 3, 1, 1);

        meaningsTV = new QTreeWidget(ThesaurusUi);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        meaningsTV->setHeaderItem(__qtreewidgetitem);
        meaningsTV->setObjectName(QStringLiteral("meaningsTV"));

        gridLayout->addWidget(meaningsTV, 3, 0, 1, 4);

        buttonBox = new QDialogButtonBox(ThesaurusUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 4, 2, 1, 2);

        entryCO = new QComboBox(ThesaurusUi);
        entryCO->setObjectName(QStringLiteral("entryCO"));
        entryCO->setEditable(true);

        gridLayout->addWidget(entryCO, 1, 1, 1, 2);

        gridLayout->setColumnStretch(1, 1);
        gridLayout->setColumnStretch(2, 1);
#ifndef QT_NO_SHORTCUT
        languageLA->setBuddy(languageCO);
        entryLA->setBuddy(entryCO);
        selectionLA->setBuddy(replaceED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(languageCO, entryCO);
        QWidget::setTabOrder(entryCO, lookupPB);
        QWidget::setTabOrder(lookupPB, replaceED);
        QWidget::setTabOrder(replaceED, replacePB);
        QWidget::setTabOrder(replacePB, meaningsTV);

        retranslateUi(ThesaurusUi);

        QMetaObject::connectSlotsByName(ThesaurusUi);
    } // setupUi

    void retranslateUi(QDialog *ThesaurusUi)
    {
        ThesaurusUi->setWindowTitle(QString());
        languageLA->setText(lyx::qt_("&Language:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        languageCO->setToolTip(lyx::qt_("Language of the thesaurus", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        entryLA->setToolTip(lyx::qt_("Index entry", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        entryLA->setText(lyx::qt_("&Keyword:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lookupPB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        lookupPB->setText(lyx::qt_("L&ookup", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        selectionLA->setToolTip(lyx::qt_("The selected entry", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        selectionLA->setText(lyx::qt_("Sele&ction:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        replaceED->setToolTip(lyx::qt_("The selected entry", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        replacePB->setToolTip(lyx::qt_("Replace the entry with the selection", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        replacePB->setText(lyx::qt_("&Replace", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        meaningsTV->setToolTip(lyx::qt_("Click to select a proposal, double click to look it up.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        entryCO->setToolTip(lyx::qt_("Word to look up", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class ThesaurusUi: public Ui_ThesaurusUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_THESAURUSUI_H
