/****************************************************************************
** Meta object code from reading C++ file 'GuiViewSource.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiViewSource.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiViewSource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__ViewSourceWidget_t {
    QByteArrayData data[14];
    char stringdata0[182];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__ViewSourceWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__ViewSourceWidget_t qt_meta_stringdata_lyx__frontend__ViewSourceWidget = {
    {
QT_MOC_LITERAL(0, 0, 31), // "lyx::frontend::ViewSourceWidget"
QT_MOC_LITERAL(1, 32, 10), // "needUpdate"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 10), // "updateView"
QT_MOC_LITERAL(4, 55, 17), // "const BufferView*"
QT_MOC_LITERAL(5, 73, 2), // "bv"
QT_MOC_LITERAL(6, 76, 13), // "setViewFormat"
QT_MOC_LITERAL(7, 90, 5), // "index"
QT_MOC_LITERAL(8, 96, 19), // "updateDefaultFormat"
QT_MOC_LITERAL(9, 116, 10), // "BufferView"
QT_MOC_LITERAL(10, 127, 15), // "contentsChanged"
QT_MOC_LITERAL(11, 143, 10), // "goToCursor"
QT_MOC_LITERAL(12, 154, 17), // "currentFormatName"
QT_MOC_LITERAL(13, 172, 9) // "docstring"

    },
    "lyx::frontend::ViewSourceWidget\0"
    "needUpdate\0\0updateView\0const BufferView*\0"
    "bv\0setViewFormat\0index\0updateDefaultFormat\0"
    "BufferView\0contentsChanged\0goToCursor\0"
    "currentFormatName\0docstring"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__ViewSourceWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   50,    2, 0x0a /* Public */,
       6,    1,   53,    2, 0x0a /* Public */,
       8,    1,   56,    2, 0x0a /* Public */,
      10,    0,   59,    2, 0x0a /* Public */,
      11,    0,   60,    2, 0x0a /* Public */,
      12,    1,   61,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, 0x80000000 | 9,    5,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 13, 0x80000000 | 4,    5,

       0        // eod
};

void lyx::frontend::ViewSourceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewSourceWidget *_t = static_cast<ViewSourceWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->needUpdate(); break;
        case 1: _t->updateView((*reinterpret_cast< const BufferView*(*)>(_a[1]))); break;
        case 2: _t->setViewFormat((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 3: _t->updateDefaultFormat((*reinterpret_cast< const BufferView(*)>(_a[1]))); break;
        case 4: _t->contentsChanged(); break;
        case 5: _t->goToCursor(); break;
        case 6: { docstring _r = _t->currentFormatName((*reinterpret_cast< const BufferView*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< docstring*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ViewSourceWidget::*_t)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewSourceWidget::needUpdate)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::ViewSourceWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__ViewSourceWidget.data,
      qt_meta_data_lyx__frontend__ViewSourceWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::ViewSourceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::ViewSourceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__ViewSourceWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ViewSourceUi"))
        return static_cast< Ui::ViewSourceUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::ViewSourceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::ViewSourceWidget::needUpdate()const
{
    QMetaObject::activate(const_cast< lyx::frontend::ViewSourceWidget *>(this), &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__GuiViewSource_t {
    QByteArrayData data[7];
    char stringdata0[110];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiViewSource_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiViewSource_t qt_meta_stringdata_lyx__frontend__GuiViewSource = {
    {
QT_MOC_LITERAL(0, 0, 28), // "lyx::frontend::GuiViewSource"
QT_MOC_LITERAL(1, 29, 19), // "onBufferViewChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 11), // "updateTitle"
QT_MOC_LITERAL(4, 62, 14), // "scheduleUpdate"
QT_MOC_LITERAL(5, 77, 17), // "scheduleUpdateNow"
QT_MOC_LITERAL(6, 95, 14) // "realUpdateView"

    },
    "lyx::frontend::GuiViewSource\0"
    "onBufferViewChanged\0\0updateTitle\0"
    "scheduleUpdate\0scheduleUpdateNow\0"
    "realUpdateView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiViewSource[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x0a /* Public */,
       3,    0,   40,    2, 0x08 /* Private */,
       4,    0,   41,    2, 0x08 /* Private */,
       5,    0,   42,    2, 0x08 /* Private */,
       6,    0,   43,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiViewSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiViewSource *_t = static_cast<GuiViewSource *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onBufferViewChanged(); break;
        case 1: _t->updateTitle(); break;
        case 2: _t->scheduleUpdate(); break;
        case 3: _t->scheduleUpdateNow(); break;
        case 4: _t->realUpdateView(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::GuiViewSource::staticMetaObject = {
    { &DockView::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiViewSource.data,
      qt_meta_data_lyx__frontend__GuiViewSource,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiViewSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiViewSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiViewSource.stringdata0))
        return static_cast<void*>(this);
    return DockView::qt_metacast(_clname);
}

int lyx::frontend::GuiViewSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
