/****************************************************************************
** Meta object code from reading C++ file 'GuiGraphics.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiGraphics.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiGraphics.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiGraphics_t {
    QByteArrayData data[14];
    char stringdata0[249];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiGraphics_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiGraphics_t qt_meta_stringdata_lyx__frontend__GuiGraphics = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiGraphics"
QT_MOC_LITERAL(1, 27, 14), // "change_adaptor"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 11), // "changeGroup"
QT_MOC_LITERAL(4, 55, 8), // "changeBB"
QT_MOC_LITERAL(5, 64, 21), // "on_newGroupPB_clicked"
QT_MOC_LITERAL(6, 86, 19), // "on_browsePB_clicked"
QT_MOC_LITERAL(7, 106, 16), // "on_getPB_clicked"
QT_MOC_LITERAL(8, 123, 18), // "on_scaleCB_toggled"
QT_MOC_LITERAL(9, 142, 18), // "on_WidthCB_toggled"
QT_MOC_LITERAL(10, 161, 19), // "on_HeightCB_toggled"
QT_MOC_LITERAL(11, 181, 23), // "updateAspectRatioStatus"
QT_MOC_LITERAL(12, 205, 22), // "on_aspectratio_toggled"
QT_MOC_LITERAL(13, 228, 20) // "on_angle_textChanged"

    },
    "lyx::frontend::GuiGraphics\0change_adaptor\0"
    "\0changeGroup\0changeBB\0on_newGroupPB_clicked\0"
    "on_browsePB_clicked\0on_getPB_clicked\0"
    "on_scaleCB_toggled\0on_WidthCB_toggled\0"
    "on_HeightCB_toggled\0updateAspectRatioStatus\0"
    "on_aspectratio_toggled\0on_angle_textChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiGraphics[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x08 /* Private */,
       3,    1,   75,    2, 0x08 /* Private */,
       4,    0,   78,    2, 0x08 /* Private */,
       5,    0,   79,    2, 0x08 /* Private */,
       6,    0,   80,    2, 0x08 /* Private */,
       7,    0,   81,    2, 0x08 /* Private */,
       8,    1,   82,    2, 0x08 /* Private */,
       9,    1,   85,    2, 0x08 /* Private */,
      10,    1,   88,    2, 0x08 /* Private */,
      11,    0,   91,    2, 0x08 /* Private */,
      12,    1,   92,    2, 0x08 /* Private */,
      13,    1,   95,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void lyx::frontend::GuiGraphics::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiGraphics *_t = static_cast<GuiGraphics *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->change_adaptor(); break;
        case 1: _t->changeGroup((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->changeBB(); break;
        case 3: _t->on_newGroupPB_clicked(); break;
        case 4: _t->on_browsePB_clicked(); break;
        case 5: _t->on_getPB_clicked(); break;
        case 6: _t->on_scaleCB_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->on_WidthCB_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->on_HeightCB_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->updateAspectRatioStatus(); break;
        case 10: _t->on_aspectratio_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->on_angle_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiGraphics::staticMetaObject = {
    { &GuiDialog::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiGraphics.data,
      qt_meta_data_lyx__frontend__GuiGraphics,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiGraphics::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiGraphics::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiGraphics.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::GraphicsUi"))
        return static_cast< Ui::GraphicsUi*>(this);
    return GuiDialog::qt_metacast(_clname);
}

int lyx::frontend::GuiGraphics::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
