/********************************************************************************
** Form generated from reading UI file 'SendtoUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SENDTOUI_H
#define UI_SENDTOUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_SendtoUi
{
public:
    QGridLayout *gridLayout;
    QListWidget *formatLW;
    QComboBox *commandCO;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;
    QLabel *formatLA;
    QLabel *commandLA;

    void setupUi(QDialog *SendtoUi)
    {
        if (SendtoUi->objectName().isEmpty())
            SendtoUi->setObjectName(QStringLiteral("SendtoUi"));
        SendtoUi->resize(296, 262);
        SendtoUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(SendtoUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        formatLW = new QListWidget(SendtoUi);
        formatLW->setObjectName(QStringLiteral("formatLW"));

        gridLayout->addWidget(formatLW, 1, 0, 1, 1);

        commandCO = new QComboBox(SendtoUi);
        commandCO->setObjectName(QStringLiteral("commandCO"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(commandCO->sizePolicy().hasHeightForWidth());
        commandCO->setSizePolicy(sizePolicy);
        commandCO->setFocusPolicy(Qt::StrongFocus);
        commandCO->setEditable(true);
        commandCO->setMaxCount(666);
        commandCO->setInsertPolicy(QComboBox::NoInsert);
        commandCO->setDuplicatesEnabled(false);

        gridLayout->addWidget(commandCO, 3, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(SendtoUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout->addWidget(buttonBox);


        gridLayout->addLayout(hboxLayout, 4, 0, 1, 1);

        formatLA = new QLabel(SendtoUi);
        formatLA->setObjectName(QStringLiteral("formatLA"));

        gridLayout->addWidget(formatLA, 0, 0, 1, 1);

        commandLA = new QLabel(SendtoUi);
        commandLA->setObjectName(QStringLiteral("commandLA"));

        gridLayout->addWidget(commandLA, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        formatLA->setBuddy(formatLW);
        commandLA->setBuddy(commandCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(formatLW, commandCO);

        retranslateUi(SendtoUi);

        QMetaObject::connectSlotsByName(SendtoUi);
    } // setupUi

    void retranslateUi(QDialog *SendtoUi)
    {
        SendtoUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        commandCO->setToolTip(lyx::qt_("Process the converted file with this command ($$FName = file name)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        formatLA->setText(lyx::qt_("Export for&mats:", Q_NULLPTR));
        commandLA->setText(lyx::qt_("Send exported file to &command:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SendtoUi: public Ui_SendtoUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SENDTOUI_H
