/********************************************************************************
** Form generated from reading UI file 'AboutUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTUI_H
#define UI_ABOUTUI_H

#include <QtCore/QVariant>
#include <QtSvg/QSvgWidget>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_AboutUi
{
public:
    QGridLayout *gridLayout_2;
    QTabWidget *tab;
    QWidget *versiontab;
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QSvgWidget *iconSW;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_3;
    QLabel *versionLA;
    QSpacerItem *verticalSpacer;
    QGroupBox *gridGroupBox;
    QGridLayout *gridLayout_3;
    QPushButton *showDirLibraryPB;
    QLabel *dirLibraryLA;
    QGroupBox *gridGroupBox1;
    QGridLayout *gridLayout_4;
    QLabel *dirUserLA;
    QPushButton *showDirUserPB;
    QGroupBox *gridGroupBox2;
    QGridLayout *gridLayout_9;
    QLabel *dirTempLA;
    QPushButton *showDirTempPB;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_4;
    QWidget *creditstab;
    QGridLayout *gridLayout1;
    QTextBrowser *creditsTB;
    QWidget *copyrighttab;
    QGridLayout *gridLayout2;
    QTextBrowser *copyrightTB;
    QWidget *buildinfotab;
    QGridLayout *gridLayout3;
    QTextBrowser *buildinfoTB;
    QWidget *releasenotestab;
    QGridLayout *gridLayout4;
    QTextBrowser *releasenotesTB;
    QHBoxLayout *hboxLayout;
    QPushButton *versionCopyPB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AboutUi)
    {
        if (AboutUi->objectName().isEmpty())
            AboutUi->setObjectName(QStringLiteral("AboutUi"));
        AboutUi->resize(552, 504);
        AboutUi->setSizeGripEnabled(true);
        gridLayout_2 = new QGridLayout(AboutUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        tab = new QTabWidget(AboutUi);
        tab->setObjectName(QStringLiteral("tab"));
        versiontab = new QWidget();
        versiontab->setObjectName(QStringLiteral("versiontab"));
        gridLayout = new QGridLayout(versiontab);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setSizeConstraint(QLayout::SetFixedSize);
        iconSW = new QSvgWidget(versiontab);
        iconSW->setObjectName(QStringLiteral("iconSW"));
        iconSW->setMinimumSize(QSize(80, 80));

        verticalLayout->addWidget(iconSW);

        verticalSpacer_2 = new QSpacerItem(20, 188, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        verticalSpacer_3 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_3);

        versionLA = new QLabel(versiontab);
        versionLA->setObjectName(QStringLiteral("versionLA"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(versionLA->sizePolicy().hasHeightForWidth());
        versionLA->setSizePolicy(sizePolicy);
        versionLA->setCursor(QCursor(Qt::IBeamCursor));
        versionLA->setText(QStringLiteral("<html><head/><body><p><span style=\" font-weight:600;\">LyX version info goes here.</span></p><p>Qt version (run-time) goes here.</p><p>Qt version (compile-time) goes here.</p></body></html>"));
        versionLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        versionLA->setWordWrap(true);
        versionLA->setMargin(0);
        versionLA->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout_2->addWidget(versionLA);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        verticalLayout_2->addItem(verticalSpacer);

        gridGroupBox = new QGroupBox(versiontab);
        gridGroupBox->setObjectName(QStringLiteral("gridGroupBox"));
        gridLayout_3 = new QGridLayout(gridGroupBox);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        showDirLibraryPB = new QPushButton(gridGroupBox);
        showDirLibraryPB->setObjectName(QStringLiteral("showDirLibraryPB"));
        QSizePolicy sizePolicy1(QSizePolicy::Maximum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(showDirLibraryPB->sizePolicy().hasHeightForWidth());
        showDirLibraryPB->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(showDirLibraryPB, 0, 2, 1, 1);

        dirLibraryLA = new QLabel(gridGroupBox);
        dirLibraryLA->setObjectName(QStringLiteral("dirLibraryLA"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(dirLibraryLA->sizePolicy().hasHeightForWidth());
        dirLibraryLA->setSizePolicy(sizePolicy2);
        dirLibraryLA->setCursor(QCursor(Qt::IBeamCursor));
        dirLibraryLA->setText(QStringLiteral("System directory goes here."));
        dirLibraryLA->setTextFormat(Qt::PlainText);
        dirLibraryLA->setWordWrap(false);
        dirLibraryLA->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_3->addWidget(dirLibraryLA, 0, 1, 1, 1);


        verticalLayout_2->addWidget(gridGroupBox);

        gridGroupBox1 = new QGroupBox(versiontab);
        gridGroupBox1->setObjectName(QStringLiteral("gridGroupBox1"));
        gridLayout_4 = new QGridLayout(gridGroupBox1);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        dirUserLA = new QLabel(gridGroupBox1);
        dirUserLA->setObjectName(QStringLiteral("dirUserLA"));
        dirUserLA->setCursor(QCursor(Qt::IBeamCursor));
        dirUserLA->setText(QStringLiteral("User directory goes here."));
        dirUserLA->setTextFormat(Qt::PlainText);
        dirUserLA->setWordWrap(false);
        dirUserLA->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_4->addWidget(dirUserLA, 0, 0, 1, 1);

        showDirUserPB = new QPushButton(gridGroupBox1);
        showDirUserPB->setObjectName(QStringLiteral("showDirUserPB"));
        sizePolicy1.setHeightForWidth(showDirUserPB->sizePolicy().hasHeightForWidth());
        showDirUserPB->setSizePolicy(sizePolicy1);
        showDirUserPB->setFlat(false);

        gridLayout_4->addWidget(showDirUserPB, 0, 1, 1, 1);


        verticalLayout_2->addWidget(gridGroupBox1);

        gridGroupBox2 = new QGroupBox(versiontab);
        gridGroupBox2->setObjectName(QStringLiteral("gridGroupBox2"));
        gridLayout_9 = new QGridLayout(gridGroupBox2);
        gridLayout_9->setObjectName(QStringLiteral("gridLayout_9"));
        dirTempLA = new QLabel(gridGroupBox2);
        dirTempLA->setObjectName(QStringLiteral("dirTempLA"));
        dirTempLA->setCursor(QCursor(Qt::IBeamCursor));
        dirTempLA->setText(QStringLiteral("Temp directory goes here."));
        dirTempLA->setTextFormat(Qt::PlainText);
        dirTempLA->setWordWrap(false);
        dirTempLA->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_9->addWidget(dirTempLA, 0, 0, 1, 1);

        showDirTempPB = new QPushButton(gridGroupBox2);
        showDirTempPB->setObjectName(QStringLiteral("showDirTempPB"));
        sizePolicy1.setHeightForWidth(showDirTempPB->sizePolicy().hasHeightForWidth());
        showDirTempPB->setSizePolicy(sizePolicy1);
        showDirTempPB->setFlat(false);

        gridLayout_9->addWidget(showDirTempPB, 0, 1, 1, 1);


        verticalLayout_2->addWidget(gridGroupBox2);


        gridLayout->addLayout(verticalLayout_2, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer_4, 1, 2, 1, 1);

        tab->addTab(versiontab, QString());
        creditstab = new QWidget();
        creditstab->setObjectName(QStringLiteral("creditstab"));
        gridLayout1 = new QGridLayout(creditstab);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        creditsTB = new QTextBrowser(creditstab);
        creditsTB->setObjectName(QStringLiteral("creditsTB"));

        gridLayout1->addWidget(creditsTB, 0, 0, 1, 1);

        tab->addTab(creditstab, QString());
        copyrighttab = new QWidget();
        copyrighttab->setObjectName(QStringLiteral("copyrighttab"));
        gridLayout2 = new QGridLayout(copyrighttab);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        copyrightTB = new QTextBrowser(copyrighttab);
        copyrightTB->setObjectName(QStringLiteral("copyrightTB"));

        gridLayout2->addWidget(copyrightTB, 0, 0, 1, 1);

        tab->addTab(copyrighttab, QString());
        buildinfotab = new QWidget();
        buildinfotab->setObjectName(QStringLiteral("buildinfotab"));
        gridLayout3 = new QGridLayout(buildinfotab);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        buildinfoTB = new QTextBrowser(buildinfotab);
        buildinfoTB->setObjectName(QStringLiteral("buildinfoTB"));

        gridLayout3->addWidget(buildinfoTB, 0, 0, 1, 1);

        tab->addTab(buildinfotab, QString());
        releasenotestab = new QWidget();
        releasenotestab->setObjectName(QStringLiteral("releasenotestab"));
        gridLayout4 = new QGridLayout(releasenotestab);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        releasenotesTB = new QTextBrowser(releasenotestab);
        releasenotesTB->setObjectName(QStringLiteral("releasenotesTB"));

        gridLayout4->addWidget(releasenotesTB, 0, 0, 1, 1);

        tab->addTab(releasenotestab, QString());

        gridLayout_2->addWidget(tab, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        versionCopyPB = new QPushButton(AboutUi);
        versionCopyPB->setObjectName(QStringLiteral("versionCopyPB"));

        hboxLayout->addWidget(versionCopyPB);

        buttonBox = new QDialogButtonBox(AboutUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        hboxLayout->addWidget(buttonBox);


        gridLayout_2->addLayout(hboxLayout, 1, 0, 1, 1);


        retranslateUi(AboutUi);

        tab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AboutUi);
    } // setupUi

    void retranslateUi(QDialog *AboutUi)
    {
        AboutUi->setWindowTitle(QString());
        gridGroupBox->setTitle(lyx::qt_("System directory", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        showDirLibraryPB->setToolTip(lyx::qt_("Open system directory in file browser", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        showDirLibraryPB->setText(lyx::qt_("[[do]]&Open", Q_NULLPTR));
        gridGroupBox1->setTitle(lyx::qt_("User directory", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        showDirUserPB->setToolTip(lyx::qt_("Open user directory in file browser", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        showDirUserPB->setText(lyx::qt_("[[do]]O&pen", Q_NULLPTR));
        gridGroupBox2->setTitle(lyx::qt_("Temporary directory", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        showDirTempPB->setToolTip(lyx::qt_("Open temporary directory in file browser", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        showDirTempPB->setText(lyx::qt_("[[do]]O&pen", Q_NULLPTR));
        tab->setTabText(tab->indexOf(versiontab), lyx::qt_("Version", Q_NULLPTR));
        tab->setTabText(tab->indexOf(creditstab), lyx::qt_("Credits", Q_NULLPTR));
        tab->setTabText(tab->indexOf(copyrighttab), lyx::qt_("Copyright", Q_NULLPTR));
        tab->setTabText(tab->indexOf(buildinfotab), lyx::qt_("Build Info", Q_NULLPTR));
        tab->setTabText(tab->indexOf(releasenotestab), lyx::qt_("Release Notes", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        versionCopyPB->setToolTip(lyx::qt_("Copy version information to clipboard", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        versionCopyPB->setText(lyx::qt_("Copy &Version Info", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class AboutUi: public Ui_AboutUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTUI_H
