/********************************************************************************
** Form generated from reading UI file 'PrefLanguageUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFLANGUAGEUI_H
#define UI_PREFLANGUAGEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefLanguageUi
{
public:
    QGridLayout *gridLayout_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *uiLanguageLA;
    QComboBox *uiLanguageCO;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *languagePackageLA;
    QComboBox *languagePackageCO;
    QLineEdit *languagePackageED;
    QLabel *startCommandLA;
    QLineEdit *startCommandED;
    QLabel *endCommandLA;
    QLineEdit *endCommandED;
    QCheckBox *globalCB;
    QCheckBox *explicitDocLangBeginCB;
    QCheckBox *explicitDocLangEndCB;
    QGroupBox *rtlGB2;
    QGridLayout *gridLayout;
    QCheckBox *markForeignCB;
    QCheckBox *respectOSkbdCB;
    QHBoxLayout *hboxLayout;
    QLabel *cursorMovementLA;
    QRadioButton *logicalCursorRB;
    QRadioButton *visualCursorRB;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QLabel *decimalPointL;
    QSpacerItem *horizontalSpacer_2;
    QLineEdit *defaultDecimalSepED;
    QLabel *defaultLengthUnitLA;
    QComboBox *defaultDecimalSepCO;
    QComboBox *defaultLengthUnitCO;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *PrefLanguageUi)
    {
        if (PrefLanguageUi->objectName().isEmpty())
            PrefLanguageUi->setObjectName(QStringLiteral("PrefLanguageUi"));
        PrefLanguageUi->resize(517, 570);
        gridLayout_4 = new QGridLayout(PrefLanguageUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        uiLanguageLA = new QLabel(PrefLanguageUi);
        uiLanguageLA->setObjectName(QStringLiteral("uiLanguageLA"));

        horizontalLayout_2->addWidget(uiLanguageLA);

        uiLanguageCO = new QComboBox(PrefLanguageUi);
        uiLanguageCO->setObjectName(QStringLiteral("uiLanguageCO"));
        uiLanguageCO->setMaxVisibleItems(20);

        horizontalLayout_2->addWidget(uiLanguageCO);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        gridLayout_4->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        groupBox = new QGroupBox(PrefLanguageUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        languagePackageLA = new QLabel(groupBox);
        languagePackageLA->setObjectName(QStringLiteral("languagePackageLA"));

        gridLayout_2->addWidget(languagePackageLA, 0, 0, 1, 1);

        languagePackageCO = new QComboBox(groupBox);
        languagePackageCO->setObjectName(QStringLiteral("languagePackageCO"));

        gridLayout_2->addWidget(languagePackageCO, 0, 1, 1, 1);

        languagePackageED = new QLineEdit(groupBox);
        languagePackageED->setObjectName(QStringLiteral("languagePackageED"));

        gridLayout_2->addWidget(languagePackageED, 0, 2, 1, 1);

        startCommandLA = new QLabel(groupBox);
        startCommandLA->setObjectName(QStringLiteral("startCommandLA"));

        gridLayout_2->addWidget(startCommandLA, 1, 0, 1, 1);

        startCommandED = new QLineEdit(groupBox);
        startCommandED->setObjectName(QStringLiteral("startCommandED"));

        gridLayout_2->addWidget(startCommandED, 1, 1, 1, 2);

        endCommandLA = new QLabel(groupBox);
        endCommandLA->setObjectName(QStringLiteral("endCommandLA"));

        gridLayout_2->addWidget(endCommandLA, 2, 0, 1, 1);

        endCommandED = new QLineEdit(groupBox);
        endCommandED->setObjectName(QStringLiteral("endCommandED"));

        gridLayout_2->addWidget(endCommandED, 2, 1, 1, 2);

        globalCB = new QCheckBox(groupBox);
        globalCB->setObjectName(QStringLiteral("globalCB"));

        gridLayout_2->addWidget(globalCB, 3, 0, 1, 2);

        explicitDocLangBeginCB = new QCheckBox(groupBox);
        explicitDocLangBeginCB->setObjectName(QStringLiteral("explicitDocLangBeginCB"));

        gridLayout_2->addWidget(explicitDocLangBeginCB, 4, 0, 1, 2);

        explicitDocLangEndCB = new QCheckBox(groupBox);
        explicitDocLangEndCB->setObjectName(QStringLiteral("explicitDocLangEndCB"));

        gridLayout_2->addWidget(explicitDocLangEndCB, 5, 0, 1, 2);


        gridLayout_4->addWidget(groupBox, 1, 0, 1, 1);

        rtlGB2 = new QGroupBox(PrefLanguageUi);
        rtlGB2->setObjectName(QStringLiteral("rtlGB2"));
        rtlGB2->setFlat(true);
        rtlGB2->setCheckable(false);
        gridLayout = new QGridLayout(rtlGB2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        markForeignCB = new QCheckBox(rtlGB2);
        markForeignCB->setObjectName(QStringLiteral("markForeignCB"));

        gridLayout->addWidget(markForeignCB, 0, 0, 1, 1);

        respectOSkbdCB = new QCheckBox(rtlGB2);
        respectOSkbdCB->setObjectName(QStringLiteral("respectOSkbdCB"));

        gridLayout->addWidget(respectOSkbdCB, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        cursorMovementLA = new QLabel(rtlGB2);
        cursorMovementLA->setObjectName(QStringLiteral("cursorMovementLA"));
        cursorMovementLA->setScaledContents(false);

        hboxLayout->addWidget(cursorMovementLA);

        logicalCursorRB = new QRadioButton(rtlGB2);
        logicalCursorRB->setObjectName(QStringLiteral("logicalCursorRB"));
        logicalCursorRB->setChecked(true);

        hboxLayout->addWidget(logicalCursorRB);

        visualCursorRB = new QRadioButton(rtlGB2);
        visualCursorRB->setObjectName(QStringLiteral("visualCursorRB"));

        hboxLayout->addWidget(visualCursorRB);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 2, 1, 1, 1);


        gridLayout_4->addWidget(rtlGB2, 2, 0, 1, 1);

        groupBox_2 = new QGroupBox(PrefLanguageUi);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        decimalPointL = new QLabel(groupBox_2);
        decimalPointL->setObjectName(QStringLiteral("decimalPointL"));

        gridLayout_3->addWidget(decimalPointL, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 1, 6, 1, 1);

        defaultDecimalSepED = new QLineEdit(groupBox_2);
        defaultDecimalSepED->setObjectName(QStringLiteral("defaultDecimalSepED"));
        defaultDecimalSepED->setMaximumSize(QSize(40, 16777215));
        defaultDecimalSepED->setAlignment(Qt::AlignCenter);

        gridLayout_3->addWidget(defaultDecimalSepED, 0, 3, 1, 1);

        defaultLengthUnitLA = new QLabel(groupBox_2);
        defaultLengthUnitLA->setObjectName(QStringLiteral("defaultLengthUnitLA"));

        gridLayout_3->addWidget(defaultLengthUnitLA, 1, 0, 1, 1);

        defaultDecimalSepCO = new QComboBox(groupBox_2);
        defaultDecimalSepCO->setObjectName(QStringLiteral("defaultDecimalSepCO"));

        gridLayout_3->addWidget(defaultDecimalSepCO, 0, 1, 1, 1);

        defaultLengthUnitCO = new QComboBox(groupBox_2);
        defaultLengthUnitCO->setObjectName(QStringLiteral("defaultLengthUnitCO"));

        gridLayout_3->addWidget(defaultLengthUnitCO, 1, 1, 1, 1);


        gridLayout_4->addWidget(groupBox_2, 3, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem, 4, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        uiLanguageLA->setBuddy(uiLanguageCO);
        languagePackageLA->setBuddy(languagePackageCO);
        startCommandLA->setBuddy(startCommandED);
        endCommandLA->setBuddy(endCommandED);
        decimalPointL->setBuddy(defaultDecimalSepED);
        defaultLengthUnitLA->setBuddy(defaultLengthUnitCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(uiLanguageCO, languagePackageCO);
        QWidget::setTabOrder(languagePackageCO, languagePackageED);
        QWidget::setTabOrder(languagePackageED, startCommandED);
        QWidget::setTabOrder(startCommandED, endCommandED);
        QWidget::setTabOrder(endCommandED, defaultDecimalSepED);
        QWidget::setTabOrder(defaultDecimalSepED, globalCB);
        QWidget::setTabOrder(globalCB, explicitDocLangBeginCB);
        QWidget::setTabOrder(explicitDocLangBeginCB, markForeignCB);
        QWidget::setTabOrder(markForeignCB, respectOSkbdCB);
        QWidget::setTabOrder(respectOSkbdCB, logicalCursorRB);
        QWidget::setTabOrder(logicalCursorRB, visualCursorRB);

        retranslateUi(PrefLanguageUi);

        QMetaObject::connectSlotsByName(PrefLanguageUi);
    } // setupUi

    void retranslateUi(QWidget *PrefLanguageUi)
    {
        PrefLanguageUi->setWindowTitle(QString());
        uiLanguageLA->setText(lyx::qt_("User &interface language:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        uiLanguageCO->setToolTip(lyx::qt_("Select the language of the user interface (menus, dialogs, etc.)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(lyx::qt_("LaTeX Language Support", Q_NULLPTR));
        languagePackageLA->setText(lyx::qt_("Language &package:", Q_NULLPTR));
        languagePackageCO->clear();
        languagePackageCO->insertItems(0, QStringList()
         << lyx::qt_("Automatic", Q_NULLPTR)
         << lyx::qt_("Always Babel", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
         << lyx::qt_("None[[language package]]", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        languagePackageCO->setToolTip(lyx::qt_("Select which (LaTeX) language package documents should use by default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        languagePackageED->setToolTip(lyx::qt_("Enter the command to load a custom language package (default: \\usepackage{babel})", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        startCommandLA->setText(lyx::qt_("Command s&tart:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        startCommandED->setToolTip(lyx::qt_("The LaTeX command that starts a switch to a different language. The placeholder $$lang is replaced by the actual language name.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        endCommandLA->setText(lyx::qt_("Command e&nd:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        endCommandED->setToolTip(lyx::qt_("The LaTeX command that ends a switch to a different language.  The placeholder $$lang is replaced by the actual language name.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        globalCB->setToolTip(lyx::qt_("Check to pass the language globally (to the document class), not locally (to the language package), so that other packages are also informed about the used languages.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        globalCB->setText(lyx::qt_("Set languages &globally", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        explicitDocLangBeginCB->setToolTip(lyx::qt_("If checked, the document language is explicitly set by a language switch command", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        explicitDocLangBeginCB->setText(lyx::qt_("Set document language e&xplicitly", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        explicitDocLangEndCB->setToolTip(lyx::qt_("If checked, the document language is explicitly closed by a language switch command", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        explicitDocLangEndCB->setText(lyx::qt_("&Unset document language explicitly", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rtlGB2->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        rtlGB2->setTitle(lyx::qt_("Editor Settings", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        markForeignCB->setToolTip(lyx::qt_("Check to highlight additional languages (to the document language) visually in the work area", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        markForeignCB->setText(lyx::qt_("&Mark additional languages", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        respectOSkbdCB->setToolTip(lyx::qt_("Select to use the current keyboard language, as set from the operating system, as default input language.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        respectOSkbdCB->setText(lyx::qt_("Respect &OS keyboard language", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        cursorMovementLA->setToolTip(lyx::qt_("Specify here how the arrow keys behave within scripts with right-to-left direction", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        cursorMovementLA->setText(lyx::qt_("Right-to-left cursor movement:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        logicalCursorRB->setToolTip(lyx::qt_("The cursor follows the logic of the text direction (e.g., in embedded right-to-left text in a left-to-right paragraph, the cursor starts at the right when coming from the left)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        logicalCursorRB->setText(lyx::qt_("&Logical", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        visualCursorRB->setToolTip(lyx::qt_("The cursor follows the visual direction (e.g., in embedded right-to-left text in a left-to-right paragraph, the cursor starts at the left when coming from the left)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        visualCursorRB->setText(lyx::qt_("&Visual", Q_NULLPTR));
        groupBox_2->setTitle(lyx::qt_("Local Preferences", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        decimalPointL->setToolTip(lyx::qt_("Here you can specify the decimal separator that is used in the tabular dialog by default. \"Language default\" selects the appropriate separator for the current language.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        decimalPointL->setText(lyx::qt_("Default decimal &separator:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultDecimalSepED->setToolTip(lyx::qt_("Insert a custom decimal separator here", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultDecimalSepED->setInputMask(QString());
#ifndef QT_NO_TOOLTIP
        defaultLengthUnitLA->setToolTip(lyx::qt_("Select the default length unit for LyX dialogs", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultLengthUnitLA->setText(lyx::qt_("Default length &unit:", Q_NULLPTR));
        defaultDecimalSepCO->clear();
        defaultDecimalSepCO->insertItems(0, QStringList()
         << lyx::qt_("Language Default", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        defaultDecimalSepCO->setToolTip(lyx::qt_("Here you can specify the decimal separator that is used in the tabular dialog by default. \"Language default\" selects the appropriate separator for the current language.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        defaultLengthUnitCO->setToolTip(lyx::qt_("Select the default length unit for LyX dialogs", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class PrefLanguageUi: public Ui_PrefLanguageUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFLANGUAGEUI_H
