/****************************************************************************
** Meta object code from reading C++ file 'GuiLyXFiles.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiLyXFiles.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiLyXFiles.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiLyXFiles_t {
    QByteArrayData data[15];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiLyXFiles_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiLyXFiles_t qt_meta_stringdata_lyx__frontend__GuiLyXFiles = {
    {
QT_MOC_LITERAL(0, 0, 26), // "lyx::frontend::GuiLyXFiles"
QT_MOC_LITERAL(1, 27, 12), // "fileSelected"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 4), // "file"
QT_MOC_LITERAL(4, 46, 20), // "fileSelectionChanged"
QT_MOC_LITERAL(5, 67, 23), // "on_fileTypeCO_activated"
QT_MOC_LITERAL(6, 91, 23), // "on_languageCO_activated"
QT_MOC_LITERAL(7, 115, 28), // "on_filesLW_itemDoubleClicked"
QT_MOC_LITERAL(8, 144, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(9, 161, 22), // "on_filesLW_itemClicked"
QT_MOC_LITERAL(10, 184, 19), // "on_browsePB_pressed"
QT_MOC_LITERAL(11, 204, 13), // "slotButtonBox"
QT_MOC_LITERAL(12, 218, 16), // "QAbstractButton*"
QT_MOC_LITERAL(13, 235, 12), // "filterLabels"
QT_MOC_LITERAL(14, 248, 11) // "resetFilter"

    },
    "lyx::frontend::GuiLyXFiles\0fileSelected\0"
    "\0file\0fileSelectionChanged\0"
    "on_fileTypeCO_activated\0on_languageCO_activated\0"
    "on_filesLW_itemDoubleClicked\0"
    "QTreeWidgetItem*\0on_filesLW_itemClicked\0"
    "on_browsePB_pressed\0slotButtonBox\0"
    "QAbstractButton*\0filterLabels\0resetFilter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiLyXFiles[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   67,    2, 0x08 /* Private */,
       5,    1,   68,    2, 0x08 /* Private */,
       6,    1,   71,    2, 0x08 /* Private */,
       7,    2,   74,    2, 0x08 /* Private */,
       9,    2,   79,    2, 0x08 /* Private */,
      10,    0,   84,    2, 0x08 /* Private */,
      11,    1,   85,    2, 0x08 /* Private */,
      13,    0,   88,    2, 0x08 /* Private */,
      14,    0,   89,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    2,    2,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiLyXFiles::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiLyXFiles *_t = static_cast<GuiLyXFiles *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->fileSelectionChanged(); break;
        case 2: _t->on_fileTypeCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_languageCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_filesLW_itemDoubleClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->on_filesLW_itemClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->on_browsePB_pressed(); break;
        case 7: _t->slotButtonBox((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 8: _t->filterLabels(); break;
        case 9: _t->resetFilter(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiLyXFiles::*_t)(QString const );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiLyXFiles::fileSelected)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiLyXFiles::staticMetaObject = {
    { &GuiDialog::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiLyXFiles.data,
      qt_meta_data_lyx__frontend__GuiLyXFiles,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiLyXFiles::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiLyXFiles::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiLyXFiles.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::LyXFilesUi"))
        return static_cast< Ui::LyXFilesUi*>(this);
    return GuiDialog::qt_metacast(_clname);
}

int lyx::frontend::GuiLyXFiles::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiLyXFiles::fileSelected(QString const _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
