/********************************************************************************
** Form generated from reading UI file 'ListingsSettingsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTINGSSETTINGSUI_H
#define UI_LISTINGSSETTINGSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ListingsSettingsUi
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QTextEdit *listingsED;
    QTextBrowser *listingsTB;
    QCheckBox *bypassCB;
    QGroupBox *packageGB;
    QHBoxLayout *horizontalLayout;
    QLabel *packageLBL;
    QComboBox *packageCO;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *ListingsSettingsUi)
    {
        if (ListingsSettingsUi->objectName().isEmpty())
            ListingsSettingsUi->setObjectName(QStringLiteral("ListingsSettingsUi"));
        ListingsSettingsUi->resize(281, 282);
        gridLayout = new QGridLayout(ListingsSettingsUi);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        spacerItem = new QSpacerItem(201, 21, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 5, 0, 1, 1);

        listingsED = new QTextEdit(ListingsSettingsUi);
        listingsED->setObjectName(QStringLiteral("listingsED"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(listingsED->sizePolicy().hasHeightForWidth());
        listingsED->setSizePolicy(sizePolicy);

        gridLayout->addWidget(listingsED, 1, 0, 1, 1);

        listingsTB = new QTextBrowser(ListingsSettingsUi);
        listingsTB->setObjectName(QStringLiteral("listingsTB"));
        sizePolicy.setHeightForWidth(listingsTB->sizePolicy().hasHeightForWidth());
        listingsTB->setSizePolicy(sizePolicy);
        listingsTB->setAcceptDrops(false);
        listingsTB->setFrameShape(QFrame::Box);
        listingsTB->setFrameShadow(QFrame::Plain);
        listingsTB->setAcceptRichText(false);

        gridLayout->addWidget(listingsTB, 0, 0, 1, 1);

        bypassCB = new QCheckBox(ListingsSettingsUi);
        bypassCB->setObjectName(QStringLiteral("bypassCB"));

        gridLayout->addWidget(bypassCB, 2, 0, 1, 1);

        packageGB = new QGroupBox(ListingsSettingsUi);
        packageGB->setObjectName(QStringLiteral("packageGB"));
        packageGB->setFlat(true);
        horizontalLayout = new QHBoxLayout(packageGB);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        packageLBL = new QLabel(packageGB);
        packageLBL->setObjectName(QStringLiteral("packageLBL"));

        horizontalLayout->addWidget(packageLBL);

        packageCO = new QComboBox(packageGB);
        packageCO->setObjectName(QStringLiteral("packageCO"));

        horizontalLayout->addWidget(packageCO);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addWidget(packageGB, 3, 0, 2, 1);

#ifndef QT_NO_SHORTCUT
        packageLBL->setBuddy(packageCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(ListingsSettingsUi);

        QMetaObject::connectSlotsByName(ListingsSettingsUi);
    } // setupUi

    void retranslateUi(QWidget *ListingsSettingsUi)
    {
        ListingsSettingsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        listingsED->setToolTip(lyx::qt_("Input here the listings parameters", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        listingsTB->setToolTip(lyx::qt_("Feedback window", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        bypassCB->setToolTip(lyx::qt_("Check it to enter parameters that are not recognizable by LyX", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bypassCB->setText(lyx::qt_("&Bypass validation", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        packageLBL->setToolTip(lyx::qt_("Choose the LaTeX package for code syntax highlighting", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        packageLBL->setText(lyx::qt_("&Syntax Highlighting Package:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ListingsSettingsUi: public Ui_ListingsSettingsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LISTINGSSETTINGSUI_H
