/****************************************************************************
** Meta object code from reading C++ file 'GuiSearch.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiSearch.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiSearch.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiSearchWidget_t {
    QByteArrayData data[20];
    char stringdata0[352];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiSearchWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiSearchWidget_t qt_meta_stringdata_lyx__frontend__GuiSearchWidget = {
    {
QT_MOC_LITERAL(0, 0, 30), // "lyx::frontend::GuiSearchWidget"
QT_MOC_LITERAL(1, 31, 18), // "needTitleBarUpdate"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 14), // "needSizeUpdate"
QT_MOC_LITERAL(4, 66, 11), // "findChanged"
QT_MOC_LITERAL(5, 78, 17), // "findBufferChanged"
QT_MOC_LITERAL(6, 96, 11), // "findClicked"
QT_MOC_LITERAL(7, 108, 15), // "findPrevClicked"
QT_MOC_LITERAL(8, 124, 14), // "replaceClicked"
QT_MOC_LITERAL(9, 139, 18), // "replacePrevClicked"
QT_MOC_LITERAL(10, 158, 17), // "replaceallClicked"
QT_MOC_LITERAL(11, 176, 15), // "minimizeClicked"
QT_MOC_LITERAL(12, 192, 6), // "toggle"
QT_MOC_LITERAL(13, 199, 21), // "caseSenseActTriggered"
QT_MOC_LITERAL(14, 221, 22), // "wholeWordsActTriggered"
QT_MOC_LITERAL(15, 244, 21), // "searchSelActTriggered"
QT_MOC_LITERAL(16, 266, 21), // "immediateActTriggered"
QT_MOC_LITERAL(17, 288, 16), // "immediateClicked"
QT_MOC_LITERAL(18, 305, 16), // "wrapActTriggered"
QT_MOC_LITERAL(19, 322, 29) // "onDockWidgetVisibilityChanged"

    },
    "lyx::frontend::GuiSearchWidget\0"
    "needTitleBarUpdate\0\0needSizeUpdate\0"
    "findChanged\0findBufferChanged\0findClicked\0"
    "findPrevClicked\0replaceClicked\0"
    "replacePrevClicked\0replaceallClicked\0"
    "minimizeClicked\0toggle\0caseSenseActTriggered\0"
    "wholeWordsActTriggered\0searchSelActTriggered\0"
    "immediateActTriggered\0immediateClicked\0"
    "wrapActTriggered\0onDockWidgetVisibilityChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiSearchWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,
       3,    0,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  106,    2, 0x08 /* Private */,
       5,    0,  107,    2, 0x08 /* Private */,
       6,    0,  108,    2, 0x08 /* Private */,
       7,    0,  109,    2, 0x08 /* Private */,
       8,    0,  110,    2, 0x08 /* Private */,
       9,    0,  111,    2, 0x08 /* Private */,
      10,    0,  112,    2, 0x08 /* Private */,
      11,    1,  113,    2, 0x08 /* Private */,
      11,    0,  116,    2, 0x28 /* Private | MethodCloned */,
      13,    0,  117,    2, 0x08 /* Private */,
      14,    0,  118,    2, 0x08 /* Private */,
      15,    0,  119,    2, 0x08 /* Private */,
      16,    0,  120,    2, 0x08 /* Private */,
      17,    0,  121,    2, 0x08 /* Private */,
      18,    0,  122,    2, 0x08 /* Private */,
      19,    0,  123,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiSearchWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiSearchWidget *_t = static_cast<GuiSearchWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->needTitleBarUpdate(); break;
        case 1: _t->needSizeUpdate(); break;
        case 2: _t->findChanged(); break;
        case 3: _t->findBufferChanged(); break;
        case 4: _t->findClicked(); break;
        case 5: _t->findPrevClicked(); break;
        case 6: _t->replaceClicked(); break;
        case 7: _t->replacePrevClicked(); break;
        case 8: _t->replaceallClicked(); break;
        case 9: _t->minimizeClicked((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 10: _t->minimizeClicked(); break;
        case 11: _t->caseSenseActTriggered(); break;
        case 12: _t->wholeWordsActTriggered(); break;
        case 13: _t->searchSelActTriggered(); break;
        case 14: _t->immediateActTriggered(); break;
        case 15: _t->immediateClicked(); break;
        case 16: _t->wrapActTriggered(); break;
        case 17: _t->onDockWidgetVisibilityChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiSearchWidget::*_t)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSearchWidget::needTitleBarUpdate)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GuiSearchWidget::*_t)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiSearchWidget::needSizeUpdate)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiSearchWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiSearchWidget.data,
      qt_meta_data_lyx__frontend__GuiSearchWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiSearchWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiSearchWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiSearchWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::SearchUi"))
        return static_cast< Ui::SearchUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::GuiSearchWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiSearchWidget::needTitleBarUpdate()const
{
    QMetaObject::activate(const_cast< lyx::frontend::GuiSearchWidget *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void lyx::frontend::GuiSearchWidget::needSizeUpdate()const
{
    QMetaObject::activate(const_cast< lyx::frontend::GuiSearchWidget *>(this), &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_lyx__frontend__GuiSearch_t {
    QByteArrayData data[5];
    char stringdata0[69];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiSearch_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiSearch_t qt_meta_stringdata_lyx__frontend__GuiSearch = {
    {
QT_MOC_LITERAL(0, 0, 24), // "lyx::frontend::GuiSearch"
QT_MOC_LITERAL(1, 25, 19), // "onBufferViewChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 11), // "updateTitle"
QT_MOC_LITERAL(4, 58, 10) // "updateSize"

    },
    "lyx::frontend::GuiSearch\0onBufferViewChanged\0"
    "\0updateTitle\0updateSize"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiSearch[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    0,   30,    2, 0x08 /* Private */,
       4,    0,   31,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::GuiSearch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiSearch *_t = static_cast<GuiSearch *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onBufferViewChanged(); break;
        case 1: _t->updateTitle(); break;
        case 2: _t->updateSize(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject lyx::frontend::GuiSearch::staticMetaObject = {
    { &DockView::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiSearch.data,
      qt_meta_data_lyx__frontend__GuiSearch,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiSearch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiSearch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiSearch.stringdata0))
        return static_cast<void*>(this);
    return DockView::qt_metacast(_clname);
}

int lyx::frontend::GuiSearch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
