/********************************************************************************
** Form generated from reading UI file 'VSpaceUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VSPACEUI_H
#define UI_VSPACEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_VSpaceUi
{
public:
    QGridLayout *gridLayout;
    QLabel *spacingL;
    QCheckBox *keepCB;
    QLabel *keepL;
    lyx::frontend::LengthCombo *unitCO;
    QLineEdit *valueLE;
    QLabel *valueL;
    QComboBox *spacingCO;

    void setupUi(QWidget *VSpaceUi)
    {
        if (VSpaceUi->objectName().isEmpty())
            VSpaceUi->setObjectName(QStringLiteral("VSpaceUi"));
        VSpaceUi->resize(288, 118);
        VSpaceUi->setProperty("sizeGripEnabled", QVariant(true));
        gridLayout = new QGridLayout(VSpaceUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        spacingL = new QLabel(VSpaceUi);
        spacingL->setObjectName(QStringLiteral("spacingL"));

        gridLayout->addWidget(spacingL, 0, 0, 1, 1);

        keepCB = new QCheckBox(VSpaceUi);
        keepCB->setObjectName(QStringLiteral("keepCB"));

        gridLayout->addWidget(keepCB, 2, 1, 1, 2);

        keepL = new QLabel(VSpaceUi);
        keepL->setObjectName(QStringLiteral("keepL"));

        gridLayout->addWidget(keepL, 2, 0, 1, 1);

        unitCO = new lyx::frontend::LengthCombo(VSpaceUi);
        unitCO->setObjectName(QStringLiteral("unitCO"));

        gridLayout->addWidget(unitCO, 1, 2, 1, 1);

        valueLE = new QLineEdit(VSpaceUi);
        valueLE->setObjectName(QStringLiteral("valueLE"));
        valueLE->setEnabled(false);

        gridLayout->addWidget(valueLE, 1, 1, 1, 1);

        valueL = new QLabel(VSpaceUi);
        valueL->setObjectName(QStringLiteral("valueL"));

        gridLayout->addWidget(valueL, 1, 0, 1, 1);

        spacingCO = new QComboBox(VSpaceUi);
        spacingCO->setObjectName(QStringLiteral("spacingCO"));

        gridLayout->addWidget(spacingCO, 0, 1, 1, 2);

#ifndef QT_NO_SHORTCUT
        spacingL->setBuddy(spacingCO);
        keepL->setBuddy(keepCB);
        valueL->setBuddy(valueLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(spacingCO, valueLE);
        QWidget::setTabOrder(valueLE, unitCO);
        QWidget::setTabOrder(unitCO, keepCB);

        retranslateUi(VSpaceUi);

        QMetaObject::connectSlotsByName(VSpaceUi);
    } // setupUi

    void retranslateUi(QWidget *VSpaceUi)
    {
        VSpaceUi->setWindowTitle(QString());
        spacingL->setText(lyx::qt_("&Spacing:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keepCB->setToolTip(lyx::qt_("Insert the spacing even after a page break", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        keepCB->setText(QString());
#ifndef QT_NO_TOOLTIP
        keepL->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        keepL->setText(lyx::qt_("&Protect:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        valueLE->setToolTip(lyx::qt_("Custom value. Needs spacing type \"Custom\".", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valueL->setText(lyx::qt_("&Value:", Q_NULLPTR));
        spacingCO->clear();
        spacingCO->insertItems(0, QStringList()
         << lyx::qt_("Default skip", Q_NULLPTR)
         << lyx::qt_("Small skip", Q_NULLPTR)
         << lyx::qt_("Medium skip", Q_NULLPTR)
         << lyx::qt_("Big skip", Q_NULLPTR)
         << lyx::qt_("Half line height", Q_NULLPTR)
         << lyx::qt_("Line height", Q_NULLPTR)
         << lyx::qt_("Vertical fill", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        spacingCO->setToolTip(lyx::qt_("Supported spacing types", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class VSpaceUi: public Ui_VSpaceUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VSPACEUI_H
