/********************************************************************************
** Form generated from reading UI file 'TexinfoUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXINFOUI_H
#define UI_TEXINFOUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_TexinfoUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QComboBox *whatStyleCO;
    QSpacerItem *spacerItem;
    QCheckBox *pathCB;
    QListWidget *fileListLW;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem1;
    QPushButton *rescanPB;
    QPushButton *viewPB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TexinfoUi)
    {
        if (TexinfoUi->objectName().isEmpty())
            TexinfoUi->setObjectName(QStringLiteral("TexinfoUi"));
        TexinfoUi->resize(373, 290);
        TexinfoUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(TexinfoUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        whatStyleCO = new QComboBox(TexinfoUi);
        whatStyleCO->setObjectName(QStringLiteral("whatStyleCO"));

        hboxLayout->addWidget(whatStyleCO);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        pathCB = new QCheckBox(TexinfoUi);
        pathCB->setObjectName(QStringLiteral("pathCB"));

        hboxLayout->addWidget(pathCB);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        fileListLW = new QListWidget(TexinfoUi);
        fileListLW->setObjectName(QStringLiteral("fileListLW"));

        gridLayout->addWidget(fileListLW, 1, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);

        rescanPB = new QPushButton(TexinfoUi);
        rescanPB->setObjectName(QStringLiteral("rescanPB"));

        hboxLayout1->addWidget(rescanPB);

        viewPB = new QPushButton(TexinfoUi);
        viewPB->setObjectName(QStringLiteral("viewPB"));
        viewPB->setEnabled(false);

        hboxLayout1->addWidget(viewPB);


        gridLayout->addLayout(hboxLayout1, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(TexinfoUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

        QWidget::setTabOrder(whatStyleCO, pathCB);
        QWidget::setTabOrder(pathCB, fileListLW);
        QWidget::setTabOrder(fileListLW, rescanPB);
        QWidget::setTabOrder(rescanPB, viewPB);

        retranslateUi(TexinfoUi);

        QMetaObject::connectSlotsByName(TexinfoUi);
    } // setupUi

    void retranslateUi(QDialog *TexinfoUi)
    {
        TexinfoUi->setWindowTitle(QString());
        whatStyleCO->clear();
        whatStyleCO->insertItems(0, QStringList()
         << lyx::qt_("LaTeX classes", Q_NULLPTR)
         << lyx::qt_("LaTeX styles", Q_NULLPTR)
         << lyx::qt_("BibTeX styles", Q_NULLPTR)
         << lyx::qt_("BibTeX databases", Q_NULLPTR)
         << lyx::qt_("Biblatex bibliography styles", Q_NULLPTR)
         << lyx::qt_("Biblatex citation styles", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        whatStyleCO->setToolTip(lyx::qt_("Selected classes or styles", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        pathCB->setToolTip(lyx::qt_("Toggles view of the file list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pathCB->setText(lyx::qt_("Show &path", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rescanPB->setToolTip(lyx::qt_("Rebuild the file lists", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rescanPB->setText(lyx::qt_("&Rescan", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        viewPB->setToolTip(lyx::qt_("Show contents of marked file. Only possible when files are shown with path", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        viewPB->setText(lyx::qt_("&View", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TexinfoUi: public Ui_TexinfoUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TEXINFOUI_H
