/********************************************************************************
** Form generated from reading UI file 'MathsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MATHSUI_H
#define UI_MATHSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_MathsUi
{
public:
    QGridLayout *gridLayout_2;
    QTableWidget *packagesTW;
    QGridLayout *gridLayout;
    QLabel *allPakcagesLA;
    QPushButton *allPackagesAutoPB;
    QPushButton *allPackagesAlwaysPB;
    QPushButton *allPackagesNotPB;
    QCheckBox *MathIndentCB;
    QComboBox *MathIndentCO;
    QSpacerItem *horizontalSpacer_3;
    QLineEdit *MathIndentLE;
    lyx::frontend::LengthCombo *MathIndentLengthCO;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QLabel *MathNumberingPosL;
    QComboBox *MathNumberingPosCO;
    QSpacerItem *horizontalSpacer_1;

    void setupUi(QWidget *MathsUi)
    {
        if (MathsUi->objectName().isEmpty())
            MathsUi->setObjectName(QStringLiteral("MathsUi"));
        MathsUi->resize(569, 367);
        gridLayout_2 = new QGridLayout(MathsUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        packagesTW = new QTableWidget(MathsUi);
        if (packagesTW->columnCount() < 4)
            packagesTW->setColumnCount(4);
        packagesTW->setObjectName(QStringLiteral("packagesTW"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(packagesTW->sizePolicy().hasHeightForWidth());
        packagesTW->setSizePolicy(sizePolicy);
        packagesTW->setEditTriggers(QAbstractItemView::NoEditTriggers);
        packagesTW->setAlternatingRowColors(true);
        packagesTW->setColumnCount(4);
        packagesTW->horizontalHeader()->setStretchLastSection(false);
        packagesTW->verticalHeader()->setVisible(false);

        gridLayout_2->addWidget(packagesTW, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        allPakcagesLA = new QLabel(MathsUi);
        allPakcagesLA->setObjectName(QStringLiteral("allPakcagesLA"));

        gridLayout->addWidget(allPakcagesLA, 0, 0, 1, 1);

        allPackagesAutoPB = new QPushButton(MathsUi);
        allPackagesAutoPB->setObjectName(QStringLiteral("allPackagesAutoPB"));

        gridLayout->addWidget(allPackagesAutoPB, 0, 1, 1, 1);

        allPackagesAlwaysPB = new QPushButton(MathsUi);
        allPackagesAlwaysPB->setObjectName(QStringLiteral("allPackagesAlwaysPB"));

        gridLayout->addWidget(allPackagesAlwaysPB, 0, 2, 1, 1);

        allPackagesNotPB = new QPushButton(MathsUi);
        allPackagesNotPB->setObjectName(QStringLiteral("allPackagesNotPB"));

        gridLayout->addWidget(allPackagesNotPB, 0, 3, 1, 1);

        MathIndentCB = new QCheckBox(MathsUi);
        MathIndentCB->setObjectName(QStringLiteral("MathIndentCB"));

        gridLayout->addWidget(MathIndentCB, 1, 0, 1, 1);

        MathIndentCO = new QComboBox(MathsUi);
        MathIndentCO->setObjectName(QStringLiteral("MathIndentCO"));
        MathIndentCO->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(MathIndentCO->sizePolicy().hasHeightForWidth());
        MathIndentCO->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(MathIndentCO, 1, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(234, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 2, 1, 2);

        MathIndentLE = new QLineEdit(MathsUi);
        MathIndentLE->setObjectName(QStringLiteral("MathIndentLE"));
        MathIndentLE->setEnabled(false);

        gridLayout->addWidget(MathIndentLE, 2, 1, 1, 1);

        MathIndentLengthCO = new lyx::frontend::LengthCombo(MathsUi);
        MathIndentLengthCO->setObjectName(QStringLiteral("MathIndentLengthCO"));
        MathIndentLengthCO->setEnabled(false);
        sizePolicy1.setHeightForWidth(MathIndentLengthCO->sizePolicy().hasHeightForWidth());
        MathIndentLengthCO->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(MathIndentLengthCO, 2, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(153, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);


        gridLayout_2->addLayout(gridLayout, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        MathNumberingPosL = new QLabel(MathsUi);
        MathNumberingPosL->setObjectName(QStringLiteral("MathNumberingPosL"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(MathNumberingPosL->sizePolicy().hasHeightForWidth());
        MathNumberingPosL->setSizePolicy(sizePolicy2);
        MathNumberingPosL->setMinimumSize(QSize(115, 18));

        horizontalLayout->addWidget(MathNumberingPosL);

        MathNumberingPosCO = new QComboBox(MathsUi);
        MathNumberingPosCO->setObjectName(QStringLiteral("MathNumberingPosCO"));
        MathNumberingPosCO->setEnabled(true);
        sizePolicy1.setHeightForWidth(MathNumberingPosCO->sizePolicy().hasHeightForWidth());
        MathNumberingPosCO->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(MathNumberingPosCO);

        horizontalSpacer_1 = new QSpacerItem(234, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_1);


        gridLayout_2->addLayout(horizontalLayout, 2, 0, 1, 1);


        retranslateUi(MathsUi);
        QObject::connect(MathIndentCB, SIGNAL(toggled(bool)), MathIndentCO, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(MathsUi);
    } // setupUi

    void retranslateUi(QWidget *MathsUi)
    {
        MathsUi->setWindowTitle(QString());
        allPakcagesLA->setText(lyx::qt_("All packages:", Q_NULLPTR));
        allPackagesAutoPB->setText(lyx::qt_("Load A&utomatically", Q_NULLPTR));
        allPackagesAlwaysPB->setText(lyx::qt_("Load Alwa&ys", Q_NULLPTR));
        allPackagesNotPB->setText(lyx::qt_("Do &Not Load", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        MathIndentCB->setToolTip(lyx::qt_("Indent displayed formulas instead of centering", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        MathIndentCB->setText(lyx::qt_("Indent &formulas", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        MathIndentCO->setToolTip(lyx::qt_("Size of the indentation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        MathIndentLE->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        MathIndentLE->setText(QString());
#ifndef QT_NO_TOOLTIP
        MathIndentLengthCO->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        MathNumberingPosL->setText(lyx::qt_("Formula numbering side:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        MathNumberingPosCO->setToolTip(lyx::qt_("Side where formulas are numbered", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class MathsUi: public Ui_MathsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MATHSUI_H
