/********************************************************************************
** Form generated from reading UI file 'HyperlinkUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HYPERLINKUI_H
#define UI_HYPERLINKUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_HyperlinkUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *targetLA;
    QLabel *nameLA;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QLineEdit *targetED;
    QLineEdit *nameED;
    QHBoxLayout *horizontalLayout;
    QCheckBox *literalCB;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *typeGB;
    QHBoxLayout *hboxLayout;
    QRadioButton *webRB;
    QRadioButton *emailRB;
    QRadioButton *fileRB;
    QRadioButton *noneRB;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *HyperlinkUi)
    {
        if (HyperlinkUi->objectName().isEmpty())
            HyperlinkUi->setObjectName(QStringLiteral("HyperlinkUi"));
        HyperlinkUi->resize(402, 226);
        gridLayout = new QGridLayout(HyperlinkUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        targetLA = new QLabel(HyperlinkUi);
        targetLA->setObjectName(QStringLiteral("targetLA"));

        verticalLayout_2->addWidget(targetLA);

        nameLA = new QLabel(HyperlinkUi);
        nameLA->setObjectName(QStringLiteral("nameLA"));

        verticalLayout_2->addWidget(nameLA);

        label = new QLabel(HyperlinkUi);
        label->setObjectName(QStringLiteral("label"));

        verticalLayout_2->addWidget(label);


        horizontalLayout_2->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        targetED = new QLineEdit(HyperlinkUi);
        targetED->setObjectName(QStringLiteral("targetED"));

        verticalLayout->addWidget(targetED);

        nameED = new QLineEdit(HyperlinkUi);
        nameED->setObjectName(QStringLiteral("nameED"));

        verticalLayout->addWidget(nameED);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        literalCB = new QCheckBox(HyperlinkUi);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        horizontalLayout->addWidget(literalCB);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 2);

        typeGB = new QGroupBox(HyperlinkUi);
        typeGB->setObjectName(QStringLiteral("typeGB"));
        typeGB->setFlat(true);
        hboxLayout = new QHBoxLayout(typeGB);
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(9, 9, 9, 9);
        webRB = new QRadioButton(typeGB);
        webRB->setObjectName(QStringLiteral("webRB"));
        webRB->setChecked(true);

        hboxLayout->addWidget(webRB);

        emailRB = new QRadioButton(typeGB);
        emailRB->setObjectName(QStringLiteral("emailRB"));

        hboxLayout->addWidget(emailRB);

        fileRB = new QRadioButton(typeGB);
        fileRB->setObjectName(QStringLiteral("fileRB"));

        hboxLayout->addWidget(fileRB);

        noneRB = new QRadioButton(typeGB);
        noneRB->setObjectName(QStringLiteral("noneRB"));

        hboxLayout->addWidget(noneRB);


        gridLayout->addWidget(typeGB, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        targetLA->setBuddy(targetED);
        nameLA->setBuddy(nameED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(targetED, nameED);
        QWidget::setTabOrder(nameED, webRB);
        QWidget::setTabOrder(webRB, emailRB);
        QWidget::setTabOrder(emailRB, fileRB);

        retranslateUi(HyperlinkUi);

        QMetaObject::connectSlotsByName(HyperlinkUi);
    } // setupUi

    void retranslateUi(QWidget *HyperlinkUi)
    {
        HyperlinkUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        targetLA->setToolTip(lyx::qt_("URL", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        targetLA->setText(lyx::qt_("&Target:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nameLA->setToolTip(lyx::qt_("Name associated with the URL", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nameLA->setText(lyx::qt_("&Name:", Q_NULLPTR));
        label->setText(QString());
#ifndef QT_NO_TOOLTIP
        targetED->setToolTip(lyx::qt_("URL", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        nameED->setToolTip(lyx::qt_("Name associated with the URL", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass content of the `Name' field literally to LaTeX. Check this if you want to enter LaTeX code.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        typeGB->setToolTip(lyx::qt_("Specify the link target", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        typeGB->setTitle(lyx::qt_("Link type", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        webRB->setToolTip(lyx::qt_("Link to the web or any other target with an \"authority\" component (i.e., :// in the URI)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        webRB->setText(lyx::qt_("&Web", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        emailRB->setToolTip(lyx::qt_("Link to an email address", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        emailRB->setText(lyx::qt_("E&mail", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        fileRB->setToolTip(lyx::qt_("Link to a file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        fileRB->setText(lyx::qt_("Fi&le", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        noneRB->setToolTip(lyx::qt_("Link to an arbitrary URI scheme not matched by the other three types (to be fully spelled out in the Target field above)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        noneRB->setText(lyx::qt_("&Other[[Link Type]]", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class HyperlinkUi: public Ui_HyperlinkUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HYPERLINKUI_H
