/********************************************************************************
** Form generated from reading UI file 'ChangesUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANGESUI_H
#define UI_CHANGESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ChangesUi
{
public:
    QGridLayout *gridLayout;
    QLabel *changeLA;
    QTextBrowser *changeTB;
    QHBoxLayout *hboxLayout;
    QPushButton *previousPB;
    QPushButton *nextPB;
    QDialogButtonBox *buttonBox;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout1;
    QPushButton *acceptPB;
    QPushButton *rejectPB;
    QSpacerItem *spacerItem1;

    void setupUi(QDialog *ChangesUi)
    {
        if (ChangesUi->objectName().isEmpty())
            ChangesUi->setObjectName(QStringLiteral("ChangesUi"));
        ChangesUi->resize(355, 264);
        ChangesUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(ChangesUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        changeLA = new QLabel(ChangesUi);
        changeLA->setObjectName(QStringLiteral("changeLA"));

        gridLayout->addWidget(changeLA, 0, 0, 1, 1);

        changeTB = new QTextBrowser(ChangesUi);
        changeTB->setObjectName(QStringLiteral("changeTB"));

        gridLayout->addWidget(changeTB, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        previousPB = new QPushButton(ChangesUi);
        previousPB->setObjectName(QStringLiteral("previousPB"));

        hboxLayout->addWidget(previousPB);

        nextPB = new QPushButton(ChangesUi);
        nextPB->setObjectName(QStringLiteral("nextPB"));

        hboxLayout->addWidget(nextPB);

        buttonBox = new QDialogButtonBox(ChangesUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        hboxLayout->addWidget(buttonBox);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout, 3, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        acceptPB = new QPushButton(ChangesUi);
        acceptPB->setObjectName(QStringLiteral("acceptPB"));
        acceptPB->setAutoDefault(false);

        hboxLayout1->addWidget(acceptPB);

        rejectPB = new QPushButton(ChangesUi);
        rejectPB->setObjectName(QStringLiteral("rejectPB"));
        rejectPB->setAutoDefault(false);

        hboxLayout1->addWidget(rejectPB);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        gridLayout->addLayout(hboxLayout1, 2, 0, 1, 1);

        QWidget::setTabOrder(changeTB, acceptPB);
        QWidget::setTabOrder(acceptPB, rejectPB);
        QWidget::setTabOrder(rejectPB, nextPB);

        retranslateUi(ChangesUi);

        previousPB->setDefault(false);
        nextPB->setDefault(true);


        QMetaObject::connectSlotsByName(ChangesUi);
    } // setupUi

    void retranslateUi(QDialog *ChangesUi)
    {
        ChangesUi->setWindowTitle(QString());
        changeLA->setText(lyx::qt_("Change:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        previousPB->setToolTip(lyx::qt_("Go to previous change", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        previousPB->setText(lyx::qt_("&Previous change", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nextPB->setToolTip(lyx::qt_("Go to next change", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nextPB->setText(lyx::qt_("&Next change", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        acceptPB->setToolTip(lyx::qt_("Accept this change", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        acceptPB->setText(lyx::qt_("&Accept", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rejectPB->setToolTip(lyx::qt_("Reject this change", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rejectPB->setText(lyx::qt_("&Reject", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ChangesUi: public Ui_ChangesUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHANGESUI_H
