/********************************************************************************
** Form generated from reading UI file 'ProgressViewUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROGRESSVIEWUI_H
#define UI_PROGRESSVIEWUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_ProgressViewUi
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout1;
    QTextEdit *outTE;
    QWidget *tab_2;
    QGridLayout *gridLayout2;
    QTreeWidget *debugMessagesTW;
    QVBoxLayout *verticalLayout;
    QCheckBox *sbarCB;
    QGroupBox *groupBox;
    QGridLayout *gridLayout3;
    QRadioButton *debugAnyRB;
    QRadioButton *debugSelectedRB;
    QRadioButton *debugNoneRB;
    QCheckBox *autoClearCB;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ProgressViewUi)
    {
        if (ProgressViewUi->objectName().isEmpty())
            ProgressViewUi->setObjectName(QStringLiteral("ProgressViewUi"));
        ProgressViewUi->resize(498, 298);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ProgressViewUi->sizePolicy().hasHeightForWidth());
        ProgressViewUi->setSizePolicy(sizePolicy);
        ProgressViewUi->setMinimumSize(QSize(0, 0));
        ProgressViewUi->setSizeIncrement(QSize(0, 0));
        ProgressViewUi->setBaseSize(QSize(0, 0));
        gridLayout = new QGridLayout(ProgressViewUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 9, 0);
        tabWidget = new QTabWidget(ProgressViewUi);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tabWidget->setEnabled(true);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setBaseSize(QSize(0, 0));
        tabWidget->setAcceptDrops(false);
        tabWidget->setLayoutDirection(Qt::LeftToRight);
        tabWidget->setAutoFillBackground(false);
        tabWidget->setTabPosition(QTabWidget::East);
        tabWidget->setTabShape(QTabWidget::Rounded);
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout1 = new QGridLayout(tab);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        outTE = new QTextEdit(tab);
        outTE->setObjectName(QStringLiteral("outTE"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Ignored);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(outTE->sizePolicy().hasHeightForWidth());
        outTE->setSizePolicy(sizePolicy1);
        outTE->setMaximumSize(QSize(16777215, 16777215));
        outTE->setStyleSheet(QStringLiteral("border: "));
        outTE->setFrameShape(QFrame::StyledPanel);
        outTE->setFrameShadow(QFrame::Sunken);
        outTE->setLineWidth(1);
        outTE->setReadOnly(true);

        gridLayout1->addWidget(outTE, 0, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout2 = new QGridLayout(tab_2);
        gridLayout2->setSpacing(0);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        debugMessagesTW = new QTreeWidget(tab_2);
        debugMessagesTW->setObjectName(QStringLiteral("debugMessagesTW"));

        gridLayout2->addWidget(debugMessagesTW, 0, 1, 6, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        sbarCB = new QCheckBox(tab_2);
        sbarCB->setObjectName(QStringLiteral("sbarCB"));
        sbarCB->setChecked(true);

        verticalLayout->addWidget(sbarCB);

        groupBox = new QGroupBox(tab_2);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy2);
        groupBox->setFlat(true);
        gridLayout3 = new QGridLayout(groupBox);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        debugAnyRB = new QRadioButton(groupBox);
        debugAnyRB->setObjectName(QStringLiteral("debugAnyRB"));

        gridLayout3->addWidget(debugAnyRB, 0, 2, 1, 1);

        debugSelectedRB = new QRadioButton(groupBox);
        debugSelectedRB->setObjectName(QStringLiteral("debugSelectedRB"));

        gridLayout3->addWidget(debugSelectedRB, 0, 1, 1, 1);

        debugNoneRB = new QRadioButton(groupBox);
        debugNoneRB->setObjectName(QStringLiteral("debugNoneRB"));

        gridLayout3->addWidget(debugNoneRB, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox);

        autoClearCB = new QCheckBox(tab_2);
        autoClearCB->setObjectName(QStringLiteral("autoClearCB"));

        verticalLayout->addWidget(autoClearCB);


        gridLayout2->addLayout(verticalLayout, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(187, 3, QSizePolicy::Minimum, QSizePolicy::Preferred);

        gridLayout2->addItem(spacerItem, 1, 0, 5, 1);

        tabWidget->addTab(tab_2, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);


        retranslateUi(ProgressViewUi);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ProgressViewUi);
    } // setupUi

    void retranslateUi(QWidget *ProgressViewUi)
    {
        ProgressViewUi->setWindowTitle(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), lyx::qt_("Output", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = debugMessagesTW->headerItem();
        ___qtreewidgetitem->setText(0, lyx::qt_("1", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        debugMessagesTW->setToolTip(lyx::qt_("Select the debug messages that should be displayed", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        sbarCB->setToolTip(lyx::qt_("Display statusbar messages?", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        sbarCB->setText(lyx::qt_("&Statusbar messages", Q_NULLPTR));
        groupBox->setTitle(lyx::qt_("Debug messages", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        debugAnyRB->setToolTip(lyx::qt_("Display all debug messages", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        debugAnyRB->setText(lyx::qt_("&All", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        debugSelectedRB->setToolTip(lyx::qt_("Display the debug messages selected to the right", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        debugSelectedRB->setText(lyx::qt_("S&elected", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        debugNoneRB->setToolTip(lyx::qt_("Display no debug messages", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        debugNoneRB->setText(lyx::qt_("&None", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        autoClearCB->setToolTip(lyx::qt_("Automatic cleanup of the window before LaTeX compilation proceeds", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        autoClearCB->setText(lyx::qt_("&Clear automatically", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), lyx::qt_("Settings", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ProgressViewUi: public Ui_ProgressViewUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROGRESSVIEWUI_H
