/********************************************************************************
** Form generated from reading UI file 'CompareUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPAREUI_H
#define UI_COMPAREUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStatusBar>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_CompareUi
{
public:
    QGridLayout *gridLayout_2;
    QProgressBar *progressBar;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QRadioButton *oldSettingsRB;
    QRadioButton *newSettingsRB;
    QSpacerItem *horizontalSpacer;
    QCheckBox *trackingCB;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout;
    QLabel *oldFileLA;
    QComboBox *oldFileCB;
    QPushButton *oldFilePB;
    QLabel *newFileLA;
    QComboBox *newFileCB;
    QPushButton *newFilePB;
    QHBoxLayout *hboxLayout;
    QHBoxLayout *horizontalLayout_4;
    QStatusBar *statusBar;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *horizontalLayout_5;
    QLabel *authorLA;
    QComboBox *authorCO;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *CompareUi)
    {
        if (CompareUi->objectName().isEmpty())
            CompareUi->setObjectName(QStringLiteral("CompareUi"));
        CompareUi->resize(622, 348);
        CompareUi->setSizeGripEnabled(true);
        gridLayout_2 = new QGridLayout(CompareUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        progressBar = new QProgressBar(CompareUi);
        progressBar->setObjectName(QStringLiteral("progressBar"));
        progressBar->setValue(24);
        progressBar->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(progressBar, 10, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        groupBox = new QGroupBox(CompareUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        groupBox->setFlat(true);
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        oldSettingsRB = new QRadioButton(groupBox);
        oldSettingsRB->setObjectName(QStringLiteral("oldSettingsRB"));

        horizontalLayout->addWidget(oldSettingsRB);

        newSettingsRB = new QRadioButton(groupBox);
        newSettingsRB->setObjectName(QStringLiteral("newSettingsRB"));

        horizontalLayout->addWidget(newSettingsRB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        horizontalLayout_3->addWidget(groupBox);


        gridLayout_2->addLayout(horizontalLayout_3, 2, 0, 1, 2);

        trackingCB = new QCheckBox(CompareUi);
        trackingCB->setObjectName(QStringLiteral("trackingCB"));
        trackingCB->setChecked(false);

        gridLayout_2->addWidget(trackingCB, 7, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 8, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        oldFileLA = new QLabel(CompareUi);
        oldFileLA->setObjectName(QStringLiteral("oldFileLA"));

        gridLayout->addWidget(oldFileLA, 0, 0, 1, 1);

        oldFileCB = new QComboBox(CompareUi);
        oldFileCB->setObjectName(QStringLiteral("oldFileCB"));
        sizePolicy.setHeightForWidth(oldFileCB->sizePolicy().hasHeightForWidth());
        oldFileCB->setSizePolicy(sizePolicy);
        oldFileCB->setEditable(true);

        gridLayout->addWidget(oldFileCB, 0, 1, 1, 1);

        oldFilePB = new QPushButton(CompareUi);
        oldFilePB->setObjectName(QStringLiteral("oldFilePB"));
        oldFilePB->setAutoDefault(false);

        gridLayout->addWidget(oldFilePB, 0, 2, 1, 1);

        newFileLA = new QLabel(CompareUi);
        newFileLA->setObjectName(QStringLiteral("newFileLA"));

        gridLayout->addWidget(newFileLA, 1, 0, 1, 1);

        newFileCB = new QComboBox(CompareUi);
        newFileCB->setObjectName(QStringLiteral("newFileCB"));
        sizePolicy.setHeightForWidth(newFileCB->sizePolicy().hasHeightForWidth());
        newFileCB->setSizePolicy(sizePolicy);
        newFileCB->setEditable(true);

        gridLayout->addWidget(newFileCB, 1, 1, 1, 1);

        newFilePB = new QPushButton(CompareUi);
        newFilePB->setObjectName(QStringLiteral("newFilePB"));
        newFilePB->setAutoDefault(false);

        gridLayout->addWidget(newFilePB, 1, 2, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        statusBar = new QStatusBar(CompareUi);
        statusBar->setObjectName(QStringLiteral("statusBar"));
        statusBar->setSizeGripEnabled(false);

        horizontalLayout_4->addWidget(statusBar);

        buttonBox = new QDialogButtonBox(CompareUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_4->addWidget(buttonBox);

        horizontalLayout_4->setStretch(0, 1);

        hboxLayout->addLayout(horizontalLayout_4);


        gridLayout_2->addLayout(hboxLayout, 11, 0, 1, 2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        authorLA = new QLabel(CompareUi);
        authorLA->setObjectName(QStringLiteral("authorLA"));

        horizontalLayout_5->addWidget(authorLA);

        authorCO = new QComboBox(CompareUi);
        authorCO->setObjectName(QStringLiteral("authorCO"));

        horizontalLayout_5->addWidget(authorCO);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout_5, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        oldFileLA->setBuddy(oldFileCB);
        newFileLA->setBuddy(newFileCB);
        authorLA->setBuddy(authorCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(CompareUi);

        QMetaObject::connectSlotsByName(CompareUi);
    } // setupUi

    void retranslateUi(QDialog *CompareUi)
    {
        CompareUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        groupBox->setToolTip(lyx::qt_("Select the document from which the settings should be taken", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(lyx::qt_("Document Settings", Q_NULLPTR));
        oldSettingsRB->setText(lyx::qt_("O&ld document", Q_NULLPTR));
        newSettingsRB->setText(lyx::qt_("New docu&ment", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        trackingCB->setToolTip(lyx::qt_("Turns on the change tracking and showing changes in LaTeX output for the resulting document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        trackingCB->setText(lyx::qt_("&Enable change tracking features in the output", Q_NULLPTR));
        oldFileLA->setText(lyx::qt_("Old documen&t:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        oldFileCB->setToolTip(lyx::qt_("Specify the original version of the document here (comparison source)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        oldFilePB->setText(lyx::qt_("Bro&wse...", Q_NULLPTR));
        newFileLA->setText(lyx::qt_("&New document:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        newFileCB->setToolTip(lyx::qt_("Specify the modified version of the document here (comparison target)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        newFilePB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        authorLA->setToolTip(lyx::qt_("Changes in the workarea are allocated to the selected author or category", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        authorLA->setText(lyx::qt_("Changes mar&kup:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        authorCO->setToolTip(lyx::qt_("Changes in the workarea are allocated to the selected author or category", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class CompareUi: public Ui_CompareUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMPAREUI_H
