/********************************************************************************
** Form generated from reading UI file 'MathMatrixUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MATHMATRIXUI_H
#define UI_MATHMATRIXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "EmptyTable.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_MathMatrixUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *alignmentGB;
    QGridLayout *grid_1;
    QLineEdit *halignED;
    QLabel *valignLA;
    QComboBox *valignCO;
    QLabel *widthLA_2;
    QDialogButtonBox *buttonBox;
    QGroupBox *decorationtGB;
    QGridLayout *grid_2;
    QLabel *typeLA;
    QComboBox *decorationCO;
    QHBoxLayout *hboxLayout;
    QLabel *rowsL;
    QSpinBox *rowsSB;
    QLabel *columnsL;
    QSpinBox *columnsSB;
    QSpacerItem *spacerItem;
    EmptyTable *table;

    void setupUi(QDialog *MathMatrixUi)
    {
        if (MathMatrixUi->objectName().isEmpty())
            MathMatrixUi->setObjectName(QStringLiteral("MathMatrixUi"));
        MathMatrixUi->resize(431, 372);
        MathMatrixUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(MathMatrixUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        alignmentGB = new QGroupBox(MathMatrixUi);
        alignmentGB->setObjectName(QStringLiteral("alignmentGB"));
        alignmentGB->setFlat(true);
        grid_1 = new QGridLayout(alignmentGB);
        grid_1->setSpacing(6);
        grid_1->setObjectName(QStringLiteral("grid_1"));
        grid_1->setContentsMargins(11, 11, 11, 11);
        halignED = new QLineEdit(alignmentGB);
        halignED->setObjectName(QStringLiteral("halignED"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(halignED->sizePolicy().hasHeightForWidth());
        halignED->setSizePolicy(sizePolicy);

        grid_1->addWidget(halignED, 1, 1, 1, 1);

        valignLA = new QLabel(alignmentGB);
        valignLA->setObjectName(QStringLiteral("valignLA"));
        valignLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        grid_1->addWidget(valignLA, 0, 0, 1, 1);

        valignCO = new QComboBox(alignmentGB);
        valignCO->setObjectName(QStringLiteral("valignCO"));

        grid_1->addWidget(valignCO, 1, 0, 1, 1);

        widthLA_2 = new QLabel(alignmentGB);
        widthLA_2->setObjectName(QStringLiteral("widthLA_2"));

        grid_1->addWidget(widthLA_2, 0, 1, 1, 1);


        gridLayout->addWidget(alignmentGB, 2, 0, 1, 2);

        buttonBox = new QDialogButtonBox(MathMatrixUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 1, 1, 2);

        decorationtGB = new QGroupBox(MathMatrixUi);
        decorationtGB->setObjectName(QStringLiteral("decorationtGB"));
        decorationtGB->setFlat(true);
        grid_2 = new QGridLayout(decorationtGB);
        grid_2->setObjectName(QStringLiteral("grid_2"));
        typeLA = new QLabel(decorationtGB);
        typeLA->setObjectName(QStringLiteral("typeLA"));
        typeLA->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        grid_2->addWidget(typeLA, 0, 0, 1, 1);

        decorationCO = new QComboBox(decorationtGB);
        decorationCO->setObjectName(QStringLiteral("decorationCO"));

        grid_2->addWidget(decorationCO, 1, 0, 1, 1);


        gridLayout->addWidget(decorationtGB, 2, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        rowsL = new QLabel(MathMatrixUi);
        rowsL->setObjectName(QStringLiteral("rowsL"));

        hboxLayout->addWidget(rowsL);

        rowsSB = new QSpinBox(MathMatrixUi);
        rowsSB->setObjectName(QStringLiteral("rowsSB"));
        rowsSB->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        rowsSB->setMinimum(1);
        rowsSB->setMaximum(511);

        hboxLayout->addWidget(rowsSB);

        columnsL = new QLabel(MathMatrixUi);
        columnsL->setObjectName(QStringLiteral("columnsL"));

        hboxLayout->addWidget(columnsL);

        columnsSB = new QSpinBox(MathMatrixUi);
        columnsSB->setObjectName(QStringLiteral("columnsSB"));
        columnsSB->setButtonSymbols(QAbstractSpinBox::PlusMinus);
        columnsSB->setMinimum(1);
        columnsSB->setMaximum(511);

        hboxLayout->addWidget(columnsSB);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 3);

        table = new EmptyTable(MathMatrixUi);
        table->setObjectName(QStringLiteral("table"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(table->sizePolicy().hasHeightForWidth());
        table->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(table, 1, 0, 1, 3);

#ifndef QT_NO_SHORTCUT
        valignLA->setBuddy(valignCO);
        widthLA_2->setBuddy(halignED);
        typeLA->setBuddy(decorationCO);
        rowsL->setBuddy(rowsSB);
        columnsL->setBuddy(columnsSB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(rowsSB, columnsSB);
        QWidget::setTabOrder(columnsSB, valignCO);
        QWidget::setTabOrder(valignCO, halignED);
        QWidget::setTabOrder(halignED, decorationCO);

        retranslateUi(MathMatrixUi);

        QMetaObject::connectSlotsByName(MathMatrixUi);
    } // setupUi

    void retranslateUi(QDialog *MathMatrixUi)
    {
        MathMatrixUi->setWindowTitle(QString());
        alignmentGB->setTitle(lyx::qt_("Alignment", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        halignED->setToolTip(lyx::qt_("Horizontal alignment per column (l,c,r)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        valignLA->setText(lyx::qt_("&Vertical:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        valignCO->setToolTip(lyx::qt_("Vertical alignment", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        widthLA_2->setText(lyx::qt_("Hori&zontal:", Q_NULLPTR));
        decorationtGB->setTitle(lyx::qt_("Appearance", Q_NULLPTR));
        typeLA->setText(lyx::qt_("&Type:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        decorationCO->setToolTip(lyx::qt_("decoration type / matrix border", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        rowsL->setToolTip(lyx::qt_("Number of rows", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rowsL->setText(lyx::qt_("&Rows:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rowsSB->setToolTip(lyx::qt_("Number of rows", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        columnsL->setToolTip(lyx::qt_("Number of columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        columnsL->setText(lyx::qt_("&Columns:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        columnsSB->setToolTip(lyx::qt_("Number of columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        table->setToolTip(lyx::qt_("Resize this to the correct table dimensions", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class MathMatrixUi: public Ui_MathMatrixUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MATHMATRIXUI_H
