/********************************************************************************
** Form generated from reading UI file 'LabelUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LABELUI_H
#define UI_LABELUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LabelUi
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *keywordLA;
    QLineEdit *keywordED;

    void setupUi(QWidget *LabelUi)
    {
        if (LabelUi->objectName().isEmpty())
            LabelUi->setObjectName(QStringLiteral("LabelUi"));
        LabelUi->resize(300, 71);
        vboxLayout = new QVBoxLayout(LabelUi);
#ifndef Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        keywordLA = new QLabel(LabelUi);
        keywordLA->setObjectName(QStringLiteral("keywordLA"));

        hboxLayout->addWidget(keywordLA);

        keywordED = new QLineEdit(LabelUi);
        keywordED->setObjectName(QStringLiteral("keywordED"));

        hboxLayout->addWidget(keywordED);


        vboxLayout->addLayout(hboxLayout);

#ifndef QT_NO_SHORTCUT
        keywordLA->setBuddy(keywordED);
#endif // QT_NO_SHORTCUT

        retranslateUi(LabelUi);

        QMetaObject::connectSlotsByName(LabelUi);
    } // setupUi

    void retranslateUi(QWidget *LabelUi)
    {
        LabelUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        keywordLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        keywordLA->setText(lyx::qt_("&Label:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keywordED->setToolTip(QString());
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class LabelUi: public Ui_LabelUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LABELUI_H
