/****************************************************************************
** Meta object code from reading C++ file 'BulletsModule.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/BulletsModule.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BulletsModule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__BulletsModule_t {
    QByteArrayData data[11];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__BulletsModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__BulletsModule_t qt_meta_stringdata_lyx__frontend__BulletsModule = {
    {
QT_MOC_LITERAL(0, 0, 28), // "lyx::frontend::BulletsModule"
QT_MOC_LITERAL(1, 29, 7), // "changed"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 25), // "on_bulletsizeCO_activated"
QT_MOC_LITERAL(4, 64, 5), // "level"
QT_MOC_LITERAL(5, 70, 19), // "on_customCB_clicked"
QT_MOC_LITERAL(6, 90, 22), // "on_customLE_textEdited"
QT_MOC_LITERAL(7, 113, 14), // "bulletSelected"
QT_MOC_LITERAL(8, 128, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(9, 145, 9), // "showLevel"
QT_MOC_LITERAL(10, 155, 14) // "setCurrentPane"

    },
    "lyx::frontend::BulletsModule\0changed\0"
    "\0on_bulletsizeCO_activated\0level\0"
    "on_customCB_clicked\0on_customLE_textEdited\0"
    "bulletSelected\0QListWidgetItem*\0"
    "showLevel\0setCurrentPane"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__BulletsModule[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   50,    2, 0x09 /* Protected */,
       5,    1,   53,    2, 0x09 /* Protected */,
       6,    1,   56,    2, 0x09 /* Protected */,
       7,    1,   59,    2, 0x09 /* Protected */,
       9,    1,   62,    2, 0x09 /* Protected */,
      10,    1,   65,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void lyx::frontend::BulletsModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BulletsModule *_t = static_cast<BulletsModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->on_bulletsizeCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->on_customCB_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->on_customLE_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->bulletSelected((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 5: _t->showLevel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setCurrentPane((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (BulletsModule::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BulletsModule::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::BulletsModule::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__BulletsModule.data,
      qt_meta_data_lyx__frontend__BulletsModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::BulletsModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::BulletsModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__BulletsModule.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::BulletsUi"))
        return static_cast< Ui::BulletsUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::BulletsModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::BulletsModule::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
