/********************************************************************************
** Form generated from reading UI file 'PrefConvertersUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFCONVERTERSUI_H
#define UI_PREFCONVERTERSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefConvertersUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *converterDefGB;
    QGridLayout *gridLayout1;
    QListWidget *convertersLW;
    QGridLayout *gridLayout2;
    QVBoxLayout *vboxLayout;
    QLineEdit *converterED;
    QLineEdit *converterFlagED;
    QVBoxLayout *vboxLayout1;
    QLabel *converterLA;
    QLabel *converterFlagLA;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout2;
    QLabel *converterFromLA;
    QComboBox *converterFromCO;
    QVBoxLayout *vboxLayout3;
    QLabel *converterToLA;
    QComboBox *converterToCO;
    QVBoxLayout *vboxLayout4;
    QPushButton *converterNewPB;
    QPushButton *converterModifyPB;
    QPushButton *converterRemovePB;
    QSpacerItem *spacerItem;
    QGroupBox *cacheGB;
    QGridLayout *gridLayout3;
    QHBoxLayout *hboxLayout1;
    QCheckBox *cacheCB;
    QSpacerItem *spacerItem1;
    QLabel *maxAgeLA;
    QLineEdit *maxAgeLE;
    QGroupBox *securityGB;
    QGridLayout *gridLayout4;
    QHBoxLayout *hboxLayout2;
    QCheckBox *needauthForbiddenCB;
    QCheckBox *needauthCB;

    void setupUi(QWidget *PrefConvertersUi)
    {
        if (PrefConvertersUi->objectName().isEmpty())
            PrefConvertersUi->setObjectName(QStringLiteral("PrefConvertersUi"));
        PrefConvertersUi->resize(483, 513);
        gridLayout = new QGridLayout(PrefConvertersUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        converterDefGB = new QGroupBox(PrefConvertersUi);
        converterDefGB->setObjectName(QStringLiteral("converterDefGB"));
        converterDefGB->setFlat(true);
        gridLayout1 = new QGridLayout(converterDefGB);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        convertersLW = new QListWidget(converterDefGB);
        convertersLW->setObjectName(QStringLiteral("convertersLW"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(convertersLW->sizePolicy().hasHeightForWidth());
        convertersLW->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(convertersLW, 0, 0, 1, 1);

        gridLayout2 = new QGridLayout();
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        converterED = new QLineEdit(converterDefGB);
        converterED->setObjectName(QStringLiteral("converterED"));

        vboxLayout->addWidget(converterED);

        converterFlagED = new QLineEdit(converterDefGB);
        converterFlagED->setObjectName(QStringLiteral("converterFlagED"));

        vboxLayout->addWidget(converterFlagED);


        gridLayout2->addLayout(vboxLayout, 0, 1, 1, 1);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        converterLA = new QLabel(converterDefGB);
        converterLA->setObjectName(QStringLiteral("converterLA"));

        vboxLayout1->addWidget(converterLA);

        converterFlagLA = new QLabel(converterDefGB);
        converterFlagLA->setObjectName(QStringLiteral("converterFlagLA"));

        vboxLayout1->addWidget(converterFlagLA);


        gridLayout2->addLayout(vboxLayout1, 0, 0, 1, 1);


        gridLayout1->addLayout(gridLayout2, 2, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        converterFromLA = new QLabel(converterDefGB);
        converterFromLA->setObjectName(QStringLiteral("converterFromLA"));

        vboxLayout2->addWidget(converterFromLA);

        converterFromCO = new QComboBox(converterDefGB);
        converterFromCO->setObjectName(QStringLiteral("converterFromCO"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(converterFromCO->sizePolicy().hasHeightForWidth());
        converterFromCO->setSizePolicy(sizePolicy1);

        vboxLayout2->addWidget(converterFromCO);


        hboxLayout->addLayout(vboxLayout2);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName(QStringLiteral("vboxLayout3"));
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        converterToLA = new QLabel(converterDefGB);
        converterToLA->setObjectName(QStringLiteral("converterToLA"));

        vboxLayout3->addWidget(converterToLA);

        converterToCO = new QComboBox(converterDefGB);
        converterToCO->setObjectName(QStringLiteral("converterToCO"));
        sizePolicy1.setHeightForWidth(converterToCO->sizePolicy().hasHeightForWidth());
        converterToCO->setSizePolicy(sizePolicy1);

        vboxLayout3->addWidget(converterToCO);


        hboxLayout->addLayout(vboxLayout3);


        gridLayout1->addLayout(hboxLayout, 1, 0, 1, 2);

        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName(QStringLiteral("vboxLayout4"));
        vboxLayout4->setContentsMargins(0, 0, 0, 0);
        converterNewPB = new QPushButton(converterDefGB);
        converterNewPB->setObjectName(QStringLiteral("converterNewPB"));

        vboxLayout4->addWidget(converterNewPB);

        converterModifyPB = new QPushButton(converterDefGB);
        converterModifyPB->setObjectName(QStringLiteral("converterModifyPB"));

        vboxLayout4->addWidget(converterModifyPB);

        converterRemovePB = new QPushButton(converterDefGB);
        converterRemovePB->setObjectName(QStringLiteral("converterRemovePB"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(converterRemovePB->sizePolicy().hasHeightForWidth());
        converterRemovePB->setSizePolicy(sizePolicy2);

        vboxLayout4->addWidget(converterRemovePB);

        spacerItem = new QSpacerItem(75, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout4->addItem(spacerItem);


        gridLayout1->addLayout(vboxLayout4, 0, 1, 1, 1);


        gridLayout->addWidget(converterDefGB, 0, 0, 1, 1);

        cacheGB = new QGroupBox(PrefConvertersUi);
        cacheGB->setObjectName(QStringLiteral("cacheGB"));
        cacheGB->setFlat(true);
        gridLayout3 = new QGridLayout(cacheGB);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        cacheCB = new QCheckBox(cacheGB);
        cacheCB->setObjectName(QStringLiteral("cacheCB"));

        hboxLayout1->addWidget(cacheCB);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);

        maxAgeLA = new QLabel(cacheGB);
        maxAgeLA->setObjectName(QStringLiteral("maxAgeLA"));

        hboxLayout1->addWidget(maxAgeLA);

        maxAgeLE = new QLineEdit(cacheGB);
        maxAgeLE->setObjectName(QStringLiteral("maxAgeLE"));

        hboxLayout1->addWidget(maxAgeLE);


        gridLayout3->addLayout(hboxLayout1, 0, 0, 1, 1);


        gridLayout->addWidget(cacheGB, 1, 0, 1, 1);

        securityGB = new QGroupBox(PrefConvertersUi);
        securityGB->setObjectName(QStringLiteral("securityGB"));
        securityGB->setFlat(true);
        gridLayout4 = new QGridLayout(securityGB);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        needauthForbiddenCB = new QCheckBox(securityGB);
        needauthForbiddenCB->setObjectName(QStringLiteral("needauthForbiddenCB"));

        hboxLayout2->addWidget(needauthForbiddenCB);

        needauthCB = new QCheckBox(securityGB);
        needauthCB->setObjectName(QStringLiteral("needauthCB"));

        hboxLayout2->addWidget(needauthCB);


        gridLayout4->addLayout(hboxLayout2, 0, 0, 1, 1);


        gridLayout->addWidget(securityGB, 2, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        converterLA->setBuddy(converterED);
        converterFlagLA->setBuddy(converterFlagED);
        converterFromLA->setBuddy(converterFromCO);
        converterToLA->setBuddy(converterToCO);
        maxAgeLA->setBuddy(maxAgeLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(convertersLW, converterFromCO);
        QWidget::setTabOrder(converterFromCO, converterToCO);
        QWidget::setTabOrder(converterToCO, converterED);
        QWidget::setTabOrder(converterED, converterFlagED);
        QWidget::setTabOrder(converterFlagED, converterNewPB);
        QWidget::setTabOrder(converterNewPB, converterModifyPB);
        QWidget::setTabOrder(converterModifyPB, converterRemovePB);

        retranslateUi(PrefConvertersUi);

        QMetaObject::connectSlotsByName(PrefConvertersUi);
    } // setupUi

    void retranslateUi(QWidget *PrefConvertersUi)
    {
        PrefConvertersUi->setWindowTitle(QString());
        converterDefGB->setTitle(lyx::qt_("Converter Defi&nitions", Q_NULLPTR));
        converterLA->setText(lyx::qt_("&Converter:", Q_NULLPTR));
        converterFlagLA->setText(lyx::qt_("E&xtra flag:", Q_NULLPTR));
        converterFromLA->setText(lyx::qt_("Fro&m format:", Q_NULLPTR));
        converterToLA->setText(lyx::qt_("&To format:", Q_NULLPTR));
        converterNewPB->setText(lyx::qt_("A&dd", Q_NULLPTR));
        converterModifyPB->setText(lyx::qt_("&Modify", Q_NULLPTR));
        converterRemovePB->setText(lyx::qt_("Remo&ve", Q_NULLPTR));
        cacheGB->setTitle(lyx::qt_("Converter File Cache", Q_NULLPTR));
        cacheCB->setText(lyx::qt_("&Enabled", Q_NULLPTR));
        maxAgeLA->setText(lyx::qt_("Maximum a&ge (in days):", Q_NULLPTR));
        securityGB->setTitle(lyx::qt_("Security", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        needauthForbiddenCB->setToolTip(lyx::qt_("When enabled, use of converters with the 'needauth' option is forbidden.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        needauthForbiddenCB->setText(lyx::qt_("&Forbid use of needauth converters", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        needauthCB->setToolTip(lyx::qt_("When enabled, ask user before launching any external converter with the 'needauth' option.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        needauthCB->setText(lyx::qt_("Use need&auth option", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefConvertersUi: public Ui_PrefConvertersUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFCONVERTERSUI_H
