/****************************************************************************
** Meta object code from reading C++ file 'TocWidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/TocWidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TocWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__TocWidget_t {
    QByteArrayData data[26];
    char stringdata0[397];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__TocWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__TocWidget_t qt_meta_stringdata_lyx__frontend__TocWidget = {
    {
QT_MOC_LITERAL(0, 0, 24), // "lyx::frontend::TocWidget"
QT_MOC_LITERAL(1, 25, 10), // "updateView"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 13), // "updateViewNow"
QT_MOC_LITERAL(4, 51, 6), // "select"
QT_MOC_LITERAL(5, 58, 5), // "index"
QT_MOC_LITERAL(6, 64, 4), // "goTo"
QT_MOC_LITERAL(7, 69, 18), // "on_tocTV_activated"
QT_MOC_LITERAL(8, 88, 16), // "on_tocTV_pressed"
QT_MOC_LITERAL(9, 105, 22), // "on_tocTV_doubleClicked"
QT_MOC_LITERAL(10, 128, 19), // "on_updateTB_clicked"
QT_MOC_LITERAL(11, 148, 22), // "on_sortCB_stateChanged"
QT_MOC_LITERAL(12, 171, 5), // "state"
QT_MOC_LITERAL(13, 177, 28), // "on_persistentCB_stateChanged"
QT_MOC_LITERAL(14, 206, 23), // "on_depthSL_valueChanged"
QT_MOC_LITERAL(15, 230, 5), // "depth"
QT_MOC_LITERAL(16, 236, 19), // "on_typeCO_activated"
QT_MOC_LITERAL(17, 256, 5), // "value"
QT_MOC_LITERAL(18, 262, 19), // "on_moveUpTB_clicked"
QT_MOC_LITERAL(19, 282, 21), // "on_moveDownTB_clicked"
QT_MOC_LITERAL(20, 304, 19), // "on_moveInTB_clicked"
QT_MOC_LITERAL(21, 324, 20), // "on_moveOutTB_clicked"
QT_MOC_LITERAL(22, 345, 14), // "filterContents"
QT_MOC_LITERAL(23, 360, 15), // "showContextMenu"
QT_MOC_LITERAL(24, 376, 3), // "pos"
QT_MOC_LITERAL(25, 380, 16) // "finishUpdateView"

    },
    "lyx::frontend::TocWidget\0updateView\0"
    "\0updateViewNow\0select\0index\0goTo\0"
    "on_tocTV_activated\0on_tocTV_pressed\0"
    "on_tocTV_doubleClicked\0on_updateTB_clicked\0"
    "on_sortCB_stateChanged\0state\0"
    "on_persistentCB_stateChanged\0"
    "on_depthSL_valueChanged\0depth\0"
    "on_typeCO_activated\0value\0on_moveUpTB_clicked\0"
    "on_moveDownTB_clicked\0on_moveInTB_clicked\0"
    "on_moveOutTB_clicked\0filterContents\0"
    "showContextMenu\0pos\0finishUpdateView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__TocWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  109,    2, 0x0a /* Public */,
       3,    0,  110,    2, 0x0a /* Public */,
       4,    1,  111,    2, 0x09 /* Protected */,
       6,    1,  114,    2, 0x09 /* Protected */,
       7,    1,  117,    2, 0x09 /* Protected */,
       8,    1,  120,    2, 0x09 /* Protected */,
       9,    1,  123,    2, 0x09 /* Protected */,
      10,    0,  126,    2, 0x09 /* Protected */,
      11,    1,  127,    2, 0x09 /* Protected */,
      13,    1,  130,    2, 0x09 /* Protected */,
      14,    1,  133,    2, 0x09 /* Protected */,
      16,    1,  136,    2, 0x09 /* Protected */,
      18,    0,  139,    2, 0x09 /* Protected */,
      19,    0,  140,    2, 0x09 /* Protected */,
      20,    0,  141,    2, 0x09 /* Protected */,
      21,    0,  142,    2, 0x09 /* Protected */,
      22,    0,  143,    2, 0x09 /* Protected */,
      23,    1,  144,    2, 0x09 /* Protected */,
      25,    0,  147,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    5,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   24,
    QMetaType::Void,

       0        // eod
};

void lyx::frontend::TocWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TocWidget *_t = static_cast<TocWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateView(); break;
        case 1: _t->updateViewNow(); break;
        case 2: _t->select((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->goTo((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->on_tocTV_activated((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 5: _t->on_tocTV_pressed((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 6: _t->on_tocTV_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->on_updateTB_clicked(); break;
        case 8: _t->on_sortCB_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_persistentCB_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_depthSL_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->on_typeCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->on_moveUpTB_clicked(); break;
        case 13: _t->on_moveDownTB_clicked(); break;
        case 14: _t->on_moveInTB_clicked(); break;
        case 15: _t->on_moveOutTB_clicked(); break;
        case 16: _t->filterContents(); break;
        case 17: _t->showContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 18: _t->finishUpdateView(); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::TocWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__TocWidget.data,
      qt_meta_data_lyx__frontend__TocWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::TocWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::TocWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__TocWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TocUi"))
        return static_cast< Ui::TocUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::TocWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
