/********************************************************************************
** Form generated from reading UI file 'BibitemUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BIBITEMUI_H
#define UI_BIBITEMUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BibitemUi
{
public:
    QGridLayout *gridLayout;
    QLabel *keyLA;
    QLineEdit *keyED;
    QLabel *labelLA;
    QHBoxLayout *horizontalLayout;
    QLineEdit *labelED;
    QLabel *yearLA;
    QLineEdit *yearED;
    QLabel *allAuthorsLA;
    QLineEdit *allAuthorsED;
    QCheckBox *literalCB;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BibitemUi)
    {
        if (BibitemUi->objectName().isEmpty())
            BibitemUi->setObjectName(QStringLiteral("BibitemUi"));
        BibitemUi->resize(503, 168);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(BibitemUi->sizePolicy().hasHeightForWidth());
        BibitemUi->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(BibitemUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        keyLA = new QLabel(BibitemUi);
        keyLA->setObjectName(QStringLiteral("keyLA"));

        gridLayout->addWidget(keyLA, 0, 0, 1, 1);

        keyED = new QLineEdit(BibitemUi);
        keyED->setObjectName(QStringLiteral("keyED"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(keyED->sizePolicy().hasHeightForWidth());
        keyED->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(keyED, 0, 1, 1, 2);

        labelLA = new QLabel(BibitemUi);
        labelLA->setObjectName(QStringLiteral("labelLA"));

        gridLayout->addWidget(labelLA, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        labelED = new QLineEdit(BibitemUi);
        labelED->setObjectName(QStringLiteral("labelED"));
        sizePolicy1.setHeightForWidth(labelED->sizePolicy().hasHeightForWidth());
        labelED->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(labelED);

        yearLA = new QLabel(BibitemUi);
        yearLA->setObjectName(QStringLiteral("yearLA"));
        yearLA->setMargin(6);

        horizontalLayout->addWidget(yearLA);

        yearED = new QLineEdit(BibitemUi);
        yearED->setObjectName(QStringLiteral("yearED"));

        horizontalLayout->addWidget(yearED);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 2);

        allAuthorsLA = new QLabel(BibitemUi);
        allAuthorsLA->setObjectName(QStringLiteral("allAuthorsLA"));

        gridLayout->addWidget(allAuthorsLA, 2, 0, 1, 2);

        allAuthorsED = new QLineEdit(BibitemUi);
        allAuthorsED->setObjectName(QStringLiteral("allAuthorsED"));

        gridLayout->addWidget(allAuthorsED, 2, 2, 1, 1);

        literalCB = new QCheckBox(BibitemUi);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        gridLayout->addWidget(literalCB, 3, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 2, 1, 1);

#ifndef QT_NO_SHORTCUT
        keyLA->setBuddy(keyED);
        labelLA->setBuddy(labelED);
        yearLA->setBuddy(yearED);
        allAuthorsLA->setBuddy(allAuthorsED);
#endif // QT_NO_SHORTCUT

        retranslateUi(BibitemUi);

        QMetaObject::connectSlotsByName(BibitemUi);
    } // setupUi

    void retranslateUi(QWidget *BibitemUi)
    {
        BibitemUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        keyLA->setToolTip(lyx::qt_("The bibliography key", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        keyLA->setText(lyx::qt_("Ke&y:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        keyED->setToolTip(lyx::qt_("The bibliography key", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        labelLA->setToolTip(lyx::qt_("The label as it appears in the document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        labelLA->setText(lyx::qt_("&Label:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        labelED->setToolTip(lyx::qt_("The label as it appears in the document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        yearLA->setText(lyx::qt_("&Year:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        yearED->setToolTip(lyx::qt_("The year with \"Author (Year)\" citations (without parentheses).", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        allAuthorsLA->setText(lyx::qt_("A&ll Author Names:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        allAuthorsED->setToolTip(lyx::qt_("If you want to use an abbreviated author list (with 'et al.') as well as a full list for author-year citation, you can put the full list here and the abbreviated list above.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass content of the `Label' field literally to LaTeX. Check this if you want to enter LaTeX code.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BibitemUi: public Ui_BibitemUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BIBITEMUI_H
