/********************************************************************************
** Form generated from reading UI file 'InsetParamsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INSETPARAMSUI_H
#define UI_INSETPARAMSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_InsetParamsUi
{
public:
    QGridLayout *gridLayout;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QWidget *page_2;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacerItem;
    QCheckBox *synchronizedCB;
    QCheckBox *immediateApplyCB;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *InsetParamsUi)
    {
        if (InsetParamsUi->objectName().isEmpty())
            InsetParamsUi->setObjectName(QStringLiteral("InsetParamsUi"));
        InsetParamsUi->resize(484, 104);
        InsetParamsUi->setFocusPolicy(Qt::NoFocus);
        gridLayout = new QGridLayout(InsetParamsUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setVerticalSpacing(12);
        stackedWidget = new QStackedWidget(InsetParamsUi);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        page = new QWidget();
        page->setObjectName(QStringLiteral("page"));
        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        stackedWidget->addWidget(page_2);

        gridLayout->addWidget(stackedWidget, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(InsetParamsUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacerItem);

        synchronizedCB = new QCheckBox(InsetParamsUi);
        synchronizedCB->setObjectName(QStringLiteral("synchronizedCB"));

        horizontalLayout->addWidget(synchronizedCB);

        immediateApplyCB = new QCheckBox(InsetParamsUi);
        immediateApplyCB->setObjectName(QStringLiteral("immediateApplyCB"));
        immediateApplyCB->setLayoutDirection(Qt::LeftToRight);

        horizontalLayout->addWidget(immediateApplyCB);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);


        retranslateUi(InsetParamsUi);

        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(InsetParamsUi);
    } // setupUi

    void retranslateUi(QDialog *InsetParamsUi)
    {
        InsetParamsUi->setWindowTitle(lyx::qt_("Inset Parameter Configuration", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        synchronizedCB->setToolTip(lyx::qt_("Update dialog when moving context", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        synchronizedCB->setText(lyx::qt_("S&ynchronize Dialog", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        immediateApplyCB->setToolTip(lyx::qt_("Apply settings immediately", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        immediateApplyCB->setText(lyx::qt_("I&mmediate Apply", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class InsetParamsUi: public Ui_InsetParamsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INSETPARAMSUI_H
