/****************************************************************************
** Meta object code from reading C++ file 'GuiIndices.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiIndices.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiIndices.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiIndices_t {
    QByteArrayData data[15];
    char stringdata0[306];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiIndices_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiIndices_t qt_meta_stringdata_lyx__frontend__GuiIndices = {
    {
QT_MOC_LITERAL(0, 0, 25), // "lyx::frontend::GuiIndices"
QT_MOC_LITERAL(1, 26, 7), // "changed"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 20), // "on_indexCO_activated"
QT_MOC_LITERAL(4, 56, 1), // "n"
QT_MOC_LITERAL(5, 58, 25), // "on_newIndexLE_textChanged"
QT_MOC_LITERAL(6, 84, 29), // "on_indexOptionsLE_textChanged"
QT_MOC_LITERAL(7, 114, 21), // "on_addIndexPB_pressed"
QT_MOC_LITERAL(8, 136, 19), // "on_renamePB_clicked"
QT_MOC_LITERAL(9, 156, 19), // "on_removePB_pressed"
QT_MOC_LITERAL(10, 176, 30), // "on_indicesTW_itemDoubleClicked"
QT_MOC_LITERAL(11, 207, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(12, 224, 33), // "on_indicesTW_itemSelectionCha..."
QT_MOC_LITERAL(13, 258, 18), // "on_colorPB_clicked"
QT_MOC_LITERAL(14, 277, 28) // "on_multipleIndicesCB_toggled"

    },
    "lyx::frontend::GuiIndices\0changed\0\0"
    "on_indexCO_activated\0n\0on_newIndexLE_textChanged\0"
    "on_indexOptionsLE_textChanged\0"
    "on_addIndexPB_pressed\0on_renamePB_clicked\0"
    "on_removePB_pressed\0on_indicesTW_itemDoubleClicked\0"
    "QTreeWidgetItem*\0on_indicesTW_itemSelectionChanged\0"
    "on_colorPB_clicked\0on_multipleIndicesCB_toggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiIndices[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   70,    2, 0x09 /* Protected */,
       5,    1,   73,    2, 0x09 /* Protected */,
       6,    1,   76,    2, 0x09 /* Protected */,
       7,    0,   79,    2, 0x09 /* Protected */,
       8,    0,   80,    2, 0x09 /* Protected */,
       9,    0,   81,    2, 0x09 /* Protected */,
      10,    2,   82,    2, 0x09 /* Protected */,
      12,    0,   87,    2, 0x09 /* Protected */,
      13,    0,   88,    2, 0x09 /* Protected */,
      14,    1,   89,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void lyx::frontend::GuiIndices::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiIndices *_t = static_cast<GuiIndices *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->on_indexCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->on_newIndexLE_textChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->on_indexOptionsLE_textChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->on_addIndexPB_pressed(); break;
        case 5: _t->on_renamePB_clicked(); break;
        case 6: _t->on_removePB_pressed(); break;
        case 7: _t->on_indicesTW_itemDoubleClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->on_indicesTW_itemSelectionChanged(); break;
        case 9: _t->on_colorPB_clicked(); break;
        case 10: _t->on_multipleIndicesCB_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GuiIndices::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GuiIndices::changed)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject lyx::frontend::GuiIndices::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiIndices.data,
      qt_meta_data_lyx__frontend__GuiIndices,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiIndices::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiIndices::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiIndices.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::IndicesUi"))
        return static_cast< Ui::IndicesUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int lyx::frontend::GuiIndices::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void lyx::frontend::GuiIndices::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
