/********************************************************************************
** Form generated from reading UI file 'NomenclUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOMENCLUI_H
#define UI_NOMENCLUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_NomenclUi
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *symbolLA;
    QLineEdit *symbolED;
    QLabel *descrLA;
    QTextEdit *descriptionTE;
    QLabel *prefixLA;
    QLineEdit *prefixED;
    QCheckBox *literalCB;

    void setupUi(QWidget *NomenclUi)
    {
        if (NomenclUi->objectName().isEmpty())
            NomenclUi->setObjectName(QStringLiteral("NomenclUi"));
        NomenclUi->resize(319, 223);
        gridLayout_2 = new QGridLayout(NomenclUi);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        symbolLA = new QLabel(NomenclUi);
        symbolLA->setObjectName(QStringLiteral("symbolLA"));

        gridLayout->addWidget(symbolLA, 0, 0, 1, 1);

        symbolED = new QLineEdit(NomenclUi);
        symbolED->setObjectName(QStringLiteral("symbolED"));

        gridLayout->addWidget(symbolED, 0, 1, 1, 1);

        descrLA = new QLabel(NomenclUi);
        descrLA->setObjectName(QStringLiteral("descrLA"));

        gridLayout->addWidget(descrLA, 1, 0, 1, 1);

        descriptionTE = new QTextEdit(NomenclUi);
        descriptionTE->setObjectName(QStringLiteral("descriptionTE"));
        descriptionTE->setAcceptRichText(false);

        gridLayout->addWidget(descriptionTE, 1, 1, 1, 1);

        prefixLA = new QLabel(NomenclUi);
        prefixLA->setObjectName(QStringLiteral("prefixLA"));

        gridLayout->addWidget(prefixLA, 2, 0, 1, 1);

        prefixED = new QLineEdit(NomenclUi);
        prefixED->setObjectName(QStringLiteral("prefixED"));

        gridLayout->addWidget(prefixED, 2, 1, 1, 1);

        literalCB = new QCheckBox(NomenclUi);
        literalCB->setObjectName(QStringLiteral("literalCB"));

        gridLayout->addWidget(literalCB, 3, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        symbolLA->setBuddy(symbolED);
        descrLA->setBuddy(descriptionTE);
        prefixLA->setBuddy(prefixED);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(symbolED, descriptionTE);
        QWidget::setTabOrder(descriptionTE, prefixED);

        retranslateUi(NomenclUi);

        QMetaObject::connectSlotsByName(NomenclUi);
    } // setupUi

    void retranslateUi(QWidget *NomenclUi)
    {
        NomenclUi->setWindowTitle(lyx::qt_("Nomenclature", Q_NULLPTR));
        symbolLA->setText(lyx::qt_("Sy&mbol:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        symbolED->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        descrLA->setText(lyx::qt_("Des&cription:", Q_NULLPTR));
        prefixLA->setText(lyx::qt_("Sort &as:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        literalCB->setToolTip(lyx::qt_("Pass content of the `Symbol' and `Description' fields literally to LaTeX. Check this if you want to enter LaTeX code.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        literalCB->setText(lyx::qt_("Li&teral", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NomenclUi: public Ui_NomenclUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NOMENCLUI_H
