/********************************************************************************
** Form generated from reading UI file 'LaTeXUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LATEXUI_H
#define UI_LATEXUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "CategorizedCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LaTeXUi
{
public:
    QGridLayout *gridLayout_2;
    QLabel *psdriverL;
    QComboBox *psdriverCO;
    QCheckBox *refstyleCB;
    QSpacerItem *verticalSpacer;
    QCheckBox *suppressDateCB;
    QSpacerItem *horizontalSpacer_1;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    lyx::frontend::CategorizedCombo *classCO;
    QPushButton *layoutPB;
    QGroupBox *childDocGB;
    QGridLayout *gridLayout1;
    QLabel *childDocLA;
    QPushButton *childDocPB;
    QLineEdit *childDocLE;
    QGroupBox *optionsGB;
    QGridLayout *gridLayout_1;
    QCheckBox *defaultOptionsCB;
    QLineEdit *defaultOptionsLE;
    QLabel *optionsL;
    QLineEdit *optionsLE;
    QCheckBox *refFormattedCB;

    void setupUi(QWidget *LaTeXUi)
    {
        if (LaTeXUi->objectName().isEmpty())
            LaTeXUi->setObjectName(QStringLiteral("LaTeXUi"));
        LaTeXUi->resize(446, 431);
        gridLayout_2 = new QGridLayout(LaTeXUi);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        psdriverL = new QLabel(LaTeXUi);
        psdriverL->setObjectName(QStringLiteral("psdriverL"));

        gridLayout_2->addWidget(psdriverL, 2, 0, 1, 1);

        psdriverCO = new QComboBox(LaTeXUi);
        psdriverCO->setObjectName(QStringLiteral("psdriverCO"));
        psdriverCO->setDuplicatesEnabled(false);

        gridLayout_2->addWidget(psdriverCO, 2, 2, 1, 1);

        refstyleCB = new QCheckBox(LaTeXUi);
        refstyleCB->setObjectName(QStringLiteral("refstyleCB"));

        gridLayout_2->addWidget(refstyleCB, 5, 0, 1, 4);

        verticalSpacer = new QSpacerItem(20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 7, 1, 1, 1);

        suppressDateCB = new QCheckBox(LaTeXUi);
        suppressDateCB->setObjectName(QStringLiteral("suppressDateCB"));
        suppressDateCB->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(suppressDateCB->sizePolicy().hasHeightForWidth());
        suppressDateCB->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(suppressDateCB, 4, 0, 1, 4);

        horizontalSpacer_1 = new QSpacerItem(261, 22, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_1, 2, 3, 1, 1);

        groupBox = new QGroupBox(LaTeXUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        classCO = new lyx::frontend::CategorizedCombo(groupBox);
        classCO->setObjectName(QStringLiteral("classCO"));
        classCO->setMaxVisibleItems(20);

        gridLayout->addWidget(classCO, 0, 0, 1, 1);

        layoutPB = new QPushButton(groupBox);
        layoutPB->setObjectName(QStringLiteral("layoutPB"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(layoutPB->sizePolicy().hasHeightForWidth());
        layoutPB->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(layoutPB, 0, 1, 1, 1);


        gridLayout_2->addWidget(groupBox, 0, 0, 1, 4);

        childDocGB = new QGroupBox(LaTeXUi);
        childDocGB->setObjectName(QStringLiteral("childDocGB"));
        childDocGB->setFlat(true);
        childDocGB->setCheckable(true);
        gridLayout1 = new QGridLayout(childDocGB);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        childDocLA = new QLabel(childDocGB);
        childDocLA->setObjectName(QStringLiteral("childDocLA"));

        gridLayout1->addWidget(childDocLA, 0, 0, 1, 1);

        childDocPB = new QPushButton(childDocGB);
        childDocPB->setObjectName(QStringLiteral("childDocPB"));

        gridLayout1->addWidget(childDocPB, 0, 2, 1, 1);

        childDocLE = new QLineEdit(childDocGB);
        childDocLE->setObjectName(QStringLiteral("childDocLE"));

        gridLayout1->addWidget(childDocLE, 0, 1, 1, 1);


        gridLayout_2->addWidget(childDocGB, 3, 0, 1, 4);

        optionsGB = new QGroupBox(LaTeXUi);
        optionsGB->setObjectName(QStringLiteral("optionsGB"));
        optionsGB->setFlat(true);
        gridLayout_1 = new QGridLayout(optionsGB);
        gridLayout_1->setObjectName(QStringLiteral("gridLayout_1"));
        defaultOptionsCB = new QCheckBox(optionsGB);
        defaultOptionsCB->setObjectName(QStringLiteral("defaultOptionsCB"));

        gridLayout_1->addWidget(defaultOptionsCB, 0, 0, 1, 1);

        defaultOptionsLE = new QLineEdit(optionsGB);
        defaultOptionsLE->setObjectName(QStringLiteral("defaultOptionsLE"));
        defaultOptionsLE->setReadOnly(true);

        gridLayout_1->addWidget(defaultOptionsLE, 0, 1, 1, 1);

        optionsL = new QLabel(optionsGB);
        optionsL->setObjectName(QStringLiteral("optionsL"));

        gridLayout_1->addWidget(optionsL, 1, 0, 1, 1);

        optionsLE = new QLineEdit(optionsGB);
        optionsLE->setObjectName(QStringLiteral("optionsLE"));

        gridLayout_1->addWidget(optionsLE, 1, 1, 1, 1);


        gridLayout_2->addWidget(optionsGB, 1, 0, 1, 4);

        refFormattedCB = new QCheckBox(LaTeXUi);
        refFormattedCB->setObjectName(QStringLiteral("refFormattedCB"));

        gridLayout_2->addWidget(refFormattedCB, 6, 0, 1, 4);

#ifndef QT_NO_SHORTCUT
        psdriverL->setBuddy(psdriverCO);
        childDocLA->setBuddy(childDocLE);
        optionsL->setBuddy(optionsLE);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(classCO, layoutPB);
        QWidget::setTabOrder(layoutPB, defaultOptionsCB);
        QWidget::setTabOrder(defaultOptionsCB, defaultOptionsLE);
        QWidget::setTabOrder(defaultOptionsLE, optionsLE);
        QWidget::setTabOrder(optionsLE, psdriverCO);
        QWidget::setTabOrder(psdriverCO, childDocGB);
        QWidget::setTabOrder(childDocGB, childDocLE);
        QWidget::setTabOrder(childDocLE, childDocPB);
        QWidget::setTabOrder(childDocPB, suppressDateCB);
        QWidget::setTabOrder(suppressDateCB, refstyleCB);

        retranslateUi(LaTeXUi);
        QObject::connect(defaultOptionsCB, SIGNAL(toggled(bool)), defaultOptionsLE, SLOT(setEnabled(bool)));
        QObject::connect(groupBox, SIGNAL(clicked()), classCO, SLOT(setFocus()));

        QMetaObject::connectSlotsByName(LaTeXUi);
    } // setupUi

    void retranslateUi(QWidget *LaTeXUi)
    {
        LaTeXUi->setWindowTitle(QString());
        psdriverL->setText(lyx::qt_("&Graphics driver:", Q_NULLPTR));
        refstyleCB->setText(lyx::qt_("&Use refstyle (not prettyref) for cross-references", Q_NULLPTR));
        suppressDateCB->setText(lyx::qt_("&Suppress default date on front page", Q_NULLPTR));
        groupBox->setTitle(lyx::qt_("Document &Class", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        layoutPB->setToolTip(lyx::qt_("Click to select a local document class definition file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        layoutPB->setText(lyx::qt_("&Local Class...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        childDocGB->setToolTip(lyx::qt_("Select if the current document is included to a master file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_STATUSTIP
        childDocGB->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
        childDocGB->setTitle(lyx::qt_("Select de&fault master document", Q_NULLPTR));
        childDocLA->setText(lyx::qt_("&Master:", Q_NULLPTR));
        childDocPB->setText(lyx::qt_("&Browse...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        childDocLE->setToolTip(lyx::qt_("Enter the name of the default master document", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        optionsGB->setTitle(lyx::qt_("Class Options", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultOptionsCB->setToolTip(lyx::qt_("Enable to use the options that are predefined in the layout file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        defaultOptionsCB->setText(lyx::qt_("&Predefined:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultOptionsLE->setToolTip(lyx::qt_("The options that are predefined in the layout file. Click to the left to select/deselect.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        optionsL->setText(lyx::qt_("Cus&tom:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        refFormattedCB->setToolTip(lyx::qt_("Attempt to display formatted cross-references as they would appear in the output, e.g., as \"Theorem 1\" rather than just as the label.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        refFormattedCB->setText(lyx::qt_("Format cross-references in the &work area", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LaTeXUi: public Ui_LaTeXUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LATEXUI_H
