/********************************************************************************
** Form generated from reading UI file 'TabularUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABULARUI_H
#define UI_TABULARUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include "GuiSetBorder.h"
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_TabularUi
{
public:
    QGridLayout *gridLayout_11;
    QTabWidget *TabWidget;
    QWidget *Settings;
    QGridLayout *gridLayout_10;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_6;
    QCheckBox *multirowCB;
    QGridLayout *gridLayout_3;
    QLabel *multirowOffsetLA;
    QLineEdit *multirowOffsetED;
    lyx::frontend::LengthCombo *multirowOffsetUnitLC;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_5;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *rotateCellCB;
    QSpinBox *rotateCellAngleSB;
    QLabel *rotateCellLA;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *tabAlignmentGB;
    QGridLayout *gridLayout_4;
    QLabel *tabularWidthLA;
    QLineEdit *tabularWidthED;
    lyx::frontend::LengthCombo *tabularWidthUnitLC;
    QLabel *TableAlignLA;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *rotateTabularCB;
    QSpinBox *rotateTabularAngleSB;
    QLabel *rotateTabularLA;
    QComboBox *TableAlignCO;
    QGroupBox *GroupBox12;
    QGridLayout *gridLayout_9;
    QGridLayout *gridLayout;
    QComboBox *columnTypeCO;
    QComboBox *hAlignCO;
    QLabel *columnWidthLA;
    QSpacerItem *horizontalSpacer_2;
    QLabel *hAlignLA;
    QComboBox *vAlignCO;
    QLabel *vAlignLA;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *columnWidthED;
    lyx::frontend::LengthCombo *columnWidthUnitLC;
    QHBoxLayout *horizontalLayout;
    QLabel *decimalLA;
    QLineEdit *decimalPointED;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *multicolumnCB;
    QHBoxLayout *horizontalLayout_5;
    QLabel *specialAlignmentLA;
    QLineEdit *specialAlignmentED;
    QWidget *Borders;
    QGridLayout *gridLayout_8;
    QGroupBox *setBordersGB;
    QGridLayout *gridLayout1;
    QFrame *bordersF;
    QGridLayout *gridLayout2;
    GuiSetBorder *borders;
    QGroupBox *allBordersGB;
    QGridLayout *gridLayout3;
    QPushButton *borderSetPB;
    QPushButton *borderUnsetPB;
    QGroupBox *borderStyleGB;
    QGridLayout *gridLayout4;
    QRadioButton *borderDefaultRB;
    QCheckBox *resetFormalCB;
    QRadioButton *booktabsRB;
    QSpacerItem *spacerItem;
    QGroupBox *SpaceGB;
    QGridLayout *gridLayout5;
    QLabel *topspaceLA;
    QLineEdit *topspaceED;
    lyx::frontend::LengthCombo *topspaceUnitLC;
    QComboBox *topspaceCO;
    QComboBox *bottomspaceCO;
    lyx::frontend::LengthCombo *bottomspaceUnitLC;
    QLineEdit *bottomspaceED;
    QLabel *bottomspaceLA;
    QLineEdit *interlinespaceED;
    QLabel *interlinespaceLA;
    QComboBox *interlinespaceCO;
    lyx::frontend::LengthCombo *interlinespaceUnitLC;
    QSpacerItem *verticalSpacer_2;
    QWidget *Longtables;
    QGridLayout *gridLayout_7;
    QCheckBox *longTabularCB;
    QGroupBox *longtableGB;
    QGridLayout *gridLayout_2;
    QLabel *StatusLA;
    QLabel *BorderAboveLA;
    QLabel *BorderBelowLA;
    QLabel *ContentsLA;
    QLabel *HeaderLA;
    QCheckBox *headerStatusCB;
    QCheckBox *headerBorderAboveCB;
    QCheckBox *headerBorderBelowCB;
    QLabel *FirstHeaderLA;
    QCheckBox *firstheaderStatusCB;
    QCheckBox *firstheaderBorderAboveCB;
    QCheckBox *firstheaderBorderBelowCB;
    QCheckBox *firstheaderNoContentsCB;
    QLabel *FooterLA;
    QCheckBox *footerStatusCB;
    QCheckBox *footerBorderAboveCB;
    QCheckBox *footerBorderBelowCB;
    QLabel *LastFooterLA;
    QCheckBox *lastfooterStatusCB;
    QCheckBox *lastfooterBorderAboveCB;
    QCheckBox *lastfooterBorderBelowCB;
    QCheckBox *lastfooterNoContentsCB;
    QLabel *label;
    QCheckBox *captionStatusCB;
    QCheckBox *newpageCB;
    QGroupBox *alignmentGB;
    QGridLayout *gridLayout9;
    QRadioButton *leftRB;
    QRadioButton *centerRB;
    QRadioButton *rightRB;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *_3;
    QLabel *TextLabel1;
    QLineEdit *tabularRowED;
    QLineEdit *tabularColumnED;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *TabularUi)
    {
        if (TabularUi->objectName().isEmpty())
            TabularUi->setObjectName(QStringLiteral("TabularUi"));
        TabularUi->resize(726, 585);
        TabularUi->setProperty("sizeGripEnabled", QVariant(false));
        gridLayout_11 = new QGridLayout(TabularUi);
        gridLayout_11->setObjectName(QStringLiteral("gridLayout_11"));
        TabWidget = new QTabWidget(TabularUi);
        TabWidget->setObjectName(QStringLiteral("TabWidget"));
        TabWidget->setTabShape(QTabWidget::Rounded);
        Settings = new QWidget();
        Settings->setObjectName(QStringLiteral("Settings"));
        gridLayout_10 = new QGridLayout(Settings);
        gridLayout_10->setObjectName(QStringLiteral("gridLayout_10"));
        groupBox = new QGroupBox(Settings);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout_6 = new QGridLayout(groupBox);
        gridLayout_6->setObjectName(QStringLiteral("gridLayout_6"));
        multirowCB = new QCheckBox(groupBox);
        multirowCB->setObjectName(QStringLiteral("multirowCB"));

        gridLayout_6->addWidget(multirowCB, 0, 0, 1, 1);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        multirowOffsetLA = new QLabel(groupBox);
        multirowOffsetLA->setObjectName(QStringLiteral("multirowOffsetLA"));

        gridLayout_3->addWidget(multirowOffsetLA, 0, 0, 1, 1);

        multirowOffsetED = new QLineEdit(groupBox);
        multirowOffsetED->setObjectName(QStringLiteral("multirowOffsetED"));
        multirowOffsetED->setEnabled(true);

        gridLayout_3->addWidget(multirowOffsetED, 0, 1, 1, 1);

        multirowOffsetUnitLC = new lyx::frontend::LengthCombo(groupBox);
        multirowOffsetUnitLC->setObjectName(QStringLiteral("multirowOffsetUnitLC"));

        gridLayout_3->addWidget(multirowOffsetUnitLC, 0, 2, 1, 1);


        gridLayout_6->addLayout(gridLayout_3, 1, 0, 1, 1);


        gridLayout_10->addWidget(groupBox, 1, 0, 1, 1);

        groupBox_2 = new QGroupBox(Settings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setFlat(true);
        gridLayout_5 = new QGridLayout(groupBox_2);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        rotateCellCB = new QCheckBox(groupBox_2);
        rotateCellCB->setObjectName(QStringLiteral("rotateCellCB"));

        horizontalLayout_3->addWidget(rotateCellCB);

        rotateCellAngleSB = new QSpinBox(groupBox_2);
        rotateCellAngleSB->setObjectName(QStringLiteral("rotateCellAngleSB"));
        rotateCellAngleSB->setMaximumSize(QSize(51, 20));
        rotateCellAngleSB->setMinimum(-180);
        rotateCellAngleSB->setMaximum(180);
        rotateCellAngleSB->setSingleStep(5);
        rotateCellAngleSB->setValue(90);

        horizontalLayout_3->addWidget(rotateCellAngleSB);

        rotateCellLA = new QLabel(groupBox_2);
        rotateCellLA->setObjectName(QStringLiteral("rotateCellLA"));

        horizontalLayout_3->addWidget(rotateCellLA);

        horizontalSpacer_3 = new QSpacerItem(13, 41, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        gridLayout_5->addLayout(horizontalLayout_3, 0, 0, 1, 1);


        gridLayout_10->addWidget(groupBox_2, 1, 1, 1, 1);

        tabAlignmentGB = new QGroupBox(Settings);
        tabAlignmentGB->setObjectName(QStringLiteral("tabAlignmentGB"));
        tabAlignmentGB->setEnabled(true);
        tabAlignmentGB->setFlat(true);
        gridLayout_4 = new QGridLayout(tabAlignmentGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        tabularWidthLA = new QLabel(tabAlignmentGB);
        tabularWidthLA->setObjectName(QStringLiteral("tabularWidthLA"));

        gridLayout_4->addWidget(tabularWidthLA, 0, 0, 1, 1);

        tabularWidthED = new QLineEdit(tabAlignmentGB);
        tabularWidthED->setObjectName(QStringLiteral("tabularWidthED"));

        gridLayout_4->addWidget(tabularWidthED, 0, 1, 1, 1);

        tabularWidthUnitLC = new lyx::frontend::LengthCombo(tabAlignmentGB);
        tabularWidthUnitLC->setObjectName(QStringLiteral("tabularWidthUnitLC"));

        gridLayout_4->addWidget(tabularWidthUnitLC, 0, 2, 1, 1);

        TableAlignLA = new QLabel(tabAlignmentGB);
        TableAlignLA->setObjectName(QStringLiteral("TableAlignLA"));

        gridLayout_4->addWidget(TableAlignLA, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        rotateTabularCB = new QCheckBox(tabAlignmentGB);
        rotateTabularCB->setObjectName(QStringLiteral("rotateTabularCB"));
        rotateTabularCB->setEnabled(true);

        horizontalLayout_4->addWidget(rotateTabularCB);

        rotateTabularAngleSB = new QSpinBox(tabAlignmentGB);
        rotateTabularAngleSB->setObjectName(QStringLiteral("rotateTabularAngleSB"));
        rotateTabularAngleSB->setMaximumSize(QSize(51, 20));
        rotateTabularAngleSB->setMinimum(-180);
        rotateTabularAngleSB->setMaximum(180);
        rotateTabularAngleSB->setSingleStep(5);
        rotateTabularAngleSB->setValue(90);

        horizontalLayout_4->addWidget(rotateTabularAngleSB);

        rotateTabularLA = new QLabel(tabAlignmentGB);
        rotateTabularLA->setObjectName(QStringLiteral("rotateTabularLA"));

        horizontalLayout_4->addWidget(rotateTabularLA);


        gridLayout_4->addLayout(horizontalLayout_4, 1, 3, 1, 1);

        TableAlignCO = new QComboBox(tabAlignmentGB);
        TableAlignCO->setObjectName(QStringLiteral("TableAlignCO"));

        gridLayout_4->addWidget(TableAlignCO, 1, 1, 1, 2);


        gridLayout_10->addWidget(tabAlignmentGB, 2, 0, 1, 2);

        GroupBox12 = new QGroupBox(Settings);
        GroupBox12->setObjectName(QStringLiteral("GroupBox12"));
        GroupBox12->setFlat(true);
        gridLayout_9 = new QGridLayout(GroupBox12);
        gridLayout_9->setObjectName(QStringLiteral("gridLayout_9"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        columnTypeCO = new QComboBox(GroupBox12);
        columnTypeCO->setObjectName(QStringLiteral("columnTypeCO"));

        gridLayout->addWidget(columnTypeCO, 1, 1, 1, 1);

        hAlignCO = new QComboBox(GroupBox12);
        hAlignCO->setObjectName(QStringLiteral("hAlignCO"));

        gridLayout->addWidget(hAlignCO, 0, 1, 1, 1);

        columnWidthLA = new QLabel(GroupBox12);
        columnWidthLA->setObjectName(QStringLiteral("columnWidthLA"));

        gridLayout->addWidget(columnWidthLA, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(109, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 2, 1, 1);

        hAlignLA = new QLabel(GroupBox12);
        hAlignLA->setObjectName(QStringLiteral("hAlignLA"));

        gridLayout->addWidget(hAlignLA, 0, 0, 1, 1);

        vAlignCO = new QComboBox(GroupBox12);
        vAlignCO->setObjectName(QStringLiteral("vAlignCO"));

        gridLayout->addWidget(vAlignCO, 2, 1, 1, 1);

        vAlignLA = new QLabel(GroupBox12);
        vAlignLA->setObjectName(QStringLiteral("vAlignLA"));

        gridLayout->addWidget(vAlignLA, 2, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        columnWidthED = new QLineEdit(GroupBox12);
        columnWidthED->setObjectName(QStringLiteral("columnWidthED"));
        columnWidthED->setEnabled(true);

        horizontalLayout_2->addWidget(columnWidthED);

        columnWidthUnitLC = new lyx::frontend::LengthCombo(GroupBox12);
        columnWidthUnitLC->setObjectName(QStringLiteral("columnWidthUnitLC"));

        horizontalLayout_2->addWidget(columnWidthUnitLC);


        gridLayout->addLayout(horizontalLayout_2, 1, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        decimalLA = new QLabel(GroupBox12);
        decimalLA->setObjectName(QStringLiteral("decimalLA"));
        decimalLA->setEnabled(false);

        horizontalLayout->addWidget(decimalLA);

        decimalPointED = new QLineEdit(GroupBox12);
        decimalPointED->setObjectName(QStringLiteral("decimalPointED"));
        decimalPointED->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(decimalPointED->sizePolicy().hasHeightForWidth());
        decimalPointED->setSizePolicy(sizePolicy);
        decimalPointED->setMaximumSize(QSize(40, 16777215));
        decimalPointED->setMaxLength(32767);
        decimalPointED->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(decimalPointED);

        horizontalSpacer = new QSpacerItem(78, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 0, 2, 1, 1);


        gridLayout_9->addLayout(gridLayout, 0, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(31, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_5, 0, 1, 1, 1);

        multicolumnCB = new QCheckBox(GroupBox12);
        multicolumnCB->setObjectName(QStringLiteral("multicolumnCB"));

        gridLayout_9->addWidget(multicolumnCB, 1, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        specialAlignmentLA = new QLabel(GroupBox12);
        specialAlignmentLA->setObjectName(QStringLiteral("specialAlignmentLA"));

        horizontalLayout_5->addWidget(specialAlignmentLA);

        specialAlignmentED = new QLineEdit(GroupBox12);
        specialAlignmentED->setObjectName(QStringLiteral("specialAlignmentED"));

        horizontalLayout_5->addWidget(specialAlignmentED);


        gridLayout_9->addLayout(horizontalLayout_5, 2, 0, 1, 1);


        gridLayout_10->addWidget(GroupBox12, 0, 0, 1, 2);

        TabWidget->addTab(Settings, QString());
        Borders = new QWidget();
        Borders->setObjectName(QStringLiteral("Borders"));
        gridLayout_8 = new QGridLayout(Borders);
        gridLayout_8->setObjectName(QStringLiteral("gridLayout_8"));
        setBordersGB = new QGroupBox(Borders);
        setBordersGB->setObjectName(QStringLiteral("setBordersGB"));
        setBordersGB->setFlat(true);
        gridLayout1 = new QGridLayout(setBordersGB);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        bordersF = new QFrame(setBordersGB);
        bordersF->setObjectName(QStringLiteral("bordersF"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bordersF->sizePolicy().hasHeightForWidth());
        bordersF->setSizePolicy(sizePolicy1);
        QPalette palette;
        QBrush brush(QColor(0, 0, 0, 255));
        brush.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::WindowText, brush);
        QBrush brush1(QColor(230, 240, 249, 255));
        brush1.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Button, brush1);
        QBrush brush2(QColor(255, 255, 255, 255));
        brush2.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Light, brush2);
        QBrush brush3(QColor(242, 247, 252, 255));
        brush3.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Midlight, brush3);
        QBrush brush4(QColor(115, 120, 124, 255));
        brush4.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Dark, brush4);
        QBrush brush5(QColor(154, 160, 166, 255));
        brush5.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Mid, brush5);
        palette.setBrush(QPalette::Active, QPalette::Text, brush);
        palette.setBrush(QPalette::Active, QPalette::BrightText, brush2);
        palette.setBrush(QPalette::Active, QPalette::ButtonText, brush);
        palette.setBrush(QPalette::Active, QPalette::Base, brush2);
        palette.setBrush(QPalette::Active, QPalette::Window, brush2);
        palette.setBrush(QPalette::Active, QPalette::Shadow, brush);
        QBrush brush6(QColor(16, 145, 210, 255));
        brush6.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Highlight, brush6);
        palette.setBrush(QPalette::Active, QPalette::HighlightedText, brush2);
        QBrush brush7(QColor(0, 0, 255, 255));
        brush7.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Link, brush7);
        QBrush brush8(QColor(255, 0, 255, 255));
        brush8.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::LinkVisited, brush8);
        QBrush brush9(QColor(232, 232, 232, 255));
        brush9.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::AlternateBase, brush9);
        palette.setBrush(QPalette::Inactive, QPalette::WindowText, brush);
        palette.setBrush(QPalette::Inactive, QPalette::Button, brush1);
        palette.setBrush(QPalette::Inactive, QPalette::Light, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::Midlight, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::Dark, brush4);
        palette.setBrush(QPalette::Inactive, QPalette::Mid, brush5);
        palette.setBrush(QPalette::Inactive, QPalette::Text, brush);
        palette.setBrush(QPalette::Inactive, QPalette::BrightText, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::ButtonText, brush);
        palette.setBrush(QPalette::Inactive, QPalette::Base, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::Window, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::Shadow, brush);
        palette.setBrush(QPalette::Inactive, QPalette::Highlight, brush6);
        palette.setBrush(QPalette::Inactive, QPalette::HighlightedText, brush2);
        palette.setBrush(QPalette::Inactive, QPalette::Link, brush7);
        palette.setBrush(QPalette::Inactive, QPalette::LinkVisited, brush8);
        palette.setBrush(QPalette::Inactive, QPalette::AlternateBase, brush9);
        QBrush brush10(QColor(128, 128, 128, 255));
        brush10.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Disabled, QPalette::WindowText, brush10);
        palette.setBrush(QPalette::Disabled, QPalette::Button, brush1);
        palette.setBrush(QPalette::Disabled, QPalette::Light, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::Midlight, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::Dark, brush4);
        palette.setBrush(QPalette::Disabled, QPalette::Mid, brush5);
        palette.setBrush(QPalette::Disabled, QPalette::Text, brush);
        palette.setBrush(QPalette::Disabled, QPalette::BrightText, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::ButtonText, brush10);
        palette.setBrush(QPalette::Disabled, QPalette::Base, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::Window, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::Shadow, brush);
        palette.setBrush(QPalette::Disabled, QPalette::Highlight, brush6);
        palette.setBrush(QPalette::Disabled, QPalette::HighlightedText, brush2);
        palette.setBrush(QPalette::Disabled, QPalette::Link, brush7);
        palette.setBrush(QPalette::Disabled, QPalette::LinkVisited, brush8);
        palette.setBrush(QPalette::Disabled, QPalette::AlternateBase, brush9);
        bordersF->setPalette(palette);
        bordersF->setFrameShape(QFrame::StyledPanel);
        bordersF->setFrameShadow(QFrame::Sunken);
        gridLayout2 = new QGridLayout(bordersF);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        borders = new GuiSetBorder(bordersF);
        borders->setObjectName(QStringLiteral("borders"));
        sizePolicy1.setHeightForWidth(borders->sizePolicy().hasHeightForWidth());
        borders->setSizePolicy(sizePolicy1);

        gridLayout2->addWidget(borders, 0, 0, 1, 1);


        gridLayout1->addWidget(bordersF, 0, 0, 1, 1);


        gridLayout_8->addWidget(setBordersGB, 0, 0, 1, 1);

        allBordersGB = new QGroupBox(Borders);
        allBordersGB->setObjectName(QStringLiteral("allBordersGB"));
        allBordersGB->setFlat(true);
        gridLayout3 = new QGridLayout(allBordersGB);
        gridLayout3->setObjectName(QStringLiteral("gridLayout3"));
        borderSetPB = new QPushButton(allBordersGB);
        borderSetPB->setObjectName(QStringLiteral("borderSetPB"));

        gridLayout3->addWidget(borderSetPB, 0, 0, 1, 1);

        borderUnsetPB = new QPushButton(allBordersGB);
        borderUnsetPB->setObjectName(QStringLiteral("borderUnsetPB"));

        gridLayout3->addWidget(borderUnsetPB, 1, 0, 1, 1);


        gridLayout_8->addWidget(allBordersGB, 0, 1, 1, 1);

        borderStyleGB = new QGroupBox(Borders);
        borderStyleGB->setObjectName(QStringLiteral("borderStyleGB"));
        borderStyleGB->setFlat(true);
        gridLayout4 = new QGridLayout(borderStyleGB);
        gridLayout4->setObjectName(QStringLiteral("gridLayout4"));
        borderDefaultRB = new QRadioButton(borderStyleGB);
        borderDefaultRB->setObjectName(QStringLiteral("borderDefaultRB"));

        gridLayout4->addWidget(borderDefaultRB, 0, 0, 1, 1);

        resetFormalCB = new QCheckBox(borderStyleGB);
        resetFormalCB->setObjectName(QStringLiteral("resetFormalCB"));

        gridLayout4->addWidget(resetFormalCB, 2, 0, 1, 1);

        booktabsRB = new QRadioButton(borderStyleGB);
        booktabsRB->setObjectName(QStringLiteral("booktabsRB"));
        booktabsRB->setChecked(true);

        gridLayout4->addWidget(booktabsRB, 1, 0, 1, 1);


        gridLayout_8->addWidget(borderStyleGB, 0, 2, 1, 1);

        spacerItem = new QSpacerItem(63, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_8->addItem(spacerItem, 0, 3, 1, 1);

        SpaceGB = new QGroupBox(Borders);
        SpaceGB->setObjectName(QStringLiteral("SpaceGB"));
        gridLayout5 = new QGridLayout(SpaceGB);
        gridLayout5->setObjectName(QStringLiteral("gridLayout5"));
        topspaceLA = new QLabel(SpaceGB);
        topspaceLA->setObjectName(QStringLiteral("topspaceLA"));

        gridLayout5->addWidget(topspaceLA, 0, 0, 1, 1);

        topspaceED = new QLineEdit(SpaceGB);
        topspaceED->setObjectName(QStringLiteral("topspaceED"));

        gridLayout5->addWidget(topspaceED, 0, 2, 1, 1);

        topspaceUnitLC = new lyx::frontend::LengthCombo(SpaceGB);
        topspaceUnitLC->setObjectName(QStringLiteral("topspaceUnitLC"));

        gridLayout5->addWidget(topspaceUnitLC, 0, 3, 1, 1);

        topspaceCO = new QComboBox(SpaceGB);
        topspaceCO->setObjectName(QStringLiteral("topspaceCO"));

        gridLayout5->addWidget(topspaceCO, 0, 1, 1, 1);

        bottomspaceCO = new QComboBox(SpaceGB);
        bottomspaceCO->setObjectName(QStringLiteral("bottomspaceCO"));

        gridLayout5->addWidget(bottomspaceCO, 1, 1, 1, 1);

        bottomspaceUnitLC = new lyx::frontend::LengthCombo(SpaceGB);
        bottomspaceUnitLC->setObjectName(QStringLiteral("bottomspaceUnitLC"));

        gridLayout5->addWidget(bottomspaceUnitLC, 1, 3, 1, 1);

        bottomspaceED = new QLineEdit(SpaceGB);
        bottomspaceED->setObjectName(QStringLiteral("bottomspaceED"));

        gridLayout5->addWidget(bottomspaceED, 1, 2, 1, 1);

        bottomspaceLA = new QLabel(SpaceGB);
        bottomspaceLA->setObjectName(QStringLiteral("bottomspaceLA"));

        gridLayout5->addWidget(bottomspaceLA, 1, 0, 1, 1);

        interlinespaceED = new QLineEdit(SpaceGB);
        interlinespaceED->setObjectName(QStringLiteral("interlinespaceED"));

        gridLayout5->addWidget(interlinespaceED, 2, 2, 1, 1);

        interlinespaceLA = new QLabel(SpaceGB);
        interlinespaceLA->setObjectName(QStringLiteral("interlinespaceLA"));

        gridLayout5->addWidget(interlinespaceLA, 2, 0, 1, 1);

        interlinespaceCO = new QComboBox(SpaceGB);
        interlinespaceCO->setObjectName(QStringLiteral("interlinespaceCO"));

        gridLayout5->addWidget(interlinespaceCO, 2, 1, 1, 1);

        interlinespaceUnitLC = new lyx::frontend::LengthCombo(SpaceGB);
        interlinespaceUnitLC->setObjectName(QStringLiteral("interlinespaceUnitLC"));

        gridLayout5->addWidget(interlinespaceUnitLC, 2, 3, 1, 1);


        gridLayout_8->addWidget(SpaceGB, 1, 0, 1, 4);

        verticalSpacer_2 = new QSpacerItem(20, 90, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_8->addItem(verticalSpacer_2, 2, 1, 1, 1);

        TabWidget->addTab(Borders, QString());
        Longtables = new QWidget();
        Longtables->setObjectName(QStringLiteral("Longtables"));
        gridLayout_7 = new QGridLayout(Longtables);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        longTabularCB = new QCheckBox(Longtables);
        longTabularCB->setObjectName(QStringLiteral("longTabularCB"));

        gridLayout_7->addWidget(longTabularCB, 0, 0, 1, 1);

        longtableGB = new QGroupBox(Longtables);
        longtableGB->setObjectName(QStringLiteral("longtableGB"));
        longtableGB->setEnabled(false);
        gridLayout_2 = new QGridLayout(longtableGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        StatusLA = new QLabel(longtableGB);
        StatusLA->setObjectName(QStringLiteral("StatusLA"));

        gridLayout_2->addWidget(StatusLA, 0, 1, 1, 1);

        BorderAboveLA = new QLabel(longtableGB);
        BorderAboveLA->setObjectName(QStringLiteral("BorderAboveLA"));

        gridLayout_2->addWidget(BorderAboveLA, 0, 2, 1, 1);

        BorderBelowLA = new QLabel(longtableGB);
        BorderBelowLA->setObjectName(QStringLiteral("BorderBelowLA"));

        gridLayout_2->addWidget(BorderBelowLA, 0, 3, 1, 1);

        ContentsLA = new QLabel(longtableGB);
        ContentsLA->setObjectName(QStringLiteral("ContentsLA"));

        gridLayout_2->addWidget(ContentsLA, 0, 4, 1, 1);

        HeaderLA = new QLabel(longtableGB);
        HeaderLA->setObjectName(QStringLiteral("HeaderLA"));

        gridLayout_2->addWidget(HeaderLA, 1, 0, 1, 1);

        headerStatusCB = new QCheckBox(longtableGB);
        headerStatusCB->setObjectName(QStringLiteral("headerStatusCB"));

        gridLayout_2->addWidget(headerStatusCB, 1, 1, 1, 1);

        headerBorderAboveCB = new QCheckBox(longtableGB);
        headerBorderAboveCB->setObjectName(QStringLiteral("headerBorderAboveCB"));

        gridLayout_2->addWidget(headerBorderAboveCB, 1, 2, 1, 1);

        headerBorderBelowCB = new QCheckBox(longtableGB);
        headerBorderBelowCB->setObjectName(QStringLiteral("headerBorderBelowCB"));

        gridLayout_2->addWidget(headerBorderBelowCB, 1, 3, 1, 1);

        FirstHeaderLA = new QLabel(longtableGB);
        FirstHeaderLA->setObjectName(QStringLiteral("FirstHeaderLA"));

        gridLayout_2->addWidget(FirstHeaderLA, 2, 0, 1, 1);

        firstheaderStatusCB = new QCheckBox(longtableGB);
        firstheaderStatusCB->setObjectName(QStringLiteral("firstheaderStatusCB"));

        gridLayout_2->addWidget(firstheaderStatusCB, 2, 1, 1, 1);

        firstheaderBorderAboveCB = new QCheckBox(longtableGB);
        firstheaderBorderAboveCB->setObjectName(QStringLiteral("firstheaderBorderAboveCB"));

        gridLayout_2->addWidget(firstheaderBorderAboveCB, 2, 2, 1, 1);

        firstheaderBorderBelowCB = new QCheckBox(longtableGB);
        firstheaderBorderBelowCB->setObjectName(QStringLiteral("firstheaderBorderBelowCB"));

        gridLayout_2->addWidget(firstheaderBorderBelowCB, 2, 3, 1, 1);

        firstheaderNoContentsCB = new QCheckBox(longtableGB);
        firstheaderNoContentsCB->setObjectName(QStringLiteral("firstheaderNoContentsCB"));

        gridLayout_2->addWidget(firstheaderNoContentsCB, 2, 4, 1, 1);

        FooterLA = new QLabel(longtableGB);
        FooterLA->setObjectName(QStringLiteral("FooterLA"));

        gridLayout_2->addWidget(FooterLA, 3, 0, 1, 1);

        footerStatusCB = new QCheckBox(longtableGB);
        footerStatusCB->setObjectName(QStringLiteral("footerStatusCB"));

        gridLayout_2->addWidget(footerStatusCB, 3, 1, 1, 1);

        footerBorderAboveCB = new QCheckBox(longtableGB);
        footerBorderAboveCB->setObjectName(QStringLiteral("footerBorderAboveCB"));

        gridLayout_2->addWidget(footerBorderAboveCB, 3, 2, 1, 1);

        footerBorderBelowCB = new QCheckBox(longtableGB);
        footerBorderBelowCB->setObjectName(QStringLiteral("footerBorderBelowCB"));

        gridLayout_2->addWidget(footerBorderBelowCB, 3, 3, 1, 1);

        LastFooterLA = new QLabel(longtableGB);
        LastFooterLA->setObjectName(QStringLiteral("LastFooterLA"));

        gridLayout_2->addWidget(LastFooterLA, 4, 0, 1, 1);

        lastfooterStatusCB = new QCheckBox(longtableGB);
        lastfooterStatusCB->setObjectName(QStringLiteral("lastfooterStatusCB"));

        gridLayout_2->addWidget(lastfooterStatusCB, 4, 1, 1, 1);

        lastfooterBorderAboveCB = new QCheckBox(longtableGB);
        lastfooterBorderAboveCB->setObjectName(QStringLiteral("lastfooterBorderAboveCB"));

        gridLayout_2->addWidget(lastfooterBorderAboveCB, 4, 2, 1, 1);

        lastfooterBorderBelowCB = new QCheckBox(longtableGB);
        lastfooterBorderBelowCB->setObjectName(QStringLiteral("lastfooterBorderBelowCB"));

        gridLayout_2->addWidget(lastfooterBorderBelowCB, 4, 3, 1, 1);

        lastfooterNoContentsCB = new QCheckBox(longtableGB);
        lastfooterNoContentsCB->setObjectName(QStringLiteral("lastfooterNoContentsCB"));

        gridLayout_2->addWidget(lastfooterNoContentsCB, 4, 4, 1, 1);

        label = new QLabel(longtableGB);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_2->addWidget(label, 5, 0, 1, 1);

        captionStatusCB = new QCheckBox(longtableGB);
        captionStatusCB->setObjectName(QStringLiteral("captionStatusCB"));

        gridLayout_2->addWidget(captionStatusCB, 5, 1, 1, 1);

        newpageCB = new QCheckBox(longtableGB);
        newpageCB->setObjectName(QStringLiteral("newpageCB"));
        newpageCB->setEnabled(false);

        gridLayout_2->addWidget(newpageCB, 6, 0, 1, 3);


        gridLayout_7->addWidget(longtableGB, 1, 0, 1, 1);

        alignmentGB = new QGroupBox(Longtables);
        alignmentGB->setObjectName(QStringLiteral("alignmentGB"));
        alignmentGB->setEnabled(false);
        alignmentGB->setFlat(true);
        gridLayout9 = new QGridLayout(alignmentGB);
        gridLayout9->setObjectName(QStringLiteral("gridLayout9"));
        leftRB = new QRadioButton(alignmentGB);
        leftRB->setObjectName(QStringLiteral("leftRB"));

        gridLayout9->addWidget(leftRB, 0, 0, 1, 1);

        centerRB = new QRadioButton(alignmentGB);
        centerRB->setObjectName(QStringLiteral("centerRB"));
        centerRB->setChecked(true);

        gridLayout9->addWidget(centerRB, 0, 1, 1, 1);

        rightRB = new QRadioButton(alignmentGB);
        rightRB->setObjectName(QStringLiteral("rightRB"));

        gridLayout9->addWidget(rightRB, 0, 2, 1, 1);


        gridLayout_7->addWidget(alignmentGB, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 91, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_7->addItem(verticalSpacer, 3, 0, 1, 1);

        TabWidget->addTab(Longtables, QString());

        gridLayout_11->addWidget(TabWidget, 0, 0, 1, 1);

        _3 = new QHBoxLayout();
        _3->setObjectName(QStringLiteral("_3"));
        TextLabel1 = new QLabel(TabularUi);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));

        _3->addWidget(TextLabel1);

        tabularRowED = new QLineEdit(TabularUi);
        tabularRowED->setObjectName(QStringLiteral("tabularRowED"));
        sizePolicy1.setHeightForWidth(tabularRowED->sizePolicy().hasHeightForWidth());
        tabularRowED->setSizePolicy(sizePolicy1);
        tabularRowED->setMaximumSize(QSize(40, 32767));
        tabularRowED->setFocusPolicy(Qt::NoFocus);

        _3->addWidget(tabularRowED);

        tabularColumnED = new QLineEdit(TabularUi);
        tabularColumnED->setObjectName(QStringLiteral("tabularColumnED"));
        sizePolicy1.setHeightForWidth(tabularColumnED->sizePolicy().hasHeightForWidth());
        tabularColumnED->setSizePolicy(sizePolicy1);
        tabularColumnED->setMaximumSize(QSize(40, 32767));
        tabularColumnED->setFocusPolicy(Qt::NoFocus);

        _3->addWidget(tabularColumnED);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _3->addItem(spacerItem1);


        gridLayout_11->addLayout(_3, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        multirowOffsetLA->setBuddy(multirowOffsetED);
        rotateCellLA->setBuddy(rotateCellAngleSB);
        tabularWidthLA->setBuddy(tabularWidthED);
        TableAlignLA->setBuddy(TableAlignCO);
        rotateTabularLA->setBuddy(rotateTabularAngleSB);
        columnWidthLA->setBuddy(columnTypeCO);
        hAlignLA->setBuddy(hAlignCO);
        vAlignLA->setBuddy(vAlignCO);
        decimalLA->setBuddy(decimalPointED);
        specialAlignmentLA->setBuddy(specialAlignmentED);
        topspaceLA->setBuddy(topspaceCO);
        bottomspaceLA->setBuddy(bottomspaceCO);
        interlinespaceLA->setBuddy(interlinespaceCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(hAlignCO, decimalPointED);
        QWidget::setTabOrder(decimalPointED, columnWidthED);
        QWidget::setTabOrder(columnWidthED, columnWidthUnitLC);
        QWidget::setTabOrder(columnWidthUnitLC, vAlignCO);
        QWidget::setTabOrder(vAlignCO, multicolumnCB);
        QWidget::setTabOrder(multicolumnCB, specialAlignmentED);
        QWidget::setTabOrder(specialAlignmentED, multirowCB);
        QWidget::setTabOrder(multirowCB, multirowOffsetED);
        QWidget::setTabOrder(multirowOffsetED, multirowOffsetUnitLC);
        QWidget::setTabOrder(multirowOffsetUnitLC, rotateCellCB);
        QWidget::setTabOrder(rotateCellCB, rotateCellAngleSB);
        QWidget::setTabOrder(rotateCellAngleSB, tabularWidthED);
        QWidget::setTabOrder(tabularWidthED, tabularWidthUnitLC);
        QWidget::setTabOrder(tabularWidthUnitLC, TableAlignCO);
        QWidget::setTabOrder(TableAlignCO, rotateTabularCB);
        QWidget::setTabOrder(rotateTabularCB, rotateTabularAngleSB);
        QWidget::setTabOrder(rotateTabularAngleSB, borderDefaultRB);
        QWidget::setTabOrder(borderDefaultRB, borderUnsetPB);
        QWidget::setTabOrder(borderUnsetPB, booktabsRB);
        QWidget::setTabOrder(booktabsRB, topspaceCO);
        QWidget::setTabOrder(topspaceCO, topspaceED);
        QWidget::setTabOrder(topspaceED, topspaceUnitLC);
        QWidget::setTabOrder(topspaceUnitLC, bottomspaceCO);
        QWidget::setTabOrder(bottomspaceCO, bottomspaceED);
        QWidget::setTabOrder(bottomspaceED, bottomspaceUnitLC);
        QWidget::setTabOrder(bottomspaceUnitLC, interlinespaceCO);
        QWidget::setTabOrder(interlinespaceCO, interlinespaceED);
        QWidget::setTabOrder(interlinespaceED, interlinespaceUnitLC);
        QWidget::setTabOrder(interlinespaceUnitLC, longTabularCB);
        QWidget::setTabOrder(longTabularCB, headerStatusCB);
        QWidget::setTabOrder(headerStatusCB, headerBorderAboveCB);
        QWidget::setTabOrder(headerBorderAboveCB, headerBorderBelowCB);
        QWidget::setTabOrder(headerBorderBelowCB, firstheaderStatusCB);
        QWidget::setTabOrder(firstheaderStatusCB, firstheaderBorderAboveCB);
        QWidget::setTabOrder(firstheaderBorderAboveCB, firstheaderBorderBelowCB);
        QWidget::setTabOrder(firstheaderBorderBelowCB, firstheaderNoContentsCB);
        QWidget::setTabOrder(firstheaderNoContentsCB, footerStatusCB);
        QWidget::setTabOrder(footerStatusCB, footerBorderAboveCB);
        QWidget::setTabOrder(footerBorderAboveCB, footerBorderBelowCB);
        QWidget::setTabOrder(footerBorderBelowCB, lastfooterStatusCB);
        QWidget::setTabOrder(lastfooterStatusCB, lastfooterBorderAboveCB);
        QWidget::setTabOrder(lastfooterBorderAboveCB, lastfooterBorderBelowCB);
        QWidget::setTabOrder(lastfooterBorderBelowCB, lastfooterNoContentsCB);
        QWidget::setTabOrder(lastfooterNoContentsCB, captionStatusCB);
        QWidget::setTabOrder(captionStatusCB, newpageCB);
        QWidget::setTabOrder(newpageCB, leftRB);
        QWidget::setTabOrder(leftRB, centerRB);
        QWidget::setTabOrder(centerRB, rightRB);
        QWidget::setTabOrder(rightRB, borderSetPB);
        QWidget::setTabOrder(borderSetPB, TabWidget);

        retranslateUi(TabularUi);

        TabWidget->setCurrentIndex(0);
        TableAlignCO->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(TabularUi);
    } // setupUi

    void retranslateUi(QWidget *TabularUi)
    {
        TabularUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        TabWidget->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        groupBox->setTitle(lyx::qt_("Row setting", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        multirowCB->setToolTip(lyx::qt_("Merge cells of different rows", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        multirowCB->setText(lyx::qt_("M&ultirow", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        multirowOffsetLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        multirowOffsetLA->setText(lyx::qt_("&Vertical Offset:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        multirowOffsetED->setToolTip(lyx::qt_("Optional vertical offset", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        multirowOffsetED->setText(QString());
        groupBox_2->setTitle(lyx::qt_("Cell setting", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rotateCellCB->setToolTip(lyx::qt_("Rotate this cell by 90 degrees", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rotateCellCB->setText(lyx::qt_("Rotate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rotateCellAngleSB->setToolTip(lyx::qt_("rotation angle", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rotateCellLA->setText(lyx::qt_("de&grees", Q_NULLPTR));
        tabAlignmentGB->setTitle(lyx::qt_("Table-wide settings", Q_NULLPTR));
        tabularWidthLA->setText(lyx::qt_("W&idth:", Q_NULLPTR));
        TableAlignLA->setText(lyx::qt_("Verti&cal alignment:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rotateTabularCB->setToolTip(lyx::qt_("Rotate the table by 90 degrees", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rotateTabularCB->setText(lyx::qt_("&Rotate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rotateTabularAngleSB->setToolTip(lyx::qt_("rotation angle", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rotateTabularLA->setText(lyx::qt_("degrees", Q_NULLPTR));
        TableAlignCO->clear();
        TableAlignCO->insertItems(0, QStringList()
         << lyx::qt_("Top", Q_NULLPTR)
         << lyx::qt_("Middle", Q_NULLPTR)
         << lyx::qt_("Bottom", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        TableAlignCO->setToolTip(lyx::qt_("Vertical alignment of the table", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        GroupBox12->setTitle(lyx::qt_("Column settings", Q_NULLPTR));
        columnTypeCO->clear();
        columnTypeCO->insertItems(0, QStringList()
         << lyx::qt_("Text length", Q_NULLPTR)
         << lyx::qt_("Variable[[Width]]", Q_NULLPTR)
         << lyx::qt_("Custom[[Width]]", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        columnTypeCO->setToolTip(lyx::qt_("<html><head/><body><p>Column width type:</p><p>* Text Length: Stretch to text width</p><p>* Variable: Adjust to match table width</p><p>* Custom: Fixed custom width</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        hAlignCO->clear();
        hAlignCO->insertItems(0, QStringList()
         << lyx::qt_("Justified", Q_NULLPTR)
         << lyx::qt_("Left", Q_NULLPTR)
         << lyx::qt_("Center", Q_NULLPTR)
         << lyx::qt_("Right", Q_NULLPTR)
         << lyx::qt_("At Decimal Separator", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        hAlignCO->setToolTip(lyx::qt_("Horizontal alignment in column", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        columnWidthLA->setText(lyx::qt_("&Width:", Q_NULLPTR));
        hAlignLA->setText(lyx::qt_("Hori&zontal alignment:", Q_NULLPTR));
        vAlignCO->clear();
        vAlignCO->insertItems(0, QStringList()
         << lyx::qt_("Top", Q_NULLPTR)
         << lyx::qt_("Middle", Q_NULLPTR)
         << lyx::qt_("Bottom", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        vAlignCO->setToolTip(lyx::qt_("Specifies the vertical alignment of this cell in relation to the baseline of the row.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        vAlignLA->setText(lyx::qt_("&Vertical alignment in row:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        columnWidthED->setToolTip(lyx::qt_("Custom width of the column", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        columnWidthED->setText(QString());
        decimalLA->setText(lyx::qt_("&Decimal separator:", Q_NULLPTR));
        decimalPointED->setInputMask(QString());
        decimalPointED->setText(QString());
#ifndef QT_NO_TOOLTIP
        multicolumnCB->setToolTip(lyx::qt_("Merge cells of different columns", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        multicolumnCB->setText(lyx::qt_("Mu&lticolumn", Q_NULLPTR));
        specialAlignmentLA->setText(lyx::qt_("LaTe&X argument:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        specialAlignmentED->setToolTip(lyx::qt_("Custom column format (LaTeX)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        specialAlignmentED->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        TabWidget->setTabText(TabWidget->indexOf(Settings), lyx::qt_("&Table Settings", Q_NULLPTR));
        setBordersGB->setTitle(lyx::qt_("Set Borders", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        borders->setToolTip(lyx::qt_("Set borders of the current (selected) cell(s)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        allBordersGB->setTitle(lyx::qt_("All Borders", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        borderSetPB->setToolTip(lyx::qt_("Set all borders of the current (selected) cell(s)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        borderSetPB->setText(lyx::qt_("&Set", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        borderUnsetPB->setToolTip(lyx::qt_("Unset all borders of the current (selected) cell(s)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        borderUnsetPB->setText(lyx::qt_("C&lear", Q_NULLPTR));
        borderStyleGB->setTitle(lyx::qt_("Style", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        borderDefaultRB->setToolTip(lyx::qt_("Use default (grid-like) border style", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        borderDefaultRB->setText(lyx::qt_("De&fault", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        resetFormalCB->setToolTip(lyx::qt_("If this is checked, the table will be reset to the formal default style (only top and bottom row have horizontal lines)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        resetFormalCB->setText(lyx::qt_("Use Default &Formal Style", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        booktabsRB->setToolTip(lyx::qt_("Use formal (a.k.a. booktabs) border style (no vertical borders)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        booktabsRB->setText(lyx::qt_("Fo&rmal", Q_NULLPTR));
        SpaceGB->setTitle(lyx::qt_("Additional Space", Q_NULLPTR));
        topspaceLA->setText(lyx::qt_("T&op of row:", Q_NULLPTR));
        topspaceCO->clear();
        topspaceCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("Default", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
        bottomspaceCO->clear();
        bottomspaceCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("Default", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
        bottomspaceLA->setText(lyx::qt_("Botto&m of row:", Q_NULLPTR));
        interlinespaceLA->setText(lyx::qt_("Bet&ween rows:", Q_NULLPTR));
        interlinespaceCO->clear();
        interlinespaceCO->insertItems(0, QStringList()
         << lyx::qt_("None", Q_NULLPTR)
         << lyx::qt_("Default", Q_NULLPTR)
         << lyx::qt_("Custom", Q_NULLPTR)
        );
        TabWidget->setTabText(TabWidget->indexOf(Borders), lyx::qt_("&Borders", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        longTabularCB->setToolTip(lyx::qt_("Select for tables that span multiple pages", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        longTabularCB->setText(lyx::qt_("&Use multi-page table", Q_NULLPTR));
        longtableGB->setTitle(lyx::qt_("Row settings", Q_NULLPTR));
        StatusLA->setText(lyx::qt_("Status", Q_NULLPTR));
        BorderAboveLA->setText(lyx::qt_("Border above", Q_NULLPTR));
        BorderBelowLA->setText(lyx::qt_("Border below", Q_NULLPTR));
        ContentsLA->setText(lyx::qt_("Contents", Q_NULLPTR));
        HeaderLA->setText(lyx::qt_("Header:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        headerStatusCB->setToolTip(lyx::qt_("Repeat this row as header on every (except the first) page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        headerStatusCB->setText(lyx::qt_("on", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        headerBorderAboveCB->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        headerBorderAboveCB->setText(lyx::qt_("double", Q_NULLPTR));
        headerBorderBelowCB->setText(lyx::qt_("double", Q_NULLPTR));
        FirstHeaderLA->setText(lyx::qt_("First header:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        firstheaderStatusCB->setToolTip(lyx::qt_("This row is the header of the first page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        firstheaderStatusCB->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        firstheaderStatusCB->setText(lyx::qt_("on", Q_NULLPTR));
        firstheaderBorderAboveCB->setText(lyx::qt_("double", Q_NULLPTR));
        firstheaderBorderBelowCB->setText(lyx::qt_("double", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        firstheaderNoContentsCB->setToolTip(lyx::qt_("Don't output the first header", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        firstheaderNoContentsCB->setText(lyx::qt_("is empty", Q_NULLPTR));
        FooterLA->setText(lyx::qt_("Footer:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        footerStatusCB->setToolTip(lyx::qt_("Repeat this row as footer on every (except the last) page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        footerStatusCB->setText(lyx::qt_("on", Q_NULLPTR));
        footerBorderAboveCB->setText(lyx::qt_("double", Q_NULLPTR));
        footerBorderBelowCB->setText(lyx::qt_("double", Q_NULLPTR));
        LastFooterLA->setText(lyx::qt_("Last footer:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lastfooterStatusCB->setToolTip(lyx::qt_("This row is the footer of the last page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        lastfooterStatusCB->setText(lyx::qt_("on", Q_NULLPTR));
        lastfooterBorderAboveCB->setText(lyx::qt_("double", Q_NULLPTR));
        lastfooterBorderBelowCB->setText(lyx::qt_("double", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lastfooterNoContentsCB->setToolTip(lyx::qt_("Don't output the last footer", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        lastfooterNoContentsCB->setText(lyx::qt_("is empty", Q_NULLPTR));
        label->setText(lyx::qt_("Caption:", Q_NULLPTR));
        captionStatusCB->setText(lyx::qt_("on", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        newpageCB->setToolTip(lyx::qt_("Set a page break on the current row", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        newpageCB->setText(lyx::qt_("Page &break on current row", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        alignmentGB->setToolTip(lyx::qt_("Horizontal alignment of the multi-page table", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        alignmentGB->setTitle(lyx::qt_("Multi-page table alignment", Q_NULLPTR));
        leftRB->setText(lyx::qt_("Left", Q_NULLPTR));
        centerRB->setText(lyx::qt_("&Center", Q_NULLPTR));
        rightRB->setText(lyx::qt_("Ri&ght", Q_NULLPTR));
        TabWidget->setTabText(TabWidget->indexOf(Longtables), lyx::qt_("&Multi-Page Table", Q_NULLPTR));
        TextLabel1->setText(lyx::qt_("Current cell:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        tabularRowED->setToolTip(lyx::qt_("Current row position", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        tabularColumnED->setToolTip(lyx::qt_("Current column position", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class TabularUi: public Ui_TabularUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABULARUI_H
