/********************************************************************************
** Form generated from reading UI file 'IndicesUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INDICESUI_H
#define UI_INDICESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_IndicesUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *indexGB;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *indexLA;
    QComboBox *indexCO;
    QHBoxLayout *horizontalLayout_2;
    QLabel *indexOptionsLA;
    QLineEdit *indexOptionsLE;
    QSpacerItem *horizontalSpacer;
    QCheckBox *multipleIndicesCB;
    QFrame *line;
    QHBoxLayout *hboxLayout;
    QLabel *newIndexLA;
    QLineEdit *newIndexLE;
    QPushButton *addIndexPB;
    QLabel *availableLA;
    QTreeWidget *indicesTW;
    QPushButton *removePB;
    QPushButton *renamePB;
    QPushButton *colorPB;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *IndicesUi)
    {
        if (IndicesUi->objectName().isEmpty())
            IndicesUi->setObjectName(QStringLiteral("IndicesUi"));
        IndicesUi->resize(401, 340);
        gridLayout = new QGridLayout(IndicesUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        indexGB = new QGroupBox(IndicesUi);
        indexGB->setObjectName(QStringLiteral("indexGB"));
        indexGB->setFlat(true);
        gridLayout_2 = new QGridLayout(indexGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        indexLA = new QLabel(indexGB);
        indexLA->setObjectName(QStringLiteral("indexLA"));

        horizontalLayout->addWidget(indexLA);

        indexCO = new QComboBox(indexGB);
        indexCO->setObjectName(QStringLiteral("indexCO"));

        horizontalLayout->addWidget(indexCO);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        indexOptionsLA = new QLabel(indexGB);
        indexOptionsLA->setObjectName(QStringLiteral("indexOptionsLA"));

        horizontalLayout_2->addWidget(indexOptionsLA);

        indexOptionsLE = new QLineEdit(indexGB);
        indexOptionsLE->setObjectName(QStringLiteral("indexOptionsLE"));

        horizontalLayout_2->addWidget(indexOptionsLE);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(183, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 2, 1);


        gridLayout->addWidget(indexGB, 0, 0, 1, 2);

        multipleIndicesCB = new QCheckBox(IndicesUi);
        multipleIndicesCB->setObjectName(QStringLiteral("multipleIndicesCB"));

        gridLayout->addWidget(multipleIndicesCB, 1, 0, 1, 1);

        line = new QFrame(IndicesUi);
        line->setObjectName(QStringLiteral("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line, 2, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        newIndexLA = new QLabel(IndicesUi);
        newIndexLA->setObjectName(QStringLiteral("newIndexLA"));

        hboxLayout->addWidget(newIndexLA);

        newIndexLE = new QLineEdit(IndicesUi);
        newIndexLE->setObjectName(QStringLiteral("newIndexLE"));

        hboxLayout->addWidget(newIndexLE);

        addIndexPB = new QPushButton(IndicesUi);
        addIndexPB->setObjectName(QStringLiteral("addIndexPB"));

        hboxLayout->addWidget(addIndexPB);


        gridLayout->addLayout(hboxLayout, 3, 0, 1, 2);

        availableLA = new QLabel(IndicesUi);
        availableLA->setObjectName(QStringLiteral("availableLA"));

        gridLayout->addWidget(availableLA, 4, 0, 1, 1);

        indicesTW = new QTreeWidget(IndicesUi);
        indicesTW->setObjectName(QStringLiteral("indicesTW"));

        gridLayout->addWidget(indicesTW, 5, 0, 4, 1);

        removePB = new QPushButton(IndicesUi);
        removePB->setObjectName(QStringLiteral("removePB"));

        gridLayout->addWidget(removePB, 5, 1, 1, 1);

        renamePB = new QPushButton(IndicesUi);
        renamePB->setObjectName(QStringLiteral("renamePB"));

        gridLayout->addWidget(renamePB, 6, 1, 1, 1);

        colorPB = new QPushButton(IndicesUi);
        colorPB->setObjectName(QStringLiteral("colorPB"));

        gridLayout->addWidget(colorPB, 7, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 121, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem, 8, 1, 1, 1);

#ifndef QT_NO_SHORTCUT
        indexLA->setBuddy(indexCO);
        indexOptionsLA->setBuddy(indexOptionsLE);
        newIndexLA->setBuddy(newIndexLE);
        availableLA->setBuddy(indicesTW);
#endif // QT_NO_SHORTCUT

        retranslateUi(IndicesUi);

        QMetaObject::connectSlotsByName(IndicesUi);
    } // setupUi

    void retranslateUi(QWidget *IndicesUi)
    {
        IndicesUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        indexGB->setToolTip(lyx::qt_("Here you can define an alternative index processor and specify its options.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        indexGB->setTitle(lyx::qt_("Index Generation", Q_NULLPTR));
        indexLA->setText(lyx::qt_("&Processor:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indexCO->setToolTip(lyx::qt_("Select a processor", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        indexOptionsLA->setText(lyx::qt_("&Options:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        indexOptionsLE->setToolTip(lyx::qt_("Define program options of the selected processor.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        multipleIndicesCB->setToolTip(lyx::qt_("Check if you need multiple indexes (e.g., an Index of Names)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        multipleIndicesCB->setText(lyx::qt_("&Use multiple indexes", Q_NULLPTR));
        newIndexLA->setText(lyx::qt_("&New:[[index]]", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        newIndexLE->setToolTip(lyx::qt_("Enter the name of the desired index (e.g. \"Index of Names\") and hit \"Add\"", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        addIndexPB->setToolTip(lyx::qt_("Add a new index to the list", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        addIndexPB->setText(lyx::qt_("&Add", Q_NULLPTR));
        availableLA->setText(lyx::qt_("A&vailable Indexes:", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = indicesTW->headerItem();
        ___qtreewidgetitem->setText(0, lyx::qt_("1", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        removePB->setToolTip(lyx::qt_("Remove the selected index", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        removePB->setText(lyx::qt_("&Remove", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        renamePB->setToolTip(lyx::qt_("Rename the selected index", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        renamePB->setText(lyx::qt_("R&ename...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorPB->setToolTip(lyx::qt_("Define or change button color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorPB->setText(lyx::qt_("Alter Co&lor...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class IndicesUi: public Ui_IndicesUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INDICESUI_H
