/********************************************************************************
** Form generated from reading UI file 'LineUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LINEUI_H
#define UI_LINEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_LineUi
{
public:
    QGridLayout *gridLayout;
    QLabel *OffsetValueL;
    QLineEdit *OffsetLE;
    lyx::frontend::LengthCombo *OffsetUnitCO;
    QLabel *WidthValueL;
    QLineEdit *WidthLE;
    lyx::frontend::LengthCombo *WidthUnitCO;
    QLabel *HeightValueL;
    QLineEdit *HeightLE;
    lyx::frontend::LengthCombo *HeightUnitCO;

    void setupUi(QWidget *LineUi)
    {
        if (LineUi->objectName().isEmpty())
            LineUi->setObjectName(QStringLiteral("LineUi"));
        LineUi->resize(311, 92);
        LineUi->setProperty("sizeGripEnabled", QVariant(true));
        gridLayout = new QGridLayout(LineUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        OffsetValueL = new QLabel(LineUi);
        OffsetValueL->setObjectName(QStringLiteral("OffsetValueL"));

        gridLayout->addWidget(OffsetValueL, 0, 0, 1, 1);

        OffsetLE = new QLineEdit(LineUi);
        OffsetLE->setObjectName(QStringLiteral("OffsetLE"));
        OffsetLE->setEnabled(true);

        gridLayout->addWidget(OffsetLE, 0, 1, 1, 2);

        OffsetUnitCO = new lyx::frontend::LengthCombo(LineUi);
        OffsetUnitCO->setObjectName(QStringLiteral("OffsetUnitCO"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OffsetUnitCO->sizePolicy().hasHeightForWidth());
        OffsetUnitCO->setSizePolicy(sizePolicy);
        OffsetUnitCO->setMinimumSize(QSize(150, 20));

        gridLayout->addWidget(OffsetUnitCO, 0, 3, 1, 1);

        WidthValueL = new QLabel(LineUi);
        WidthValueL->setObjectName(QStringLiteral("WidthValueL"));

        gridLayout->addWidget(WidthValueL, 1, 0, 1, 1);

        WidthLE = new QLineEdit(LineUi);
        WidthLE->setObjectName(QStringLiteral("WidthLE"));
        WidthLE->setEnabled(true);

        gridLayout->addWidget(WidthLE, 1, 1, 1, 2);

        WidthUnitCO = new lyx::frontend::LengthCombo(LineUi);
        WidthUnitCO->setObjectName(QStringLiteral("WidthUnitCO"));
        sizePolicy.setHeightForWidth(WidthUnitCO->sizePolicy().hasHeightForWidth());
        WidthUnitCO->setSizePolicy(sizePolicy);
        WidthUnitCO->setMinimumSize(QSize(150, 20));

        gridLayout->addWidget(WidthUnitCO, 1, 3, 1, 1);

        HeightValueL = new QLabel(LineUi);
        HeightValueL->setObjectName(QStringLiteral("HeightValueL"));

        gridLayout->addWidget(HeightValueL, 2, 0, 1, 1);

        HeightLE = new QLineEdit(LineUi);
        HeightLE->setObjectName(QStringLiteral("HeightLE"));
        HeightLE->setEnabled(true);

        gridLayout->addWidget(HeightLE, 2, 1, 1, 2);

        HeightUnitCO = new lyx::frontend::LengthCombo(LineUi);
        HeightUnitCO->setObjectName(QStringLiteral("HeightUnitCO"));
        sizePolicy.setHeightForWidth(HeightUnitCO->sizePolicy().hasHeightForWidth());
        HeightUnitCO->setSizePolicy(sizePolicy);
        HeightUnitCO->setMinimumSize(QSize(150, 20));

        gridLayout->addWidget(HeightUnitCO, 2, 3, 1, 1);

#ifndef QT_NO_SHORTCUT
        OffsetValueL->setBuddy(OffsetLE);
        WidthValueL->setBuddy(WidthLE);
        HeightValueL->setBuddy(HeightLE);
#endif // QT_NO_SHORTCUT

        retranslateUi(LineUi);

        QMetaObject::connectSlotsByName(LineUi);
    } // setupUi

    void retranslateUi(QWidget *LineUi)
    {
        LineUi->setWindowTitle(QString());
        OffsetValueL->setText(lyx::qt_("Of&fset:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        OffsetLE->setToolTip(lyx::qt_("Value of the vertical line offset.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        WidthValueL->setText(lyx::qt_("&Width:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        WidthLE->setToolTip(lyx::qt_("Value of the line width.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        HeightValueL->setText(lyx::qt_("&Thickness:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        HeightLE->setToolTip(lyx::qt_("Value of the line thickness.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class LineUi: public Ui_LineUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LINEUI_H
