/********************************************************************************
** Form generated from reading UI file 'PrefsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFSUI_H
#define UI_PREFSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include "PanelStack.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefsUi
{
public:
    QGridLayout *gridLayout;
    lyx::frontend::PanelStack *prefsPS;
    QSpacerItem *horizontalSpacer;
    QCheckBox *tempSaveCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PrefsUi)
    {
        if (PrefsUi->objectName().isEmpty())
            PrefsUi->setObjectName(QStringLiteral("PrefsUi"));
        PrefsUi->resize(650, 266);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefsUi->sizePolicy().hasHeightForWidth());
        PrefsUi->setSizePolicy(sizePolicy);
        PrefsUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(PrefsUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        prefsPS = new lyx::frontend::PanelStack(PrefsUi);
        prefsPS->setObjectName(QStringLiteral("prefsPS"));

        gridLayout->addWidget(prefsPS, 0, 0, 1, 2);

        horizontalSpacer = new QSpacerItem(405, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        tempSaveCB = new QCheckBox(PrefsUi);
        tempSaveCB->setObjectName(QStringLiteral("tempSaveCB"));

        gridLayout->addWidget(tempSaveCB, 1, 1, 1, 1);

        buttonBox = new QDialogButtonBox(PrefsUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 2);


        retranslateUi(PrefsUi);

        QMetaObject::connectSlotsByName(PrefsUi);
    } // setupUi

    void retranslateUi(QDialog *PrefsUi)
    {
        PrefsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        tempSaveCB->setToolTip(lyx::qt_("If this is checked, pressing OK or Apply will save the changes only for the current LyX session, not permanently.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        tempSaveCB->setText(lyx::qt_("A&pply to current session only", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefsUi: public Ui_PrefsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFSUI_H
