/********************************************************************************
** Form generated from reading UI file 'SymbolsUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYMBOLSUI_H
#define UI_SYMBOLSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_SymbolsUi
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *categoryLA;
    QComboBox *categoryCO;
    QSpacerItem *spacerItem;
    QCheckBox *categoryFilterCB;
    QListView *symbolsLW;
    QLineEdit *chosenLE;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SymbolsUi)
    {
        if (SymbolsUi->objectName().isEmpty())
            SymbolsUi->setObjectName(QStringLiteral("SymbolsUi"));
        SymbolsUi->resize(430, 296);
        SymbolsUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(SymbolsUi);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        categoryLA = new QLabel(SymbolsUi);
        categoryLA->setObjectName(QStringLiteral("categoryLA"));

        hboxLayout->addWidget(categoryLA);

        categoryCO = new QComboBox(SymbolsUi);
        categoryCO->setObjectName(QStringLiteral("categoryCO"));
        categoryCO->setMaxVisibleItems(20);

        hboxLayout->addWidget(categoryCO);

        spacerItem = new QSpacerItem(191, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        categoryFilterCB = new QCheckBox(SymbolsUi);
        categoryFilterCB->setObjectName(QStringLiteral("categoryFilterCB"));

        hboxLayout->addWidget(categoryFilterCB);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        symbolsLW = new QListView(SymbolsUi);
        symbolsLW->setObjectName(QStringLiteral("symbolsLW"));
        symbolsLW->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        symbolsLW->setIconSize(QSize(16, 16));
        symbolsLW->setResizeMode(QListView::Adjust);
        symbolsLW->setSpacing(0);

        gridLayout->addWidget(symbolsLW, 1, 0, 1, 1);

        chosenLE = new QLineEdit(SymbolsUi);
        chosenLE->setObjectName(QStringLiteral("chosenLE"));
        chosenLE->setReadOnly(false);

        gridLayout->addWidget(chosenLE, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(SymbolsUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        categoryLA->setBuddy(categoryCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(SymbolsUi);

        QMetaObject::connectSlotsByName(SymbolsUi);
    } // setupUi

    void retranslateUi(QDialog *SymbolsUi)
    {
        SymbolsUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        categoryLA->setToolTip(lyx::qt_("Available categories depend on the document encoding. Select UTF-8 for the full range.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        categoryLA->setText(lyx::qt_("Ca&tegory:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        categoryFilterCB->setToolTip(lyx::qt_("Select this to display all available characters at once", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        categoryFilterCB->setText(lyx::qt_("&Display all", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SymbolsUi: public Ui_SymbolsUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SYMBOLSUI_H
