/********************************************************************************
** Form generated from reading UI file 'PrefCompletionUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFCOMPLETIONUI_H
#define UI_PREFCOMPLETIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefCompletionUi
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout;
    QCheckBox *inlineMathCB;
    QCheckBox *popupMathCB;
    QCheckBox *autocorrectionCB;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QCheckBox *inlineTextCB;
    QCheckBox *popupTextCB;
    QCheckBox *cursorTextCB;
    QGroupBox *groupBox_4;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout;
    QDoubleSpinBox *inlineDelaySB;
    QLabel *label_4;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout1;
    QDoubleSpinBox *popupDelaySB;
    QLabel *label_3;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout2;
    QSpinBox *minlengthSB;
    QLabel *label_5;
    QSpacerItem *spacerItem2;
    QCheckBox *popupAfterCompleteCB;
    QCheckBox *inlineDotsCB;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *PrefCompletionUi)
    {
        if (PrefCompletionUi->objectName().isEmpty())
            PrefCompletionUi->setObjectName(QStringLiteral("PrefCompletionUi"));
        PrefCompletionUi->resize(400, 404);
        gridLayout = new QGridLayout(PrefCompletionUi);
#ifndef Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        groupBox_3 = new QGroupBox(PrefCompletionUi);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        groupBox_3->setFlat(true);
        vboxLayout = new QVBoxLayout(groupBox_3);
#ifndef Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        inlineMathCB = new QCheckBox(groupBox_3);
        inlineMathCB->setObjectName(QStringLiteral("inlineMathCB"));

        vboxLayout->addWidget(inlineMathCB);

        popupMathCB = new QCheckBox(groupBox_3);
        popupMathCB->setObjectName(QStringLiteral("popupMathCB"));

        vboxLayout->addWidget(popupMathCB);

        autocorrectionCB = new QCheckBox(groupBox_3);
        autocorrectionCB->setObjectName(QStringLiteral("autocorrectionCB"));

        vboxLayout->addWidget(autocorrectionCB);


        gridLayout->addWidget(groupBox_3, 1, 0, 1, 1);

        groupBox_2 = new QGroupBox(PrefCompletionUi);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setFlat(true);
        vboxLayout1 = new QVBoxLayout(groupBox_2);
#ifndef Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        inlineTextCB = new QCheckBox(groupBox_2);
        inlineTextCB->setObjectName(QStringLiteral("inlineTextCB"));

        vboxLayout1->addWidget(inlineTextCB);

        popupTextCB = new QCheckBox(groupBox_2);
        popupTextCB->setObjectName(QStringLiteral("popupTextCB"));

        vboxLayout1->addWidget(popupTextCB);

        cursorTextCB = new QCheckBox(groupBox_2);
        cursorTextCB->setObjectName(QStringLiteral("cursorTextCB"));

        vboxLayout1->addWidget(cursorTextCB);


        gridLayout->addWidget(groupBox_2, 0, 0, 1, 1);

        groupBox_4 = new QGroupBox(PrefCompletionUi);
        groupBox_4->setObjectName(QStringLiteral("groupBox_4"));
        groupBox_4->setFlat(true);
        vboxLayout2 = new QVBoxLayout(groupBox_4);
#ifndef Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        inlineDelaySB = new QDoubleSpinBox(groupBox_4);
        inlineDelaySB->setObjectName(QStringLiteral("inlineDelaySB"));
        inlineDelaySB->setMaximum(10);
        inlineDelaySB->setSingleStep(0.1);

        hboxLayout->addWidget(inlineDelaySB);

        label_4 = new QLabel(groupBox_4);
        label_4->setObjectName(QStringLiteral("label_4"));

        hboxLayout->addWidget(label_4);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        popupDelaySB = new QDoubleSpinBox(groupBox_4);
        popupDelaySB->setObjectName(QStringLiteral("popupDelaySB"));
        popupDelaySB->setMaximum(10);
        popupDelaySB->setSingleStep(0.1);

        hboxLayout1->addWidget(popupDelaySB);

        label_3 = new QLabel(groupBox_4);
        label_3->setObjectName(QStringLiteral("label_3"));

        hboxLayout1->addWidget(label_3);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        vboxLayout2->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        minlengthSB = new QSpinBox(groupBox_4);
        minlengthSB->setObjectName(QStringLiteral("minlengthSB"));
        minlengthSB->setMinimum(5);
        minlengthSB->setMaximum(24);
        minlengthSB->setValue(6);

        hboxLayout2->addWidget(minlengthSB);

        label_5 = new QLabel(groupBox_4);
        label_5->setObjectName(QStringLiteral("label_5"));

        hboxLayout2->addWidget(label_5);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout2->addItem(spacerItem2);


        vboxLayout2->addLayout(hboxLayout2);

        popupAfterCompleteCB = new QCheckBox(groupBox_4);
        popupAfterCompleteCB->setObjectName(QStringLiteral("popupAfterCompleteCB"));

        vboxLayout2->addWidget(popupAfterCompleteCB);

        inlineDotsCB = new QCheckBox(groupBox_4);
        inlineDotsCB->setObjectName(QStringLiteral("inlineDotsCB"));

        vboxLayout2->addWidget(inlineDotsCB);


        gridLayout->addWidget(groupBox_4, 2, 0, 1, 1);

        spacerItem3 = new QSpacerItem(0, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem3, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        label_4->setBuddy(inlineDelaySB);
        label_3->setBuddy(popupDelaySB);
        label_5->setBuddy(minlengthSB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(inlineTextCB, popupTextCB);
        QWidget::setTabOrder(popupTextCB, cursorTextCB);
        QWidget::setTabOrder(cursorTextCB, inlineMathCB);
        QWidget::setTabOrder(inlineMathCB, popupMathCB);
        QWidget::setTabOrder(popupMathCB, autocorrectionCB);

        retranslateUi(PrefCompletionUi);

        QMetaObject::connectSlotsByName(PrefCompletionUi);
    } // setupUi

    void retranslateUi(QWidget *PrefCompletionUi)
    {
        PrefCompletionUi->setWindowTitle(QString());
        groupBox_3->setTitle(lyx::qt_("In Math", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inlineMathCB->setToolTip(lyx::qt_("Show the grey inline completion behind the cursor in math mode after the delay.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        inlineMathCB->setText(lyx::qt_("Automatic in&line completion", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        popupMathCB->setToolTip(lyx::qt_("Show the popup in math mode after the delay.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        popupMathCB->setText(lyx::qt_("Automatic p&opup", Q_NULLPTR));
        autocorrectionCB->setText(lyx::qt_("Autoco&rrection", Q_NULLPTR));
        groupBox_2->setTitle(lyx::qt_("In Text", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inlineTextCB->setToolTip(lyx::qt_("Show the grey inline completion behind the cursor in text mode after the delay.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        inlineTextCB->setText(lyx::qt_("Automatic &inline completion", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        popupTextCB->setToolTip(lyx::qt_("Show the popup after the set delay in text mode.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        popupTextCB->setText(lyx::qt_("Automatic &popup", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        cursorTextCB->setToolTip(lyx::qt_("Show a small triangle on the cursor if a completion is available in text mode.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        cursorTextCB->setText(lyx::qt_("Cursor i&ndicator", Q_NULLPTR));
        groupBox_4->setTitle(lyx::qt_("General[[settings]]", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inlineDelaySB->setToolTip(lyx::qt_("After the cursor has not moved for this time, the inline completion is shown if it is available.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_4->setText(lyx::qt_("s inline completion dela&y", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        popupDelaySB->setToolTip(lyx::qt_("After the cursor has not moved for this time, the completion popup is shown if it is available.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_3->setText(lyx::qt_("s popup d&elay", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        minlengthSB->setToolTip(lyx::qt_("Words with less than the specified number of characters will not be completed.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_5->setText(lyx::qt_("Minimum characters for words that should be completed", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        popupAfterCompleteCB->setToolTip(lyx::qt_("When the TAB completion is not unique, there won't be a delay of the popup. It will be shown right away.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        popupAfterCompleteCB->setText(lyx::qt_("Sho&w popup without delay for non-unique completions", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        inlineDotsCB->setToolTip(lyx::qt_("Long completions are cut-off and shown with \"...\".", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        inlineDotsCB->setText(lyx::qt_("&Use \"...\" to shorten long completions", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefCompletionUi: public Ui_PrefCompletionUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFCOMPLETIONUI_H
