/****************************************************************************
** Meta object code from reading C++ file 'GuiDelimiter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/lyx-2.4.4/src/frontends/qt/GuiDelimiter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'GuiDelimiter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_lyx__frontend__GuiDelimiter_t {
    QByteArrayData data[14];
    char stringdata0[266];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_lyx__frontend__GuiDelimiter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_lyx__frontend__GuiDelimiter_t qt_meta_stringdata_lyx__frontend__GuiDelimiter = {
    {
QT_MOC_LITERAL(0, 0, 27), // "lyx::frontend::GuiDelimiter"
QT_MOC_LITERAL(1, 28, 20), // "on_buttonBox_clicked"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 16), // "QAbstractButton*"
QT_MOC_LITERAL(4, 67, 6), // "button"
QT_MOC_LITERAL(5, 74, 23), // "on_leftLW_itemActivated"
QT_MOC_LITERAL(6, 98, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(7, 115, 24), // "on_rightLW_itemActivated"
QT_MOC_LITERAL(8, 140, 27), // "on_leftLW_currentRowChanged"
QT_MOC_LITERAL(9, 168, 28), // "on_rightLW_currentRowChanged"
QT_MOC_LITERAL(10, 197, 23), // "on_matchCB_stateChanged"
QT_MOC_LITERAL(11, 221, 6), // "insert"
QT_MOC_LITERAL(12, 228, 17), // "on_swapPB_clicked"
QT_MOC_LITERAL(13, 246, 19) // "on_sizeCO_activated"

    },
    "lyx::frontend::GuiDelimiter\0"
    "on_buttonBox_clicked\0\0QAbstractButton*\0"
    "button\0on_leftLW_itemActivated\0"
    "QListWidgetItem*\0on_rightLW_itemActivated\0"
    "on_leftLW_currentRowChanged\0"
    "on_rightLW_currentRowChanged\0"
    "on_matchCB_stateChanged\0insert\0"
    "on_swapPB_clicked\0on_sizeCO_activated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_lyx__frontend__GuiDelimiter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x0a /* Public */,
       5,    1,   62,    2, 0x0a /* Public */,
       7,    1,   65,    2, 0x0a /* Public */,
       8,    1,   68,    2, 0x0a /* Public */,
       9,    1,   71,    2, 0x0a /* Public */,
      10,    1,   74,    2, 0x0a /* Public */,
      11,    0,   77,    2, 0x0a /* Public */,
      12,    0,   78,    2, 0x0a /* Public */,
      13,    1,   79,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void lyx::frontend::GuiDelimiter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GuiDelimiter *_t = static_cast<GuiDelimiter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_buttonBox_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 1: _t->on_leftLW_itemActivated((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->on_rightLW_itemActivated((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 3: _t->on_leftLW_currentRowChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_rightLW_currentRowChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->on_matchCB_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->insert(); break;
        case 7: _t->on_swapPB_clicked(); break;
        case 8: _t->on_sizeCO_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject lyx::frontend::GuiDelimiter::staticMetaObject = {
    { &GuiDialog::staticMetaObject, qt_meta_stringdata_lyx__frontend__GuiDelimiter.data,
      qt_meta_data_lyx__frontend__GuiDelimiter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *lyx::frontend::GuiDelimiter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *lyx::frontend::GuiDelimiter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_lyx__frontend__GuiDelimiter.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::DelimiterUi"))
        return static_cast< Ui::DelimiterUi*>(this);
    return GuiDialog::qt_metacast(_clname);
}

int lyx::frontend::GuiDelimiter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GuiDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
