/********************************************************************************
** Form generated from reading UI file 'BiblioUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BIBLIOUI_H
#define UI_BIBLIOUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_BiblioUi
{
public:
    QGridLayout *gridLayout_4;
    QGroupBox *CiteStyleBG;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *citeEngineLA;
    QComboBox *citeEngineCO;
    QLabel *citationStyleL;
    QComboBox *citeStyleCO;
    QSpacerItem *spacerItem;
    QHBoxLayout *horizontalLayout_7;
    QLabel *citePackageOptionsL;
    QLineEdit *citePackageOptionsLE;
    QHBoxLayout *horizontalLayout_5;
    QLabel *biblatexCbxLA;
    QComboBox *biblatexCbxCO;
    QPushButton *resetCbxPB;
    QGroupBox *BiblioStyleBG;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_4;
    QLabel *biblatexBbxLA;
    QComboBox *biblatexBbxCO;
    QPushButton *resetBbxPB;
    QPushButton *matchBbxPB;
    QHBoxLayout *horizontalLayout_3;
    QLabel *bibtexStyleLA;
    QComboBox *defaultBiblioCO;
    QPushButton *resetDefaultBiblioPB;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *bibtopicCB;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *rescanBibliosPB;
    QHBoxLayout *horizontalLayout_8;
    QLabel *bibunitsLA;
    QComboBox *bibunitsCO;
    QGroupBox *bibtexGB;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *bibtexLA;
    QComboBox *bibtexCO;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *bibtexOptionsLA;
    QLineEdit *bibtexOptionsLE;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *BiblioUi)
    {
        if (BiblioUi->objectName().isEmpty())
            BiblioUi->setObjectName(QStringLiteral("BiblioUi"));
        BiblioUi->resize(534, 482);
        gridLayout_4 = new QGridLayout(BiblioUi);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        CiteStyleBG = new QGroupBox(BiblioUi);
        CiteStyleBG->setObjectName(QStringLiteral("CiteStyleBG"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CiteStyleBG->sizePolicy().hasHeightForWidth());
        CiteStyleBG->setSizePolicy(sizePolicy);
        CiteStyleBG->setFlat(true);
        gridLayout = new QGridLayout(CiteStyleBG);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        citeEngineLA = new QLabel(CiteStyleBG);
        citeEngineLA->setObjectName(QStringLiteral("citeEngineLA"));

        hboxLayout->addWidget(citeEngineLA);

        citeEngineCO = new QComboBox(CiteStyleBG);
        citeEngineCO->setObjectName(QStringLiteral("citeEngineCO"));

        hboxLayout->addWidget(citeEngineCO);

        citationStyleL = new QLabel(CiteStyleBG);
        citationStyleL->setObjectName(QStringLiteral("citationStyleL"));
        citationStyleL->setEnabled(false);

        hboxLayout->addWidget(citationStyleL);

        citeStyleCO = new QComboBox(CiteStyleBG);
        citeStyleCO->setObjectName(QStringLiteral("citeStyleCO"));
        citeStyleCO->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(citeStyleCO->sizePolicy().hasHeightForWidth());
        citeStyleCO->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(citeStyleCO);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 1, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QStringLiteral("horizontalLayout_7"));
        citePackageOptionsL = new QLabel(CiteStyleBG);
        citePackageOptionsL->setObjectName(QStringLiteral("citePackageOptionsL"));

        horizontalLayout_7->addWidget(citePackageOptionsL);

        citePackageOptionsLE = new QLineEdit(CiteStyleBG);
        citePackageOptionsLE->setObjectName(QStringLiteral("citePackageOptionsLE"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(citePackageOptionsLE->sizePolicy().hasHeightForWidth());
        citePackageOptionsLE->setSizePolicy(sizePolicy2);

        horizontalLayout_7->addWidget(citePackageOptionsLE);


        gridLayout->addLayout(horizontalLayout_7, 1, 0, 1, 2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        biblatexCbxLA = new QLabel(CiteStyleBG);
        biblatexCbxLA->setObjectName(QStringLiteral("biblatexCbxLA"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(biblatexCbxLA->sizePolicy().hasHeightForWidth());
        biblatexCbxLA->setSizePolicy(sizePolicy3);

        horizontalLayout_5->addWidget(biblatexCbxLA);

        biblatexCbxCO = new QComboBox(CiteStyleBG);
        biblatexCbxCO->setObjectName(QStringLiteral("biblatexCbxCO"));
        biblatexCbxCO->setEditable(true);

        horizontalLayout_5->addWidget(biblatexCbxCO);

        resetCbxPB = new QPushButton(CiteStyleBG);
        resetCbxPB->setObjectName(QStringLiteral("resetCbxPB"));
        sizePolicy1.setHeightForWidth(resetCbxPB->sizePolicy().hasHeightForWidth());
        resetCbxPB->setSizePolicy(sizePolicy1);

        horizontalLayout_5->addWidget(resetCbxPB);


        gridLayout->addLayout(horizontalLayout_5, 2, 0, 1, 2);


        gridLayout_4->addWidget(CiteStyleBG, 0, 0, 1, 1);

        BiblioStyleBG = new QGroupBox(BiblioUi);
        BiblioStyleBG->setObjectName(QStringLiteral("BiblioStyleBG"));
        sizePolicy.setHeightForWidth(BiblioStyleBG->sizePolicy().hasHeightForWidth());
        BiblioStyleBG->setSizePolicy(sizePolicy);
        BiblioStyleBG->setFlat(true);
        gridLayout_3 = new QGridLayout(BiblioStyleBG);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        biblatexBbxLA = new QLabel(BiblioStyleBG);
        biblatexBbxLA->setObjectName(QStringLiteral("biblatexBbxLA"));

        horizontalLayout_4->addWidget(biblatexBbxLA);

        biblatexBbxCO = new QComboBox(BiblioStyleBG);
        biblatexBbxCO->setObjectName(QStringLiteral("biblatexBbxCO"));
        sizePolicy2.setHeightForWidth(biblatexBbxCO->sizePolicy().hasHeightForWidth());
        biblatexBbxCO->setSizePolicy(sizePolicy2);
        biblatexBbxCO->setEditable(true);

        horizontalLayout_4->addWidget(biblatexBbxCO);

        resetBbxPB = new QPushButton(BiblioStyleBG);
        resetBbxPB->setObjectName(QStringLiteral("resetBbxPB"));

        horizontalLayout_4->addWidget(resetBbxPB);

        matchBbxPB = new QPushButton(BiblioStyleBG);
        matchBbxPB->setObjectName(QStringLiteral("matchBbxPB"));

        horizontalLayout_4->addWidget(matchBbxPB);


        gridLayout_3->addLayout(horizontalLayout_4, 0, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        bibtexStyleLA = new QLabel(BiblioStyleBG);
        bibtexStyleLA->setObjectName(QStringLiteral("bibtexStyleLA"));

        horizontalLayout_3->addWidget(bibtexStyleLA);

        defaultBiblioCO = new QComboBox(BiblioStyleBG);
        defaultBiblioCO->setObjectName(QStringLiteral("defaultBiblioCO"));
        sizePolicy2.setHeightForWidth(defaultBiblioCO->sizePolicy().hasHeightForWidth());
        defaultBiblioCO->setSizePolicy(sizePolicy2);
        defaultBiblioCO->setEditable(true);

        horizontalLayout_3->addWidget(defaultBiblioCO);

        resetDefaultBiblioPB = new QPushButton(BiblioStyleBG);
        resetDefaultBiblioPB->setObjectName(QStringLiteral("resetDefaultBiblioPB"));

        horizontalLayout_3->addWidget(resetDefaultBiblioPB);


        gridLayout_3->addLayout(horizontalLayout_3, 1, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QStringLiteral("horizontalLayout_6"));
        bibtopicCB = new QCheckBox(BiblioStyleBG);
        bibtopicCB->setObjectName(QStringLiteral("bibtopicCB"));

        horizontalLayout_6->addWidget(bibtopicCB);

        horizontalSpacer_4 = new QSpacerItem(189, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);

        rescanBibliosPB = new QPushButton(BiblioStyleBG);
        rescanBibliosPB->setObjectName(QStringLiteral("rescanBibliosPB"));

        horizontalLayout_6->addWidget(rescanBibliosPB);


        gridLayout_3->addLayout(horizontalLayout_6, 2, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QStringLiteral("horizontalLayout_8"));
        bibunitsLA = new QLabel(BiblioStyleBG);
        bibunitsLA->setObjectName(QStringLiteral("bibunitsLA"));

        horizontalLayout_8->addWidget(bibunitsLA);

        bibunitsCO = new QComboBox(BiblioStyleBG);
        bibunitsCO->setObjectName(QStringLiteral("bibunitsCO"));
        sizePolicy2.setHeightForWidth(bibunitsCO->sizePolicy().hasHeightForWidth());
        bibunitsCO->setSizePolicy(sizePolicy2);

        horizontalLayout_8->addWidget(bibunitsCO);


        gridLayout_3->addLayout(horizontalLayout_8, 3, 0, 1, 1);


        gridLayout_4->addWidget(BiblioStyleBG, 1, 0, 1, 1);

        bibtexGB = new QGroupBox(BiblioUi);
        bibtexGB->setObjectName(QStringLiteral("bibtexGB"));
        sizePolicy.setHeightForWidth(bibtexGB->sizePolicy().hasHeightForWidth());
        bibtexGB->setSizePolicy(sizePolicy);
        bibtexGB->setFlat(true);
        gridLayout_2 = new QGridLayout(bibtexGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        bibtexLA = new QLabel(bibtexGB);
        bibtexLA->setObjectName(QStringLiteral("bibtexLA"));

        horizontalLayout->addWidget(bibtexLA);

        bibtexCO = new QComboBox(bibtexGB);
        bibtexCO->setObjectName(QStringLiteral("bibtexCO"));

        horizontalLayout->addWidget(bibtexCO);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(183, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        bibtexOptionsLA = new QLabel(bibtexGB);
        bibtexOptionsLA->setObjectName(QStringLiteral("bibtexOptionsLA"));

        horizontalLayout_2->addWidget(bibtexOptionsLA);

        bibtexOptionsLE = new QLineEdit(bibtexGB);
        bibtexOptionsLE->setObjectName(QStringLiteral("bibtexOptionsLE"));
        sizePolicy2.setHeightForWidth(bibtexOptionsLE->sizePolicy().hasHeightForWidth());
        bibtexOptionsLE->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(bibtexOptionsLE);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 0, 1, 2);


        gridLayout_4->addWidget(bibtexGB, 2, 0, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(spacerItem1, 3, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        citeEngineLA->setBuddy(citeEngineCO);
        citationStyleL->setBuddy(citeStyleCO);
        citePackageOptionsL->setBuddy(citePackageOptionsLE);
        biblatexCbxLA->setBuddy(biblatexCbxCO);
        biblatexBbxLA->setBuddy(biblatexBbxCO);
        bibtexStyleLA->setBuddy(defaultBiblioCO);
        bibunitsLA->setBuddy(bibunitsCO);
        bibtexLA->setBuddy(bibtexCO);
        bibtexOptionsLA->setBuddy(bibtexOptionsLE);
#endif // QT_NO_SHORTCUT

        retranslateUi(BiblioUi);

        QMetaObject::connectSlotsByName(BiblioUi);
    } // setupUi

    void retranslateUi(QWidget *BiblioUi)
    {
        BiblioUi->setWindowTitle(QString());
        CiteStyleBG->setTitle(lyx::qt_("Citation Style", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citeEngineLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        citeEngineLA->setText(lyx::qt_("Sty&le format:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citeEngineCO->setToolTip(lyx::qt_("A selection of different style format approaches (such as natbib) that respectively provide support for specific citation and bibliography styles. Expand to get more information.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        citationStyleL->setText(lyx::qt_("&Variant:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citeStyleCO->setToolTip(lyx::qt_("Provides available cite style variants.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        citePackageOptionsL->setText(lyx::qt_("Opt&ions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citePackageOptionsLE->setToolTip(lyx::qt_("Here you can enter further options of the bibliography package", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        biblatexCbxLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        biblatexCbxLA->setText(lyx::qt_("Biblatex &citation style:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        biblatexCbxCO->setToolTip(lyx::qt_("The style that determines the layout of the citations", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        resetCbxPB->setToolTip(lyx::qt_("Reset to the preset default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        resetCbxPB->setText(lyx::qt_("Rese&t", Q_NULLPTR));
        BiblioStyleBG->setTitle(lyx::qt_("Bibliography Style", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        biblatexBbxLA->setToolTip(QString());
#endif // QT_NO_TOOLTIP
        biblatexBbxLA->setText(lyx::qt_("Biblate&x bibliography style:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        biblatexBbxCO->setToolTip(lyx::qt_("The style that determines the layout of the biblatex-generated bibliography", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        resetBbxPB->setToolTip(lyx::qt_("Reset to the preset default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        resetBbxPB->setText(lyx::qt_("R&eset", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        matchBbxPB->setToolTip(lyx::qt_("Match biblatex bibliography with citation style", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        matchBbxPB->setText(lyx::qt_("&Match", Q_NULLPTR));
        bibtexStyleLA->setText(lyx::qt_("Default BibTeX st&yle:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        defaultBiblioCO->setToolTip(lyx::qt_("Here, you can define a BibTeX style that is suggested in the BibTeX dialog by default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        resetDefaultBiblioPB->setToolTip(lyx::qt_("Reset to the preset default", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        resetDefaultBiblioPB->setText(lyx::qt_("&Reset", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bibtopicCB->setToolTip(lyx::qt_("Select this if you want to split your bibliography into sections", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibtopicCB->setText(lyx::qt_("Subdivided bibli&ography", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        rescanBibliosPB->setToolTip(lyx::qt_("Rescan style files", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        rescanBibliosPB->setText(lyx::qt_("Re&scan", Q_NULLPTR));
        bibunitsLA->setText(lyx::qt_("&Multiple bibliographies:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bibunitsCO->setToolTip(lyx::qt_("Generate a bibliography per defined unit.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        bibtexGB->setToolTip(lyx::qt_("Here you can define an alternative program to or specific options of BibTeX.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibtexGB->setTitle(lyx::qt_("Bibliography Generation", Q_NULLPTR));
        bibtexLA->setText(lyx::qt_("&Processor:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bibtexCO->setToolTip(lyx::qt_("Select a processor", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        bibtexOptionsLA->setText(lyx::qt_("Op&tions:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bibtexOptionsLE->setToolTip(lyx::qt_("Define options such as --min-crossrefs (see the documentation of BibTeX)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class BiblioUi: public Ui_BiblioUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BIBLIOUI_H
