/********************************************************************************
** Form generated from reading UI file 'PrefDisplayUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFDISPLAYUI_H
#define UI_PREFDISPLAYUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefDisplayUi
{
public:
    QGridLayout *gridLayout;
    QDoubleSpinBox *previewSizeSB;
    QCheckBox *displayGraphicsCB;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QLabel *instantPreviewLA;
    QComboBox *instantPreviewCO;
    QCheckBox *paragraphMarkerCB;
    QLabel *previewSizeLA;
    QCheckBox *ctAdditionsUnderlinedCB;

    void setupUi(QWidget *PrefDisplayUi)
    {
        if (PrefDisplayUi->objectName().isEmpty())
            PrefDisplayUi->setObjectName(QStringLiteral("PrefDisplayUi"));
        PrefDisplayUi->resize(507, 206);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefDisplayUi->sizePolicy().hasHeightForWidth());
        PrefDisplayUi->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(PrefDisplayUi);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        previewSizeSB = new QDoubleSpinBox(PrefDisplayUi);
        previewSizeSB->setObjectName(QStringLiteral("previewSizeSB"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(previewSizeSB->sizePolicy().hasHeightForWidth());
        previewSizeSB->setSizePolicy(sizePolicy1);
        previewSizeSB->setDecimals(1);
        previewSizeSB->setMinimum(0.1);
        previewSizeSB->setMaximum(10);
        previewSizeSB->setSingleStep(0.1);
        previewSizeSB->setValue(1);

        gridLayout->addWidget(previewSizeSB, 1, 3, 1, 1);

        displayGraphicsCB = new QCheckBox(PrefDisplayUi);
        displayGraphicsCB->setObjectName(QStringLiteral("displayGraphicsCB"));

        gridLayout->addWidget(displayGraphicsCB, 0, 0, 1, 2);

        spacerItem = new QSpacerItem(57, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 4, 5, 1);

        spacerItem1 = new QSpacerItem(0, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem1, 4, 0, 1, 1);

        instantPreviewLA = new QLabel(PrefDisplayUi);
        instantPreviewLA->setObjectName(QStringLiteral("instantPreviewLA"));

        gridLayout->addWidget(instantPreviewLA, 1, 0, 1, 1);

        instantPreviewCO = new QComboBox(PrefDisplayUi);
        instantPreviewCO->setObjectName(QStringLiteral("instantPreviewCO"));

        gridLayout->addWidget(instantPreviewCO, 1, 1, 1, 1);

        paragraphMarkerCB = new QCheckBox(PrefDisplayUi);
        paragraphMarkerCB->setObjectName(QStringLiteral("paragraphMarkerCB"));

        gridLayout->addWidget(paragraphMarkerCB, 2, 0, 1, 2);

        previewSizeLA = new QLabel(PrefDisplayUi);
        previewSizeLA->setObjectName(QStringLiteral("previewSizeLA"));

        gridLayout->addWidget(previewSizeLA, 1, 2, 1, 1);

        ctAdditionsUnderlinedCB = new QCheckBox(PrefDisplayUi);
        ctAdditionsUnderlinedCB->setObjectName(QStringLiteral("ctAdditionsUnderlinedCB"));

        gridLayout->addWidget(ctAdditionsUnderlinedCB, 3, 0, 1, 2);

#ifndef QT_NO_SHORTCUT
        instantPreviewLA->setBuddy(instantPreviewCO);
        previewSizeLA->setBuddy(instantPreviewCO);
#endif // QT_NO_SHORTCUT

        retranslateUi(PrefDisplayUi);

        QMetaObject::connectSlotsByName(PrefDisplayUi);
    } // setupUi

    void retranslateUi(QWidget *PrefDisplayUi)
    {
        PrefDisplayUi->setWindowTitle(QString());
#ifndef QT_NO_TOOLTIP
        previewSizeSB->setToolTip(lyx::qt_("Factor for the preview size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        displayGraphicsCB->setText(lyx::qt_("Display &graphics", Q_NULLPTR));
        instantPreviewLA->setText(lyx::qt_("Instant &preview:", Q_NULLPTR));
        instantPreviewCO->clear();
        instantPreviewCO->insertItems(0, QStringList()
         << lyx::qt_("Off", Q_NULLPTR)
         << lyx::qt_("No math", Q_NULLPTR)
         << lyx::qt_("On", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        paragraphMarkerCB->setToolTip(lyx::qt_("Mark end of paragraphs on screen with a pilcrow character.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        paragraphMarkerCB->setText(lyx::qt_("&Mark end of paragraphs", Q_NULLPTR));
        previewSizeLA->setText(lyx::qt_("Preview si&ze:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ctAdditionsUnderlinedCB->setToolTip(lyx::qt_("If this is checked, additions in change tracking are underlined in the workarea", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ctAdditionsUnderlinedCB->setText(lyx::qt_("&Underline change tracking additions", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PrefDisplayUi: public Ui_PrefDisplayUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFDISPLAYUI_H
