/********************************************************************************
** Form generated from reading UI file 'PrefEditUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFEDITUI_H
#define UI_PREFEDITUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "LengthCombo.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_PrefEditUi
{
public:
    QGridLayout *gridLayout_3;
    QGroupBox *scrollGB;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QCheckBox *scrollBelowCB;
    QSpacerItem *horizontalSpacer_3;
    QComboBox *macroEditStyleCO;
    QCheckBox *copyCTMarkupCB;
    QCheckBox *sortEnvironmentsCB;
    QCheckBox *cursorFollowsCB;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *citationSearchCB;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_3;
    QLabel *citationSearchLA;
    QLineEdit *citationSearchLE;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QSpinBox *cursorWidthSB;
    QCheckBox *macLikeCursorMovementCB;
    QCheckBox *groupEnvironmentsCB;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *screenLimitCB;
    QSpacerItem *horizontalSpacer_9;
    QLineEdit *screenWidthLE;
    lyx::frontend::LengthCombo *screenWidthUnitCO;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *PrefEditUi)
    {
        if (PrefEditUi->objectName().isEmpty())
            PrefEditUi->setObjectName(QStringLiteral("PrefEditUi"));
        PrefEditUi->resize(610, 552);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PrefEditUi->sizePolicy().hasHeightForWidth());
        PrefEditUi->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(PrefEditUi);
        gridLayout_3->setSpacing(4);
        gridLayout_3->setContentsMargins(9, 9, 9, 9);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        scrollGB = new QGroupBox(PrefEditUi);
        scrollGB->setObjectName(QStringLiteral("scrollGB"));
        scrollGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        scrollGB->setFlat(true);
        gridLayout = new QGridLayout(scrollGB);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 8, 3, 1, 1);

        scrollBelowCB = new QCheckBox(scrollGB);
        scrollBelowCB->setObjectName(QStringLiteral("scrollBelowCB"));

        gridLayout->addWidget(scrollBelowCB, 2, 0, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(200, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 2, 1, 1);

        macroEditStyleCO = new QComboBox(scrollGB);
        macroEditStyleCO->setObjectName(QStringLiteral("macroEditStyleCO"));

        gridLayout->addWidget(macroEditStyleCO, 8, 0, 1, 3);

        copyCTMarkupCB = new QCheckBox(scrollGB);
        copyCTMarkupCB->setObjectName(QStringLiteral("copyCTMarkupCB"));

        gridLayout->addWidget(copyCTMarkupCB, 4, 0, 1, 2);

        sortEnvironmentsCB = new QCheckBox(scrollGB);
        sortEnvironmentsCB->setObjectName(QStringLiteral("sortEnvironmentsCB"));

        gridLayout->addWidget(sortEnvironmentsCB, 5, 0, 2, 2);

        cursorFollowsCB = new QCheckBox(scrollGB);
        cursorFollowsCB->setObjectName(QStringLiteral("cursorFollowsCB"));

        gridLayout->addWidget(cursorFollowsCB, 0, 0, 1, 2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(4);
        horizontalLayout_5->setObjectName(QStringLiteral("horizontalLayout_5"));
        citationSearchCB = new QCheckBox(scrollGB);
        citationSearchCB->setObjectName(QStringLiteral("citationSearchCB"));

        horizontalLayout_5->addWidget(citationSearchCB);

        horizontalSpacer_8 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_8);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(4);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        citationSearchLA = new QLabel(scrollGB);
        citationSearchLA->setObjectName(QStringLiteral("citationSearchLA"));

        horizontalLayout_3->addWidget(citationSearchLA);

        citationSearchLE = new QLineEdit(scrollGB);
        citationSearchLE->setObjectName(QStringLiteral("citationSearchLE"));

        horizontalLayout_3->addWidget(citationSearchLE);


        horizontalLayout_5->addLayout(horizontalLayout_3);


        gridLayout->addLayout(horizontalLayout_5, 9, 0, 1, 3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(4);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_3 = new QLabel(scrollGB);
        label_3->setObjectName(QStringLiteral("label_3"));

        horizontalLayout->addWidget(label_3);

        cursorWidthSB = new QSpinBox(scrollGB);
        cursorWidthSB->setObjectName(QStringLiteral("cursorWidthSB"));
        cursorWidthSB->setMinimum(0);
        cursorWidthSB->setMaximum(10);
        cursorWidthSB->setSingleStep(1);
        cursorWidthSB->setValue(1);

        horizontalLayout->addWidget(cursorWidthSB);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 2);

        macLikeCursorMovementCB = new QCheckBox(scrollGB);
        macLikeCursorMovementCB->setObjectName(QStringLiteral("macLikeCursorMovementCB"));

        gridLayout->addWidget(macLikeCursorMovementCB, 3, 0, 1, 2);

        groupEnvironmentsCB = new QCheckBox(scrollGB);
        groupEnvironmentsCB->setObjectName(QStringLiteral("groupEnvironmentsCB"));

        gridLayout->addWidget(groupEnvironmentsCB, 7, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(4);
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        screenLimitCB = new QCheckBox(scrollGB);
        screenLimitCB->setObjectName(QStringLiteral("screenLimitCB"));

        horizontalLayout_4->addWidget(screenLimitCB);

        horizontalSpacer_9 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_9);

        screenWidthLE = new QLineEdit(scrollGB);
        screenWidthLE->setObjectName(QStringLiteral("screenWidthLE"));

        horizontalLayout_4->addWidget(screenWidthLE);

        screenWidthUnitCO = new lyx::frontend::LengthCombo(scrollGB);
        screenWidthUnitCO->setObjectName(QStringLiteral("screenWidthUnitCO"));

        horizontalLayout_4->addWidget(screenWidthUnitCO);

        horizontalSpacer_2 = new QSpacerItem(157, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_4, 10, 0, 1, 3);


        gridLayout_3->addWidget(scrollGB, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_3->addItem(spacerItem, 1, 0, 1, 1);

#ifndef QT_NO_SHORTCUT
        citationSearchLA->setBuddy(citationSearchLE);
        label_3->setBuddy(cursorWidthSB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(cursorFollowsCB, cursorWidthSB);
        QWidget::setTabOrder(cursorWidthSB, scrollBelowCB);
        QWidget::setTabOrder(scrollBelowCB, macLikeCursorMovementCB);
        QWidget::setTabOrder(macLikeCursorMovementCB, sortEnvironmentsCB);
        QWidget::setTabOrder(sortEnvironmentsCB, macroEditStyleCO);

        retranslateUi(PrefEditUi);

        QMetaObject::connectSlotsByName(PrefEditUi);
    } // setupUi

    void retranslateUi(QWidget *PrefEditUi)
    {
        PrefEditUi->setWindowTitle(QString());
        scrollGB->setTitle(lyx::qt_("Editing", Q_NULLPTR));
        scrollBelowCB->setText(lyx::qt_("Scroll &below end of document", Q_NULLPTR));
        macroEditStyleCO->clear();
        macroEditStyleCO->insertItems(0, QStringList()
         << lyx::qt_("Edit Math Macros inline with a box around", Q_NULLPTR)
         << lyx::qt_("Edit Math Macros inline with the name in the status bar", Q_NULLPTR)
         << lyx::qt_("Edit Math Macros with a parameter list (like in LyX < 1.6)", Q_NULLPTR)
        );
#ifndef QT_NO_TOOLTIP
        copyCTMarkupCB->setToolTip(lyx::qt_("If this is checked, change tracking markup will not be resolved on copy/paste operations and when moving content from/to insets if change tracking is deactivated.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        copyCTMarkupCB->setText(lyx::qt_("&Keep change tracking markup on copy and paste", Q_NULLPTR));
        sortEnvironmentsCB->setText(lyx::qt_("Sort &environments alphabetically", Q_NULLPTR));
        cursorFollowsCB->setText(lyx::qt_("Cursor &follows scrollbar", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citationSearchCB->setToolTip(lyx::qt_("If this is activated, LyX will search your disk for matching files when clicking on \"Try to Open Citation Content...\" in the citation context menu. Note the security implications described in User Guide, 6.6.4.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_STATUSTIP
        citationSearchCB->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
        citationSearchCB->setText(lyx::qt_("Search &drive for cited files", Q_NULLPTR));
        citationSearchLA->setText(lyx::qt_("Patte&rn:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        citationSearchLE->setToolTip(lyx::qt_("Define search pattern (see UserGuide for syntax)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        label_3->setText(lyx::qt_("Cursor width (&pixels):", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        cursorWidthSB->setToolTip(lyx::qt_("Configure the width of the text cursor.  \"Auto\" means that zoom-controlled width is used.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        cursorWidthSB->setSpecialValueText(lyx::qt_("Auto", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        macLikeCursorMovementCB->setToolTip(lyx::qt_("Skip trailing non-word characters", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        macLikeCursorMovementCB->setText(lyx::qt_("Use M&ac-style cursor movement", Q_NULLPTR));
        groupEnvironmentsCB->setText(lyx::qt_("&Group environments by their category", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        screenLimitCB->setToolTip(lyx::qt_("Limit the width of the text in the work area to the specified length", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        screenLimitCB->setText(lyx::qt_("&Limit text width", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        screenWidthLE->setToolTip(lyx::qt_("Limit the width of the text in the work area to the specified length", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
    } // retranslateUi

};

namespace Ui {
    class PrefEditUi: public Ui_PrefEditUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFEDITUI_H
