/********************************************************************************
** Form generated from reading UI file 'CharacterUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHARACTERUI_H
#define UI_CHARACTERUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_CharacterUi
{
public:
    QGridLayout *gridLayout_7;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QLabel *familyLA;
    QComboBox *familyCO;
    QLabel *seriesLA;
    QComboBox *seriesCO;
    QLabel *shapeLA;
    QComboBox *shapeCO;
    QLabel *sizeLA;
    QComboBox *sizeCO;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QGridLayout *gridLayout_3;
    QLabel *colorLA;
    QComboBox *colorCO;
    QLabel *ulineLA;
    QComboBox *ulineCO;
    QLabel *strikeLA;
    QComboBox *strikeCO;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_6;
    QHBoxLayout *horizontalLayout;
    QLabel *LanguageLA;
    QComboBox *langCO;
    QCheckBox *nospellcheckCB;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_5;
    QCheckBox *emphCB;
    QCheckBox *nounCB;
    QHBoxLayout *hboxLayout;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *spacerItem;
    QCheckBox *autoapplyCB;

    void setupUi(QDialog *CharacterUi)
    {
        if (CharacterUi->objectName().isEmpty())
            CharacterUi->setObjectName(QStringLiteral("CharacterUi"));
        CharacterUi->resize(545, 428);
        CharacterUi->setSizeGripEnabled(true);
        gridLayout_7 = new QGridLayout(CharacterUi);
        gridLayout_7->setObjectName(QStringLiteral("gridLayout_7"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        groupBox = new QGroupBox(CharacterUi);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setFlat(true);
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        familyLA = new QLabel(groupBox);
        familyLA->setObjectName(QStringLiteral("familyLA"));

        gridLayout->addWidget(familyLA, 0, 0, 1, 1);

        familyCO = new QComboBox(groupBox);
        familyCO->setObjectName(QStringLiteral("familyCO"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(familyCO->sizePolicy().hasHeightForWidth());
        familyCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(familyCO, 0, 1, 1, 1);

        seriesLA = new QLabel(groupBox);
        seriesLA->setObjectName(QStringLiteral("seriesLA"));

        gridLayout->addWidget(seriesLA, 1, 0, 1, 1);

        seriesCO = new QComboBox(groupBox);
        seriesCO->setObjectName(QStringLiteral("seriesCO"));
        sizePolicy.setHeightForWidth(seriesCO->sizePolicy().hasHeightForWidth());
        seriesCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(seriesCO, 1, 1, 1, 1);

        shapeLA = new QLabel(groupBox);
        shapeLA->setObjectName(QStringLiteral("shapeLA"));

        gridLayout->addWidget(shapeLA, 2, 0, 1, 1);

        shapeCO = new QComboBox(groupBox);
        shapeCO->setObjectName(QStringLiteral("shapeCO"));
        sizePolicy.setHeightForWidth(shapeCO->sizePolicy().hasHeightForWidth());
        shapeCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(shapeCO, 2, 1, 1, 1);

        sizeLA = new QLabel(groupBox);
        sizeLA->setObjectName(QStringLiteral("sizeLA"));

        gridLayout->addWidget(sizeLA, 3, 0, 1, 1);

        sizeCO = new QComboBox(groupBox);
        sizeCO->setObjectName(QStringLiteral("sizeCO"));
        sizePolicy.setHeightForWidth(sizeCO->sizePolicy().hasHeightForWidth());
        sizeCO->setSizePolicy(sizePolicy);

        gridLayout->addWidget(sizeCO, 3, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);


        horizontalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CharacterUi);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        groupBox_2->setFlat(true);
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        colorLA = new QLabel(groupBox_2);
        colorLA->setObjectName(QStringLiteral("colorLA"));
        colorLA->setEnabled(true);

        gridLayout_3->addWidget(colorLA, 0, 0, 1, 1);

        colorCO = new QComboBox(groupBox_2);
        colorCO->setObjectName(QStringLiteral("colorCO"));
        sizePolicy.setHeightForWidth(colorCO->sizePolicy().hasHeightForWidth());
        colorCO->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(colorCO, 0, 1, 1, 1);

        ulineLA = new QLabel(groupBox_2);
        ulineLA->setObjectName(QStringLiteral("ulineLA"));

        gridLayout_3->addWidget(ulineLA, 1, 0, 1, 1);

        ulineCO = new QComboBox(groupBox_2);
        ulineCO->setObjectName(QStringLiteral("ulineCO"));
        sizePolicy.setHeightForWidth(ulineCO->sizePolicy().hasHeightForWidth());
        ulineCO->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(ulineCO, 1, 1, 1, 1);

        strikeLA = new QLabel(groupBox_2);
        strikeLA->setObjectName(QStringLiteral("strikeLA"));

        gridLayout_3->addWidget(strikeLA, 2, 0, 1, 1);

        strikeCO = new QComboBox(groupBox_2);
        strikeCO->setObjectName(QStringLiteral("strikeCO"));
        sizePolicy.setHeightForWidth(strikeCO->sizePolicy().hasHeightForWidth());
        strikeCO->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(strikeCO, 2, 1, 1, 1);


        gridLayout_4->addLayout(gridLayout_3, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 36, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_4->addItem(verticalSpacer_2, 1, 0, 1, 1);


        horizontalLayout_2->addWidget(groupBox_2);


        gridLayout_7->addLayout(horizontalLayout_2, 0, 0, 1, 2);

        groupBox_4 = new QGroupBox(CharacterUi);
        groupBox_4->setObjectName(QStringLiteral("groupBox_4"));
        groupBox_4->setFlat(true);
        gridLayout_6 = new QGridLayout(groupBox_4);
        gridLayout_6->setObjectName(QStringLiteral("gridLayout_6"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        LanguageLA = new QLabel(groupBox_4);
        LanguageLA->setObjectName(QStringLiteral("LanguageLA"));

        horizontalLayout->addWidget(LanguageLA);

        langCO = new QComboBox(groupBox_4);
        langCO->setObjectName(QStringLiteral("langCO"));
        sizePolicy.setHeightForWidth(langCO->sizePolicy().hasHeightForWidth());
        langCO->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(langCO);


        gridLayout_6->addLayout(horizontalLayout, 0, 0, 1, 1);

        nospellcheckCB = new QCheckBox(groupBox_4);
        nospellcheckCB->setObjectName(QStringLiteral("nospellcheckCB"));

        gridLayout_6->addWidget(nospellcheckCB, 1, 0, 1, 1);


        gridLayout_7->addWidget(groupBox_4, 1, 0, 1, 1);

        groupBox_3 = new QGroupBox(CharacterUi);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        groupBox_3->setFlat(true);
        gridLayout_5 = new QGridLayout(groupBox_3);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        emphCB = new QCheckBox(groupBox_3);
        emphCB->setObjectName(QStringLiteral("emphCB"));

        gridLayout_5->addWidget(emphCB, 0, 0, 1, 1);

        nounCB = new QCheckBox(groupBox_3);
        nounCB->setObjectName(QStringLiteral("nounCB"));

        gridLayout_5->addWidget(nounCB, 1, 0, 1, 1);


        gridLayout_7->addWidget(groupBox_3, 1, 1, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        buttonBox = new QDialogButtonBox(CharacterUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset|QDialogButtonBox::RestoreDefaults);

        hboxLayout->addWidget(buttonBox);


        gridLayout_7->addLayout(hboxLayout, 3, 0, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(spacerItem);

        autoapplyCB = new QCheckBox(CharacterUi);
        autoapplyCB->setObjectName(QStringLiteral("autoapplyCB"));

        horizontalLayout_3->addWidget(autoapplyCB);


        gridLayout_7->addLayout(horizontalLayout_3, 2, 0, 1, 2);

#ifndef QT_NO_SHORTCUT
        familyLA->setBuddy(familyCO);
        seriesLA->setBuddy(seriesCO);
        shapeLA->setBuddy(shapeCO);
        sizeLA->setBuddy(sizeCO);
        colorLA->setBuddy(colorCO);
        ulineLA->setBuddy(ulineCO);
        strikeLA->setBuddy(strikeCO);
        LanguageLA->setBuddy(langCO);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(familyCO, seriesCO);
        QWidget::setTabOrder(seriesCO, shapeCO);
        QWidget::setTabOrder(shapeCO, colorCO);
        QWidget::setTabOrder(colorCO, langCO);

        retranslateUi(CharacterUi);

        QMetaObject::connectSlotsByName(CharacterUi);
    } // setupUi

    void retranslateUi(QDialog *CharacterUi)
    {
        CharacterUi->setWindowTitle(QString());
        groupBox->setTitle(lyx::qt_("Font Properties", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        familyLA->setToolTip(lyx::qt_("Font family", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        familyLA->setText(lyx::qt_("Fa&mily:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        familyCO->setToolTip(lyx::qt_("Font family", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        seriesLA->setToolTip(lyx::qt_("Font series", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        seriesLA->setText(lyx::qt_("&Series:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        seriesCO->setToolTip(lyx::qt_("Font series", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        shapeLA->setToolTip(lyx::qt_("Font shape", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        shapeLA->setText(lyx::qt_("S&hape:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        shapeCO->setToolTip(lyx::qt_("Font shape", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        sizeLA->setToolTip(lyx::qt_("Font size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        sizeLA->setText(lyx::qt_("Si&ze:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        sizeCO->setToolTip(lyx::qt_("Font size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_2->setTitle(lyx::qt_("Decoration", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorLA->setToolTip(lyx::qt_("Font color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        colorLA->setText(lyx::qt_("&Color:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        colorCO->setToolTip(lyx::qt_("Font color", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        ulineLA->setText(lyx::qt_("U&nderlining:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        ulineCO->setToolTip(lyx::qt_("Underlining of text", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        strikeLA->setText(lyx::qt_("S&trikethrough:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        strikeCO->setToolTip(lyx::qt_("Strike-through text", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        groupBox_4->setTitle(lyx::qt_("Language Settings", Q_NULLPTR));
        LanguageLA->setText(lyx::qt_("&Language:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        langCO->setToolTip(lyx::qt_("Language", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        nospellcheckCB->setToolTip(lyx::qt_("If this is selected, the marked text will not be spellchecked", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nospellcheckCB->setText(lyx::qt_("E&xclude from Spellchecking", Q_NULLPTR));
        groupBox_3->setTitle(lyx::qt_("Semantic Markup", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        emphCB->setToolTip(lyx::qt_("Semantic emphasizing (italic by default, but can be adapted)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        emphCB->setText(lyx::qt_("&Emphasized", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nounCB->setToolTip(lyx::qt_("Semantic markup of nouns (small caps by default, but can be adapted)", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        nounCB->setText(lyx::qt_("&Noun", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        autoapplyCB->setToolTip(lyx::qt_("Apply each change automatically", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        autoapplyCB->setText(lyx::qt_("Apply changes &immediately", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class CharacterUi: public Ui_CharacterUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHARACTERUI_H
