/********************************************************************************
** Form generated from reading UI file 'ShortcutUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHORTCUTUI_H
#define UI_SHORTCUTUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include "CustomizedWidgets.h"
#include "qt_i18n.h"

QT_BEGIN_NAMESPACE

class Ui_shortcutUi
{
public:
    QGridLayout *gridLayout;
    QLabel *lfunLBL;
    QLineEdit *lfunLE;
    QLabel *shortcutLBL;
    lyx::frontend::ShortcutWidget *shortcutWG;
    QPushButton *removePB;
    QPushButton *clearPB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *shortcutUi)
    {
        if (shortcutUi->objectName().isEmpty())
            shortcutUi->setObjectName(QStringLiteral("shortcutUi"));
        shortcutUi->resize(421, 137);
        shortcutUi->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(shortcutUi);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        lfunLBL = new QLabel(shortcutUi);
        lfunLBL->setObjectName(QStringLiteral("lfunLBL"));

        gridLayout->addWidget(lfunLBL, 0, 0, 1, 1);

        lfunLE = new QLineEdit(shortcutUi);
        lfunLE->setObjectName(QStringLiteral("lfunLE"));

        gridLayout->addWidget(lfunLE, 0, 1, 1, 3);

        shortcutLBL = new QLabel(shortcutUi);
        shortcutLBL->setObjectName(QStringLiteral("shortcutLBL"));

        gridLayout->addWidget(shortcutLBL, 1, 0, 1, 1);

        shortcutWG = new lyx::frontend::ShortcutWidget(shortcutUi);
        shortcutWG->setObjectName(QStringLiteral("shortcutWG"));
        shortcutWG->setEnabled(true);

        gridLayout->addWidget(shortcutWG, 1, 1, 1, 1);

        removePB = new QPushButton(shortcutUi);
        removePB->setObjectName(QStringLiteral("removePB"));

        gridLayout->addWidget(removePB, 1, 2, 1, 1);

        clearPB = new QPushButton(shortcutUi);
        clearPB->setObjectName(QStringLiteral("clearPB"));

        gridLayout->addWidget(clearPB, 1, 3, 1, 1);

        buttonBox = new QDialogButtonBox(shortcutUi);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 2, 1, 2);

#ifndef QT_NO_SHORTCUT
        lfunLBL->setBuddy(lfunLE);
        shortcutLBL->setBuddy(shortcutWG);
#endif // QT_NO_SHORTCUT

        retranslateUi(shortcutUi);

        QMetaObject::connectSlotsByName(shortcutUi);
    } // setupUi

    void retranslateUi(QDialog *shortcutUi)
    {
        shortcutUi->setWindowTitle(lyx::qt_("Edit shortcut", Q_NULLPTR));
        lfunLBL->setText(lyx::qt_("Fu&nction:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        lfunLE->setToolTip(lyx::qt_("Enter LyX function or command sequence", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        lfunLE->setText(QString());
        shortcutLBL->setText(lyx::qt_("Short&cut:", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        shortcutWG->setToolTip(lyx::qt_("Type shortcut after clicking on this field. You can reset the content with the 'Clear' button", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        shortcutWG->setText(QString());
#ifndef QT_NO_TOOLTIP
        removePB->setToolTip(lyx::qt_("Remove last key from the shortcut sequence", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        removePB->setText(lyx::qt_("&Delete Key", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        clearPB->setToolTip(lyx::qt_("Clear current shortcut", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        clearPB->setText(lyx::qt_("C&lear", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class shortcutUi: public Ui_shortcutUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHORTCUTUI_H
